/*!
 * gulp
 * $ npm install gulp-ruby-sass gulp-autoprefixer gulp-minify-css gulp-jshint gulp-concat gulp-uglify gulp-imagemin gulp-notify gulp-rename gulp-livereload gulp-cache del --save-dev
 * $ apt-get install libnotify-binnpm gem
 * $ gem install sass
 */

// Load plugins
var gulp = require('gulp'),
    less = require('gulp-less'),
    autoprefixer = require('gulp-autoprefixer'),
    minifycss = require('gulp-minify-css'),
    uglify = require('gulp-uglify'),
    //imagemin = require('gulp-imagemin'),
    rename = require('gulp-rename'),
    notify = require('gulp-notify'),
    cache = require('gulp-cache'),
    browserify = require('browserify'),
    source = require('vinyl-source-stream'),
    buffer = require('vinyl-buffer'),
    concat = require('gulp-concat'),
    gzip = require('gulp-gzip'),
    webp = require('gulp-webp'),
    imageminWebp = require('imagemin-webp'),
    _ = require('underscore'),
    inline_urls_plugin = require('less-plugin-inline-urls');
    //del = require('del');

// Styles

function handleError(err) {
  notify({ message: err.toString() })
  this.emit('end');
}




gulp.task('styles_site', function() {
  //return less('public/styles/site.less', {style: 'expanded'})
  //  //.pipe(autoprefixer('last 2 version', 'safari 5', 'ie 8', 'ie 9', 'opera 12.1', 'ios 6', 'android 4'))
  //  .pipe(gulp.dest('public/styles/'))
  //  //.pipe(rename({ suffix: '.min' }))
  //  //.pipe(minifycss())
  //  //.pipe(gulp.dest('build/assets/css'))
  //  .pipe(notify({ message: 'Styles task complete' }));

  return gulp.src('./public/styles/site.less')
    .pipe(less({
        ieCompat:false,
       plugins:[inline_urls_plugin],
    }))
    //.pipe(minifycss())
    //.pipe(rename({ suffix: '.min' }))
    .pipe(gulp.dest('./public/styles'))
    .pipe(notify({ message: 'Styles task complete' }));
});

gulp.task('styles_site_minified', function() {
  return gulp.src('./public/styles/site.less')
    .pipe(less({
        ieCompat:false,
       plugins:[inline_urls_plugin],
    }))
    .pipe(minifycss())
    .pipe(rename({ suffix: '.min' }))
    .pipe(gulp.dest('./public/styles'))
    .pipe(notify({ message: 'Styles minified task complete' }));
});
gulp.task('styles_site_compress', function() {
    gulp.src([
        './public/styles/site.css',
        './public/styles/site.min.css',
      ])
    .pipe(gzip({ gzipOptions: { level: 9 } }))
    .pipe(gulp.dest('./public/styles'))
    .pipe(notify({ message: 'Compress task complete' }));
});





gulp.task('styles_permalink', function() {
  //return less('public/styles/permalink.less', {style: 'expanded'})
  //  //.pipe(autoprefixer('last 2 version', 'safari 5', 'ie 8', 'ie 9', 'opera 12.1', 'ios 6', 'android 4'))
  //  .pipe(gulp.dest('public/styles/'))
  //  //.pipe(rename({ suffix: '.min' }))
  //  //.pipe(minifycss())
  //  //.pipe(gulp.dest('build/assets/css'))
  //  .pipe(notify({ message: 'Styles task complete' }));

  return gulp.src('./public/styles/permalink.less')
    .pipe(less({
        ieCompat:false,
       plugins:[inline_urls_plugin],
    }))
    //.pipe(minifycss())
    //.pipe(rename({ suffix: '.min' }))
    .pipe(gulp.dest('./public/styles'))
    .pipe(notify({ message: 'Styles task complete' }));
});

gulp.task('styles_permalink_minified', function() {
  return gulp.src('./public/styles/permalink.less')
    .pipe(less({
        ieCompat:false,
       plugins:[inline_urls_plugin],
    }))
    .pipe(minifycss())
    .pipe(rename({ suffix: '.min' }))
    .pipe(gulp.dest('./public/styles'))
    .pipe(notify({ message: 'Styles minified task complete' }));
});
gulp.task('styles_permalink_compress', function() {
    gulp.src([
        './public/styles/permalink.css',
        './public/styles/permalink.min.css',
      ])
    .pipe(gzip({ gzipOptions: { level: 9 } }))
    .pipe(gulp.dest('./public/styles'))
    .pipe(notify({ message: 'Compress task complete' }));
});












gulp.task('styles_moderation', function() {
  //return less('public/styles/moderation.less', {style: 'expanded'})
  //  //.pipe(autoprefixer('last 2 version', 'safari 5', 'ie 8', 'ie 9', 'opera 12.1', 'ios 6', 'android 4'))
  //  .pipe(gulp.dest('public/styles/'))
  //  //.pipe(rename({ suffix: '.min' }))
  //  //.pipe(minifycss())
  //  //.pipe(gulp.dest('build/assets/css'))
  //  .pipe(notify({ message: 'Styles task complete' }));

  return gulp.src('./public/styles/moderation.less')
    .pipe(less({
        ieCompat:false,
       plugins:[inline_urls_plugin],
    }))
    //.pipe(minifycss())
    //.pipe(rename({ suffix: '.min' }))
    .pipe(gulp.dest('./public/styles'))
    .pipe(notify({ message: 'Styles task complete' }));
});

gulp.task('styles_moderation_minified', function() {
  return gulp.src('./public/styles/moderation.less')
    .pipe(less({
        ieCompat:false,
       plugins:[inline_urls_plugin],
    }))
    .pipe(minifycss())
    .pipe(rename({ suffix: '.min' }))
    .pipe(gulp.dest('./public/styles'))
    .pipe(notify({ message: 'Styles minified task complete' }));
});
gulp.task('styles_moderation_compress', function() {
    gulp.src([
        './public/styles/moderation.css',
        './public/styles/moderation.min.css',
      ])
    .pipe(gzip({ gzipOptions: { level: 9 } }))
    .pipe(gulp.dest('./public/styles'))
    .pipe(notify({ message: 'Compress task complete' }));
});







gulp.task('scripts_site', function() {
  return gulp.src([
        './public/js/lib/jquery/jquery-2.1.4.js',
        //'./public/js/lib/jquery/jquery-1.11.1.js',
        //'./public/js/lib/jquery/jgestures.js',
        //'./public/js/lib/jquery/jquery.cloudinary.js',
        './public/js/lib/slick.min.js',
        './public/js/site.js',
        './public/js/videoPlayer.js'
      ])
      .pipe(concat('site.bundle.js'))
      .pipe(gulp.dest('public/js'));
});
gulp.task('scripts_site_minified', function() {
  return gulp.src('./public/js/site.bundle.js')
    .pipe(uglify())
    .pipe(rename({ suffix: '.min' }))
    .pipe(gulp.dest('public/js'))
    .pipe(notify({ message: 'Scripts minified task complete' }));
});
gulp.task('scripts_site_compress', function() {
    gulp.src([
        './public/js/site.bundle.js',
        './public/js/site.bundle.min.js',
      ])
    .pipe(gzip({ gzipOptions: { level: 9 } }))
    .pipe(gulp.dest('./public/js/'))
    .pipe(notify({ message: 'Compress task complete' }));
});





gulp.task('scripts_permalink', function() {
  return gulp.src([
        './public/js/lib/jquery/jquery-2.1.4.js',
        //'./public/js/lib/jquery/jquery-1.11.1.js',
        //'./public/js/lib/jquery/jgestures.js',
        //'./public/js/lib/jquery/jquery.cloudinary.js',
        './public/js/permalink.js'
      ])
      .pipe(concat('permalink.bundle.js'))
      .pipe(gulp.dest('public/js'));
});
gulp.task('scripts_permalink_minified', function() {
  return gulp.src('./public/js/permalink.bundle.js')
    .pipe(uglify())
    .pipe(rename({ suffix: '.min' }))
    .pipe(gulp.dest('public/js'))
    .pipe(notify({ message: 'Scripts minified task complete' }));
});
gulp.task('scripts_permalink_compress', function() {
    gulp.src([
        './public/js/permalink.bundle.js',
        './public/js/permalink.bundle.min.js',
      ])
    .pipe(gzip({ gzipOptions: { level: 9 } }))
    .pipe(gulp.dest('./public/js/'))
    .pipe(notify({ message: 'Compress task complete' }));
});






var sprites_webp_1x = _.debounce(function(){
      gulp.src('./public/images/sprite/to-sprite.png')
        .pipe(imageminWebp({ /*lossless:true,*/ quality: 70,  method: 6 })())
        .on('error', handleError)
        .pipe(gulp.dest('./public/images/sprite/'))
        .pipe(notify({ message: 'Webp sprite@1x images complete' }));
    }, 1000);

var sprites_webp_2x = _.debounce(function(){
      gulp.src('./public/images/sprite/to-sprite@2x.png')
          .pipe(imageminWebp({ /*lossless:true,*/ quality: 70,  method: 6  })())
          .on('error', handleError)
          .pipe(gulp.dest('./public/images/sprite/'))
          .pipe(notify({ message: 'Webp sprite@2x images complete' }));
    }, 1000);

gulp.task('sprites_webp_1x', function() {
    sprites_webp_1x();
});

gulp.task('sprites_webp_2x', function() {
    sprites_webp_2x();
});

// Watch
gulp.task('watch', function() {

  // Watch .scss files
  gulp.watch('./public/styles/site.less', ['styles_site','styles_site_minified']);
  gulp.watch('./public/styles/site/*.less', ['styles_site','styles_site_minified']);
  gulp.watch('./public/styles/site/**/*.less', ['styles_site','styles_site_minified']);
  gulp.watch('./public/styles/bootstrap-site/*.less', ['styles_site','styles_site_minified']);
  gulp.watch('./public/styles/bootstrap-site/**/*.less', ['styles_site','styles_site_minified']);
  gulp.watch('./public/images/sprite/*.less', ['styles_site','styles_site_minified']);
  gulp.watch('./public/styles/site.min.css', ['styles_site_compress']);

  gulp.watch('./public/styles/permalink.less', ['styles_permalink','styles_permalink_minified']);
  gulp.watch('./public/styles/permalink/*.less', ['styles_permalink','styles_permalink_minified']);
  gulp.watch('./public/styles/permalink/**/*.less', ['styles_permalink','styles_permalink_minified']);
  //gulp.watch('./public/styles/bootstrap-permalink/*.less', ['styles_permalink','styles_permalink_minified']);
  //gulp.watch('./public/styles/bootstrap-permalink/**/*.less', ['styles_permalink','styles_permalink_minified']);
  gulp.watch('./public/images/sprite/*.less', ['styles_permalink','styles_permalink_minified']);
  gulp.watch('./public/styles/permalink.min.css', ['styles_permalink_compress']);

  gulp.watch('./public/styles/moderation.less', ['styles_moderation','styles_moderation_minified']);
  gulp.watch('./public/styles/moderation/*.less', ['styles_moderation','styles_moderation_minified']);
  gulp.watch('./public/styles/moderation/**/*.less', ['styles_moderation','styles_moderation_minified']);
  gulp.watch('./public/styles/bootstrap-moderation/*.less', ['styles_moderation','styles_moderation_minified']);
  gulp.watch('./public/styles/bootstrap-moderation/**/*.less', ['styles_moderation','styles_moderation_minified']);
  //gulp.watch('./public/images/sprite/*.less', ['styles_moderation','styles_moderation_minified']);
  gulp.watch('./public/styles/moderation.min.css', ['styles_moderation_compress']);

  gulp.watch('./public/images/sprite/to-sprite.png', ['sprites_webp_1x']);
  gulp.watch('./public/images/sprite/to-sprite@2x.png', ['sprites_webp_2x']);

  // Watch .js files
  gulp.watch('./public/js/site.js', ['scripts_site']);
  gulp.watch('./public/js/videoPlayer.js', ['scripts_site']);
  gulp.watch('./public/js/lib/*.js', ['scripts_site']);
  gulp.watch('./public/js/lib/**/*.js', ['scripts_site']);
  gulp.watch('./public/js/site.bundle.js', ['scripts_site_minified']);
  gulp.watch('./public/js/site.bundle.min.js', ['scripts_site_compress']);


  gulp.watch('./public/js/permalink.js', ['scripts_permalink']);
  gulp.watch('./public/js/lib/*.js', ['scripts_permalink']);
  gulp.watch('./public/js/lib/**/*.js', ['scripts_permalink']);
  gulp.watch('./public/js/permalink.bundle.js', ['scripts_permalink_minified']);
  gulp.watch('./public/js/permalink.bundle.min.js', ['scripts_permalink_compress']);

  //gulp.watch('./public/styles/site.css', ['styles_site_compress']);

  //gulp.watch('./public/js/site.bundle.js', ['scripts_site_compress']);


});
