var keystone = require('keystone'),
	Types = keystone.Field.Types,
	_ = require('underscore'),
	async = require('async'),
	cloudinary = require('cloudinary'),
	shortid = require('shortid');

var tp = keystone.get('cloudinary prefix') || '';

var Model = new keystone.List('Card', {
	map: { name: 'summary' },
	autokey: { path: 'slug', from: 'shortid', unique: true },
	//sortable: true,
	//defaultSort: '-sortOrder',
	defaultSort: '-displayDate',
	track: true,
});

Model.add(
{
	summary: { 
		type: String, 
		required: false 
	},
},
{ 
	heading: 'Card Config',
},
{ 
	//modelType: { 
	//	type: String, 
	//	default: modelType,
	//	noedit:true,
	//	hidden:true,
	//
	//},

	

	displayDate: { 
		type: Types.Datetime, default: Date.now },

	forceDisplayInPosition: { 
		label: 'Force position (1,2,3...)',
		type: Number, 
	},

	state: { 
		type: Types.Select, 
		options: 'draft, pending, published, rejected, archived', 
		default: 'draft', 
		index: true 
	},
	
	


	//publishedDate: { type: Types.Date, index: true, dependsOn: { state: 'published' } },
	display: { 
		type: Types.Select, 
		options: ['Custom Card', 'Twitter Text', 'Twitter Image', 'Instagram Image', 'Instagram Video'],
		default: 'Custom Card',
		//noedit: true,

	},

	shortid: {
		type: String,
		default: shortid.generate,
		unique: true,
		index: true,
		noedit: true,
	},

	
	

	//secondsPerImage: { 
	//	type: Number, 
	//	required:false, 
	//	default: 5, 
	//	dependsOn: { display: ['Images'] } 
	//},

	//darken: { 
	//	type: Types.Boolean, 
	//	label: 'Darken Images/Video (send assets in correct darkness and keep this unchecked for better performance)',
	//	required:false, 
	//	default: false, 
	//	dependsOn: { display: ['Images','Video'] } 
	//},
	//displaySeekBar: { 
	//	type: Types.Boolean, 
	//	required:false, 
	//	default:false, 
	//	dependsOn: { display: ['Video'], modelType: ['Default',false,null,undefined]  } 
	//},
	//videoAutoplay: { 
	//	type: Types.Boolean, 
	//	required:false, 
	//	default:true, 
	//	dependsOn: { display: ['Video'], modelType: ['Default',false,null,undefined]  } 
	//},
	//videoMuted: { 
	//	type: Types.Boolean, 
	//	required:false, 
	//	default:true, 
	//	dependsOn: { display: ['Video'] } 
	//},
	//videoLoop: { 
	//	type: Types.Boolean, 
	//	required:false, 
	//	default:true, 
	//	dependsOn: { display: ['Video'] } 
	//},
	//videoCanPlayAtMobile: { 
	//	type: Types.Boolean, 
	//	required:false, 
	//	default:false, 
	//	dependsOn: { display: ['Video'], modelType: ['Default',false,null,undefined]  } 
	//},
	//videoHasPlayButtonAtMobile: { 
	//	type: Types.Boolean, 
	//	required:false, 
	//	default:true, 
	//	dependsOn: { display: ['Video'], videoCanPlayAtMobile: true, modelType: ['Default',false,null,undefined]  } 
	//},
	//videoHasPlayAndPauseButtonsAtDesktop: { 
	//	type: Types.Boolean, 
	//	required:false, 
	//	default:false, 
	//	dependsOn: { display: ['Video'], modelType: ['Default',false,null,undefined]  } 
	//},
	//videoPlayAndPauseButtonsForDesktopAutohide: { 
	//	type: Types.Boolean, 
	//	required:false, 
	//	default:true, 
	//	dependsOn: { display: ['Video'], videoHasPlayAndPauseButtonsAtDesktop: true, modelType: ['Default',false,null,undefined]  } 
	//},

	
},
{ 
	heading: 'Custom Card Content',
	dependsOn: {  display: ['Custom Card']  },
},
{
	//buttonTitle: { 
	//	type: String, 
	//	required: false,
	//	dependsOn: {  modelType: ['Default',false,null,undefined]  },
	//},
	cardTitle: { 
		type: Types.Textarea, 
		required: false,
		dependsOn: {  display: ['Custom Card']  },
	},
	cardText: { 
		type: Types.Textarea, 
		required: false,
		dependsOn: {  display: ['Custom Card']  },
	},
	
	cardImage: { 
		type: Types.CloudinaryImage, 
		required: false, 
		dependsOn: {  display: ['Custom Card']  },
	},

	cardSymbol: { 
		type: Types.Boolean, 
		label: 'Show Icecream Badge',
		default: true, 
		dependsOn: {  display: ['Custom Card']  },
	},


//	twitterUser: { 
//		type: Types.Text, 
//		required: false,
//		dependsOn: { display: ['Twitter Text', 'Twitter Image'] },
//	},
//	twitterText: { 
//		type: Types.Textarea, 
//		required: false,
//		dependsOn: { display: ['Twitter Text', 'Twitter Image'] },
//	},
//	twitterProfilePicture: { 
//		type: Types.CloudinaryImages, 
//		required: false, 
//		dependsOn: { display: ['Twitter Text', 'Twitter Image'] },
//	},
//	twitterImage: { 
//		type: Types.CloudinaryImages, 
//		required: false, 
//		dependsOn: {  display: ['Twitter Image',]  },
//	},
//
//
//	instagramUser: { 
//		type: Types.Text, 
//		required: false,
//		dependsOn: { display: ['Instagram Image', 'Instagram Video'] },
//	},
//	instagramText: { 
//		type: Types.Text, 
//		required: false,
//		dependsOn: { display: ['Instagram Image', 'Instagram Video'] },
//	},
//	instagramProfilePicture: { 
//		type: Types.CloudinaryImages, 
//		required: false, 
//		dependsOn: { display: ['Instagram Image', 'Instagram Video'] },
//	},
//	instagramImage: { 
//		type: Types.CloudinaryImages, 
//		required: false, 
//		dependsOn: {  display: ['Instagram Image', 'Instagram Video'] },
//	},
	
	/*videoForDesktop: { 
		type: Types.S3File,
		s3path: '/cards/videos',
		filename: function(item, filename){
			// prefix file name with object id
			return item.slug + '-desktop-' + filename;
		},
		dependsOn: { display: ['Video'] },
	},
	videoForMobile: { 
		type: Types.S3File,
		s3path: '/cards/videos',
		filename: function(item, filename){
			// prefix file name with object id
			return item.slug + '-mobile-' + filename;
		},
		dependsOn: { display: ['Video'] },
	},*/

	//video720p: {
	//	label: 'Video File',
	//	type: Types.LocalFile,
	//	dest: __base+'public/data/videos',
	//	filename: function(item, file){
	//		return tp+'-'+item.slug + '-' + item._id + '-' + file.name;//+'.' + file.extension
	//	},
	//	dependsOn: { display: ['Video'] },
	//},
	//video480p: {
	//	type: Types.LocalFile,
	//	dest: __base+'public/data/videos',
	//	filename: function(item, file){
	//		return item.slug + '-480p-' + file.name;//+'.' + file.extension
	//	},
	//	dependsOn: { display: ['Video'] },
	//	hidden:true,
	//},
	//imageFirstFrame: { 
	//	label: 'Override Image of First Frame',
	//	type: Types.CloudinaryImage, 
	//	required: false, 
	//	dependsOn: { display: ['Video'], modelType: ['Default',false,null,undefined]  },
	//},
	//imageForMobile: { 
	//	label: 'Alternate Image for Mobile',
	//	type: Types.CloudinaryImage, 
	//	required: false, 
	//	dependsOn: { display: ['Video'] },
	//},



	unique_media_id: { dependsOn: { display: ['Twitter Image', 'Twitter Text', 'Instagram Image', 'Instagram Video'] }, label: 'Unique Media id',                          noedit:true, type: String, required:true, initial:true, index: {unique:true }, default: Date.now },
},

{ 
	heading: 'Instagram Info',
	dependsOn: { display: ['Instagram Image', 'Instagram Video'] },
},
{
	instagram_media_id: 							{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Media id',                          noedit:true, type: String, required:false },
	instagram_createdDate: 							{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Created Date',                      noedit:true, type: Types.Datetime, required:false },
	instagram_media_type: 							{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Media Type',                        noedit:true, type: String, required: false },
	instagram_timestamp: 							{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Timestamp',                         noedit:true, type: Number, required: false },
	instagram_user_id: 								{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram User Id',                           boedit:true, type: String, required: false },
	instagram_user_name: 							{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram User Name',                         noedit:true, type: String, required: false },
	instagram_user_full_name: 						{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram User Full Name',                    noedit:true, type: String, required: false },
	instagram_user_profile_picture: 				{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram User Profile Picture',              noedit:true, type: String, required: false },
	instagram_caption_id: 							{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Caption Id',                        noedit:true, type: String, required: false },
	instagram_caption_created_time: 				{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Caption Created Time',              noedit:true, type: Number, required: false },
	instagram_caption_text: 						{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Caption Text',                      noedit:true, type: String, required: false },
	instagram_filter: 								{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Filter',                            noedit:true, type: String, required: false },
	instagram_link: 								{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Link',                              noedit:true, type: String, required: false },
	instagram_longitude: 							{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Longitude',                         noedit:true, type: Number, required: false },
	instagram_latitude: 							{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Latitude',                          noedit:true, type: Number, required: false },        
	instagram_image_low_resolution_url: 			{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Image low resolution url',          noedit:true, type: String }, 
	instagram_image_low_resolution_width: 			{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Image low resolution width',        noedit:true, type: Number }, 
	instagram_image_low_resolution_height: 			{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Image low resolution height',       noedit:true, type: Number }, 
	instagram_image_thumbnail_url: 					{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Image thumbnail url',               noedit:true, type: String }, 
	instagram_image_thumbnail_width: 				{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Image thumbnail width',             noedit:true, type: Number }, 
	instagram_image_thumbnail_height: 				{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Image thumbnail height',            noedit:true, type: Number }, 
	instagram_image_standard_resolution_url: 		{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Image standard resolution url',     noedit:true, type: String }, 
	instagram_image_standard_resolution_width: 		{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Image standard resolution width',   noedit:true, type: Number }, 
	instagram_image_standard_resolution_height: 	{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Image standard resolution height',  noedit:true, type: Number }, 
	instagram_video_low_resolution_url: 			{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Video low resolution url',          noedit:true, type: String }, 
	instagram_video_low_resolution_width: 			{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Video low resolution width',        noedit:true, type: Number }, 
	instagram_video_low_resolution_height: 			{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Video low resolution height',       noedit:true, type: Number }, 
	instagram_video_thumbnail_url: 					{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Video thumbnail url',               noedit:true, type: String }, 
	instagram_video_thumbnail_width: 				{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Video thumbnail width',             noedit:true, type: Number }, 
	instagram_video_thumbnail_height: 				{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Video thumbnail height',            noedit:true, type: Number }, 
	instagram_video_standard_resolution_url: 		{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Video standard resolution url',     noedit:true, type: String }, 
	instagram_video_standard_resolution_width: 		{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Video standard resolution width',   noedit:true, type: Number }, 
	instagram_video_standard_resolution_height: 	{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Video standard resolution height',  noedit:true, type: Number }, 
	instagram_json_data: 							{ dependsOn: { display: ['Instagram Image', 'Instagram Video'] }, label: 'Instagram Json data',                         noedit:true, type: Types.Textarea , required: false },

},

{ 
	heading: 'Twitter Info',
	dependsOn: { display: ['Twitter Image', 'Twitter Text'] },
},
{

  //twitter_id:                         { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Number, required:false },
  twitter_id_str:                     { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_created_at:                 { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Datetime, required:false },
  twitter_text:                       { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_source:                     { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_truncated:                  { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  twitter_in_reply_to_status_id:      { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_in_reply_to_status_id_str:  { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_in_reply_to_user_id:        { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_in_reply_to_user_id_str:    { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_in_reply_to_screen_name:    { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_id:                    { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Number, required:false },
  twitter_user_id_str:                { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_name:                  { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_screen_name:           { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_location:              { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_url:                   { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_description:           { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_protected:             { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  twitter_user_verified:              { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  twitter_user_followers_count:       { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Number, required:false },
  twitter_user_friends_count:         { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Number, required:false },
  twitter_user_listed_count:          { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Number, required:false },
  twitter_user_favourites_count:      { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Number, required:false },
  twitter_user_statuses_count:        { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Number, required:false },
  twitter_user_created_at:            { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Datetime, required:false },
  //twitter_user_utc_offset: null,
  //twitter_user_time_zone: null,
  //twitter_user_geo_enabled:         { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  twitter_user_lang:                  { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_contributors_enabled:                { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  twitter_user_is_translator:                       { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  twitter_user_profile_background_color:            { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_profile_background_image_url:        { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_profile_background_image_url_https:  { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_profile_background_tile:             { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  twitter_user_profile_link_color:                  { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_profile_sidebar_border_color:        { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_profile_sidebar_fill_color:          { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_profile_text_color:                  { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_profile_use_background_image:        { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  twitter_user_profile_image_url:                   { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_profile_image_url_https:             { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_profile_banner_url:                  { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_user_default_profile:                     { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  twitter_user_default_profile_image:               { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  //twitter_user_following: null,
  //twitter_user_follow_request_sent: null,
  //twitter_user_notifications: null,
  //twitter_geo: null,
  //twitter_coordinates: null,
  //twitter_place: null,
  //twitter_contributors: null,
  //twitter_retweeted_status_created_at: 'Mon Sep 07 18:51:42 +0000 2015',
  //twitter_retweeted_status_id: 640960653507862500,
  //twitter_retweeted_status_id_str: '640960653507862528',
  //twitter_retweeted_status_text: 'Nuevo #empleo en Nestle en #CiudaddeMéxico - #Becario #Compras Empaques #empleos http://t.co/ruyxBrR6tn http://t.co/EjdYgMBULn',
  //twitter_retweeted_status_source: '<a href="http://neuvoo.ca" rel="nofollow">seed.mytweetsys.app.t00</a>',
  //twitter_retweeted_status_truncated: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  //twitter_retweeted_status_in_reply_to_status_id: null,
  //twitter_retweeted_status_in_reply_to_status_id_str: null,
  //twitter_retweeted_status_in_reply_to_user_id: null,
  //twitter_retweeted_status_in_reply_to_user_id_str: null,
  //twitter_retweeted_status_in_reply_to_screen_name: null,
  //twitter_retweeted_status_user_id: 3301823864,
  //twitter_retweeted_status_user_id_str: '3301823864',
  //twitter_retweeted_status_user_name: 'Jobs Distribución M',
  //twitter_retweeted_status_user_screen_name: 'NeuvooDisMexic',
  //twitter_retweeted_status_user_location: 'Mexico City, Distrito Federal',
  //twitter_retweeted_status_user_url: 'http://neuvoo.com.mx/trabajos/?k=Venta+al+detalle&l=Mexico+City%2C+Distrito+Federal&r=15',
  //twitter_retweeted_status_user_description: '¿Buscas trabajos de Venta al detalle en Mexico City? Chequea nuestra página web http://t.co/EqwxnWFiAr',
  //twitter_retweeted_status_user_protected: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  //twitter_retweeted_status_user_verified: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  //twitter_retweeted_status_user_followers_count: 312,
  //twitter_retweeted_status_user_friends_count: 965,
  //twitter_retweeted_status_user_listed_count: 10,
  //twitter_retweeted_status_user_favourites_count: 0,
  //twitter_retweeted_status_user_statuses_count: 3472,
  //twitter_retweeted_status_user_created_at: 'Thu Jul 30 19:21:19 +0000 2015',
  //twitter_retweeted_status_user_utc_offset: null,
  //twitter_retweeted_status_user_time_zone: null,
  //twitter_retweeted_status_user_geo_enabled: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  //twitter_retweeted_status_user_lang: 'en',
  //twitter_retweeted_status_user_contributors_enabled: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  //twitter_retweeted_status_user_is_translator: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  //twitter_retweeted_status_user_profile_background_color: 'C0DEED',
  //twitter_retweeted_status_user_profile_background_image_url: 'http://abs.twimg.com/images/themes/theme1/bg.png',
  //twitter_retweeted_status_user_profile_background_image_url_https: 'https://abs.twimg.com/images/themes/theme1/bg.png',
  //twitter_retweeted_status_user_profile_background_tile: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  //twitter_retweeted_status_user_profile_link_color: '0084B4',
  //twitter_retweeted_status_user_profile_sidebar_border_color: 'C0DEED',
  //twitter_retweeted_status_user_profile_sidebar_fill_color: 'DDEEF6',
  //twitter_retweeted_status_user_profile_text_color: '333333',
  //twitter_retweeted_status_user_profile_use_background_image: true,
  //twitter_retweeted_status_user_profile_image_url: 'http://pbs.twimg.com/profile_images/626835302292811776/aM3ol2ae_normal.png',
  //twitter_retweeted_status_user_profile_image_url_https: 'https://pbs.twimg.com/profile_images/626835302292811776/aM3ol2ae_normal.png',
  //twitter_retweeted_status_user_profile_banner_url: 'https://pbs.twimg.com/profile_banners/3301823864/1438284157',
  //twitter_retweeted_status_user_default_profile: true,
  //twitter_retweeted_status_user_default_profile_image: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  //twitter_retweeted_status_user_following: null,
  //twitter_retweeted_status_user_follow_request_sent: null,
  //twitter_retweeted_status_user_notifications: null,
  //twitter_retweeted_status_geo: null,
  //twitter_retweeted_status_coordinates: null,
  //twitter_retweeted_status_place: null,
  //twitter_retweeted_status_contributors: null,
  //twitter_retweeted_status_retweet_count: 1,
  //twitter_retweeted_status_favorite_count: 0,
  //twitter_retweeted_status_entities_hashtags: [Object],
  //twitter_retweeted_status_entities_trends: [],
  //twitter_retweeted_status_entities_urls: [Object],
  //twitter_retweeted_status_entities_user_mentions: [],
  //twitter_retweeted_status_entities_symbols: [],
  //twitter_retweeted_status_entities_media: [Object] },
  //twitter_retweeted_status_extended_entities: { media: [Object] },
  //twitter_retweeted_status_favorited: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  //twitter_retweeted_status_retweeted: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  //twitter_retweeted_status_possibly_sensitive: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  //twitter_retweeted_status_filter_level: 'low',
  //twitter_retweeted_status_lang: 'es' },
  twitter_retweet_count: 				{ dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Number, required:false },
  twitter_favorite_count: 				{ dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Number, required:false },
  twitter_entities_hashtags: 			{ dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  //twitter_entities_trends: 				{ dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_entities_urls: 				{ dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_entities_user_mentions: 		{ dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  //twitter_entities_symbols: 			{ dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_entities_media: 				{ dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  //twitter_extended_entities: 			{ media: [ [Object] ]
  twitter_favorited: 					{ dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  twitter_retweeted: 					{ dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  twitter_possibly_sensitive: 			{ dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Boolean, required:false },
  twitter_filter_level: 				{ dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_lang: 						{ dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_timestamp_ms: 				{ dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },



  twitter_picture_id: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Number, required:false },
  twitter_picture_id_str: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_picture_media_url: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_picture_media_url_https: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_picture_url: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_picture_display_url: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_picture_expanded_url: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },
  twitter_picture_type: { dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: String, required:false },

  twitter_json_data: 					{ dependsOn: { display: ['Twitter Image', 'Twitter Text'] }, noedit:true, type: Types.Textarea , required: false },





},

{ 
	heading: 'More info',
},
{
	origin: { 
		type: Types.Select, 
		options: 'CMS, Twitter, Instagram', 
		default: 'CMS', 
		index: true,
		noedit: true,

	},
	isFromHashtag: { type: Boolean, default: false, noedit:true },
	isFromPreapprovedUser: { type: Boolean, default: false, noedit:true },
	isFromBannedUser: { type: Boolean, default: false, noedit:true },
	publishedDate: { type: Types.Datetime, dependsOn: { state: 'published' } 	},
	archivedDate: { type: Types.Datetime, dependsOn: { state: 'archived' } 		},
	rejectedDate: { type: Types.Datetime, dependsOn: { state: 'rejected' } 		},
}
//											{ 
//	heading: 'Original Video File Info',
//	dependsOn: { display: ['Video'] },
//},
//{
//	videoLocalFilename: { 
//		type:String, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoPublicId: { 
//		type:String, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoVersion: { 
//		type:Number, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoSignature: { 
//		type:String, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoWidth: { 
//		type:Number, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoHeight: { 
//		type:Number, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoFormat: { 
//		type:String, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoResourceType: { 
//		type:String, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoCreatedAt: { 
//		type:String, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoTags: { 
//		type:String, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoBytes: { 
//		type:Number, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoType: { 
//		type:String, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoEtag: { 
//		type:String, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoUrl: { 
//		type:String, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoSecureUrl: { 
//		type:String, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoAudioCodec: { 
//		type:String, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoAudioBitRate: { 
//		type:String, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoAudioFrequency: { 
//		type:Number, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoAudioChannels: { 
//		type:Number, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoAudioChannelLayout: { 
//		type:String, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoPixFormat: { 
//		type:String, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoCodec: { 
//		type:String, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoLevel: { 
//		type:Number, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoBitRate: { 
//		type:String, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoFrameRate: { 
//		type:Number, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoBitRate: { 
//		type:Number, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//	videoDuration: { 
//		type:Number, 
//		noedit: true,
//		dependsOn: {display: ['Video'] }, 
//	},
//}
);



//var uploadVideoToCloudinary=function(item) {
//	
//
//	//console.log('uploadVideoToCloudinary item=',item);
//
// 	if( item.video720p && item.video720p.filename && item.video720p.filename.length ){
// 		console.log('there is some video');
// 		if(item.videoLocalFilename === item.video720p.filename){
// 			console.log('nothçng to do here');
//
// 		}else{
// 			console.log('update video to cloudinary');
// 			
// 			var pathToVideo= __base+'public/data/videos/'+item.video720p.filename
// 			console.log('pathToVideo=',pathToVideo);
// 			
// 			var tp = keystone.get('cloudinary prefix') || '';
// 			
//
// 			cloudinary.uploader.upload(pathToVideo,function(result) {
// 				console.log('result from cloudinary = ',result); 
//
// 				if(result && result.public_id){
// 					item.videoLocalFilename            = item.video720p.filename;
//					item.videoPublicId                 = result.public_id;
//					item.videoVersion                  = result.version;
//					item.videoSignature                = result.signature;
//					item.videoWidth                    = result.width;
//					item.videoHeight                   = result.height;
//					item.videoFormat                   = result.format;
//					item.videoResourceType             = result.resource_type;
//					item.videoCreatedAt                = result.created_at;
//					item.videoTags                     = result.tags;
//					item.videoBytes                    = result.bytes;
//					item.videoType                     = result.type;
//					item.videoEtag                     = result.etag;
//					item.videoUrl                      = result.url;
//					item.videoSecureUrl                = result.secure_url;
//					if (result.audio) {
//						item.videoAudioCodec           = result.audio.codec;
//						item.videoAudioBitRate         = result.audio.bit_rate;
//						item.videoAudioFrequency       = result.audio.frequency;
//						item.videoAudioChannels        = result.audio.channels;
//						item.videoAudioChannelLayout   = result.audio.channel_layout;
//					}else{
//						item.videoAudioCodec           = null;
//						item.videoAudioBitRate         = null;
//						item.videoAudioFrequency       = null;
//						item.videoAudioChannels        = null;
//						item.videoAudioChannelLayout   = null;
//					}
//					if (result.video) {
//						item.videoPixFormat            = result.video.pix_format;
//						item.videoCodec                = result.video.codec;
//						item.videoLevel                = result.video.level;
//						item.videoBitRate              = result.video.bit_rate;
//					}else{     
//						item.videoPixFormat            = null;
//						item.videoCodec                = null;
//						item.videoLevel                = null;
//						item.videoBitRate              = null;
//					}                
//					item.videoFrameRate                = result.frame_rate;
//					item.videoBitRate                  = result.bit_rate;
//					item.videoDuration                 = result.duration;
//
//					item.save(); 
// 				}else{
// 					//item.save();
// 				}
//
// 				
//
// 			},{ 
// 				resource_type: "video",
// 				tags: [tp, tp+'_video', tp + '_video_' + item.id]
// 			});
// 		}
//
// 		/*
// 		//console.log('item.image ', item.image);
// 		if(item.image.public_id===undefined ){
// 			console.log('upload to cloudinary ',item.image_standard_resolution_url);
//	 		
//	 		var promise=item._.image.upload(item.image_standard_resolution_url);
//	 		promise.onFulfill(function(result) {
//				if (result.error) {
//					console.log(result.error)
//				} else {
//					console.log('sucessfully uploaded to cloudinary ',item.image_standard_resolution_url);
//					//console.log('result ',result);
//					item.set('image', result);
//					item.save();
//					//field.apply(item, 'upload', req.files[paths.upload].path, uploadOptions).onFulfill(uploadComplete);
//
//				}
//			});
// 		}
// 		*/
// 		
// 	}else{
// 		console.log('there is no video');
// 		if( item.videoLocalFilename         
//			|| item.videoPublicId              
//			|| item.videoVersion               
//			|| item.videoSignature             
//			|| item.videoWidth                 
//			|| item.videoHeight                
//			|| item.videoFormat                
//			|| item.videoResourceType          
//			|| item.videoCreatedAt             
//			|| item.videoTags                  
//			|| item.videoBytes                 
//			|| item.videoType                  
//			|| item.videoEtag                  
//			|| item.videoUrl                   
//			|| item.videoSecureUrl             
//			|| item.videoAudioCodec            
//			|| item.videoAudioBitRate          
//			|| item.videoAudioFrequency        
//			|| item.videoAudioChannels         
//			|| item.videoAudioChannelLayout    
//			|| item.videoPixFormat        
//			|| item.videoCodec            
//			|| item.videoLevel            
//			|| item.videoBitRate          
//			|| item.videoFrameRate             
//			|| item.videoBitRate               
//			|| item.videoDuration
//		){
//			item.videoLocalFilename            = null;
//			item.videoPublicId                 = null;          
//			item.videoVersion                  = null;     
//			item.videoSignature                = null;           
//			item.videoWidth                    = null;
//			item.videoHeight                   = null;  
//			item.videoFormat                   = null;  
//			item.videoResourceType             = null;                  
//			item.videoCreatedAt                = null;             
//			item.videoTags                     = null;
//			item.videoBytes                    = null;
//			item.videoType                     = null;
//			item.videoEtag                     = null;
//			item.videoUrl                      = null;
//			item.videoSecureUrl                = null;
//			item.videoAudioCodec               = null;
//			item.videoAudioBitRate             = null;
//			item.videoAudioFrequency           = null;
//			item.videoAudioChannels            = null;
//			item.videoAudioChannelLayout       = null;
//			item.videoPixFormat           = null;
//			item.videoCodec               = null;
//			item.videoLevel               = null;
//			item.videoBitRate             = null;    
//			item.videoFrameRate                = null;               
//			item.videoBitRate                  = null;         
//			item.videoDuration                 = null;
//			item.save();
//		}
// 		
// 	}
//}
//var throttleUploadVideoToCloudinary =_.throttle(uploadVideoToCloudinary,1000);
//Model.schema.post('save',throttleUploadVideoToCloudinary);

Model.defaultColumns = 'summary, displayDate|15%, display|15%, state|10%';
Model.register();

//Model.schema.post('save', function (item) {
//	
// 	if(item.state=='published' ){
//
// 		//console.log('item.image ', item.image);
// 		//if(item.image.public_id===undefined ){
// 		//	console.log('upload to cloudinary ',item.instagram_image_standard_resolution_url);
//	 	//	
//	 	//	var promise=item._.image.upload(item.instagram_image_standard_resolution_url);
//	 	//	promise.onFulfill(function(result) {
//		//		if (result.error) {
//		//			console.log(result.error)
//		//		} else {
//		//			console.log('sucessfully uploaded to cloudinary ',item.instagram_image_standard_resolution_url);
//		//			//console.log('result ',result);
//		//			item.set('image', result);
//		//			item.save();
//		//			//field.apply(item, 'upload', req.files[paths.upload].path, uploadOptions).onFulfill(uploadComplete);
//		//
//		//		}
//		//	});
// 		//}
// 		
// 	}
//
//});


function updateCache(){
	
	//console.log('updateInstagramCache');
	var q=Model.model.find();
    q.sort('-displayDate');
    q.where('state','published');
    //q.limit(1)
    q.exec(function(err, items) {
        // do something with posts

        var cards={};

        _.each(items, function(item){ 
        	cards[item.shortid]=item;
        });

        console.log('[CACHE] cards cached');
		cachedResponses['cards']=cards;
		cachedResponses['index']=undefined;
		//console.log(JSON.stringify(cards,null,4));

    });

}
var lazyCache = _.debounce(updateCache, 1000);


//Model.schema.post('save', function (item) {
//	if(item.instagram_image.public_id){
//		lazyUpdateInstagramCache();
//	}
//});
//Model.schema.post('remove', function (item) {
//	
//	if(item.instagram_image.public_id && item.state=='published'){
//		lazyUpdateInstagramCache();
//	}
//});
//Model.schema.pre('update', function (next) {
//	//lazyUpdateInstagramCache();
//});


Model.schema.post('save', function (item) { lazyCache(); });
Model.schema.post('remove', function (item) { lazyCache(); });
Model.schema.pre('update', function (next) { lazyCache(); next(); });
lazyCache();


module.exports = Model;



