var keystone = require('keystone'),
	Types = keystone.Field.Types,
	_ = require('underscore');
	
var Model = new keystone.List('Marker', {
	map: { name: 'title' },
	autokey: { path: 'slug', from: 'title', unique: true },
	//sortable: true,
	defaultSort: 'createdAt',
	//nocreate: true,
	//nodelete: true,
	track: true,
});

Model.add({
	
	title: { type: String, required: true, initial:true  },
	type: { type: Types.Select, options: ['Ponto','Restaurante'], default: 'Ponto', required:true, initial:true },
	logradouro: { label:'Logr.', type: String, required: false, initial:true  },
    numero: { label:'Num.', type: String, required: false, initial:true  },
    bairro: { type: String, required: false, initial:true  },
    cidade: { type: String, required: false, initial:true  },
    estado: { label:'UF', type: String, required: false, initial:true  },
    cep: { type: String, required: false, initial:true  },
	telefone: { label:'Fone',type: String, required: false, initial:true },
	lat: { label: 'Latitude', type: String, required: false, initial:true },
	lng: { label: 'Longitude', type: String, required: false, initial:true },

});

function updateCache(){
	var q=Model.model.find();
    q.exec(function(err, items) {


        var data=[];
        _.each(items,function(item){
        	
            if(!item.lat){
        		return false;
        	}
        	if(!item.lng){
        		return false;
        	}
            if(!item.lat.length){
                return false;
            }
            if(!item.lng.length){
                return false;
            }
        	if(item.content !== false){
                var addr='';

                if(item.logradouro && item.logradouro.length){
                    //if(addr.length) addr+=', ';
                    addr+=item.logradouro;
                }
                if(item.numero && item.numero.length){
                    if(addr.length) addr+=', ';
                    addr+=item.numero;
                }
                if(item.bairro && item.bairro.length){
                    if(addr.length) addr+=', ';
                    addr+=item.bairro;
                }
                if(item.cidade && item.cidade.length){
                    if(addr.length) addr+=', ';
                    addr+=item.cidade;
                }
                if(item.estado && item.estado.length){
                    if(addr.length) addr+=', ';
                    addr+=item.estado;
                }
                if(item.cep && item.cep.length){
                    if(addr.length) addr+=', ';
                    addr+='CEP&nbsp;'+item.cep;
                }
        		data.push({
        			lat: item.lat,
        			lng: item.lng,
        			title: item.title,
        			phone: item.telefone,
        			address: addr,
        			icon: item.type.toLowerCase(),
        		});
        	}
        	
        });
        if(items.length===0) data=false;

		//console.log('metadata cache = ',JSON.stringify(data,null,4));
		console.log('[CACHE] markers cached');
		cachedResponses['markers']=data;
		cachedResponses['index']=undefined;
    });
}
var lazyCache = _.debounce(updateCache, 50);
Model.schema.post('save', function (item) { lazyCache(); });
Model.schema.post('remove', function (item) { lazyCache(); });
Model.schema.pre('update', function (next) { lazyCache(); next(); });
lazyCache();




Model.defaultColumns = 'title,type,logradouro,numero,bairro,cidade,estado,cep,telefone,lat,lng';


Model.register();

module.exports = Model;


