var keystone = require('keystone'),
	Types = keystone.Field.Types,
	_ = require('underscore');
	
var Model = new keystone.List('Metadata', {
	map: { name: 'title' },
	autokey: { path: 'slug', from: 'title', unique: true },
	//sortable: true,
	defaultSort: 'createdAt',
	nocreate: true,
	//nodelete: true,
	track: true,
});

Model.add({
	title: { type: String, required: true, noedit:true  },
	type: { type: Types.Select, options: 'text, image, url', default: 'text', noedit:true },
	text: { type: String, required: false, dependsOn: {type: 'text'} },
	image: { type: Types.CloudinaryImage, dependsOn: {type: 'image'} },
	url: { type: Types.Url, dependsOn: {type: 'url'} },
	content: { 
		type: String, 
		noedit:true, 
		watch:'text image url', 
		value: function() { 
			if(this.type=='text') return this.text;
			if(this.type=='image') return this._.image.src();
			if(this.type=='url') return this.url;
			return '';
		}
	},
});

function updateCache(){
	var q=Model.model.find();
    q.exec(function(err, items) {


        var data={};
        _.each(items,function(item){
        	if(item.content !== false){
        		data[item.title]=item;
        	}
        	
        });
        if(items.length===0) data=false;

		//console.log('metadata cache = ',JSON.stringify(data,null,4));
		console.log('[CACHE] metadata cached');
		cachedResponses['metadata']=data;
		cachedResponses['index']=undefined;
    });
}
var lazyCache = _.debounce(updateCache, 50);
Model.schema.post('save', function (item) { lazyCache(); });
Model.schema.post('remove', function (item) { lazyCache(); });
Model.schema.pre('update', function (next) { lazyCache(); next(); });
lazyCache();




Model.defaultColumns = 'title,type,content';
Model.register();

module.exports = Model;


