var keystone = require('keystone'),
	Types = keystone.Field.Types,
	_ = require('underscore');
	
var Model = new keystone.List('MobileContents', {
	map: { name: 'title' },
	autokey: { path: 'slug', from: 'title', unique: true },
	//sortable: true,
	defaultSort: 'createdAt',
	nocreate: true,
	//nodelete: true,
	track: true,
});

Model.add({
	title: { type: String, required: true, noedit:true  },
	type: { type: Types.Select, options: 'text, textarea, image, images, video, url', default: 'text', noedit:true },
	text: { type: String, required: false, dependsOn: {type: 'text'} },
	textarea: { type: Types.Textarea, required: false, dependsOn: {type: 'textarea'} },
	image: { type: Types.CloudinaryImage, dependsOn: {type: 'image'} },
	images: { type: Types.CloudinaryImages, dependsOn: {type: 'images'} },
	url: { type: Types.Url, dependsOn: {type: 'url'} },
	video: {
		type: Types.LocalFile,
		dest: __base+'public/data/videos',
		filename: function(item, file){
			return item.slug + '-' + file.name;//+'.' + file.extension
		},
		dependsOn: { type: 'video' },
	},
	content: { 
		type: String, 
		noedit:true, 
		watch: true, 
		value: function() { 
			if(this.type=='text'){ return this.text;}
			if(this.type=='textarea'){ return this.textarea;}
			if(this.type=='image'){ return this._.image.src();}
			if(this.type=='images'){ return this.images.reduce(function(image){ return image.src();  });}
			if(this.type=='url'){ return this.url;}
			if(this.type=='video'){
				if (this.video.filename) return '/data/videos/'+this.video.filename;
				else return '';
			}

			return '';
		}
	},
});

function updateCache(){
	var q=Model.model.find();
    q.exec(function(err, items) {


        var data={};
        _.each(items,function(item){
        	if(item.content !== false){
        		data[item.title]=item;
        	}
        	
        });
        if(items.length===0) data=false;

		//console.log('layoutdata cache = ',JSON.stringify(data,null,4));
		console.log('[CACHE] mobile_content cached');
		cachedResponses['mobile_content']=data;
		cachedResponses['index']=undefined;
    });
}
var lazyCache = _.debounce(updateCache, 50);
Model.schema.post('save', function (item) { lazyCache(); });
Model.schema.post('remove', function (item) { lazyCache(); });
Model.schema.pre('update', function (next) { lazyCache(); next(); });
lazyCache();




Model.defaultColumns = 'title,type,content';
Model.register();

module.exports = Model;


