/**
 * This file is where you define your application routes and controllers.
 *
 * Start by including the middleware you want to run for every request;
 * you can attach middleware to the pre('routes') and pre('render') events.
 *
 * For simplicity, the default setup for route controllers is for each to be
 * in its own file, and we import all the files in the /routes/views directory.
 *
 * Each of these files is a route controller, and is responsible for all the
 * processing that needs to happen for the route (e.g. loading data, handling
 * form submissions, rendering the view template, etc).
 *
 * Bind each route pattern your application should respond to in the function
 * that is exported from this module, following the examples below.
 *
 * See the Express application routing documentation for more information:
 * http://expressjs.com/api.html#app.VERB
 */

var keystone = require('keystone'),
	middleware = require('./middleware'),
	importRoutes = keystone.importer(__dirname);

// Common Middleware
keystone.pre('routes', middleware.initLocals);
keystone.pre('render', middleware.flashMessages);

// Import Route Controllers
var routes = {
	views: importRoutes('./views')
};

// Setup Route Bindings
exports = module.exports = function(app) {

	// Views
	app.get('/', routes.views.index);
	app.get('/storytelling', routes.views.index);
	app.get('/la_mia_gelateria', routes.views.index);
	app.get('/isapori', routes.views.index);
	app.get('/cioccolato_nero', routes.views.index);
	app.get('/vaniglia', routes.views.index);
	app.get('/caramello_salato', routes.views.index);
	app.get('/limoncello', routes.views.index);
	app.get('/pistacchio', routes.views.index);
	app.get('/panna_cotta', routes.views.index);
	app.get('/gianduia', routes.views.index);
	app.get('/fragola', routes.views.index);
	app.get('/cappuccino', routes.views.index);
	app.get('/limoncello_picole', routes.views.index);
	app.get('/pisctacchio_picole', routes.views.index);
	app.get('/fragola_picole', routes.views.index);
	app.get('/harmonizacoes_cioccolato_nero', routes.views.index);
	app.get('/harmonizacoes_vaniglia', routes.views.index);
	app.get('/harmonizacoes_caramello_salato', routes.views.index);
	app.get('/harmonizacoes_limoncello', routes.views.index);
	app.get('/harmonizacoes_pistacchio', routes.views.index);
	app.get('/harmonizacoes_panna_cotta', routes.views.index);
	app.get('/harmonizacoes_gianduia', routes.views.index);
	app.get('/harmonizacoes_fragola', routes.views.index);
	app.get('/harmonizacoes_cappuccino', routes.views.index);
	app.get('/harmonizacoes_limoncello_picole', routes.views.index);
	app.get('/harmonizacoes_pisctacchio_picole', routes.views.index);
	app.get('/harmonizacoes_fragola_picole', routes.views.index);
	app.get('/dove_trovare', routes.views.index);

	app.get('/instagram', routes.views.instagram.get);
	app.post('/instagram', routes.views.instagram.post);
	app.post('/moderation/post/:id/:state', middleware.requireUser, routes.views.moderate);
	app.all('/moderation', middleware.requireUser, routes.views.moderation);
	app.all('/moderation/pending/hashtag', middleware.requireUser, routes.views.moderation);
	app.all('/moderation/pending/all', middleware.requireUser, routes.views.moderation);
	//app.all('/moderation/pending/location', middleware.requireUser, routes.views.moderation);
	app.all('/moderation/published', middleware.requireUser, routes.views.moderation);
	app.all('/moderation/rejected', middleware.requireUser, routes.views.moderation);
	app.all('/moderation/archived', middleware.requireUser, routes.views.moderation);
	app.all('/moderation/preapprooved', middleware.requireUser, routes.views.moderation);
	app.all('/moderation/banned', middleware.requireUser, routes.views.moderation);
	app.all('/moderation/pending/hashtag/cleanup', middleware.requireUser, routes.views.cleanup);
	app.all('/moderation/pending/all/cleanup', middleware.requireUser, routes.views.cleanup);
	//app.all('/moderation/pending/location/cleanup', middleware.requireUser, routes.views.cleanup);
	app.all('/moderation/rejected/cleanup', middleware.requireUser, routes.views.cleanup);
	app.all('/moderation/banned/cleanup', middleware.requireUser, routes.views.cleanup);

	app.get('/markers.json',  routes.views.markers);
	app.get('/pack',  routes.views.pack);
	app.all('/:id/', routes.views.permalink);


	// NOTE: To protect a route so that only admins can see it, use the requireUser middleware:
	// app.get('/protected', middleware.requireUser, routes.views.protected);

};
