
var _ = require('underscore');
var async = require('async');
var keystone = require('keystone');
var Card = keystone.list('Card');
var AuthorizedInstagramUsers = keystone.list('PreauthorizedInstagramUsers');
var BannedInstagramUsers = keystone.list('BannedInstagramUsers');
var shortid = require('shortid');
var tags = [ 'nestlegelato', 'lamiagelateria',   ];


function saveMedia(media){
    //console.log('save media '+media.id+' '+media.created_time);
	var card = new Card.model({});
	card.origin='Instagram';
	card.instagram_json_data= JSON.stringify(media,null,4);
	card.unique_media_id = media.id;
	card.instagram_media_id = media.id;
	card.instagram_media_type = media.type;
	card.instagram_timestamp =parseInt(media.created_time);
	card.displayDate=new Date(card.instagram_timestamp*1000);
	
	if(media.filter){
		card.instagram_filter =media.filter;
	}
	if(media.link){
		card.instagram_link =media.link;
	}
	if(media.username){
		card.instagram_user_name = media.username;
	}
	if(media.user){
		card.instagram_user_name = media.user.username;
		card.instagram_user_profile_picture =media.user.profile_picture;
		card.instagram_user_full_name =media.user.full_name;
		card.instagram_user_id =media.user.id;
	}

	if(_.intersection(approved_instagram_users_handles,[card.instagram_user_name]).length){
		card.isFromPreapprovedUser=true;
	}
	if(_.intersection(banned_instagram_users_handles,[card.instagram_user_name]).length){
		card.isFromBannedUser=true;
	}

	if(card.isFromBannedUser){
		card.state='rejected';
	}else if(card.isFromPreapprovedUser){
		card.state='published';
	}else{
		card.state='pending';
	}
	

	if(media.tags){
		if(_.intersection(tags,media.tags).length){
			card.isFromHashtag=true;
		}
	}
	
	if(media.caption){
		card.instagram_caption_id = media.caption.id;
		card.instagram_caption_created_time = media.caption.created_time;
		card.instagram_caption_text = media.caption.text;
	}
	
	if(media.location){
		card.instagram_latitude   =  media.location.latitude;
		card.instagram_longitude  =  media.location.longitude;
	}
	
	if(media.images){
		if(media.images.low_resolution) card.instagram_image_low_resolution_url         		=  media.images.low_resolution.url        ;
		if(media.images.low_resolution) card.instagram_image_low_resolution_width       		=  media.images.low_resolution.width      ;
		if(media.images.low_resolution) card.instagram_image_low_resolution_height      		=  media.images.low_resolution.height     ;
		if(media.images.thumbnail) card.instagram_image_thumbnail_url              			=  media.images.thumbnail.url             ;
		if(media.images.thumbnail) card.instagram_image_thumbnail_width            			=  media.images.thumbnail.width           ;
		if(media.images.thumbnail) card.instagram_image_thumbnail_height           			=  media.images.thumbnail.height          ;
		if(media.images.standard_resolution) card.instagram_image_standard_resolution_url    =  media.images.standard_resolution.url   ;
		if(media.images.standard_resolution) card.instagram_image_standard_resolution_width  =  media.images.standard_resolution.width ;
		if(media.images.standard_resolution) card.instagram_image_standard_resolution_height =  media.images.standard_resolution.height;
	}

	if(media.videos){
		if(media.videos.low_resolution) card.instagram_video_low_resolution_url         		=  media.videos.low_resolution.url        ;
		if(media.videos.low_resolution) card.instagram_video_low_resolution_width       		=  media.videos.low_resolution.width      ;
		if(media.videos.low_resolution) card.instagram_video_low_resolution_height      		=  media.videos.low_resolution.height     ;
		if(media.videos.thumbnail) card.instagram_video_thumbnail_url              			=  media.videos.thumbnail.url             ;
		if(media.videos.thumbnail) card.instagram_video_thumbnail_width            			=  media.videos.thumbnail.width           ;
		if(media.videos.thumbnail) card.instagram_video_thumbnail_height           			=  media.videos.thumbnail.height          ;
		if(media.videos.standard_resolution) card.instagram_video_standard_resolution_url    =  media.videos.standard_resolution.url   ;
		if(media.videos.standard_resolution) card.instagram_video_standard_resolution_width  =  media.videos.standard_resolution.width ;
		if(media.videos.standard_resolution) card.instagram_video_standard_resolution_height =  media.videos.standard_resolution.height;
	}

	if(card.instagram_video_standard_resolution_url && card.instagram_video_standard_resolution_url.length){
		card.display='Instagram Video';
	}else{
		card.display='Instagram Image';
	}

	card.summary=card.display+' from @'+card.instagram_user_name+' saying "'+card.instagram_caption_text+'"';

	card.shortid=shortid.generate();
	
	card.save(function(err) {
		if (err) {

			if(err.code==11000){
				//console.error("Duplicate instagram picture ",media.id, media.created_time);
			}else{
				console.error("Error adding instagram picture ", media.id, media.created_time, err);
			}
			
			
		} else {
			console.log("Added instagram picture ", media.id, media.created_time);
		}
	});
	
	
}

module.exports =  saveMedia;