/*!
 * jQuery JavaScript Library v2.1.4
 * http://jquery.com/
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 *
 * Copyright 2005, 2014 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2015-04-28T16:01Z
 */

(function( global, factory ) {

	if ( typeof module === "object" && typeof module.exports === "object" ) {
		// For CommonJS and CommonJS-like environments where a proper `window`
		// is present, execute the factory and get jQuery.
		// For environments that do not have a `window` with a `document`
		// (such as Node.js), expose a factory as module.exports.
		// This accentuates the need for the creation of a real `window`.
		// e.g. var jQuery = require("jquery")(window);
		// See ticket #14549 for more info.
		module.exports = global.document ?
			factory( global, true ) :
			function( w ) {
				if ( !w.document ) {
					throw new Error( "jQuery requires a window with a document" );
				}
				return factory( w );
			};
	} else {
		factory( global );
	}

// Pass this if window is not defined yet
}(typeof window !== "undefined" ? window : this, function( window, noGlobal ) {

// Support: Firefox 18+
// Can't be in strict mode, several libs including ASP.NET trace
// the stack via arguments.caller.callee and Firefox dies if
// you try to trace through "use strict" call chains. (#13335)
//

var arr = [];

var slice = arr.slice;

var concat = arr.concat;

var push = arr.push;

var indexOf = arr.indexOf;

var class2type = {};

var toString = class2type.toString;

var hasOwn = class2type.hasOwnProperty;

var support = {};



var
	// Use the correct document accordingly with window argument (sandbox)
	document = window.document,

	version = "2.1.4",

	// Define a local copy of jQuery
	jQuery = function( selector, context ) {
		// The jQuery object is actually just the init constructor 'enhanced'
		// Need init if jQuery is called (just allow error to be thrown if not included)
		return new jQuery.fn.init( selector, context );
	},

	// Support: Android<4.1
	// Make sure we trim BOM and NBSP
	rtrim = /^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,

	// Matches dashed string for camelizing
	rmsPrefix = /^-ms-/,
	rdashAlpha = /-([\da-z])/gi,

	// Used by jQuery.camelCase as callback to replace()
	fcamelCase = function( all, letter ) {
		return letter.toUpperCase();
	};

jQuery.fn = jQuery.prototype = {
	// The current version of jQuery being used
	jquery: version,

	constructor: jQuery,

	// Start with an empty selector
	selector: "",

	// The default length of a jQuery object is 0
	length: 0,

	toArray: function() {
		return slice.call( this );
	},

	// Get the Nth element in the matched element set OR
	// Get the whole matched element set as a clean array
	get: function( num ) {
		return num != null ?

			// Return just the one element from the set
			( num < 0 ? this[ num + this.length ] : this[ num ] ) :

			// Return all the elements in a clean array
			slice.call( this );
	},

	// Take an array of elements and push it onto the stack
	// (returning the new matched element set)
	pushStack: function( elems ) {

		// Build a new jQuery matched element set
		var ret = jQuery.merge( this.constructor(), elems );

		// Add the old object onto the stack (as a reference)
		ret.prevObject = this;
		ret.context = this.context;

		// Return the newly-formed element set
		return ret;
	},

	// Execute a callback for every element in the matched set.
	// (You can seed the arguments with an array of args, but this is
	// only used internally.)
	each: function( callback, args ) {
		return jQuery.each( this, callback, args );
	},

	map: function( callback ) {
		return this.pushStack( jQuery.map(this, function( elem, i ) {
			return callback.call( elem, i, elem );
		}));
	},

	slice: function() {
		return this.pushStack( slice.apply( this, arguments ) );
	},

	first: function() {
		return this.eq( 0 );
	},

	last: function() {
		return this.eq( -1 );
	},

	eq: function( i ) {
		var len = this.length,
			j = +i + ( i < 0 ? len : 0 );
		return this.pushStack( j >= 0 && j < len ? [ this[j] ] : [] );
	},

	end: function() {
		return this.prevObject || this.constructor(null);
	},

	// For internal use only.
	// Behaves like an Array's method, not like a jQuery method.
	push: push,
	sort: arr.sort,
	splice: arr.splice
};

jQuery.extend = jQuery.fn.extend = function() {
	var options, name, src, copy, copyIsArray, clone,
		target = arguments[0] || {},
		i = 1,
		length = arguments.length,
		deep = false;

	// Handle a deep copy situation
	if ( typeof target === "boolean" ) {
		deep = target;

		// Skip the boolean and the target
		target = arguments[ i ] || {};
		i++;
	}

	// Handle case when target is a string or something (possible in deep copy)
	if ( typeof target !== "object" && !jQuery.isFunction(target) ) {
		target = {};
	}

	// Extend jQuery itself if only one argument is passed
	if ( i === length ) {
		target = this;
		i--;
	}

	for ( ; i < length; i++ ) {
		// Only deal with non-null/undefined values
		if ( (options = arguments[ i ]) != null ) {
			// Extend the base object
			for ( name in options ) {
				src = target[ name ];
				copy = options[ name ];

				// Prevent never-ending loop
				if ( target === copy ) {
					continue;
				}

				// Recurse if we're merging plain objects or arrays
				if ( deep && copy && ( jQuery.isPlainObject(copy) || (copyIsArray = jQuery.isArray(copy)) ) ) {
					if ( copyIsArray ) {
						copyIsArray = false;
						clone = src && jQuery.isArray(src) ? src : [];

					} else {
						clone = src && jQuery.isPlainObject(src) ? src : {};
					}

					// Never move original objects, clone them
					target[ name ] = jQuery.extend( deep, clone, copy );

				// Don't bring in undefined values
				} else if ( copy !== undefined ) {
					target[ name ] = copy;
				}
			}
		}
	}

	// Return the modified object
	return target;
};

jQuery.extend({
	// Unique for each copy of jQuery on the page
	expando: "jQuery" + ( version + Math.random() ).replace( /\D/g, "" ),

	// Assume jQuery is ready without the ready module
	isReady: true,

	error: function( msg ) {
		throw new Error( msg );
	},

	noop: function() {},

	isFunction: function( obj ) {
		return jQuery.type(obj) === "function";
	},

	isArray: Array.isArray,

	isWindow: function( obj ) {
		return obj != null && obj === obj.window;
	},

	isNumeric: function( obj ) {
		// parseFloat NaNs numeric-cast false positives (null|true|false|"")
		// ...but misinterprets leading-number strings, particularly hex literals ("0x...")
		// subtraction forces infinities to NaN
		// adding 1 corrects loss of precision from parseFloat (#15100)
		return !jQuery.isArray( obj ) && (obj - parseFloat( obj ) + 1) >= 0;
	},

	isPlainObject: function( obj ) {
		// Not plain objects:
		// - Any object or value whose internal [[Class]] property is not "[object Object]"
		// - DOM nodes
		// - window
		if ( jQuery.type( obj ) !== "object" || obj.nodeType || jQuery.isWindow( obj ) ) {
			return false;
		}

		if ( obj.constructor &&
				!hasOwn.call( obj.constructor.prototype, "isPrototypeOf" ) ) {
			return false;
		}

		// If the function hasn't returned already, we're confident that
		// |obj| is a plain object, created by {} or constructed with new Object
		return true;
	},

	isEmptyObject: function( obj ) {
		var name;
		for ( name in obj ) {
			return false;
		}
		return true;
	},

	type: function( obj ) {
		if ( obj == null ) {
			return obj + "";
		}
		// Support: Android<4.0, iOS<6 (functionish RegExp)
		return typeof obj === "object" || typeof obj === "function" ?
			class2type[ toString.call(obj) ] || "object" :
			typeof obj;
	},

	// Evaluates a script in a global context
	globalEval: function( code ) {
		var script,
			indirect = eval;

		code = jQuery.trim( code );

		if ( code ) {
			// If the code includes a valid, prologue position
			// strict mode pragma, execute code by injecting a
			// script tag into the document.
			if ( code.indexOf("use strict") === 1 ) {
				script = document.createElement("script");
				script.text = code;
				document.head.appendChild( script ).parentNode.removeChild( script );
			} else {
			// Otherwise, avoid the DOM node creation, insertion
			// and removal by using an indirect global eval
				indirect( code );
			}
		}
	},

	// Convert dashed to camelCase; used by the css and data modules
	// Support: IE9-11+
	// Microsoft forgot to hump their vendor prefix (#9572)
	camelCase: function( string ) {
		return string.replace( rmsPrefix, "ms-" ).replace( rdashAlpha, fcamelCase );
	},

	nodeName: function( elem, name ) {
		return elem.nodeName && elem.nodeName.toLowerCase() === name.toLowerCase();
	},

	// args is for internal usage only
	each: function( obj, callback, args ) {
		var value,
			i = 0,
			length = obj.length,
			isArray = isArraylike( obj );

		if ( args ) {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			}

		// A special, fast, case for the most common use of each
		} else {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			}
		}

		return obj;
	},

	// Support: Android<4.1
	trim: function( text ) {
		return text == null ?
			"" :
			( text + "" ).replace( rtrim, "" );
	},

	// results is for internal usage only
	makeArray: function( arr, results ) {
		var ret = results || [];

		if ( arr != null ) {
			if ( isArraylike( Object(arr) ) ) {
				jQuery.merge( ret,
					typeof arr === "string" ?
					[ arr ] : arr
				);
			} else {
				push.call( ret, arr );
			}
		}

		return ret;
	},

	inArray: function( elem, arr, i ) {
		return arr == null ? -1 : indexOf.call( arr, elem, i );
	},

	merge: function( first, second ) {
		var len = +second.length,
			j = 0,
			i = first.length;

		for ( ; j < len; j++ ) {
			first[ i++ ] = second[ j ];
		}

		first.length = i;

		return first;
	},

	grep: function( elems, callback, invert ) {
		var callbackInverse,
			matches = [],
			i = 0,
			length = elems.length,
			callbackExpect = !invert;

		// Go through the array, only saving the items
		// that pass the validator function
		for ( ; i < length; i++ ) {
			callbackInverse = !callback( elems[ i ], i );
			if ( callbackInverse !== callbackExpect ) {
				matches.push( elems[ i ] );
			}
		}

		return matches;
	},

	// arg is for internal usage only
	map: function( elems, callback, arg ) {
		var value,
			i = 0,
			length = elems.length,
			isArray = isArraylike( elems ),
			ret = [];

		// Go through the array, translating each of the items to their new values
		if ( isArray ) {
			for ( ; i < length; i++ ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}

		// Go through every key on the object,
		} else {
			for ( i in elems ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}
		}

		// Flatten any nested arrays
		return concat.apply( [], ret );
	},

	// A global GUID counter for objects
	guid: 1,

	// Bind a function to a context, optionally partially applying any
	// arguments.
	proxy: function( fn, context ) {
		var tmp, args, proxy;

		if ( typeof context === "string" ) {
			tmp = fn[ context ];
			context = fn;
			fn = tmp;
		}

		// Quick check to determine if target is callable, in the spec
		// this throws a TypeError, but we will just return undefined.
		if ( !jQuery.isFunction( fn ) ) {
			return undefined;
		}

		// Simulated bind
		args = slice.call( arguments, 2 );
		proxy = function() {
			return fn.apply( context || this, args.concat( slice.call( arguments ) ) );
		};

		// Set the guid of unique handler to the same of original handler, so it can be removed
		proxy.guid = fn.guid = fn.guid || jQuery.guid++;

		return proxy;
	},

	now: Date.now,

	// jQuery.support is not used in Core but other projects attach their
	// properties to it so it needs to exist.
	support: support
});

// Populate the class2type map
jQuery.each("Boolean Number String Function Array Date RegExp Object Error".split(" "), function(i, name) {
	class2type[ "[object " + name + "]" ] = name.toLowerCase();
});

function isArraylike( obj ) {

	// Support: iOS 8.2 (not reproducible in simulator)
	// `in` check used to prevent JIT error (gh-2145)
	// hasOwn isn't used here due to false negatives
	// regarding Nodelist length in IE
	var length = "length" in obj && obj.length,
		type = jQuery.type( obj );

	if ( type === "function" || jQuery.isWindow( obj ) ) {
		return false;
	}

	if ( obj.nodeType === 1 && length ) {
		return true;
	}

	return type === "array" || length === 0 ||
		typeof length === "number" && length > 0 && ( length - 1 ) in obj;
}
var Sizzle =
/*!
 * Sizzle CSS Selector Engine v2.2.0-pre
 * http://sizzlejs.com/
 *
 * Copyright 2008, 2014 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2014-12-16
 */
(function( window ) {

var i,
	support,
	Expr,
	getText,
	isXML,
	tokenize,
	compile,
	select,
	outermostContext,
	sortInput,
	hasDuplicate,

	// Local document vars
	setDocument,
	document,
	docElem,
	documentIsHTML,
	rbuggyQSA,
	rbuggyMatches,
	matches,
	contains,

	// Instance-specific data
	expando = "sizzle" + 1 * new Date(),
	preferredDoc = window.document,
	dirruns = 0,
	done = 0,
	classCache = createCache(),
	tokenCache = createCache(),
	compilerCache = createCache(),
	sortOrder = function( a, b ) {
		if ( a === b ) {
			hasDuplicate = true;
		}
		return 0;
	},

	// General-purpose constants
	MAX_NEGATIVE = 1 << 31,

	// Instance methods
	hasOwn = ({}).hasOwnProperty,
	arr = [],
	pop = arr.pop,
	push_native = arr.push,
	push = arr.push,
	slice = arr.slice,
	// Use a stripped-down indexOf as it's faster than native
	// http://jsperf.com/thor-indexof-vs-for/5
	indexOf = function( list, elem ) {
		var i = 0,
			len = list.length;
		for ( ; i < len; i++ ) {
			if ( list[i] === elem ) {
				return i;
			}
		}
		return -1;
	},

	booleans = "checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",

	// Regular expressions

	// Whitespace characters http://www.w3.org/TR/css3-selectors/#whitespace
	whitespace = "[\\x20\\t\\r\\n\\f]",
	// http://www.w3.org/TR/css3-syntax/#characters
	characterEncoding = "(?:\\\\.|[\\w-]|[^\\x00-\\xa0])+",

	// Loosely modeled on CSS identifier characters
	// An unquoted value should be a CSS identifier http://www.w3.org/TR/css3-selectors/#attribute-selectors
	// Proper syntax: http://www.w3.org/TR/CSS21/syndata.html#value-def-identifier
	identifier = characterEncoding.replace( "w", "w#" ),

	// Attribute selectors: http://www.w3.org/TR/selectors/#attribute-selectors
	attributes = "\\[" + whitespace + "*(" + characterEncoding + ")(?:" + whitespace +
		// Operator (capture 2)
		"*([*^$|!~]?=)" + whitespace +
		// "Attribute values must be CSS identifiers [capture 5] or strings [capture 3 or capture 4]"
		"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|(" + identifier + "))|)" + whitespace +
		"*\\]",

	pseudos = ":(" + characterEncoding + ")(?:\\((" +
		// To reduce the number of selectors needing tokenize in the preFilter, prefer arguments:
		// 1. quoted (capture 3; capture 4 or capture 5)
		"('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|" +
		// 2. simple (capture 6)
		"((?:\\\\.|[^\\\\()[\\]]|" + attributes + ")*)|" +
		// 3. anything else (capture 2)
		".*" +
		")\\)|)",

	// Leading and non-escaped trailing whitespace, capturing some non-whitespace characters preceding the latter
	rwhitespace = new RegExp( whitespace + "+", "g" ),
	rtrim = new RegExp( "^" + whitespace + "+|((?:^|[^\\\\])(?:\\\\.)*)" + whitespace + "+$", "g" ),

	rcomma = new RegExp( "^" + whitespace + "*," + whitespace + "*" ),
	rcombinators = new RegExp( "^" + whitespace + "*([>+~]|" + whitespace + ")" + whitespace + "*" ),

	rattributeQuotes = new RegExp( "=" + whitespace + "*([^\\]'\"]*?)" + whitespace + "*\\]", "g" ),

	rpseudo = new RegExp( pseudos ),
	ridentifier = new RegExp( "^" + identifier + "$" ),

	matchExpr = {
		"ID": new RegExp( "^#(" + characterEncoding + ")" ),
		"CLASS": new RegExp( "^\\.(" + characterEncoding + ")" ),
		"TAG": new RegExp( "^(" + characterEncoding.replace( "w", "w*" ) + ")" ),
		"ATTR": new RegExp( "^" + attributes ),
		"PSEUDO": new RegExp( "^" + pseudos ),
		"CHILD": new RegExp( "^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\(" + whitespace +
			"*(even|odd|(([+-]|)(\\d*)n|)" + whitespace + "*(?:([+-]|)" + whitespace +
			"*(\\d+)|))" + whitespace + "*\\)|)", "i" ),
		"bool": new RegExp( "^(?:" + booleans + ")$", "i" ),
		// For use in libraries implementing .is()
		// We use this for POS matching in `select`
		"needsContext": new RegExp( "^" + whitespace + "*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\(" +
			whitespace + "*((?:-\\d)?\\d*)" + whitespace + "*\\)|)(?=[^-]|$)", "i" )
	},

	rinputs = /^(?:input|select|textarea|button)$/i,
	rheader = /^h\d$/i,

	rnative = /^[^{]+\{\s*\[native \w/,

	// Easily-parseable/retrievable ID or TAG or CLASS selectors
	rquickExpr = /^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,

	rsibling = /[+~]/,
	rescape = /'|\\/g,

	// CSS escapes http://www.w3.org/TR/CSS21/syndata.html#escaped-characters
	runescape = new RegExp( "\\\\([\\da-f]{1,6}" + whitespace + "?|(" + whitespace + ")|.)", "ig" ),
	funescape = function( _, escaped, escapedWhitespace ) {
		var high = "0x" + escaped - 0x10000;
		// NaN means non-codepoint
		// Support: Firefox<24
		// Workaround erroneous numeric interpretation of +"0x"
		return high !== high || escapedWhitespace ?
			escaped :
			high < 0 ?
				// BMP codepoint
				String.fromCharCode( high + 0x10000 ) :
				// Supplemental Plane codepoint (surrogate pair)
				String.fromCharCode( high >> 10 | 0xD800, high & 0x3FF | 0xDC00 );
	},

	// Used for iframes
	// See setDocument()
	// Removing the function wrapper causes a "Permission Denied"
	// error in IE
	unloadHandler = function() {
		setDocument();
	};

// Optimize for push.apply( _, NodeList )
try {
	push.apply(
		(arr = slice.call( preferredDoc.childNodes )),
		preferredDoc.childNodes
	);
	// Support: Android<4.0
	// Detect silently failing push.apply
	arr[ preferredDoc.childNodes.length ].nodeType;
} catch ( e ) {
	push = { apply: arr.length ?

		// Leverage slice if possible
		function( target, els ) {
			push_native.apply( target, slice.call(els) );
		} :

		// Support: IE<9
		// Otherwise append directly
		function( target, els ) {
			var j = target.length,
				i = 0;
			// Can't trust NodeList.length
			while ( (target[j++] = els[i++]) ) {}
			target.length = j - 1;
		}
	};
}

function Sizzle( selector, context, results, seed ) {
	var match, elem, m, nodeType,
		// QSA vars
		i, groups, old, nid, newContext, newSelector;

	if ( ( context ? context.ownerDocument || context : preferredDoc ) !== document ) {
		setDocument( context );
	}

	context = context || document;
	results = results || [];
	nodeType = context.nodeType;

	if ( typeof selector !== "string" || !selector ||
		nodeType !== 1 && nodeType !== 9 && nodeType !== 11 ) {

		return results;
	}

	if ( !seed && documentIsHTML ) {

		// Try to shortcut find operations when possible (e.g., not under DocumentFragment)
		if ( nodeType !== 11 && (match = rquickExpr.exec( selector )) ) {
			// Speed-up: Sizzle("#ID")
			if ( (m = match[1]) ) {
				if ( nodeType === 9 ) {
					elem = context.getElementById( m );
					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document (jQuery #6963)
					if ( elem && elem.parentNode ) {
						// Handle the case where IE, Opera, and Webkit return items
						// by name instead of ID
						if ( elem.id === m ) {
							results.push( elem );
							return results;
						}
					} else {
						return results;
					}
				} else {
					// Context is not a document
					if ( context.ownerDocument && (elem = context.ownerDocument.getElementById( m )) &&
						contains( context, elem ) && elem.id === m ) {
						results.push( elem );
						return results;
					}
				}

			// Speed-up: Sizzle("TAG")
			} else if ( match[2] ) {
				push.apply( results, context.getElementsByTagName( selector ) );
				return results;

			// Speed-up: Sizzle(".CLASS")
			} else if ( (m = match[3]) && support.getElementsByClassName ) {
				push.apply( results, context.getElementsByClassName( m ) );
				return results;
			}
		}

		// QSA path
		if ( support.qsa && (!rbuggyQSA || !rbuggyQSA.test( selector )) ) {
			nid = old = expando;
			newContext = context;
			newSelector = nodeType !== 1 && selector;

			// qSA works strangely on Element-rooted queries
			// We can work around this by specifying an extra ID on the root
			// and working up from there (Thanks to Andrew Dupont for the technique)
			// IE 8 doesn't work on object elements
			if ( nodeType === 1 && context.nodeName.toLowerCase() !== "object" ) {
				groups = tokenize( selector );

				if ( (old = context.getAttribute("id")) ) {
					nid = old.replace( rescape, "\\$&" );
				} else {
					context.setAttribute( "id", nid );
				}
				nid = "[id='" + nid + "'] ";

				i = groups.length;
				while ( i-- ) {
					groups[i] = nid + toSelector( groups[i] );
				}
				newContext = rsibling.test( selector ) && testContext( context.parentNode ) || context;
				newSelector = groups.join(",");
			}

			if ( newSelector ) {
				try {
					push.apply( results,
						newContext.querySelectorAll( newSelector )
					);
					return results;
				} catch(qsaError) {
				} finally {
					if ( !old ) {
						context.removeAttribute("id");
					}
				}
			}
		}
	}

	// All others
	return select( selector.replace( rtrim, "$1" ), context, results, seed );
}

/**
 * Create key-value caches of limited size
 * @returns {Function(string, Object)} Returns the Object data after storing it on itself with
 *	property name the (space-suffixed) string and (if the cache is larger than Expr.cacheLength)
 *	deleting the oldest entry
 */
function createCache() {
	var keys = [];

	function cache( key, value ) {
		// Use (key + " ") to avoid collision with native prototype properties (see Issue #157)
		if ( keys.push( key + " " ) > Expr.cacheLength ) {
			// Only keep the most recent entries
			delete cache[ keys.shift() ];
		}
		return (cache[ key + " " ] = value);
	}
	return cache;
}

/**
 * Mark a function for special use by Sizzle
 * @param {Function} fn The function to mark
 */
function markFunction( fn ) {
	fn[ expando ] = true;
	return fn;
}

/**
 * Support testing using an element
 * @param {Function} fn Passed the created div and expects a boolean result
 */
function assert( fn ) {
	var div = document.createElement("div");

	try {
		return !!fn( div );
	} catch (e) {
		return false;
	} finally {
		// Remove from its parent by default
		if ( div.parentNode ) {
			div.parentNode.removeChild( div );
		}
		// release memory in IE
		div = null;
	}
}

/**
 * Adds the same handler for all of the specified attrs
 * @param {String} attrs Pipe-separated list of attributes
 * @param {Function} handler The method that will be applied
 */
function addHandle( attrs, handler ) {
	var arr = attrs.split("|"),
		i = attrs.length;

	while ( i-- ) {
		Expr.attrHandle[ arr[i] ] = handler;
	}
}

/**
 * Checks document order of two siblings
 * @param {Element} a
 * @param {Element} b
 * @returns {Number} Returns less than 0 if a precedes b, greater than 0 if a follows b
 */
function siblingCheck( a, b ) {
	var cur = b && a,
		diff = cur && a.nodeType === 1 && b.nodeType === 1 &&
			( ~b.sourceIndex || MAX_NEGATIVE ) -
			( ~a.sourceIndex || MAX_NEGATIVE );

	// Use IE sourceIndex if available on both nodes
	if ( diff ) {
		return diff;
	}

	// Check if b follows a
	if ( cur ) {
		while ( (cur = cur.nextSibling) ) {
			if ( cur === b ) {
				return -1;
			}
		}
	}

	return a ? 1 : -1;
}

/**
 * Returns a function to use in pseudos for input types
 * @param {String} type
 */
function createInputPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return name === "input" && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for buttons
 * @param {String} type
 */
function createButtonPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return (name === "input" || name === "button") && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for positionals
 * @param {Function} fn
 */
function createPositionalPseudo( fn ) {
	return markFunction(function( argument ) {
		argument = +argument;
		return markFunction(function( seed, matches ) {
			var j,
				matchIndexes = fn( [], seed.length, argument ),
				i = matchIndexes.length;

			// Match elements found at the specified indexes
			while ( i-- ) {
				if ( seed[ (j = matchIndexes[i]) ] ) {
					seed[j] = !(matches[j] = seed[j]);
				}
			}
		});
	});
}

/**
 * Checks a node for validity as a Sizzle context
 * @param {Element|Object=} context
 * @returns {Element|Object|Boolean} The input node if acceptable, otherwise a falsy value
 */
function testContext( context ) {
	return context && typeof context.getElementsByTagName !== "undefined" && context;
}

// Expose support vars for convenience
support = Sizzle.support = {};

/**
 * Detects XML nodes
 * @param {Element|Object} elem An element or a document
 * @returns {Boolean} True iff elem is a non-HTML XML node
 */
isXML = Sizzle.isXML = function( elem ) {
	// documentElement is verified for cases where it doesn't yet exist
	// (such as loading iframes in IE - #4833)
	var documentElement = elem && (elem.ownerDocument || elem).documentElement;
	return documentElement ? documentElement.nodeName !== "HTML" : false;
};

/**
 * Sets document-related variables once based on the current document
 * @param {Element|Object} [doc] An element or document object to use to set the document
 * @returns {Object} Returns the current document
 */
setDocument = Sizzle.setDocument = function( node ) {
	var hasCompare, parent,
		doc = node ? node.ownerDocument || node : preferredDoc;

	// If no document and documentElement is available, return
	if ( doc === document || doc.nodeType !== 9 || !doc.documentElement ) {
		return document;
	}

	// Set our document
	document = doc;
	docElem = doc.documentElement;
	parent = doc.defaultView;

	// Support: IE>8
	// If iframe document is assigned to "document" variable and if iframe has been reloaded,
	// IE will throw "permission denied" error when accessing "document" variable, see jQuery #13936
	// IE6-8 do not support the defaultView property so parent will be undefined
	if ( parent && parent !== parent.top ) {
		// IE11 does not have attachEvent, so all must suffer
		if ( parent.addEventListener ) {
			parent.addEventListener( "unload", unloadHandler, false );
		} else if ( parent.attachEvent ) {
			parent.attachEvent( "onunload", unloadHandler );
		}
	}

	/* Support tests
	---------------------------------------------------------------------- */
	documentIsHTML = !isXML( doc );

	/* Attributes
	---------------------------------------------------------------------- */

	// Support: IE<8
	// Verify that getAttribute really returns attributes and not properties
	// (excepting IE8 booleans)
	support.attributes = assert(function( div ) {
		div.className = "i";
		return !div.getAttribute("className");
	});

	/* getElement(s)By*
	---------------------------------------------------------------------- */

	// Check if getElementsByTagName("*") returns only elements
	support.getElementsByTagName = assert(function( div ) {
		div.appendChild( doc.createComment("") );
		return !div.getElementsByTagName("*").length;
	});

	// Support: IE<9
	support.getElementsByClassName = rnative.test( doc.getElementsByClassName );

	// Support: IE<10
	// Check if getElementById returns elements by name
	// The broken getElementById methods don't pick up programatically-set names,
	// so use a roundabout getElementsByName test
	support.getById = assert(function( div ) {
		docElem.appendChild( div ).id = expando;
		return !doc.getElementsByName || !doc.getElementsByName( expando ).length;
	});

	// ID find and filter
	if ( support.getById ) {
		Expr.find["ID"] = function( id, context ) {
			if ( typeof context.getElementById !== "undefined" && documentIsHTML ) {
				var m = context.getElementById( id );
				// Check parentNode to catch when Blackberry 4.6 returns
				// nodes that are no longer in the document #6963
				return m && m.parentNode ? [ m ] : [];
			}
		};
		Expr.filter["ID"] = function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				return elem.getAttribute("id") === attrId;
			};
		};
	} else {
		// Support: IE6/7
		// getElementById is not reliable as a find shortcut
		delete Expr.find["ID"];

		Expr.filter["ID"] =  function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				var node = typeof elem.getAttributeNode !== "undefined" && elem.getAttributeNode("id");
				return node && node.value === attrId;
			};
		};
	}

	// Tag
	Expr.find["TAG"] = support.getElementsByTagName ?
		function( tag, context ) {
			if ( typeof context.getElementsByTagName !== "undefined" ) {
				return context.getElementsByTagName( tag );

			// DocumentFragment nodes don't have gEBTN
			} else if ( support.qsa ) {
				return context.querySelectorAll( tag );
			}
		} :

		function( tag, context ) {
			var elem,
				tmp = [],
				i = 0,
				// By happy coincidence, a (broken) gEBTN appears on DocumentFragment nodes too
				results = context.getElementsByTagName( tag );

			// Filter out possible comments
			if ( tag === "*" ) {
				while ( (elem = results[i++]) ) {
					if ( elem.nodeType === 1 ) {
						tmp.push( elem );
					}
				}

				return tmp;
			}
			return results;
		};

	// Class
	Expr.find["CLASS"] = support.getElementsByClassName && function( className, context ) {
		if ( documentIsHTML ) {
			return context.getElementsByClassName( className );
		}
	};

	/* QSA/matchesSelector
	---------------------------------------------------------------------- */

	// QSA and matchesSelector support

	// matchesSelector(:active) reports false when true (IE9/Opera 11.5)
	rbuggyMatches = [];

	// qSa(:focus) reports false when true (Chrome 21)
	// We allow this because of a bug in IE8/9 that throws an error
	// whenever `document.activeElement` is accessed on an iframe
	// So, we allow :focus to pass through QSA all the time to avoid the IE error
	// See http://bugs.jquery.com/ticket/13378
	rbuggyQSA = [];

	if ( (support.qsa = rnative.test( doc.querySelectorAll )) ) {
		// Build QSA regex
		// Regex strategy adopted from Diego Perini
		assert(function( div ) {
			// Select is set to empty string on purpose
			// This is to test IE's treatment of not explicitly
			// setting a boolean content attribute,
			// since its presence should be enough
			// http://bugs.jquery.com/ticket/12359
			docElem.appendChild( div ).innerHTML = "<a id='" + expando + "'></a>" +
				"<select id='" + expando + "-\f]' msallowcapture=''>" +
				"<option selected=''></option></select>";

			// Support: IE8, Opera 11-12.16
			// Nothing should be selected when empty strings follow ^= or $= or *=
			// The test attribute must be unknown in Opera but "safe" for WinRT
			// http://msdn.microsoft.com/en-us/library/ie/hh465388.aspx#attribute_section
			if ( div.querySelectorAll("[msallowcapture^='']").length ) {
				rbuggyQSA.push( "[*^$]=" + whitespace + "*(?:''|\"\")" );
			}

			// Support: IE8
			// Boolean attributes and "value" are not treated correctly
			if ( !div.querySelectorAll("[selected]").length ) {
				rbuggyQSA.push( "\\[" + whitespace + "*(?:value|" + booleans + ")" );
			}

			// Support: Chrome<29, Android<4.2+, Safari<7.0+, iOS<7.0+, PhantomJS<1.9.7+
			if ( !div.querySelectorAll( "[id~=" + expando + "-]" ).length ) {
				rbuggyQSA.push("~=");
			}

			// Webkit/Opera - :checked should return selected option elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":checked").length ) {
				rbuggyQSA.push(":checked");
			}

			// Support: Safari 8+, iOS 8+
			// https://bugs.webkit.org/show_bug.cgi?id=136851
			// In-page `selector#id sibing-combinator selector` fails
			if ( !div.querySelectorAll( "a#" + expando + "+*" ).length ) {
				rbuggyQSA.push(".#.+[+~]");
			}
		});

		assert(function( div ) {
			// Support: Windows 8 Native Apps
			// The type and name attributes are restricted during .innerHTML assignment
			var input = doc.createElement("input");
			input.setAttribute( "type", "hidden" );
			div.appendChild( input ).setAttribute( "name", "D" );

			// Support: IE8
			// Enforce case-sensitivity of name attribute
			if ( div.querySelectorAll("[name=d]").length ) {
				rbuggyQSA.push( "name" + whitespace + "*[*^$|!~]?=" );
			}

			// FF 3.5 - :enabled/:disabled and hidden elements (hidden elements are still enabled)
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":enabled").length ) {
				rbuggyQSA.push( ":enabled", ":disabled" );
			}

			// Opera 10-11 does not throw on post-comma invalid pseudos
			div.querySelectorAll("*,:x");
			rbuggyQSA.push(",.*:");
		});
	}

	if ( (support.matchesSelector = rnative.test( (matches = docElem.matches ||
		docElem.webkitMatchesSelector ||
		docElem.mozMatchesSelector ||
		docElem.oMatchesSelector ||
		docElem.msMatchesSelector) )) ) {

		assert(function( div ) {
			// Check to see if it's possible to do matchesSelector
			// on a disconnected node (IE 9)
			support.disconnectedMatch = matches.call( div, "div" );

			// This should fail with an exception
			// Gecko does not error, returns false instead
			matches.call( div, "[s!='']:x" );
			rbuggyMatches.push( "!=", pseudos );
		});
	}

	rbuggyQSA = rbuggyQSA.length && new RegExp( rbuggyQSA.join("|") );
	rbuggyMatches = rbuggyMatches.length && new RegExp( rbuggyMatches.join("|") );

	/* Contains
	---------------------------------------------------------------------- */
	hasCompare = rnative.test( docElem.compareDocumentPosition );

	// Element contains another
	// Purposefully does not implement inclusive descendent
	// As in, an element does not contain itself
	contains = hasCompare || rnative.test( docElem.contains ) ?
		function( a, b ) {
			var adown = a.nodeType === 9 ? a.documentElement : a,
				bup = b && b.parentNode;
			return a === bup || !!( bup && bup.nodeType === 1 && (
				adown.contains ?
					adown.contains( bup ) :
					a.compareDocumentPosition && a.compareDocumentPosition( bup ) & 16
			));
		} :
		function( a, b ) {
			if ( b ) {
				while ( (b = b.parentNode) ) {
					if ( b === a ) {
						return true;
					}
				}
			}
			return false;
		};

	/* Sorting
	---------------------------------------------------------------------- */

	// Document order sorting
	sortOrder = hasCompare ?
	function( a, b ) {

		// Flag for duplicate removal
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		// Sort on method existence if only one input has compareDocumentPosition
		var compare = !a.compareDocumentPosition - !b.compareDocumentPosition;
		if ( compare ) {
			return compare;
		}

		// Calculate position if both inputs belong to the same document
		compare = ( a.ownerDocument || a ) === ( b.ownerDocument || b ) ?
			a.compareDocumentPosition( b ) :

			// Otherwise we know they are disconnected
			1;

		// Disconnected nodes
		if ( compare & 1 ||
			(!support.sortDetached && b.compareDocumentPosition( a ) === compare) ) {

			// Choose the first element that is related to our preferred document
			if ( a === doc || a.ownerDocument === preferredDoc && contains(preferredDoc, a) ) {
				return -1;
			}
			if ( b === doc || b.ownerDocument === preferredDoc && contains(preferredDoc, b) ) {
				return 1;
			}

			// Maintain original order
			return sortInput ?
				( indexOf( sortInput, a ) - indexOf( sortInput, b ) ) :
				0;
		}

		return compare & 4 ? -1 : 1;
	} :
	function( a, b ) {
		// Exit early if the nodes are identical
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		var cur,
			i = 0,
			aup = a.parentNode,
			bup = b.parentNode,
			ap = [ a ],
			bp = [ b ];

		// Parentless nodes are either documents or disconnected
		if ( !aup || !bup ) {
			return a === doc ? -1 :
				b === doc ? 1 :
				aup ? -1 :
				bup ? 1 :
				sortInput ?
				( indexOf( sortInput, a ) - indexOf( sortInput, b ) ) :
				0;

		// If the nodes are siblings, we can do a quick check
		} else if ( aup === bup ) {
			return siblingCheck( a, b );
		}

		// Otherwise we need full lists of their ancestors for comparison
		cur = a;
		while ( (cur = cur.parentNode) ) {
			ap.unshift( cur );
		}
		cur = b;
		while ( (cur = cur.parentNode) ) {
			bp.unshift( cur );
		}

		// Walk down the tree looking for a discrepancy
		while ( ap[i] === bp[i] ) {
			i++;
		}

		return i ?
			// Do a sibling check if the nodes have a common ancestor
			siblingCheck( ap[i], bp[i] ) :

			// Otherwise nodes in our document sort first
			ap[i] === preferredDoc ? -1 :
			bp[i] === preferredDoc ? 1 :
			0;
	};

	return doc;
};

Sizzle.matches = function( expr, elements ) {
	return Sizzle( expr, null, null, elements );
};

Sizzle.matchesSelector = function( elem, expr ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	// Make sure that attribute selectors are quoted
	expr = expr.replace( rattributeQuotes, "='$1']" );

	if ( support.matchesSelector && documentIsHTML &&
		( !rbuggyMatches || !rbuggyMatches.test( expr ) ) &&
		( !rbuggyQSA     || !rbuggyQSA.test( expr ) ) ) {

		try {
			var ret = matches.call( elem, expr );

			// IE 9's matchesSelector returns false on disconnected nodes
			if ( ret || support.disconnectedMatch ||
					// As well, disconnected nodes are said to be in a document
					// fragment in IE 9
					elem.document && elem.document.nodeType !== 11 ) {
				return ret;
			}
		} catch (e) {}
	}

	return Sizzle( expr, document, null, [ elem ] ).length > 0;
};

Sizzle.contains = function( context, elem ) {
	// Set document vars if needed
	if ( ( context.ownerDocument || context ) !== document ) {
		setDocument( context );
	}
	return contains( context, elem );
};

Sizzle.attr = function( elem, name ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	var fn = Expr.attrHandle[ name.toLowerCase() ],
		// Don't get fooled by Object.prototype properties (jQuery #13807)
		val = fn && hasOwn.call( Expr.attrHandle, name.toLowerCase() ) ?
			fn( elem, name, !documentIsHTML ) :
			undefined;

	return val !== undefined ?
		val :
		support.attributes || !documentIsHTML ?
			elem.getAttribute( name ) :
			(val = elem.getAttributeNode(name)) && val.specified ?
				val.value :
				null;
};

Sizzle.error = function( msg ) {
	throw new Error( "Syntax error, unrecognized expression: " + msg );
};

/**
 * Document sorting and removing duplicates
 * @param {ArrayLike} results
 */
Sizzle.uniqueSort = function( results ) {
	var elem,
		duplicates = [],
		j = 0,
		i = 0;

	// Unless we *know* we can detect duplicates, assume their presence
	hasDuplicate = !support.detectDuplicates;
	sortInput = !support.sortStable && results.slice( 0 );
	results.sort( sortOrder );

	if ( hasDuplicate ) {
		while ( (elem = results[i++]) ) {
			if ( elem === results[ i ] ) {
				j = duplicates.push( i );
			}
		}
		while ( j-- ) {
			results.splice( duplicates[ j ], 1 );
		}
	}

	// Clear input after sorting to release objects
	// See https://github.com/jquery/sizzle/pull/225
	sortInput = null;

	return results;
};

/**
 * Utility function for retrieving the text value of an array of DOM nodes
 * @param {Array|Element} elem
 */
getText = Sizzle.getText = function( elem ) {
	var node,
		ret = "",
		i = 0,
		nodeType = elem.nodeType;

	if ( !nodeType ) {
		// If no nodeType, this is expected to be an array
		while ( (node = elem[i++]) ) {
			// Do not traverse comment nodes
			ret += getText( node );
		}
	} else if ( nodeType === 1 || nodeType === 9 || nodeType === 11 ) {
		// Use textContent for elements
		// innerText usage removed for consistency of new lines (jQuery #11153)
		if ( typeof elem.textContent === "string" ) {
			return elem.textContent;
		} else {
			// Traverse its children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				ret += getText( elem );
			}
		}
	} else if ( nodeType === 3 || nodeType === 4 ) {
		return elem.nodeValue;
	}
	// Do not include comment or processing instruction nodes

	return ret;
};

Expr = Sizzle.selectors = {

	// Can be adjusted by the user
	cacheLength: 50,

	createPseudo: markFunction,

	match: matchExpr,

	attrHandle: {},

	find: {},

	relative: {
		">": { dir: "parentNode", first: true },
		" ": { dir: "parentNode" },
		"+": { dir: "previousSibling", first: true },
		"~": { dir: "previousSibling" }
	},

	preFilter: {
		"ATTR": function( match ) {
			match[1] = match[1].replace( runescape, funescape );

			// Move the given value to match[3] whether quoted or unquoted
			match[3] = ( match[3] || match[4] || match[5] || "" ).replace( runescape, funescape );

			if ( match[2] === "~=" ) {
				match[3] = " " + match[3] + " ";
			}

			return match.slice( 0, 4 );
		},

		"CHILD": function( match ) {
			/* matches from matchExpr["CHILD"]
				1 type (only|nth|...)
				2 what (child|of-type)
				3 argument (even|odd|\d*|\d*n([+-]\d+)?|...)
				4 xn-component of xn+y argument ([+-]?\d*n|)
				5 sign of xn-component
				6 x of xn-component
				7 sign of y-component
				8 y of y-component
			*/
			match[1] = match[1].toLowerCase();

			if ( match[1].slice( 0, 3 ) === "nth" ) {
				// nth-* requires argument
				if ( !match[3] ) {
					Sizzle.error( match[0] );
				}

				// numeric x and y parameters for Expr.filter.CHILD
				// remember that false/true cast respectively to 0/1
				match[4] = +( match[4] ? match[5] + (match[6] || 1) : 2 * ( match[3] === "even" || match[3] === "odd" ) );
				match[5] = +( ( match[7] + match[8] ) || match[3] === "odd" );

			// other types prohibit arguments
			} else if ( match[3] ) {
				Sizzle.error( match[0] );
			}

			return match;
		},

		"PSEUDO": function( match ) {
			var excess,
				unquoted = !match[6] && match[2];

			if ( matchExpr["CHILD"].test( match[0] ) ) {
				return null;
			}

			// Accept quoted arguments as-is
			if ( match[3] ) {
				match[2] = match[4] || match[5] || "";

			// Strip excess characters from unquoted arguments
			} else if ( unquoted && rpseudo.test( unquoted ) &&
				// Get excess from tokenize (recursively)
				(excess = tokenize( unquoted, true )) &&
				// advance to the next closing parenthesis
				(excess = unquoted.indexOf( ")", unquoted.length - excess ) - unquoted.length) ) {

				// excess is a negative index
				match[0] = match[0].slice( 0, excess );
				match[2] = unquoted.slice( 0, excess );
			}

			// Return only captures needed by the pseudo filter method (type and argument)
			return match.slice( 0, 3 );
		}
	},

	filter: {

		"TAG": function( nodeNameSelector ) {
			var nodeName = nodeNameSelector.replace( runescape, funescape ).toLowerCase();
			return nodeNameSelector === "*" ?
				function() { return true; } :
				function( elem ) {
					return elem.nodeName && elem.nodeName.toLowerCase() === nodeName;
				};
		},

		"CLASS": function( className ) {
			var pattern = classCache[ className + " " ];

			return pattern ||
				(pattern = new RegExp( "(^|" + whitespace + ")" + className + "(" + whitespace + "|$)" )) &&
				classCache( className, function( elem ) {
					return pattern.test( typeof elem.className === "string" && elem.className || typeof elem.getAttribute !== "undefined" && elem.getAttribute("class") || "" );
				});
		},

		"ATTR": function( name, operator, check ) {
			return function( elem ) {
				var result = Sizzle.attr( elem, name );

				if ( result == null ) {
					return operator === "!=";
				}
				if ( !operator ) {
					return true;
				}

				result += "";

				return operator === "=" ? result === check :
					operator === "!=" ? result !== check :
					operator === "^=" ? check && result.indexOf( check ) === 0 :
					operator === "*=" ? check && result.indexOf( check ) > -1 :
					operator === "$=" ? check && result.slice( -check.length ) === check :
					operator === "~=" ? ( " " + result.replace( rwhitespace, " " ) + " " ).indexOf( check ) > -1 :
					operator === "|=" ? result === check || result.slice( 0, check.length + 1 ) === check + "-" :
					false;
			};
		},

		"CHILD": function( type, what, argument, first, last ) {
			var simple = type.slice( 0, 3 ) !== "nth",
				forward = type.slice( -4 ) !== "last",
				ofType = what === "of-type";

			return first === 1 && last === 0 ?

				// Shortcut for :nth-*(n)
				function( elem ) {
					return !!elem.parentNode;
				} :

				function( elem, context, xml ) {
					var cache, outerCache, node, diff, nodeIndex, start,
						dir = simple !== forward ? "nextSibling" : "previousSibling",
						parent = elem.parentNode,
						name = ofType && elem.nodeName.toLowerCase(),
						useCache = !xml && !ofType;

					if ( parent ) {

						// :(first|last|only)-(child|of-type)
						if ( simple ) {
							while ( dir ) {
								node = elem;
								while ( (node = node[ dir ]) ) {
									if ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) {
										return false;
									}
								}
								// Reverse direction for :only-* (if we haven't yet done so)
								start = dir = type === "only" && !start && "nextSibling";
							}
							return true;
						}

						start = [ forward ? parent.firstChild : parent.lastChild ];

						// non-xml :nth-child(...) stores cache data on `parent`
						if ( forward && useCache ) {
							// Seek `elem` from a previously-cached index
							outerCache = parent[ expando ] || (parent[ expando ] = {});
							cache = outerCache[ type ] || [];
							nodeIndex = cache[0] === dirruns && cache[1];
							diff = cache[0] === dirruns && cache[2];
							node = nodeIndex && parent.childNodes[ nodeIndex ];

							while ( (node = ++nodeIndex && node && node[ dir ] ||

								// Fallback to seeking `elem` from the start
								(diff = nodeIndex = 0) || start.pop()) ) {

								// When found, cache indexes on `parent` and break
								if ( node.nodeType === 1 && ++diff && node === elem ) {
									outerCache[ type ] = [ dirruns, nodeIndex, diff ];
									break;
								}
							}

						// Use previously-cached element index if available
						} else if ( useCache && (cache = (elem[ expando ] || (elem[ expando ] = {}))[ type ]) && cache[0] === dirruns ) {
							diff = cache[1];

						// xml :nth-child(...) or :nth-last-child(...) or :nth(-last)?-of-type(...)
						} else {
							// Use the same loop as above to seek `elem` from the start
							while ( (node = ++nodeIndex && node && node[ dir ] ||
								(diff = nodeIndex = 0) || start.pop()) ) {

								if ( ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) && ++diff ) {
									// Cache the index of each encountered element
									if ( useCache ) {
										(node[ expando ] || (node[ expando ] = {}))[ type ] = [ dirruns, diff ];
									}

									if ( node === elem ) {
										break;
									}
								}
							}
						}

						// Incorporate the offset, then check against cycle size
						diff -= last;
						return diff === first || ( diff % first === 0 && diff / first >= 0 );
					}
				};
		},

		"PSEUDO": function( pseudo, argument ) {
			// pseudo-class names are case-insensitive
			// http://www.w3.org/TR/selectors/#pseudo-classes
			// Prioritize by case sensitivity in case custom pseudos are added with uppercase letters
			// Remember that setFilters inherits from pseudos
			var args,
				fn = Expr.pseudos[ pseudo ] || Expr.setFilters[ pseudo.toLowerCase() ] ||
					Sizzle.error( "unsupported pseudo: " + pseudo );

			// The user may use createPseudo to indicate that
			// arguments are needed to create the filter function
			// just as Sizzle does
			if ( fn[ expando ] ) {
				return fn( argument );
			}

			// But maintain support for old signatures
			if ( fn.length > 1 ) {
				args = [ pseudo, pseudo, "", argument ];
				return Expr.setFilters.hasOwnProperty( pseudo.toLowerCase() ) ?
					markFunction(function( seed, matches ) {
						var idx,
							matched = fn( seed, argument ),
							i = matched.length;
						while ( i-- ) {
							idx = indexOf( seed, matched[i] );
							seed[ idx ] = !( matches[ idx ] = matched[i] );
						}
					}) :
					function( elem ) {
						return fn( elem, 0, args );
					};
			}

			return fn;
		}
	},

	pseudos: {
		// Potentially complex pseudos
		"not": markFunction(function( selector ) {
			// Trim the selector passed to compile
			// to avoid treating leading and trailing
			// spaces as combinators
			var input = [],
				results = [],
				matcher = compile( selector.replace( rtrim, "$1" ) );

			return matcher[ expando ] ?
				markFunction(function( seed, matches, context, xml ) {
					var elem,
						unmatched = matcher( seed, null, xml, [] ),
						i = seed.length;

					// Match elements unmatched by `matcher`
					while ( i-- ) {
						if ( (elem = unmatched[i]) ) {
							seed[i] = !(matches[i] = elem);
						}
					}
				}) :
				function( elem, context, xml ) {
					input[0] = elem;
					matcher( input, null, xml, results );
					// Don't keep the element (issue #299)
					input[0] = null;
					return !results.pop();
				};
		}),

		"has": markFunction(function( selector ) {
			return function( elem ) {
				return Sizzle( selector, elem ).length > 0;
			};
		}),

		"contains": markFunction(function( text ) {
			text = text.replace( runescape, funescape );
			return function( elem ) {
				return ( elem.textContent || elem.innerText || getText( elem ) ).indexOf( text ) > -1;
			};
		}),

		// "Whether an element is represented by a :lang() selector
		// is based solely on the element's language value
		// being equal to the identifier C,
		// or beginning with the identifier C immediately followed by "-".
		// The matching of C against the element's language value is performed case-insensitively.
		// The identifier C does not have to be a valid language name."
		// http://www.w3.org/TR/selectors/#lang-pseudo
		"lang": markFunction( function( lang ) {
			// lang value must be a valid identifier
			if ( !ridentifier.test(lang || "") ) {
				Sizzle.error( "unsupported lang: " + lang );
			}
			lang = lang.replace( runescape, funescape ).toLowerCase();
			return function( elem ) {
				var elemLang;
				do {
					if ( (elemLang = documentIsHTML ?
						elem.lang :
						elem.getAttribute("xml:lang") || elem.getAttribute("lang")) ) {

						elemLang = elemLang.toLowerCase();
						return elemLang === lang || elemLang.indexOf( lang + "-" ) === 0;
					}
				} while ( (elem = elem.parentNode) && elem.nodeType === 1 );
				return false;
			};
		}),

		// Miscellaneous
		"target": function( elem ) {
			var hash = window.location && window.location.hash;
			return hash && hash.slice( 1 ) === elem.id;
		},

		"root": function( elem ) {
			return elem === docElem;
		},

		"focus": function( elem ) {
			return elem === document.activeElement && (!document.hasFocus || document.hasFocus()) && !!(elem.type || elem.href || ~elem.tabIndex);
		},

		// Boolean properties
		"enabled": function( elem ) {
			return elem.disabled === false;
		},

		"disabled": function( elem ) {
			return elem.disabled === true;
		},

		"checked": function( elem ) {
			// In CSS3, :checked should return both checked and selected elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			var nodeName = elem.nodeName.toLowerCase();
			return (nodeName === "input" && !!elem.checked) || (nodeName === "option" && !!elem.selected);
		},

		"selected": function( elem ) {
			// Accessing this property makes selected-by-default
			// options in Safari work properly
			if ( elem.parentNode ) {
				elem.parentNode.selectedIndex;
			}

			return elem.selected === true;
		},

		// Contents
		"empty": function( elem ) {
			// http://www.w3.org/TR/selectors/#empty-pseudo
			// :empty is negated by element (1) or content nodes (text: 3; cdata: 4; entity ref: 5),
			//   but not by others (comment: 8; processing instruction: 7; etc.)
			// nodeType < 6 works because attributes (2) do not appear as children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				if ( elem.nodeType < 6 ) {
					return false;
				}
			}
			return true;
		},

		"parent": function( elem ) {
			return !Expr.pseudos["empty"]( elem );
		},

		// Element/input types
		"header": function( elem ) {
			return rheader.test( elem.nodeName );
		},

		"input": function( elem ) {
			return rinputs.test( elem.nodeName );
		},

		"button": function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return name === "input" && elem.type === "button" || name === "button";
		},

		"text": function( elem ) {
			var attr;
			return elem.nodeName.toLowerCase() === "input" &&
				elem.type === "text" &&

				// Support: IE<8
				// New HTML5 attribute values (e.g., "search") appear with elem.type === "text"
				( (attr = elem.getAttribute("type")) == null || attr.toLowerCase() === "text" );
		},

		// Position-in-collection
		"first": createPositionalPseudo(function() {
			return [ 0 ];
		}),

		"last": createPositionalPseudo(function( matchIndexes, length ) {
			return [ length - 1 ];
		}),

		"eq": createPositionalPseudo(function( matchIndexes, length, argument ) {
			return [ argument < 0 ? argument + length : argument ];
		}),

		"even": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 0;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"odd": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 1;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"lt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; --i >= 0; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"gt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; ++i < length; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		})
	}
};

Expr.pseudos["nth"] = Expr.pseudos["eq"];

// Add button/input type pseudos
for ( i in { radio: true, checkbox: true, file: true, password: true, image: true } ) {
	Expr.pseudos[ i ] = createInputPseudo( i );
}
for ( i in { submit: true, reset: true } ) {
	Expr.pseudos[ i ] = createButtonPseudo( i );
}

// Easy API for creating new setFilters
function setFilters() {}
setFilters.prototype = Expr.filters = Expr.pseudos;
Expr.setFilters = new setFilters();

tokenize = Sizzle.tokenize = function( selector, parseOnly ) {
	var matched, match, tokens, type,
		soFar, groups, preFilters,
		cached = tokenCache[ selector + " " ];

	if ( cached ) {
		return parseOnly ? 0 : cached.slice( 0 );
	}

	soFar = selector;
	groups = [];
	preFilters = Expr.preFilter;

	while ( soFar ) {

		// Comma and first run
		if ( !matched || (match = rcomma.exec( soFar )) ) {
			if ( match ) {
				// Don't consume trailing commas as valid
				soFar = soFar.slice( match[0].length ) || soFar;
			}
			groups.push( (tokens = []) );
		}

		matched = false;

		// Combinators
		if ( (match = rcombinators.exec( soFar )) ) {
			matched = match.shift();
			tokens.push({
				value: matched,
				// Cast descendant combinators to space
				type: match[0].replace( rtrim, " " )
			});
			soFar = soFar.slice( matched.length );
		}

		// Filters
		for ( type in Expr.filter ) {
			if ( (match = matchExpr[ type ].exec( soFar )) && (!preFilters[ type ] ||
				(match = preFilters[ type ]( match ))) ) {
				matched = match.shift();
				tokens.push({
					value: matched,
					type: type,
					matches: match
				});
				soFar = soFar.slice( matched.length );
			}
		}

		if ( !matched ) {
			break;
		}
	}

	// Return the length of the invalid excess
	// if we're just parsing
	// Otherwise, throw an error or return tokens
	return parseOnly ?
		soFar.length :
		soFar ?
			Sizzle.error( selector ) :
			// Cache the tokens
			tokenCache( selector, groups ).slice( 0 );
};

function toSelector( tokens ) {
	var i = 0,
		len = tokens.length,
		selector = "";
	for ( ; i < len; i++ ) {
		selector += tokens[i].value;
	}
	return selector;
}

function addCombinator( matcher, combinator, base ) {
	var dir = combinator.dir,
		checkNonElements = base && dir === "parentNode",
		doneName = done++;

	return combinator.first ?
		// Check against closest ancestor/preceding element
		function( elem, context, xml ) {
			while ( (elem = elem[ dir ]) ) {
				if ( elem.nodeType === 1 || checkNonElements ) {
					return matcher( elem, context, xml );
				}
			}
		} :

		// Check against all ancestor/preceding elements
		function( elem, context, xml ) {
			var oldCache, outerCache,
				newCache = [ dirruns, doneName ];

			// We can't set arbitrary data on XML nodes, so they don't benefit from dir caching
			if ( xml ) {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						if ( matcher( elem, context, xml ) ) {
							return true;
						}
					}
				}
			} else {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						outerCache = elem[ expando ] || (elem[ expando ] = {});
						if ( (oldCache = outerCache[ dir ]) &&
							oldCache[ 0 ] === dirruns && oldCache[ 1 ] === doneName ) {

							// Assign to newCache so results back-propagate to previous elements
							return (newCache[ 2 ] = oldCache[ 2 ]);
						} else {
							// Reuse newcache so results back-propagate to previous elements
							outerCache[ dir ] = newCache;

							// A match means we're done; a fail means we have to keep checking
							if ( (newCache[ 2 ] = matcher( elem, context, xml )) ) {
								return true;
							}
						}
					}
				}
			}
		};
}

function elementMatcher( matchers ) {
	return matchers.length > 1 ?
		function( elem, context, xml ) {
			var i = matchers.length;
			while ( i-- ) {
				if ( !matchers[i]( elem, context, xml ) ) {
					return false;
				}
			}
			return true;
		} :
		matchers[0];
}

function multipleContexts( selector, contexts, results ) {
	var i = 0,
		len = contexts.length;
	for ( ; i < len; i++ ) {
		Sizzle( selector, contexts[i], results );
	}
	return results;
}

function condense( unmatched, map, filter, context, xml ) {
	var elem,
		newUnmatched = [],
		i = 0,
		len = unmatched.length,
		mapped = map != null;

	for ( ; i < len; i++ ) {
		if ( (elem = unmatched[i]) ) {
			if ( !filter || filter( elem, context, xml ) ) {
				newUnmatched.push( elem );
				if ( mapped ) {
					map.push( i );
				}
			}
		}
	}

	return newUnmatched;
}

function setMatcher( preFilter, selector, matcher, postFilter, postFinder, postSelector ) {
	if ( postFilter && !postFilter[ expando ] ) {
		postFilter = setMatcher( postFilter );
	}
	if ( postFinder && !postFinder[ expando ] ) {
		postFinder = setMatcher( postFinder, postSelector );
	}
	return markFunction(function( seed, results, context, xml ) {
		var temp, i, elem,
			preMap = [],
			postMap = [],
			preexisting = results.length,

			// Get initial elements from seed or context
			elems = seed || multipleContexts( selector || "*", context.nodeType ? [ context ] : context, [] ),

			// Prefilter to get matcher input, preserving a map for seed-results synchronization
			matcherIn = preFilter && ( seed || !selector ) ?
				condense( elems, preMap, preFilter, context, xml ) :
				elems,

			matcherOut = matcher ?
				// If we have a postFinder, or filtered seed, or non-seed postFilter or preexisting results,
				postFinder || ( seed ? preFilter : preexisting || postFilter ) ?

					// ...intermediate processing is necessary
					[] :

					// ...otherwise use results directly
					results :
				matcherIn;

		// Find primary matches
		if ( matcher ) {
			matcher( matcherIn, matcherOut, context, xml );
		}

		// Apply postFilter
		if ( postFilter ) {
			temp = condense( matcherOut, postMap );
			postFilter( temp, [], context, xml );

			// Un-match failing elements by moving them back to matcherIn
			i = temp.length;
			while ( i-- ) {
				if ( (elem = temp[i]) ) {
					matcherOut[ postMap[i] ] = !(matcherIn[ postMap[i] ] = elem);
				}
			}
		}

		if ( seed ) {
			if ( postFinder || preFilter ) {
				if ( postFinder ) {
					// Get the final matcherOut by condensing this intermediate into postFinder contexts
					temp = [];
					i = matcherOut.length;
					while ( i-- ) {
						if ( (elem = matcherOut[i]) ) {
							// Restore matcherIn since elem is not yet a final match
							temp.push( (matcherIn[i] = elem) );
						}
					}
					postFinder( null, (matcherOut = []), temp, xml );
				}

				// Move matched elements from seed to results to keep them synchronized
				i = matcherOut.length;
				while ( i-- ) {
					if ( (elem = matcherOut[i]) &&
						(temp = postFinder ? indexOf( seed, elem ) : preMap[i]) > -1 ) {

						seed[temp] = !(results[temp] = elem);
					}
				}
			}

		// Add elements to results, through postFinder if defined
		} else {
			matcherOut = condense(
				matcherOut === results ?
					matcherOut.splice( preexisting, matcherOut.length ) :
					matcherOut
			);
			if ( postFinder ) {
				postFinder( null, results, matcherOut, xml );
			} else {
				push.apply( results, matcherOut );
			}
		}
	});
}

function matcherFromTokens( tokens ) {
	var checkContext, matcher, j,
		len = tokens.length,
		leadingRelative = Expr.relative[ tokens[0].type ],
		implicitRelative = leadingRelative || Expr.relative[" "],
		i = leadingRelative ? 1 : 0,

		// The foundational matcher ensures that elements are reachable from top-level context(s)
		matchContext = addCombinator( function( elem ) {
			return elem === checkContext;
		}, implicitRelative, true ),
		matchAnyContext = addCombinator( function( elem ) {
			return indexOf( checkContext, elem ) > -1;
		}, implicitRelative, true ),
		matchers = [ function( elem, context, xml ) {
			var ret = ( !leadingRelative && ( xml || context !== outermostContext ) ) || (
				(checkContext = context).nodeType ?
					matchContext( elem, context, xml ) :
					matchAnyContext( elem, context, xml ) );
			// Avoid hanging onto element (issue #299)
			checkContext = null;
			return ret;
		} ];

	for ( ; i < len; i++ ) {
		if ( (matcher = Expr.relative[ tokens[i].type ]) ) {
			matchers = [ addCombinator(elementMatcher( matchers ), matcher) ];
		} else {
			matcher = Expr.filter[ tokens[i].type ].apply( null, tokens[i].matches );

			// Return special upon seeing a positional matcher
			if ( matcher[ expando ] ) {
				// Find the next relative operator (if any) for proper handling
				j = ++i;
				for ( ; j < len; j++ ) {
					if ( Expr.relative[ tokens[j].type ] ) {
						break;
					}
				}
				return setMatcher(
					i > 1 && elementMatcher( matchers ),
					i > 1 && toSelector(
						// If the preceding token was a descendant combinator, insert an implicit any-element `*`
						tokens.slice( 0, i - 1 ).concat({ value: tokens[ i - 2 ].type === " " ? "*" : "" })
					).replace( rtrim, "$1" ),
					matcher,
					i < j && matcherFromTokens( tokens.slice( i, j ) ),
					j < len && matcherFromTokens( (tokens = tokens.slice( j )) ),
					j < len && toSelector( tokens )
				);
			}
			matchers.push( matcher );
		}
	}

	return elementMatcher( matchers );
}

function matcherFromGroupMatchers( elementMatchers, setMatchers ) {
	var bySet = setMatchers.length > 0,
		byElement = elementMatchers.length > 0,
		superMatcher = function( seed, context, xml, results, outermost ) {
			var elem, j, matcher,
				matchedCount = 0,
				i = "0",
				unmatched = seed && [],
				setMatched = [],
				contextBackup = outermostContext,
				// We must always have either seed elements or outermost context
				elems = seed || byElement && Expr.find["TAG"]( "*", outermost ),
				// Use integer dirruns iff this is the outermost matcher
				dirrunsUnique = (dirruns += contextBackup == null ? 1 : Math.random() || 0.1),
				len = elems.length;

			if ( outermost ) {
				outermostContext = context !== document && context;
			}

			// Add elements passing elementMatchers directly to results
			// Keep `i` a string if there are no elements so `matchedCount` will be "00" below
			// Support: IE<9, Safari
			// Tolerate NodeList properties (IE: "length"; Safari: <number>) matching elements by id
			for ( ; i !== len && (elem = elems[i]) != null; i++ ) {
				if ( byElement && elem ) {
					j = 0;
					while ( (matcher = elementMatchers[j++]) ) {
						if ( matcher( elem, context, xml ) ) {
							results.push( elem );
							break;
						}
					}
					if ( outermost ) {
						dirruns = dirrunsUnique;
					}
				}

				// Track unmatched elements for set filters
				if ( bySet ) {
					// They will have gone through all possible matchers
					if ( (elem = !matcher && elem) ) {
						matchedCount--;
					}

					// Lengthen the array for every element, matched or not
					if ( seed ) {
						unmatched.push( elem );
					}
				}
			}

			// Apply set filters to unmatched elements
			matchedCount += i;
			if ( bySet && i !== matchedCount ) {
				j = 0;
				while ( (matcher = setMatchers[j++]) ) {
					matcher( unmatched, setMatched, context, xml );
				}

				if ( seed ) {
					// Reintegrate element matches to eliminate the need for sorting
					if ( matchedCount > 0 ) {
						while ( i-- ) {
							if ( !(unmatched[i] || setMatched[i]) ) {
								setMatched[i] = pop.call( results );
							}
						}
					}

					// Discard index placeholder values to get only actual matches
					setMatched = condense( setMatched );
				}

				// Add matches to results
				push.apply( results, setMatched );

				// Seedless set matches succeeding multiple successful matchers stipulate sorting
				if ( outermost && !seed && setMatched.length > 0 &&
					( matchedCount + setMatchers.length ) > 1 ) {

					Sizzle.uniqueSort( results );
				}
			}

			// Override manipulation of globals by nested matchers
			if ( outermost ) {
				dirruns = dirrunsUnique;
				outermostContext = contextBackup;
			}

			return unmatched;
		};

	return bySet ?
		markFunction( superMatcher ) :
		superMatcher;
}

compile = Sizzle.compile = function( selector, match /* Internal Use Only */ ) {
	var i,
		setMatchers = [],
		elementMatchers = [],
		cached = compilerCache[ selector + " " ];

	if ( !cached ) {
		// Generate a function of recursive functions that can be used to check each element
		if ( !match ) {
			match = tokenize( selector );
		}
		i = match.length;
		while ( i-- ) {
			cached = matcherFromTokens( match[i] );
			if ( cached[ expando ] ) {
				setMatchers.push( cached );
			} else {
				elementMatchers.push( cached );
			}
		}

		// Cache the compiled function
		cached = compilerCache( selector, matcherFromGroupMatchers( elementMatchers, setMatchers ) );

		// Save selector and tokenization
		cached.selector = selector;
	}
	return cached;
};

/**
 * A low-level selection function that works with Sizzle's compiled
 *  selector functions
 * @param {String|Function} selector A selector or a pre-compiled
 *  selector function built with Sizzle.compile
 * @param {Element} context
 * @param {Array} [results]
 * @param {Array} [seed] A set of elements to match against
 */
select = Sizzle.select = function( selector, context, results, seed ) {
	var i, tokens, token, type, find,
		compiled = typeof selector === "function" && selector,
		match = !seed && tokenize( (selector = compiled.selector || selector) );

	results = results || [];

	// Try to minimize operations if there is no seed and only one group
	if ( match.length === 1 ) {

		// Take a shortcut and set the context if the root selector is an ID
		tokens = match[0] = match[0].slice( 0 );
		if ( tokens.length > 2 && (token = tokens[0]).type === "ID" &&
				support.getById && context.nodeType === 9 && documentIsHTML &&
				Expr.relative[ tokens[1].type ] ) {

			context = ( Expr.find["ID"]( token.matches[0].replace(runescape, funescape), context ) || [] )[0];
			if ( !context ) {
				return results;

			// Precompiled matchers will still verify ancestry, so step up a level
			} else if ( compiled ) {
				context = context.parentNode;
			}

			selector = selector.slice( tokens.shift().value.length );
		}

		// Fetch a seed set for right-to-left matching
		i = matchExpr["needsContext"].test( selector ) ? 0 : tokens.length;
		while ( i-- ) {
			token = tokens[i];

			// Abort if we hit a combinator
			if ( Expr.relative[ (type = token.type) ] ) {
				break;
			}
			if ( (find = Expr.find[ type ]) ) {
				// Search, expanding context for leading sibling combinators
				if ( (seed = find(
					token.matches[0].replace( runescape, funescape ),
					rsibling.test( tokens[0].type ) && testContext( context.parentNode ) || context
				)) ) {

					// If seed is empty or no tokens remain, we can return early
					tokens.splice( i, 1 );
					selector = seed.length && toSelector( tokens );
					if ( !selector ) {
						push.apply( results, seed );
						return results;
					}

					break;
				}
			}
		}
	}

	// Compile and execute a filtering function if one is not provided
	// Provide `match` to avoid retokenization if we modified the selector above
	( compiled || compile( selector, match ) )(
		seed,
		context,
		!documentIsHTML,
		results,
		rsibling.test( selector ) && testContext( context.parentNode ) || context
	);
	return results;
};

// One-time assignments

// Sort stability
support.sortStable = expando.split("").sort( sortOrder ).join("") === expando;

// Support: Chrome 14-35+
// Always assume duplicates if they aren't passed to the comparison function
support.detectDuplicates = !!hasDuplicate;

// Initialize against the default document
setDocument();

// Support: Webkit<537.32 - Safari 6.0.3/Chrome 25 (fixed in Chrome 27)
// Detached nodes confoundingly follow *each other*
support.sortDetached = assert(function( div1 ) {
	// Should return 1, but returns 4 (following)
	return div1.compareDocumentPosition( document.createElement("div") ) & 1;
});

// Support: IE<8
// Prevent attribute/property "interpolation"
// http://msdn.microsoft.com/en-us/library/ms536429%28VS.85%29.aspx
if ( !assert(function( div ) {
	div.innerHTML = "<a href='#'></a>";
	return div.firstChild.getAttribute("href") === "#" ;
}) ) {
	addHandle( "type|href|height|width", function( elem, name, isXML ) {
		if ( !isXML ) {
			return elem.getAttribute( name, name.toLowerCase() === "type" ? 1 : 2 );
		}
	});
}

// Support: IE<9
// Use defaultValue in place of getAttribute("value")
if ( !support.attributes || !assert(function( div ) {
	div.innerHTML = "<input/>";
	div.firstChild.setAttribute( "value", "" );
	return div.firstChild.getAttribute( "value" ) === "";
}) ) {
	addHandle( "value", function( elem, name, isXML ) {
		if ( !isXML && elem.nodeName.toLowerCase() === "input" ) {
			return elem.defaultValue;
		}
	});
}

// Support: IE<9
// Use getAttributeNode to fetch booleans when getAttribute lies
if ( !assert(function( div ) {
	return div.getAttribute("disabled") == null;
}) ) {
	addHandle( booleans, function( elem, name, isXML ) {
		var val;
		if ( !isXML ) {
			return elem[ name ] === true ? name.toLowerCase() :
					(val = elem.getAttributeNode( name )) && val.specified ?
					val.value :
				null;
		}
	});
}

return Sizzle;

})( window );



jQuery.find = Sizzle;
jQuery.expr = Sizzle.selectors;
jQuery.expr[":"] = jQuery.expr.pseudos;
jQuery.unique = Sizzle.uniqueSort;
jQuery.text = Sizzle.getText;
jQuery.isXMLDoc = Sizzle.isXML;
jQuery.contains = Sizzle.contains;



var rneedsContext = jQuery.expr.match.needsContext;

var rsingleTag = (/^<(\w+)\s*\/?>(?:<\/\1>|)$/);



var risSimple = /^.[^:#\[\.,]*$/;

// Implement the identical functionality for filter and not
function winnow( elements, qualifier, not ) {
	if ( jQuery.isFunction( qualifier ) ) {
		return jQuery.grep( elements, function( elem, i ) {
			/* jshint -W018 */
			return !!qualifier.call( elem, i, elem ) !== not;
		});

	}

	if ( qualifier.nodeType ) {
		return jQuery.grep( elements, function( elem ) {
			return ( elem === qualifier ) !== not;
		});

	}

	if ( typeof qualifier === "string" ) {
		if ( risSimple.test( qualifier ) ) {
			return jQuery.filter( qualifier, elements, not );
		}

		qualifier = jQuery.filter( qualifier, elements );
	}

	return jQuery.grep( elements, function( elem ) {
		return ( indexOf.call( qualifier, elem ) >= 0 ) !== not;
	});
}

jQuery.filter = function( expr, elems, not ) {
	var elem = elems[ 0 ];

	if ( not ) {
		expr = ":not(" + expr + ")";
	}

	return elems.length === 1 && elem.nodeType === 1 ?
		jQuery.find.matchesSelector( elem, expr ) ? [ elem ] : [] :
		jQuery.find.matches( expr, jQuery.grep( elems, function( elem ) {
			return elem.nodeType === 1;
		}));
};

jQuery.fn.extend({
	find: function( selector ) {
		var i,
			len = this.length,
			ret = [],
			self = this;

		if ( typeof selector !== "string" ) {
			return this.pushStack( jQuery( selector ).filter(function() {
				for ( i = 0; i < len; i++ ) {
					if ( jQuery.contains( self[ i ], this ) ) {
						return true;
					}
				}
			}) );
		}

		for ( i = 0; i < len; i++ ) {
			jQuery.find( selector, self[ i ], ret );
		}

		// Needed because $( selector, context ) becomes $( context ).find( selector )
		ret = this.pushStack( len > 1 ? jQuery.unique( ret ) : ret );
		ret.selector = this.selector ? this.selector + " " + selector : selector;
		return ret;
	},
	filter: function( selector ) {
		return this.pushStack( winnow(this, selector || [], false) );
	},
	not: function( selector ) {
		return this.pushStack( winnow(this, selector || [], true) );
	},
	is: function( selector ) {
		return !!winnow(
			this,

			// If this is a positional/relative selector, check membership in the returned set
			// so $("p:first").is("p:last") won't return true for a doc with two "p".
			typeof selector === "string" && rneedsContext.test( selector ) ?
				jQuery( selector ) :
				selector || [],
			false
		).length;
	}
});


// Initialize a jQuery object


// A central reference to the root jQuery(document)
var rootjQuery,

	// A simple way to check for HTML strings
	// Prioritize #id over <tag> to avoid XSS via location.hash (#9521)
	// Strict HTML recognition (#11290: must start with <)
	rquickExpr = /^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]*))$/,

	init = jQuery.fn.init = function( selector, context ) {
		var match, elem;

		// HANDLE: $(""), $(null), $(undefined), $(false)
		if ( !selector ) {
			return this;
		}

		// Handle HTML strings
		if ( typeof selector === "string" ) {
			if ( selector[0] === "<" && selector[ selector.length - 1 ] === ">" && selector.length >= 3 ) {
				// Assume that strings that start and end with <> are HTML and skip the regex check
				match = [ null, selector, null ];

			} else {
				match = rquickExpr.exec( selector );
			}

			// Match html or make sure no context is specified for #id
			if ( match && (match[1] || !context) ) {

				// HANDLE: $(html) -> $(array)
				if ( match[1] ) {
					context = context instanceof jQuery ? context[0] : context;

					// Option to run scripts is true for back-compat
					// Intentionally let the error be thrown if parseHTML is not present
					jQuery.merge( this, jQuery.parseHTML(
						match[1],
						context && context.nodeType ? context.ownerDocument || context : document,
						true
					) );

					// HANDLE: $(html, props)
					if ( rsingleTag.test( match[1] ) && jQuery.isPlainObject( context ) ) {
						for ( match in context ) {
							// Properties of context are called as methods if possible
							if ( jQuery.isFunction( this[ match ] ) ) {
								this[ match ]( context[ match ] );

							// ...and otherwise set as attributes
							} else {
								this.attr( match, context[ match ] );
							}
						}
					}

					return this;

				// HANDLE: $(#id)
				} else {
					elem = document.getElementById( match[2] );

					// Support: Blackberry 4.6
					// gEBID returns nodes no longer in the document (#6963)
					if ( elem && elem.parentNode ) {
						// Inject the element directly into the jQuery object
						this.length = 1;
						this[0] = elem;
					}

					this.context = document;
					this.selector = selector;
					return this;
				}

			// HANDLE: $(expr, $(...))
			} else if ( !context || context.jquery ) {
				return ( context || rootjQuery ).find( selector );

			// HANDLE: $(expr, context)
			// (which is just equivalent to: $(context).find(expr)
			} else {
				return this.constructor( context ).find( selector );
			}

		// HANDLE: $(DOMElement)
		} else if ( selector.nodeType ) {
			this.context = this[0] = selector;
			this.length = 1;
			return this;

		// HANDLE: $(function)
		// Shortcut for document ready
		} else if ( jQuery.isFunction( selector ) ) {
			return typeof rootjQuery.ready !== "undefined" ?
				rootjQuery.ready( selector ) :
				// Execute immediately if ready is not present
				selector( jQuery );
		}

		if ( selector.selector !== undefined ) {
			this.selector = selector.selector;
			this.context = selector.context;
		}

		return jQuery.makeArray( selector, this );
	};

// Give the init function the jQuery prototype for later instantiation
init.prototype = jQuery.fn;

// Initialize central reference
rootjQuery = jQuery( document );


var rparentsprev = /^(?:parents|prev(?:Until|All))/,
	// Methods guaranteed to produce a unique set when starting from a unique set
	guaranteedUnique = {
		children: true,
		contents: true,
		next: true,
		prev: true
	};

jQuery.extend({
	dir: function( elem, dir, until ) {
		var matched = [],
			truncate = until !== undefined;

		while ( (elem = elem[ dir ]) && elem.nodeType !== 9 ) {
			if ( elem.nodeType === 1 ) {
				if ( truncate && jQuery( elem ).is( until ) ) {
					break;
				}
				matched.push( elem );
			}
		}
		return matched;
	},

	sibling: function( n, elem ) {
		var matched = [];

		for ( ; n; n = n.nextSibling ) {
			if ( n.nodeType === 1 && n !== elem ) {
				matched.push( n );
			}
		}

		return matched;
	}
});

jQuery.fn.extend({
	has: function( target ) {
		var targets = jQuery( target, this ),
			l = targets.length;

		return this.filter(function() {
			var i = 0;
			for ( ; i < l; i++ ) {
				if ( jQuery.contains( this, targets[i] ) ) {
					return true;
				}
			}
		});
	},

	closest: function( selectors, context ) {
		var cur,
			i = 0,
			l = this.length,
			matched = [],
			pos = rneedsContext.test( selectors ) || typeof selectors !== "string" ?
				jQuery( selectors, context || this.context ) :
				0;

		for ( ; i < l; i++ ) {
			for ( cur = this[i]; cur && cur !== context; cur = cur.parentNode ) {
				// Always skip document fragments
				if ( cur.nodeType < 11 && (pos ?
					pos.index(cur) > -1 :

					// Don't pass non-elements to Sizzle
					cur.nodeType === 1 &&
						jQuery.find.matchesSelector(cur, selectors)) ) {

					matched.push( cur );
					break;
				}
			}
		}

		return this.pushStack( matched.length > 1 ? jQuery.unique( matched ) : matched );
	},

	// Determine the position of an element within the set
	index: function( elem ) {

		// No argument, return index in parent
		if ( !elem ) {
			return ( this[ 0 ] && this[ 0 ].parentNode ) ? this.first().prevAll().length : -1;
		}

		// Index in selector
		if ( typeof elem === "string" ) {
			return indexOf.call( jQuery( elem ), this[ 0 ] );
		}

		// Locate the position of the desired element
		return indexOf.call( this,

			// If it receives a jQuery object, the first element is used
			elem.jquery ? elem[ 0 ] : elem
		);
	},

	add: function( selector, context ) {
		return this.pushStack(
			jQuery.unique(
				jQuery.merge( this.get(), jQuery( selector, context ) )
			)
		);
	},

	addBack: function( selector ) {
		return this.add( selector == null ?
			this.prevObject : this.prevObject.filter(selector)
		);
	}
});

function sibling( cur, dir ) {
	while ( (cur = cur[dir]) && cur.nodeType !== 1 ) {}
	return cur;
}

jQuery.each({
	parent: function( elem ) {
		var parent = elem.parentNode;
		return parent && parent.nodeType !== 11 ? parent : null;
	},
	parents: function( elem ) {
		return jQuery.dir( elem, "parentNode" );
	},
	parentsUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "parentNode", until );
	},
	next: function( elem ) {
		return sibling( elem, "nextSibling" );
	},
	prev: function( elem ) {
		return sibling( elem, "previousSibling" );
	},
	nextAll: function( elem ) {
		return jQuery.dir( elem, "nextSibling" );
	},
	prevAll: function( elem ) {
		return jQuery.dir( elem, "previousSibling" );
	},
	nextUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "nextSibling", until );
	},
	prevUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "previousSibling", until );
	},
	siblings: function( elem ) {
		return jQuery.sibling( ( elem.parentNode || {} ).firstChild, elem );
	},
	children: function( elem ) {
		return jQuery.sibling( elem.firstChild );
	},
	contents: function( elem ) {
		return elem.contentDocument || jQuery.merge( [], elem.childNodes );
	}
}, function( name, fn ) {
	jQuery.fn[ name ] = function( until, selector ) {
		var matched = jQuery.map( this, fn, until );

		if ( name.slice( -5 ) !== "Until" ) {
			selector = until;
		}

		if ( selector && typeof selector === "string" ) {
			matched = jQuery.filter( selector, matched );
		}

		if ( this.length > 1 ) {
			// Remove duplicates
			if ( !guaranteedUnique[ name ] ) {
				jQuery.unique( matched );
			}

			// Reverse order for parents* and prev-derivatives
			if ( rparentsprev.test( name ) ) {
				matched.reverse();
			}
		}

		return this.pushStack( matched );
	};
});
var rnotwhite = (/\S+/g);



// String to Object options format cache
var optionsCache = {};

// Convert String-formatted options into Object-formatted ones and store in cache
function createOptions( options ) {
	var object = optionsCache[ options ] = {};
	jQuery.each( options.match( rnotwhite ) || [], function( _, flag ) {
		object[ flag ] = true;
	});
	return object;
}

/*
 * Create a callback list using the following parameters:
 *
 *	options: an optional list of space-separated options that will change how
 *			the callback list behaves or a more traditional option object
 *
 * By default a callback list will act like an event callback list and can be
 * "fired" multiple times.
 *
 * Possible options:
 *
 *	once:			will ensure the callback list can only be fired once (like a Deferred)
 *
 *	memory:			will keep track of previous values and will call any callback added
 *					after the list has been fired right away with the latest "memorized"
 *					values (like a Deferred)
 *
 *	unique:			will ensure a callback can only be added once (no duplicate in the list)
 *
 *	stopOnFalse:	interrupt callings when a callback returns false
 *
 */
jQuery.Callbacks = function( options ) {

	// Convert options from String-formatted to Object-formatted if needed
	// (we check in cache first)
	options = typeof options === "string" ?
		( optionsCache[ options ] || createOptions( options ) ) :
		jQuery.extend( {}, options );

	var // Last fire value (for non-forgettable lists)
		memory,
		// Flag to know if list was already fired
		fired,
		// Flag to know if list is currently firing
		firing,
		// First callback to fire (used internally by add and fireWith)
		firingStart,
		// End of the loop when firing
		firingLength,
		// Index of currently firing callback (modified by remove if needed)
		firingIndex,
		// Actual callback list
		list = [],
		// Stack of fire calls for repeatable lists
		stack = !options.once && [],
		// Fire callbacks
		fire = function( data ) {
			memory = options.memory && data;
			fired = true;
			firingIndex = firingStart || 0;
			firingStart = 0;
			firingLength = list.length;
			firing = true;
			for ( ; list && firingIndex < firingLength; firingIndex++ ) {
				if ( list[ firingIndex ].apply( data[ 0 ], data[ 1 ] ) === false && options.stopOnFalse ) {
					memory = false; // To prevent further calls using add
					break;
				}
			}
			firing = false;
			if ( list ) {
				if ( stack ) {
					if ( stack.length ) {
						fire( stack.shift() );
					}
				} else if ( memory ) {
					list = [];
				} else {
					self.disable();
				}
			}
		},
		// Actual Callbacks object
		self = {
			// Add a callback or a collection of callbacks to the list
			add: function() {
				if ( list ) {
					// First, we save the current length
					var start = list.length;
					(function add( args ) {
						jQuery.each( args, function( _, arg ) {
							var type = jQuery.type( arg );
							if ( type === "function" ) {
								if ( !options.unique || !self.has( arg ) ) {
									list.push( arg );
								}
							} else if ( arg && arg.length && type !== "string" ) {
								// Inspect recursively
								add( arg );
							}
						});
					})( arguments );
					// Do we need to add the callbacks to the
					// current firing batch?
					if ( firing ) {
						firingLength = list.length;
					// With memory, if we're not firing then
					// we should call right away
					} else if ( memory ) {
						firingStart = start;
						fire( memory );
					}
				}
				return this;
			},
			// Remove a callback from the list
			remove: function() {
				if ( list ) {
					jQuery.each( arguments, function( _, arg ) {
						var index;
						while ( ( index = jQuery.inArray( arg, list, index ) ) > -1 ) {
							list.splice( index, 1 );
							// Handle firing indexes
							if ( firing ) {
								if ( index <= firingLength ) {
									firingLength--;
								}
								if ( index <= firingIndex ) {
									firingIndex--;
								}
							}
						}
					});
				}
				return this;
			},
			// Check if a given callback is in the list.
			// If no argument is given, return whether or not list has callbacks attached.
			has: function( fn ) {
				return fn ? jQuery.inArray( fn, list ) > -1 : !!( list && list.length );
			},
			// Remove all callbacks from the list
			empty: function() {
				list = [];
				firingLength = 0;
				return this;
			},
			// Have the list do nothing anymore
			disable: function() {
				list = stack = memory = undefined;
				return this;
			},
			// Is it disabled?
			disabled: function() {
				return !list;
			},
			// Lock the list in its current state
			lock: function() {
				stack = undefined;
				if ( !memory ) {
					self.disable();
				}
				return this;
			},
			// Is it locked?
			locked: function() {
				return !stack;
			},
			// Call all callbacks with the given context and arguments
			fireWith: function( context, args ) {
				if ( list && ( !fired || stack ) ) {
					args = args || [];
					args = [ context, args.slice ? args.slice() : args ];
					if ( firing ) {
						stack.push( args );
					} else {
						fire( args );
					}
				}
				return this;
			},
			// Call all the callbacks with the given arguments
			fire: function() {
				self.fireWith( this, arguments );
				return this;
			},
			// To know if the callbacks have already been called at least once
			fired: function() {
				return !!fired;
			}
		};

	return self;
};


jQuery.extend({

	Deferred: function( func ) {
		var tuples = [
				// action, add listener, listener list, final state
				[ "resolve", "done", jQuery.Callbacks("once memory"), "resolved" ],
				[ "reject", "fail", jQuery.Callbacks("once memory"), "rejected" ],
				[ "notify", "progress", jQuery.Callbacks("memory") ]
			],
			state = "pending",
			promise = {
				state: function() {
					return state;
				},
				always: function() {
					deferred.done( arguments ).fail( arguments );
					return this;
				},
				then: function( /* fnDone, fnFail, fnProgress */ ) {
					var fns = arguments;
					return jQuery.Deferred(function( newDefer ) {
						jQuery.each( tuples, function( i, tuple ) {
							var fn = jQuery.isFunction( fns[ i ] ) && fns[ i ];
							// deferred[ done | fail | progress ] for forwarding actions to newDefer
							deferred[ tuple[1] ](function() {
								var returned = fn && fn.apply( this, arguments );
								if ( returned && jQuery.isFunction( returned.promise ) ) {
									returned.promise()
										.done( newDefer.resolve )
										.fail( newDefer.reject )
										.progress( newDefer.notify );
								} else {
									newDefer[ tuple[ 0 ] + "With" ]( this === promise ? newDefer.promise() : this, fn ? [ returned ] : arguments );
								}
							});
						});
						fns = null;
					}).promise();
				},
				// Get a promise for this deferred
				// If obj is provided, the promise aspect is added to the object
				promise: function( obj ) {
					return obj != null ? jQuery.extend( obj, promise ) : promise;
				}
			},
			deferred = {};

		// Keep pipe for back-compat
		promise.pipe = promise.then;

		// Add list-specific methods
		jQuery.each( tuples, function( i, tuple ) {
			var list = tuple[ 2 ],
				stateString = tuple[ 3 ];

			// promise[ done | fail | progress ] = list.add
			promise[ tuple[1] ] = list.add;

			// Handle state
			if ( stateString ) {
				list.add(function() {
					// state = [ resolved | rejected ]
					state = stateString;

				// [ reject_list | resolve_list ].disable; progress_list.lock
				}, tuples[ i ^ 1 ][ 2 ].disable, tuples[ 2 ][ 2 ].lock );
			}

			// deferred[ resolve | reject | notify ]
			deferred[ tuple[0] ] = function() {
				deferred[ tuple[0] + "With" ]( this === deferred ? promise : this, arguments );
				return this;
			};
			deferred[ tuple[0] + "With" ] = list.fireWith;
		});

		// Make the deferred a promise
		promise.promise( deferred );

		// Call given func if any
		if ( func ) {
			func.call( deferred, deferred );
		}

		// All done!
		return deferred;
	},

	// Deferred helper
	when: function( subordinate /* , ..., subordinateN */ ) {
		var i = 0,
			resolveValues = slice.call( arguments ),
			length = resolveValues.length,

			// the count of uncompleted subordinates
			remaining = length !== 1 || ( subordinate && jQuery.isFunction( subordinate.promise ) ) ? length : 0,

			// the master Deferred. If resolveValues consist of only a single Deferred, just use that.
			deferred = remaining === 1 ? subordinate : jQuery.Deferred(),

			// Update function for both resolve and progress values
			updateFunc = function( i, contexts, values ) {
				return function( value ) {
					contexts[ i ] = this;
					values[ i ] = arguments.length > 1 ? slice.call( arguments ) : value;
					if ( values === progressValues ) {
						deferred.notifyWith( contexts, values );
					} else if ( !( --remaining ) ) {
						deferred.resolveWith( contexts, values );
					}
				};
			},

			progressValues, progressContexts, resolveContexts;

		// Add listeners to Deferred subordinates; treat others as resolved
		if ( length > 1 ) {
			progressValues = new Array( length );
			progressContexts = new Array( length );
			resolveContexts = new Array( length );
			for ( ; i < length; i++ ) {
				if ( resolveValues[ i ] && jQuery.isFunction( resolveValues[ i ].promise ) ) {
					resolveValues[ i ].promise()
						.done( updateFunc( i, resolveContexts, resolveValues ) )
						.fail( deferred.reject )
						.progress( updateFunc( i, progressContexts, progressValues ) );
				} else {
					--remaining;
				}
			}
		}

		// If we're not waiting on anything, resolve the master
		if ( !remaining ) {
			deferred.resolveWith( resolveContexts, resolveValues );
		}

		return deferred.promise();
	}
});


// The deferred used on DOM ready
var readyList;

jQuery.fn.ready = function( fn ) {
	// Add the callback
	jQuery.ready.promise().done( fn );

	return this;
};

jQuery.extend({
	// Is the DOM ready to be used? Set to true once it occurs.
	isReady: false,

	// A counter to track how many items to wait for before
	// the ready event fires. See #6781
	readyWait: 1,

	// Hold (or release) the ready event
	holdReady: function( hold ) {
		if ( hold ) {
			jQuery.readyWait++;
		} else {
			jQuery.ready( true );
		}
	},

	// Handle when the DOM is ready
	ready: function( wait ) {

		// Abort if there are pending holds or we're already ready
		if ( wait === true ? --jQuery.readyWait : jQuery.isReady ) {
			return;
		}

		// Remember that the DOM is ready
		jQuery.isReady = true;

		// If a normal DOM Ready event fired, decrement, and wait if need be
		if ( wait !== true && --jQuery.readyWait > 0 ) {
			return;
		}

		// If there are functions bound, to execute
		readyList.resolveWith( document, [ jQuery ] );

		// Trigger any bound ready events
		if ( jQuery.fn.triggerHandler ) {
			jQuery( document ).triggerHandler( "ready" );
			jQuery( document ).off( "ready" );
		}
	}
});

/**
 * The ready event handler and self cleanup method
 */
function completed() {
	document.removeEventListener( "DOMContentLoaded", completed, false );
	window.removeEventListener( "load", completed, false );
	jQuery.ready();
}

jQuery.ready.promise = function( obj ) {
	if ( !readyList ) {

		readyList = jQuery.Deferred();

		// Catch cases where $(document).ready() is called after the browser event has already occurred.
		// We once tried to use readyState "interactive" here, but it caused issues like the one
		// discovered by ChrisS here: http://bugs.jquery.com/ticket/12282#comment:15
		if ( document.readyState === "complete" ) {
			// Handle it asynchronously to allow scripts the opportunity to delay ready
			setTimeout( jQuery.ready );

		} else {

			// Use the handy event callback
			document.addEventListener( "DOMContentLoaded", completed, false );

			// A fallback to window.onload, that will always work
			window.addEventListener( "load", completed, false );
		}
	}
	return readyList.promise( obj );
};

// Kick off the DOM ready check even if the user does not
jQuery.ready.promise();




// Multifunctional method to get and set values of a collection
// The value/s can optionally be executed if it's a function
var access = jQuery.access = function( elems, fn, key, value, chainable, emptyGet, raw ) {
	var i = 0,
		len = elems.length,
		bulk = key == null;

	// Sets many values
	if ( jQuery.type( key ) === "object" ) {
		chainable = true;
		for ( i in key ) {
			jQuery.access( elems, fn, i, key[i], true, emptyGet, raw );
		}

	// Sets one value
	} else if ( value !== undefined ) {
		chainable = true;

		if ( !jQuery.isFunction( value ) ) {
			raw = true;
		}

		if ( bulk ) {
			// Bulk operations run against the entire set
			if ( raw ) {
				fn.call( elems, value );
				fn = null;

			// ...except when executing function values
			} else {
				bulk = fn;
				fn = function( elem, key, value ) {
					return bulk.call( jQuery( elem ), value );
				};
			}
		}

		if ( fn ) {
			for ( ; i < len; i++ ) {
				fn( elems[i], key, raw ? value : value.call( elems[i], i, fn( elems[i], key ) ) );
			}
		}
	}

	return chainable ?
		elems :

		// Gets
		bulk ?
			fn.call( elems ) :
			len ? fn( elems[0], key ) : emptyGet;
};


/**
 * Determines whether an object can have data
 */
jQuery.acceptData = function( owner ) {
	// Accepts only:
	//  - Node
	//    - Node.ELEMENT_NODE
	//    - Node.DOCUMENT_NODE
	//  - Object
	//    - Any
	/* jshint -W018 */
	return owner.nodeType === 1 || owner.nodeType === 9 || !( +owner.nodeType );
};


function Data() {
	// Support: Android<4,
	// Old WebKit does not have Object.preventExtensions/freeze method,
	// return new empty object instead with no [[set]] accessor
	Object.defineProperty( this.cache = {}, 0, {
		get: function() {
			return {};
		}
	});

	this.expando = jQuery.expando + Data.uid++;
}

Data.uid = 1;
Data.accepts = jQuery.acceptData;

Data.prototype = {
	key: function( owner ) {
		// We can accept data for non-element nodes in modern browsers,
		// but we should not, see #8335.
		// Always return the key for a frozen object.
		if ( !Data.accepts( owner ) ) {
			return 0;
		}

		var descriptor = {},
			// Check if the owner object already has a cache key
			unlock = owner[ this.expando ];

		// If not, create one
		if ( !unlock ) {
			unlock = Data.uid++;

			// Secure it in a non-enumerable, non-writable property
			try {
				descriptor[ this.expando ] = { value: unlock };
				Object.defineProperties( owner, descriptor );

			// Support: Android<4
			// Fallback to a less secure definition
			} catch ( e ) {
				descriptor[ this.expando ] = unlock;
				jQuery.extend( owner, descriptor );
			}
		}

		// Ensure the cache object
		if ( !this.cache[ unlock ] ) {
			this.cache[ unlock ] = {};
		}

		return unlock;
	},
	set: function( owner, data, value ) {
		var prop,
			// There may be an unlock assigned to this node,
			// if there is no entry for this "owner", create one inline
			// and set the unlock as though an owner entry had always existed
			unlock = this.key( owner ),
			cache = this.cache[ unlock ];

		// Handle: [ owner, key, value ] args
		if ( typeof data === "string" ) {
			cache[ data ] = value;

		// Handle: [ owner, { properties } ] args
		} else {
			// Fresh assignments by object are shallow copied
			if ( jQuery.isEmptyObject( cache ) ) {
				jQuery.extend( this.cache[ unlock ], data );
			// Otherwise, copy the properties one-by-one to the cache object
			} else {
				for ( prop in data ) {
					cache[ prop ] = data[ prop ];
				}
			}
		}
		return cache;
	},
	get: function( owner, key ) {
		// Either a valid cache is found, or will be created.
		// New caches will be created and the unlock returned,
		// allowing direct access to the newly created
		// empty data object. A valid owner object must be provided.
		var cache = this.cache[ this.key( owner ) ];

		return key === undefined ?
			cache : cache[ key ];
	},
	access: function( owner, key, value ) {
		var stored;
		// In cases where either:
		//
		//   1. No key was specified
		//   2. A string key was specified, but no value provided
		//
		// Take the "read" path and allow the get method to determine
		// which value to return, respectively either:
		//
		//   1. The entire cache object
		//   2. The data stored at the key
		//
		if ( key === undefined ||
				((key && typeof key === "string") && value === undefined) ) {

			stored = this.get( owner, key );

			return stored !== undefined ?
				stored : this.get( owner, jQuery.camelCase(key) );
		}

		// [*]When the key is not a string, or both a key and value
		// are specified, set or extend (existing objects) with either:
		//
		//   1. An object of properties
		//   2. A key and value
		//
		this.set( owner, key, value );

		// Since the "set" path can have two possible entry points
		// return the expected data based on which path was taken[*]
		return value !== undefined ? value : key;
	},
	remove: function( owner, key ) {
		var i, name, camel,
			unlock = this.key( owner ),
			cache = this.cache[ unlock ];

		if ( key === undefined ) {
			this.cache[ unlock ] = {};

		} else {
			// Support array or space separated string of keys
			if ( jQuery.isArray( key ) ) {
				// If "name" is an array of keys...
				// When data is initially created, via ("key", "val") signature,
				// keys will be converted to camelCase.
				// Since there is no way to tell _how_ a key was added, remove
				// both plain key and camelCase key. #12786
				// This will only penalize the array argument path.
				name = key.concat( key.map( jQuery.camelCase ) );
			} else {
				camel = jQuery.camelCase( key );
				// Try the string as a key before any manipulation
				if ( key in cache ) {
					name = [ key, camel ];
				} else {
					// If a key with the spaces exists, use it.
					// Otherwise, create an array by matching non-whitespace
					name = camel;
					name = name in cache ?
						[ name ] : ( name.match( rnotwhite ) || [] );
				}
			}

			i = name.length;
			while ( i-- ) {
				delete cache[ name[ i ] ];
			}
		}
	},
	hasData: function( owner ) {
		return !jQuery.isEmptyObject(
			this.cache[ owner[ this.expando ] ] || {}
		);
	},
	discard: function( owner ) {
		if ( owner[ this.expando ] ) {
			delete this.cache[ owner[ this.expando ] ];
		}
	}
};
var data_priv = new Data();

var data_user = new Data();



//	Implementation Summary
//
//	1. Enforce API surface and semantic compatibility with 1.9.x branch
//	2. Improve the module's maintainability by reducing the storage
//		paths to a single mechanism.
//	3. Use the same single mechanism to support "private" and "user" data.
//	4. _Never_ expose "private" data to user code (TODO: Drop _data, _removeData)
//	5. Avoid exposing implementation details on user objects (eg. expando properties)
//	6. Provide a clear path for implementation upgrade to WeakMap in 2014

var rbrace = /^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,
	rmultiDash = /([A-Z])/g;

function dataAttr( elem, key, data ) {
	var name;

	// If nothing was found internally, try to fetch any
	// data from the HTML5 data-* attribute
	if ( data === undefined && elem.nodeType === 1 ) {
		name = "data-" + key.replace( rmultiDash, "-$1" ).toLowerCase();
		data = elem.getAttribute( name );

		if ( typeof data === "string" ) {
			try {
				data = data === "true" ? true :
					data === "false" ? false :
					data === "null" ? null :
					// Only convert to a number if it doesn't change the string
					+data + "" === data ? +data :
					rbrace.test( data ) ? jQuery.parseJSON( data ) :
					data;
			} catch( e ) {}

			// Make sure we set the data so it isn't changed later
			data_user.set( elem, key, data );
		} else {
			data = undefined;
		}
	}
	return data;
}

jQuery.extend({
	hasData: function( elem ) {
		return data_user.hasData( elem ) || data_priv.hasData( elem );
	},

	data: function( elem, name, data ) {
		return data_user.access( elem, name, data );
	},

	removeData: function( elem, name ) {
		data_user.remove( elem, name );
	},

	// TODO: Now that all calls to _data and _removeData have been replaced
	// with direct calls to data_priv methods, these can be deprecated.
	_data: function( elem, name, data ) {
		return data_priv.access( elem, name, data );
	},

	_removeData: function( elem, name ) {
		data_priv.remove( elem, name );
	}
});

jQuery.fn.extend({
	data: function( key, value ) {
		var i, name, data,
			elem = this[ 0 ],
			attrs = elem && elem.attributes;

		// Gets all values
		if ( key === undefined ) {
			if ( this.length ) {
				data = data_user.get( elem );

				if ( elem.nodeType === 1 && !data_priv.get( elem, "hasDataAttrs" ) ) {
					i = attrs.length;
					while ( i-- ) {

						// Support: IE11+
						// The attrs elements can be null (#14894)
						if ( attrs[ i ] ) {
							name = attrs[ i ].name;
							if ( name.indexOf( "data-" ) === 0 ) {
								name = jQuery.camelCase( name.slice(5) );
								dataAttr( elem, name, data[ name ] );
							}
						}
					}
					data_priv.set( elem, "hasDataAttrs", true );
				}
			}

			return data;
		}

		// Sets multiple values
		if ( typeof key === "object" ) {
			return this.each(function() {
				data_user.set( this, key );
			});
		}

		return access( this, function( value ) {
			var data,
				camelKey = jQuery.camelCase( key );

			// The calling jQuery object (element matches) is not empty
			// (and therefore has an element appears at this[ 0 ]) and the
			// `value` parameter was not undefined. An empty jQuery object
			// will result in `undefined` for elem = this[ 0 ] which will
			// throw an exception if an attempt to read a data cache is made.
			if ( elem && value === undefined ) {
				// Attempt to get data from the cache
				// with the key as-is
				data = data_user.get( elem, key );
				if ( data !== undefined ) {
					return data;
				}

				// Attempt to get data from the cache
				// with the key camelized
				data = data_user.get( elem, camelKey );
				if ( data !== undefined ) {
					return data;
				}

				// Attempt to "discover" the data in
				// HTML5 custom data-* attrs
				data = dataAttr( elem, camelKey, undefined );
				if ( data !== undefined ) {
					return data;
				}

				// We tried really hard, but the data doesn't exist.
				return;
			}

			// Set the data...
			this.each(function() {
				// First, attempt to store a copy or reference of any
				// data that might've been store with a camelCased key.
				var data = data_user.get( this, camelKey );

				// For HTML5 data-* attribute interop, we have to
				// store property names with dashes in a camelCase form.
				// This might not apply to all properties...*
				data_user.set( this, camelKey, value );

				// *... In the case of properties that might _actually_
				// have dashes, we need to also store a copy of that
				// unchanged property.
				if ( key.indexOf("-") !== -1 && data !== undefined ) {
					data_user.set( this, key, value );
				}
			});
		}, null, value, arguments.length > 1, null, true );
	},

	removeData: function( key ) {
		return this.each(function() {
			data_user.remove( this, key );
		});
	}
});


jQuery.extend({
	queue: function( elem, type, data ) {
		var queue;

		if ( elem ) {
			type = ( type || "fx" ) + "queue";
			queue = data_priv.get( elem, type );

			// Speed up dequeue by getting out quickly if this is just a lookup
			if ( data ) {
				if ( !queue || jQuery.isArray( data ) ) {
					queue = data_priv.access( elem, type, jQuery.makeArray(data) );
				} else {
					queue.push( data );
				}
			}
			return queue || [];
		}
	},

	dequeue: function( elem, type ) {
		type = type || "fx";

		var queue = jQuery.queue( elem, type ),
			startLength = queue.length,
			fn = queue.shift(),
			hooks = jQuery._queueHooks( elem, type ),
			next = function() {
				jQuery.dequeue( elem, type );
			};

		// If the fx queue is dequeued, always remove the progress sentinel
		if ( fn === "inprogress" ) {
			fn = queue.shift();
			startLength--;
		}

		if ( fn ) {

			// Add a progress sentinel to prevent the fx queue from being
			// automatically dequeued
			if ( type === "fx" ) {
				queue.unshift( "inprogress" );
			}

			// Clear up the last queue stop function
			delete hooks.stop;
			fn.call( elem, next, hooks );
		}

		if ( !startLength && hooks ) {
			hooks.empty.fire();
		}
	},

	// Not public - generate a queueHooks object, or return the current one
	_queueHooks: function( elem, type ) {
		var key = type + "queueHooks";
		return data_priv.get( elem, key ) || data_priv.access( elem, key, {
			empty: jQuery.Callbacks("once memory").add(function() {
				data_priv.remove( elem, [ type + "queue", key ] );
			})
		});
	}
});

jQuery.fn.extend({
	queue: function( type, data ) {
		var setter = 2;

		if ( typeof type !== "string" ) {
			data = type;
			type = "fx";
			setter--;
		}

		if ( arguments.length < setter ) {
			return jQuery.queue( this[0], type );
		}

		return data === undefined ?
			this :
			this.each(function() {
				var queue = jQuery.queue( this, type, data );

				// Ensure a hooks for this queue
				jQuery._queueHooks( this, type );

				if ( type === "fx" && queue[0] !== "inprogress" ) {
					jQuery.dequeue( this, type );
				}
			});
	},
	dequeue: function( type ) {
		return this.each(function() {
			jQuery.dequeue( this, type );
		});
	},
	clearQueue: function( type ) {
		return this.queue( type || "fx", [] );
	},
	// Get a promise resolved when queues of a certain type
	// are emptied (fx is the type by default)
	promise: function( type, obj ) {
		var tmp,
			count = 1,
			defer = jQuery.Deferred(),
			elements = this,
			i = this.length,
			resolve = function() {
				if ( !( --count ) ) {
					defer.resolveWith( elements, [ elements ] );
				}
			};

		if ( typeof type !== "string" ) {
			obj = type;
			type = undefined;
		}
		type = type || "fx";

		while ( i-- ) {
			tmp = data_priv.get( elements[ i ], type + "queueHooks" );
			if ( tmp && tmp.empty ) {
				count++;
				tmp.empty.add( resolve );
			}
		}
		resolve();
		return defer.promise( obj );
	}
});
var pnum = (/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/).source;

var cssExpand = [ "Top", "Right", "Bottom", "Left" ];

var isHidden = function( elem, el ) {
		// isHidden might be called from jQuery#filter function;
		// in that case, element will be second argument
		elem = el || elem;
		return jQuery.css( elem, "display" ) === "none" || !jQuery.contains( elem.ownerDocument, elem );
	};

var rcheckableType = (/^(?:checkbox|radio)$/i);



(function() {
	var fragment = document.createDocumentFragment(),
		div = fragment.appendChild( document.createElement( "div" ) ),
		input = document.createElement( "input" );

	// Support: Safari<=5.1
	// Check state lost if the name is set (#11217)
	// Support: Windows Web Apps (WWA)
	// `name` and `type` must use .setAttribute for WWA (#14901)
	input.setAttribute( "type", "radio" );
	input.setAttribute( "checked", "checked" );
	input.setAttribute( "name", "t" );

	div.appendChild( input );

	// Support: Safari<=5.1, Android<4.2
	// Older WebKit doesn't clone checked state correctly in fragments
	support.checkClone = div.cloneNode( true ).cloneNode( true ).lastChild.checked;

	// Support: IE<=11+
	// Make sure textarea (and checkbox) defaultValue is properly cloned
	div.innerHTML = "<textarea>x</textarea>";
	support.noCloneChecked = !!div.cloneNode( true ).lastChild.defaultValue;
})();
var strundefined = typeof undefined;



support.focusinBubbles = "onfocusin" in window;


var
	rkeyEvent = /^key/,
	rmouseEvent = /^(?:mouse|pointer|contextmenu)|click/,
	rfocusMorph = /^(?:focusinfocus|focusoutblur)$/,
	rtypenamespace = /^([^.]*)(?:\.(.+)|)$/;

function returnTrue() {
	return true;
}

function returnFalse() {
	return false;
}

function safeActiveElement() {
	try {
		return document.activeElement;
	} catch ( err ) { }
}

/*
 * Helper functions for managing events -- not part of the public interface.
 * Props to Dean Edwards' addEvent library for many of the ideas.
 */
jQuery.event = {

	global: {},

	add: function( elem, types, handler, data, selector ) {

		var handleObjIn, eventHandle, tmp,
			events, t, handleObj,
			special, handlers, type, namespaces, origType,
			elemData = data_priv.get( elem );

		// Don't attach events to noData or text/comment nodes (but allow plain objects)
		if ( !elemData ) {
			return;
		}

		// Caller can pass in an object of custom data in lieu of the handler
		if ( handler.handler ) {
			handleObjIn = handler;
			handler = handleObjIn.handler;
			selector = handleObjIn.selector;
		}

		// Make sure that the handler has a unique ID, used to find/remove it later
		if ( !handler.guid ) {
			handler.guid = jQuery.guid++;
		}

		// Init the element's event structure and main handler, if this is the first
		if ( !(events = elemData.events) ) {
			events = elemData.events = {};
		}
		if ( !(eventHandle = elemData.handle) ) {
			eventHandle = elemData.handle = function( e ) {
				// Discard the second event of a jQuery.event.trigger() and
				// when an event is called after a page has unloaded
				return typeof jQuery !== strundefined && jQuery.event.triggered !== e.type ?
					jQuery.event.dispatch.apply( elem, arguments ) : undefined;
			};
		}

		// Handle multiple events separated by a space
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// There *must* be a type, no attaching namespace-only handlers
			if ( !type ) {
				continue;
			}

			// If event changes its type, use the special event handlers for the changed type
			special = jQuery.event.special[ type ] || {};

			// If selector defined, determine special event api type, otherwise given type
			type = ( selector ? special.delegateType : special.bindType ) || type;

			// Update special based on newly reset type
			special = jQuery.event.special[ type ] || {};

			// handleObj is passed to all event handlers
			handleObj = jQuery.extend({
				type: type,
				origType: origType,
				data: data,
				handler: handler,
				guid: handler.guid,
				selector: selector,
				needsContext: selector && jQuery.expr.match.needsContext.test( selector ),
				namespace: namespaces.join(".")
			}, handleObjIn );

			// Init the event handler queue if we're the first
			if ( !(handlers = events[ type ]) ) {
				handlers = events[ type ] = [];
				handlers.delegateCount = 0;

				// Only use addEventListener if the special events handler returns false
				if ( !special.setup || special.setup.call( elem, data, namespaces, eventHandle ) === false ) {
					if ( elem.addEventListener ) {
						elem.addEventListener( type, eventHandle, false );
					}
				}
			}

			if ( special.add ) {
				special.add.call( elem, handleObj );

				if ( !handleObj.handler.guid ) {
					handleObj.handler.guid = handler.guid;
				}
			}

			// Add to the element's handler list, delegates in front
			if ( selector ) {
				handlers.splice( handlers.delegateCount++, 0, handleObj );
			} else {
				handlers.push( handleObj );
			}

			// Keep track of which events have ever been used, for event optimization
			jQuery.event.global[ type ] = true;
		}

	},

	// Detach an event or set of events from an element
	remove: function( elem, types, handler, selector, mappedTypes ) {

		var j, origCount, tmp,
			events, t, handleObj,
			special, handlers, type, namespaces, origType,
			elemData = data_priv.hasData( elem ) && data_priv.get( elem );

		if ( !elemData || !(events = elemData.events) ) {
			return;
		}

		// Once for each type.namespace in types; type may be omitted
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// Unbind all events (on this namespace, if provided) for the element
			if ( !type ) {
				for ( type in events ) {
					jQuery.event.remove( elem, type + types[ t ], handler, selector, true );
				}
				continue;
			}

			special = jQuery.event.special[ type ] || {};
			type = ( selector ? special.delegateType : special.bindType ) || type;
			handlers = events[ type ] || [];
			tmp = tmp[2] && new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" );

			// Remove matching events
			origCount = j = handlers.length;
			while ( j-- ) {
				handleObj = handlers[ j ];

				if ( ( mappedTypes || origType === handleObj.origType ) &&
					( !handler || handler.guid === handleObj.guid ) &&
					( !tmp || tmp.test( handleObj.namespace ) ) &&
					( !selector || selector === handleObj.selector || selector === "**" && handleObj.selector ) ) {
					handlers.splice( j, 1 );

					if ( handleObj.selector ) {
						handlers.delegateCount--;
					}
					if ( special.remove ) {
						special.remove.call( elem, handleObj );
					}
				}
			}

			// Remove generic event handler if we removed something and no more handlers exist
			// (avoids potential for endless recursion during removal of special event handlers)
			if ( origCount && !handlers.length ) {
				if ( !special.teardown || special.teardown.call( elem, namespaces, elemData.handle ) === false ) {
					jQuery.removeEvent( elem, type, elemData.handle );
				}

				delete events[ type ];
			}
		}

		// Remove the expando if it's no longer used
		if ( jQuery.isEmptyObject( events ) ) {
			delete elemData.handle;
			data_priv.remove( elem, "events" );
		}
	},

	trigger: function( event, data, elem, onlyHandlers ) {

		var i, cur, tmp, bubbleType, ontype, handle, special,
			eventPath = [ elem || document ],
			type = hasOwn.call( event, "type" ) ? event.type : event,
			namespaces = hasOwn.call( event, "namespace" ) ? event.namespace.split(".") : [];

		cur = tmp = elem = elem || document;

		// Don't do events on text and comment nodes
		if ( elem.nodeType === 3 || elem.nodeType === 8 ) {
			return;
		}

		// focus/blur morphs to focusin/out; ensure we're not firing them right now
		if ( rfocusMorph.test( type + jQuery.event.triggered ) ) {
			return;
		}

		if ( type.indexOf(".") >= 0 ) {
			// Namespaced trigger; create a regexp to match event type in handle()
			namespaces = type.split(".");
			type = namespaces.shift();
			namespaces.sort();
		}
		ontype = type.indexOf(":") < 0 && "on" + type;

		// Caller can pass in a jQuery.Event object, Object, or just an event type string
		event = event[ jQuery.expando ] ?
			event :
			new jQuery.Event( type, typeof event === "object" && event );

		// Trigger bitmask: & 1 for native handlers; & 2 for jQuery (always true)
		event.isTrigger = onlyHandlers ? 2 : 3;
		event.namespace = namespaces.join(".");
		event.namespace_re = event.namespace ?
			new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" ) :
			null;

		// Clean up the event in case it is being reused
		event.result = undefined;
		if ( !event.target ) {
			event.target = elem;
		}

		// Clone any incoming data and prepend the event, creating the handler arg list
		data = data == null ?
			[ event ] :
			jQuery.makeArray( data, [ event ] );

		// Allow special events to draw outside the lines
		special = jQuery.event.special[ type ] || {};
		if ( !onlyHandlers && special.trigger && special.trigger.apply( elem, data ) === false ) {
			return;
		}

		// Determine event propagation path in advance, per W3C events spec (#9951)
		// Bubble up to document, then to window; watch for a global ownerDocument var (#9724)
		if ( !onlyHandlers && !special.noBubble && !jQuery.isWindow( elem ) ) {

			bubbleType = special.delegateType || type;
			if ( !rfocusMorph.test( bubbleType + type ) ) {
				cur = cur.parentNode;
			}
			for ( ; cur; cur = cur.parentNode ) {
				eventPath.push( cur );
				tmp = cur;
			}

			// Only add window if we got to document (e.g., not plain obj or detached DOM)
			if ( tmp === (elem.ownerDocument || document) ) {
				eventPath.push( tmp.defaultView || tmp.parentWindow || window );
			}
		}

		// Fire handlers on the event path
		i = 0;
		while ( (cur = eventPath[i++]) && !event.isPropagationStopped() ) {

			event.type = i > 1 ?
				bubbleType :
				special.bindType || type;

			// jQuery handler
			handle = ( data_priv.get( cur, "events" ) || {} )[ event.type ] && data_priv.get( cur, "handle" );
			if ( handle ) {
				handle.apply( cur, data );
			}

			// Native handler
			handle = ontype && cur[ ontype ];
			if ( handle && handle.apply && jQuery.acceptData( cur ) ) {
				event.result = handle.apply( cur, data );
				if ( event.result === false ) {
					event.preventDefault();
				}
			}
		}
		event.type = type;

		// If nobody prevented the default action, do it now
		if ( !onlyHandlers && !event.isDefaultPrevented() ) {

			if ( (!special._default || special._default.apply( eventPath.pop(), data ) === false) &&
				jQuery.acceptData( elem ) ) {

				// Call a native DOM method on the target with the same name name as the event.
				// Don't do default actions on window, that's where global variables be (#6170)
				if ( ontype && jQuery.isFunction( elem[ type ] ) && !jQuery.isWindow( elem ) ) {

					// Don't re-trigger an onFOO event when we call its FOO() method
					tmp = elem[ ontype ];

					if ( tmp ) {
						elem[ ontype ] = null;
					}

					// Prevent re-triggering of the same event, since we already bubbled it above
					jQuery.event.triggered = type;
					elem[ type ]();
					jQuery.event.triggered = undefined;

					if ( tmp ) {
						elem[ ontype ] = tmp;
					}
				}
			}
		}

		return event.result;
	},

	dispatch: function( event ) {

		// Make a writable jQuery.Event from the native event object
		event = jQuery.event.fix( event );

		var i, j, ret, matched, handleObj,
			handlerQueue = [],
			args = slice.call( arguments ),
			handlers = ( data_priv.get( this, "events" ) || {} )[ event.type ] || [],
			special = jQuery.event.special[ event.type ] || {};

		// Use the fix-ed jQuery.Event rather than the (read-only) native event
		args[0] = event;
		event.delegateTarget = this;

		// Call the preDispatch hook for the mapped type, and let it bail if desired
		if ( special.preDispatch && special.preDispatch.call( this, event ) === false ) {
			return;
		}

		// Determine handlers
		handlerQueue = jQuery.event.handlers.call( this, event, handlers );

		// Run delegates first; they may want to stop propagation beneath us
		i = 0;
		while ( (matched = handlerQueue[ i++ ]) && !event.isPropagationStopped() ) {
			event.currentTarget = matched.elem;

			j = 0;
			while ( (handleObj = matched.handlers[ j++ ]) && !event.isImmediatePropagationStopped() ) {

				// Triggered event must either 1) have no namespace, or 2) have namespace(s)
				// a subset or equal to those in the bound event (both can have no namespace).
				if ( !event.namespace_re || event.namespace_re.test( handleObj.namespace ) ) {

					event.handleObj = handleObj;
					event.data = handleObj.data;

					ret = ( (jQuery.event.special[ handleObj.origType ] || {}).handle || handleObj.handler )
							.apply( matched.elem, args );

					if ( ret !== undefined ) {
						if ( (event.result = ret) === false ) {
							event.preventDefault();
							event.stopPropagation();
						}
					}
				}
			}
		}

		// Call the postDispatch hook for the mapped type
		if ( special.postDispatch ) {
			special.postDispatch.call( this, event );
		}

		return event.result;
	},

	handlers: function( event, handlers ) {
		var i, matches, sel, handleObj,
			handlerQueue = [],
			delegateCount = handlers.delegateCount,
			cur = event.target;

		// Find delegate handlers
		// Black-hole SVG <use> instance trees (#13180)
		// Avoid non-left-click bubbling in Firefox (#3861)
		if ( delegateCount && cur.nodeType && (!event.button || event.type !== "click") ) {

			for ( ; cur !== this; cur = cur.parentNode || this ) {

				// Don't process clicks on disabled elements (#6911, #8165, #11382, #11764)
				if ( cur.disabled !== true || event.type !== "click" ) {
					matches = [];
					for ( i = 0; i < delegateCount; i++ ) {
						handleObj = handlers[ i ];

						// Don't conflict with Object.prototype properties (#13203)
						sel = handleObj.selector + " ";

						if ( matches[ sel ] === undefined ) {
							matches[ sel ] = handleObj.needsContext ?
								jQuery( sel, this ).index( cur ) >= 0 :
								jQuery.find( sel, this, null, [ cur ] ).length;
						}
						if ( matches[ sel ] ) {
							matches.push( handleObj );
						}
					}
					if ( matches.length ) {
						handlerQueue.push({ elem: cur, handlers: matches });
					}
				}
			}
		}

		// Add the remaining (directly-bound) handlers
		if ( delegateCount < handlers.length ) {
			handlerQueue.push({ elem: this, handlers: handlers.slice( delegateCount ) });
		}

		return handlerQueue;
	},

	// Includes some event props shared by KeyEvent and MouseEvent
	props: "altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),

	fixHooks: {},

	keyHooks: {
		props: "char charCode key keyCode".split(" "),
		filter: function( event, original ) {

			// Add which for key events
			if ( event.which == null ) {
				event.which = original.charCode != null ? original.charCode : original.keyCode;
			}

			return event;
		}
	},

	mouseHooks: {
		props: "button buttons clientX clientY offsetX offsetY pageX pageY screenX screenY toElement".split(" "),
		filter: function( event, original ) {
			var eventDoc, doc, body,
				button = original.button;

			// Calculate pageX/Y if missing and clientX/Y available
			if ( event.pageX == null && original.clientX != null ) {
				eventDoc = event.target.ownerDocument || document;
				doc = eventDoc.documentElement;
				body = eventDoc.body;

				event.pageX = original.clientX + ( doc && doc.scrollLeft || body && body.scrollLeft || 0 ) - ( doc && doc.clientLeft || body && body.clientLeft || 0 );
				event.pageY = original.clientY + ( doc && doc.scrollTop  || body && body.scrollTop  || 0 ) - ( doc && doc.clientTop  || body && body.clientTop  || 0 );
			}

			// Add which for click: 1 === left; 2 === middle; 3 === right
			// Note: button is not normalized, so don't use it
			if ( !event.which && button !== undefined ) {
				event.which = ( button & 1 ? 1 : ( button & 2 ? 3 : ( button & 4 ? 2 : 0 ) ) );
			}

			return event;
		}
	},

	fix: function( event ) {
		if ( event[ jQuery.expando ] ) {
			return event;
		}

		// Create a writable copy of the event object and normalize some properties
		var i, prop, copy,
			type = event.type,
			originalEvent = event,
			fixHook = this.fixHooks[ type ];

		if ( !fixHook ) {
			this.fixHooks[ type ] = fixHook =
				rmouseEvent.test( type ) ? this.mouseHooks :
				rkeyEvent.test( type ) ? this.keyHooks :
				{};
		}
		copy = fixHook.props ? this.props.concat( fixHook.props ) : this.props;

		event = new jQuery.Event( originalEvent );

		i = copy.length;
		while ( i-- ) {
			prop = copy[ i ];
			event[ prop ] = originalEvent[ prop ];
		}

		// Support: Cordova 2.5 (WebKit) (#13255)
		// All events should have a target; Cordova deviceready doesn't
		if ( !event.target ) {
			event.target = document;
		}

		// Support: Safari 6.0+, Chrome<28
		// Target should not be a text node (#504, #13143)
		if ( event.target.nodeType === 3 ) {
			event.target = event.target.parentNode;
		}

		return fixHook.filter ? fixHook.filter( event, originalEvent ) : event;
	},

	special: {
		load: {
			// Prevent triggered image.load events from bubbling to window.load
			noBubble: true
		},
		focus: {
			// Fire native event if possible so blur/focus sequence is correct
			trigger: function() {
				if ( this !== safeActiveElement() && this.focus ) {
					this.focus();
					return false;
				}
			},
			delegateType: "focusin"
		},
		blur: {
			trigger: function() {
				if ( this === safeActiveElement() && this.blur ) {
					this.blur();
					return false;
				}
			},
			delegateType: "focusout"
		},
		click: {
			// For checkbox, fire native event so checked state will be right
			trigger: function() {
				if ( this.type === "checkbox" && this.click && jQuery.nodeName( this, "input" ) ) {
					this.click();
					return false;
				}
			},

			// For cross-browser consistency, don't fire native .click() on links
			_default: function( event ) {
				return jQuery.nodeName( event.target, "a" );
			}
		},

		beforeunload: {
			postDispatch: function( event ) {

				// Support: Firefox 20+
				// Firefox doesn't alert if the returnValue field is not set.
				if ( event.result !== undefined && event.originalEvent ) {
					event.originalEvent.returnValue = event.result;
				}
			}
		}
	},

	simulate: function( type, elem, event, bubble ) {
		// Piggyback on a donor event to simulate a different one.
		// Fake originalEvent to avoid donor's stopPropagation, but if the
		// simulated event prevents default then we do the same on the donor.
		var e = jQuery.extend(
			new jQuery.Event(),
			event,
			{
				type: type,
				isSimulated: true,
				originalEvent: {}
			}
		);
		if ( bubble ) {
			jQuery.event.trigger( e, null, elem );
		} else {
			jQuery.event.dispatch.call( elem, e );
		}
		if ( e.isDefaultPrevented() ) {
			event.preventDefault();
		}
	}
};

jQuery.removeEvent = function( elem, type, handle ) {
	if ( elem.removeEventListener ) {
		elem.removeEventListener( type, handle, false );
	}
};

jQuery.Event = function( src, props ) {
	// Allow instantiation without the 'new' keyword
	if ( !(this instanceof jQuery.Event) ) {
		return new jQuery.Event( src, props );
	}

	// Event object
	if ( src && src.type ) {
		this.originalEvent = src;
		this.type = src.type;

		// Events bubbling up the document may have been marked as prevented
		// by a handler lower down the tree; reflect the correct value.
		this.isDefaultPrevented = src.defaultPrevented ||
				src.defaultPrevented === undefined &&
				// Support: Android<4.0
				src.returnValue === false ?
			returnTrue :
			returnFalse;

	// Event type
	} else {
		this.type = src;
	}

	// Put explicitly provided properties onto the event object
	if ( props ) {
		jQuery.extend( this, props );
	}

	// Create a timestamp if incoming event doesn't have one
	this.timeStamp = src && src.timeStamp || jQuery.now();

	// Mark it as fixed
	this[ jQuery.expando ] = true;
};

// jQuery.Event is based on DOM3 Events as specified by the ECMAScript Language Binding
// http://www.w3.org/TR/2003/WD-DOM-Level-3-Events-20030331/ecma-script-binding.html
jQuery.Event.prototype = {
	isDefaultPrevented: returnFalse,
	isPropagationStopped: returnFalse,
	isImmediatePropagationStopped: returnFalse,

	preventDefault: function() {
		var e = this.originalEvent;

		this.isDefaultPrevented = returnTrue;

		if ( e && e.preventDefault ) {
			e.preventDefault();
		}
	},
	stopPropagation: function() {
		var e = this.originalEvent;

		this.isPropagationStopped = returnTrue;

		if ( e && e.stopPropagation ) {
			e.stopPropagation();
		}
	},
	stopImmediatePropagation: function() {
		var e = this.originalEvent;

		this.isImmediatePropagationStopped = returnTrue;

		if ( e && e.stopImmediatePropagation ) {
			e.stopImmediatePropagation();
		}

		this.stopPropagation();
	}
};

// Create mouseenter/leave events using mouseover/out and event-time checks
// Support: Chrome 15+
jQuery.each({
	mouseenter: "mouseover",
	mouseleave: "mouseout",
	pointerenter: "pointerover",
	pointerleave: "pointerout"
}, function( orig, fix ) {
	jQuery.event.special[ orig ] = {
		delegateType: fix,
		bindType: fix,

		handle: function( event ) {
			var ret,
				target = this,
				related = event.relatedTarget,
				handleObj = event.handleObj;

			// For mousenter/leave call the handler if related is outside the target.
			// NB: No relatedTarget if the mouse left/entered the browser window
			if ( !related || (related !== target && !jQuery.contains( target, related )) ) {
				event.type = handleObj.origType;
				ret = handleObj.handler.apply( this, arguments );
				event.type = fix;
			}
			return ret;
		}
	};
});

// Support: Firefox, Chrome, Safari
// Create "bubbling" focus and blur events
if ( !support.focusinBubbles ) {
	jQuery.each({ focus: "focusin", blur: "focusout" }, function( orig, fix ) {

		// Attach a single capturing handler on the document while someone wants focusin/focusout
		var handler = function( event ) {
				jQuery.event.simulate( fix, event.target, jQuery.event.fix( event ), true );
			};

		jQuery.event.special[ fix ] = {
			setup: function() {
				var doc = this.ownerDocument || this,
					attaches = data_priv.access( doc, fix );

				if ( !attaches ) {
					doc.addEventListener( orig, handler, true );
				}
				data_priv.access( doc, fix, ( attaches || 0 ) + 1 );
			},
			teardown: function() {
				var doc = this.ownerDocument || this,
					attaches = data_priv.access( doc, fix ) - 1;

				if ( !attaches ) {
					doc.removeEventListener( orig, handler, true );
					data_priv.remove( doc, fix );

				} else {
					data_priv.access( doc, fix, attaches );
				}
			}
		};
	});
}

jQuery.fn.extend({

	on: function( types, selector, data, fn, /*INTERNAL*/ one ) {
		var origFn, type;

		// Types can be a map of types/handlers
		if ( typeof types === "object" ) {
			// ( types-Object, selector, data )
			if ( typeof selector !== "string" ) {
				// ( types-Object, data )
				data = data || selector;
				selector = undefined;
			}
			for ( type in types ) {
				this.on( type, selector, data, types[ type ], one );
			}
			return this;
		}

		if ( data == null && fn == null ) {
			// ( types, fn )
			fn = selector;
			data = selector = undefined;
		} else if ( fn == null ) {
			if ( typeof selector === "string" ) {
				// ( types, selector, fn )
				fn = data;
				data = undefined;
			} else {
				// ( types, data, fn )
				fn = data;
				data = selector;
				selector = undefined;
			}
		}
		if ( fn === false ) {
			fn = returnFalse;
		} else if ( !fn ) {
			return this;
		}

		if ( one === 1 ) {
			origFn = fn;
			fn = function( event ) {
				// Can use an empty set, since event contains the info
				jQuery().off( event );
				return origFn.apply( this, arguments );
			};
			// Use same guid so caller can remove using origFn
			fn.guid = origFn.guid || ( origFn.guid = jQuery.guid++ );
		}
		return this.each( function() {
			jQuery.event.add( this, types, fn, data, selector );
		});
	},
	one: function( types, selector, data, fn ) {
		return this.on( types, selector, data, fn, 1 );
	},
	off: function( types, selector, fn ) {
		var handleObj, type;
		if ( types && types.preventDefault && types.handleObj ) {
			// ( event )  dispatched jQuery.Event
			handleObj = types.handleObj;
			jQuery( types.delegateTarget ).off(
				handleObj.namespace ? handleObj.origType + "." + handleObj.namespace : handleObj.origType,
				handleObj.selector,
				handleObj.handler
			);
			return this;
		}
		if ( typeof types === "object" ) {
			// ( types-object [, selector] )
			for ( type in types ) {
				this.off( type, selector, types[ type ] );
			}
			return this;
		}
		if ( selector === false || typeof selector === "function" ) {
			// ( types [, fn] )
			fn = selector;
			selector = undefined;
		}
		if ( fn === false ) {
			fn = returnFalse;
		}
		return this.each(function() {
			jQuery.event.remove( this, types, fn, selector );
		});
	},

	trigger: function( type, data ) {
		return this.each(function() {
			jQuery.event.trigger( type, data, this );
		});
	},
	triggerHandler: function( type, data ) {
		var elem = this[0];
		if ( elem ) {
			return jQuery.event.trigger( type, data, elem, true );
		}
	}
});


var
	rxhtmlTag = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/gi,
	rtagName = /<([\w:]+)/,
	rhtml = /<|&#?\w+;/,
	rnoInnerhtml = /<(?:script|style|link)/i,
	// checked="checked" or checked
	rchecked = /checked\s*(?:[^=]|=\s*.checked.)/i,
	rscriptType = /^$|\/(?:java|ecma)script/i,
	rscriptTypeMasked = /^true\/(.*)/,
	rcleanScript = /^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g,

	// We have to close these tags to support XHTML (#13200)
	wrapMap = {

		// Support: IE9
		option: [ 1, "<select multiple='multiple'>", "</select>" ],

		thead: [ 1, "<table>", "</table>" ],
		col: [ 2, "<table><colgroup>", "</colgroup></table>" ],
		tr: [ 2, "<table><tbody>", "</tbody></table>" ],
		td: [ 3, "<table><tbody><tr>", "</tr></tbody></table>" ],

		_default: [ 0, "", "" ]
	};

// Support: IE9
wrapMap.optgroup = wrapMap.option;

wrapMap.tbody = wrapMap.tfoot = wrapMap.colgroup = wrapMap.caption = wrapMap.thead;
wrapMap.th = wrapMap.td;

// Support: 1.x compatibility
// Manipulating tables requires a tbody
function manipulationTarget( elem, content ) {
	return jQuery.nodeName( elem, "table" ) &&
		jQuery.nodeName( content.nodeType !== 11 ? content : content.firstChild, "tr" ) ?

		elem.getElementsByTagName("tbody")[0] ||
			elem.appendChild( elem.ownerDocument.createElement("tbody") ) :
		elem;
}

// Replace/restore the type attribute of script elements for safe DOM manipulation
function disableScript( elem ) {
	elem.type = (elem.getAttribute("type") !== null) + "/" + elem.type;
	return elem;
}
function restoreScript( elem ) {
	var match = rscriptTypeMasked.exec( elem.type );

	if ( match ) {
		elem.type = match[ 1 ];
	} else {
		elem.removeAttribute("type");
	}

	return elem;
}

// Mark scripts as having already been evaluated
function setGlobalEval( elems, refElements ) {
	var i = 0,
		l = elems.length;

	for ( ; i < l; i++ ) {
		data_priv.set(
			elems[ i ], "globalEval", !refElements || data_priv.get( refElements[ i ], "globalEval" )
		);
	}
}

function cloneCopyEvent( src, dest ) {
	var i, l, type, pdataOld, pdataCur, udataOld, udataCur, events;

	if ( dest.nodeType !== 1 ) {
		return;
	}

	// 1. Copy private data: events, handlers, etc.
	if ( data_priv.hasData( src ) ) {
		pdataOld = data_priv.access( src );
		pdataCur = data_priv.set( dest, pdataOld );
		events = pdataOld.events;

		if ( events ) {
			delete pdataCur.handle;
			pdataCur.events = {};

			for ( type in events ) {
				for ( i = 0, l = events[ type ].length; i < l; i++ ) {
					jQuery.event.add( dest, type, events[ type ][ i ] );
				}
			}
		}
	}

	// 2. Copy user data
	if ( data_user.hasData( src ) ) {
		udataOld = data_user.access( src );
		udataCur = jQuery.extend( {}, udataOld );

		data_user.set( dest, udataCur );
	}
}

function getAll( context, tag ) {
	var ret = context.getElementsByTagName ? context.getElementsByTagName( tag || "*" ) :
			context.querySelectorAll ? context.querySelectorAll( tag || "*" ) :
			[];

	return tag === undefined || tag && jQuery.nodeName( context, tag ) ?
		jQuery.merge( [ context ], ret ) :
		ret;
}

// Fix IE bugs, see support tests
function fixInput( src, dest ) {
	var nodeName = dest.nodeName.toLowerCase();

	// Fails to persist the checked state of a cloned checkbox or radio button.
	if ( nodeName === "input" && rcheckableType.test( src.type ) ) {
		dest.checked = src.checked;

	// Fails to return the selected option to the default selected state when cloning options
	} else if ( nodeName === "input" || nodeName === "textarea" ) {
		dest.defaultValue = src.defaultValue;
	}
}

jQuery.extend({
	clone: function( elem, dataAndEvents, deepDataAndEvents ) {
		var i, l, srcElements, destElements,
			clone = elem.cloneNode( true ),
			inPage = jQuery.contains( elem.ownerDocument, elem );

		// Fix IE cloning issues
		if ( !support.noCloneChecked && ( elem.nodeType === 1 || elem.nodeType === 11 ) &&
				!jQuery.isXMLDoc( elem ) ) {

			// We eschew Sizzle here for performance reasons: http://jsperf.com/getall-vs-sizzle/2
			destElements = getAll( clone );
			srcElements = getAll( elem );

			for ( i = 0, l = srcElements.length; i < l; i++ ) {
				fixInput( srcElements[ i ], destElements[ i ] );
			}
		}

		// Copy the events from the original to the clone
		if ( dataAndEvents ) {
			if ( deepDataAndEvents ) {
				srcElements = srcElements || getAll( elem );
				destElements = destElements || getAll( clone );

				for ( i = 0, l = srcElements.length; i < l; i++ ) {
					cloneCopyEvent( srcElements[ i ], destElements[ i ] );
				}
			} else {
				cloneCopyEvent( elem, clone );
			}
		}

		// Preserve script evaluation history
		destElements = getAll( clone, "script" );
		if ( destElements.length > 0 ) {
			setGlobalEval( destElements, !inPage && getAll( elem, "script" ) );
		}

		// Return the cloned set
		return clone;
	},

	buildFragment: function( elems, context, scripts, selection ) {
		var elem, tmp, tag, wrap, contains, j,
			fragment = context.createDocumentFragment(),
			nodes = [],
			i = 0,
			l = elems.length;

		for ( ; i < l; i++ ) {
			elem = elems[ i ];

			if ( elem || elem === 0 ) {

				// Add nodes directly
				if ( jQuery.type( elem ) === "object" ) {
					// Support: QtWebKit, PhantomJS
					// push.apply(_, arraylike) throws on ancient WebKit
					jQuery.merge( nodes, elem.nodeType ? [ elem ] : elem );

				// Convert non-html into a text node
				} else if ( !rhtml.test( elem ) ) {
					nodes.push( context.createTextNode( elem ) );

				// Convert html into DOM nodes
				} else {
					tmp = tmp || fragment.appendChild( context.createElement("div") );

					// Deserialize a standard representation
					tag = ( rtagName.exec( elem ) || [ "", "" ] )[ 1 ].toLowerCase();
					wrap = wrapMap[ tag ] || wrapMap._default;
					tmp.innerHTML = wrap[ 1 ] + elem.replace( rxhtmlTag, "<$1></$2>" ) + wrap[ 2 ];

					// Descend through wrappers to the right content
					j = wrap[ 0 ];
					while ( j-- ) {
						tmp = tmp.lastChild;
					}

					// Support: QtWebKit, PhantomJS
					// push.apply(_, arraylike) throws on ancient WebKit
					jQuery.merge( nodes, tmp.childNodes );

					// Remember the top-level container
					tmp = fragment.firstChild;

					// Ensure the created nodes are orphaned (#12392)
					tmp.textContent = "";
				}
			}
		}

		// Remove wrapper from fragment
		fragment.textContent = "";

		i = 0;
		while ( (elem = nodes[ i++ ]) ) {

			// #4087 - If origin and destination elements are the same, and this is
			// that element, do not do anything
			if ( selection && jQuery.inArray( elem, selection ) !== -1 ) {
				continue;
			}

			contains = jQuery.contains( elem.ownerDocument, elem );

			// Append to fragment
			tmp = getAll( fragment.appendChild( elem ), "script" );

			// Preserve script evaluation history
			if ( contains ) {
				setGlobalEval( tmp );
			}

			// Capture executables
			if ( scripts ) {
				j = 0;
				while ( (elem = tmp[ j++ ]) ) {
					if ( rscriptType.test( elem.type || "" ) ) {
						scripts.push( elem );
					}
				}
			}
		}

		return fragment;
	},

	cleanData: function( elems ) {
		var data, elem, type, key,
			special = jQuery.event.special,
			i = 0;

		for ( ; (elem = elems[ i ]) !== undefined; i++ ) {
			if ( jQuery.acceptData( elem ) ) {
				key = elem[ data_priv.expando ];

				if ( key && (data = data_priv.cache[ key ]) ) {
					if ( data.events ) {
						for ( type in data.events ) {
							if ( special[ type ] ) {
								jQuery.event.remove( elem, type );

							// This is a shortcut to avoid jQuery.event.remove's overhead
							} else {
								jQuery.removeEvent( elem, type, data.handle );
							}
						}
					}
					if ( data_priv.cache[ key ] ) {
						// Discard any remaining `private` data
						delete data_priv.cache[ key ];
					}
				}
			}
			// Discard any remaining `user` data
			delete data_user.cache[ elem[ data_user.expando ] ];
		}
	}
});

jQuery.fn.extend({
	text: function( value ) {
		return access( this, function( value ) {
			return value === undefined ?
				jQuery.text( this ) :
				this.empty().each(function() {
					if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
						this.textContent = value;
					}
				});
		}, null, value, arguments.length );
	},

	append: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.appendChild( elem );
			}
		});
	},

	prepend: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.insertBefore( elem, target.firstChild );
			}
		});
	},

	before: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this );
			}
		});
	},

	after: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this.nextSibling );
			}
		});
	},

	remove: function( selector, keepData /* Internal Use Only */ ) {
		var elem,
			elems = selector ? jQuery.filter( selector, this ) : this,
			i = 0;

		for ( ; (elem = elems[i]) != null; i++ ) {
			if ( !keepData && elem.nodeType === 1 ) {
				jQuery.cleanData( getAll( elem ) );
			}

			if ( elem.parentNode ) {
				if ( keepData && jQuery.contains( elem.ownerDocument, elem ) ) {
					setGlobalEval( getAll( elem, "script" ) );
				}
				elem.parentNode.removeChild( elem );
			}
		}

		return this;
	},

	empty: function() {
		var elem,
			i = 0;

		for ( ; (elem = this[i]) != null; i++ ) {
			if ( elem.nodeType === 1 ) {

				// Prevent memory leaks
				jQuery.cleanData( getAll( elem, false ) );

				// Remove any remaining nodes
				elem.textContent = "";
			}
		}

		return this;
	},

	clone: function( dataAndEvents, deepDataAndEvents ) {
		dataAndEvents = dataAndEvents == null ? false : dataAndEvents;
		deepDataAndEvents = deepDataAndEvents == null ? dataAndEvents : deepDataAndEvents;

		return this.map(function() {
			return jQuery.clone( this, dataAndEvents, deepDataAndEvents );
		});
	},

	html: function( value ) {
		return access( this, function( value ) {
			var elem = this[ 0 ] || {},
				i = 0,
				l = this.length;

			if ( value === undefined && elem.nodeType === 1 ) {
				return elem.innerHTML;
			}

			// See if we can take a shortcut and just use innerHTML
			if ( typeof value === "string" && !rnoInnerhtml.test( value ) &&
				!wrapMap[ ( rtagName.exec( value ) || [ "", "" ] )[ 1 ].toLowerCase() ] ) {

				value = value.replace( rxhtmlTag, "<$1></$2>" );

				try {
					for ( ; i < l; i++ ) {
						elem = this[ i ] || {};

						// Remove element nodes and prevent memory leaks
						if ( elem.nodeType === 1 ) {
							jQuery.cleanData( getAll( elem, false ) );
							elem.innerHTML = value;
						}
					}

					elem = 0;

				// If using innerHTML throws an exception, use the fallback method
				} catch( e ) {}
			}

			if ( elem ) {
				this.empty().append( value );
			}
		}, null, value, arguments.length );
	},

	replaceWith: function() {
		var arg = arguments[ 0 ];

		// Make the changes, replacing each context element with the new content
		this.domManip( arguments, function( elem ) {
			arg = this.parentNode;

			jQuery.cleanData( getAll( this ) );

			if ( arg ) {
				arg.replaceChild( elem, this );
			}
		});

		// Force removal if there was no new content (e.g., from empty arguments)
		return arg && (arg.length || arg.nodeType) ? this : this.remove();
	},

	detach: function( selector ) {
		return this.remove( selector, true );
	},

	domManip: function( args, callback ) {

		// Flatten any nested arrays
		args = concat.apply( [], args );

		var fragment, first, scripts, hasScripts, node, doc,
			i = 0,
			l = this.length,
			set = this,
			iNoClone = l - 1,
			value = args[ 0 ],
			isFunction = jQuery.isFunction( value );

		// We can't cloneNode fragments that contain checked, in WebKit
		if ( isFunction ||
				( l > 1 && typeof value === "string" &&
					!support.checkClone && rchecked.test( value ) ) ) {
			return this.each(function( index ) {
				var self = set.eq( index );
				if ( isFunction ) {
					args[ 0 ] = value.call( this, index, self.html() );
				}
				self.domManip( args, callback );
			});
		}

		if ( l ) {
			fragment = jQuery.buildFragment( args, this[ 0 ].ownerDocument, false, this );
			first = fragment.firstChild;

			if ( fragment.childNodes.length === 1 ) {
				fragment = first;
			}

			if ( first ) {
				scripts = jQuery.map( getAll( fragment, "script" ), disableScript );
				hasScripts = scripts.length;

				// Use the original fragment for the last item instead of the first because it can end up
				// being emptied incorrectly in certain situations (#8070).
				for ( ; i < l; i++ ) {
					node = fragment;

					if ( i !== iNoClone ) {
						node = jQuery.clone( node, true, true );

						// Keep references to cloned scripts for later restoration
						if ( hasScripts ) {
							// Support: QtWebKit
							// jQuery.merge because push.apply(_, arraylike) throws
							jQuery.merge( scripts, getAll( node, "script" ) );
						}
					}

					callback.call( this[ i ], node, i );
				}

				if ( hasScripts ) {
					doc = scripts[ scripts.length - 1 ].ownerDocument;

					// Reenable scripts
					jQuery.map( scripts, restoreScript );

					// Evaluate executable scripts on first document insertion
					for ( i = 0; i < hasScripts; i++ ) {
						node = scripts[ i ];
						if ( rscriptType.test( node.type || "" ) &&
							!data_priv.access( node, "globalEval" ) && jQuery.contains( doc, node ) ) {

							if ( node.src ) {
								// Optional AJAX dependency, but won't run scripts if not present
								if ( jQuery._evalUrl ) {
									jQuery._evalUrl( node.src );
								}
							} else {
								jQuery.globalEval( node.textContent.replace( rcleanScript, "" ) );
							}
						}
					}
				}
			}
		}

		return this;
	}
});

jQuery.each({
	appendTo: "append",
	prependTo: "prepend",
	insertBefore: "before",
	insertAfter: "after",
	replaceAll: "replaceWith"
}, function( name, original ) {
	jQuery.fn[ name ] = function( selector ) {
		var elems,
			ret = [],
			insert = jQuery( selector ),
			last = insert.length - 1,
			i = 0;

		for ( ; i <= last; i++ ) {
			elems = i === last ? this : this.clone( true );
			jQuery( insert[ i ] )[ original ]( elems );

			// Support: QtWebKit
			// .get() because push.apply(_, arraylike) throws
			push.apply( ret, elems.get() );
		}

		return this.pushStack( ret );
	};
});


var iframe,
	elemdisplay = {};

/**
 * Retrieve the actual display of a element
 * @param {String} name nodeName of the element
 * @param {Object} doc Document object
 */
// Called only from within defaultDisplay
function actualDisplay( name, doc ) {
	var style,
		elem = jQuery( doc.createElement( name ) ).appendTo( doc.body ),

		// getDefaultComputedStyle might be reliably used only on attached element
		display = window.getDefaultComputedStyle && ( style = window.getDefaultComputedStyle( elem[ 0 ] ) ) ?

			// Use of this method is a temporary fix (more like optimization) until something better comes along,
			// since it was removed from specification and supported only in FF
			style.display : jQuery.css( elem[ 0 ], "display" );

	// We don't have any data stored on the element,
	// so use "detach" method as fast way to get rid of the element
	elem.detach();

	return display;
}

/**
 * Try to determine the default display value of an element
 * @param {String} nodeName
 */
function defaultDisplay( nodeName ) {
	var doc = document,
		display = elemdisplay[ nodeName ];

	if ( !display ) {
		display = actualDisplay( nodeName, doc );

		// If the simple way fails, read from inside an iframe
		if ( display === "none" || !display ) {

			// Use the already-created iframe if possible
			iframe = (iframe || jQuery( "<iframe frameborder='0' width='0' height='0'/>" )).appendTo( doc.documentElement );

			// Always write a new HTML skeleton so Webkit and Firefox don't choke on reuse
			doc = iframe[ 0 ].contentDocument;

			// Support: IE
			doc.write();
			doc.close();

			display = actualDisplay( nodeName, doc );
			iframe.detach();
		}

		// Store the correct default display
		elemdisplay[ nodeName ] = display;
	}

	return display;
}
var rmargin = (/^margin/);

var rnumnonpx = new RegExp( "^(" + pnum + ")(?!px)[a-z%]+$", "i" );

var getStyles = function( elem ) {
		// Support: IE<=11+, Firefox<=30+ (#15098, #14150)
		// IE throws on elements created in popups
		// FF meanwhile throws on frame elements through "defaultView.getComputedStyle"
		if ( elem.ownerDocument.defaultView.opener ) {
			return elem.ownerDocument.defaultView.getComputedStyle( elem, null );
		}

		return window.getComputedStyle( elem, null );
	};



function curCSS( elem, name, computed ) {
	var width, minWidth, maxWidth, ret,
		style = elem.style;

	computed = computed || getStyles( elem );

	// Support: IE9
	// getPropertyValue is only needed for .css('filter') (#12537)
	if ( computed ) {
		ret = computed.getPropertyValue( name ) || computed[ name ];
	}

	if ( computed ) {

		if ( ret === "" && !jQuery.contains( elem.ownerDocument, elem ) ) {
			ret = jQuery.style( elem, name );
		}

		// Support: iOS < 6
		// A tribute to the "awesome hack by Dean Edwards"
		// iOS < 6 (at least) returns percentage for a larger set of values, but width seems to be reliably pixels
		// this is against the CSSOM draft spec: http://dev.w3.org/csswg/cssom/#resolved-values
		if ( rnumnonpx.test( ret ) && rmargin.test( name ) ) {

			// Remember the original values
			width = style.width;
			minWidth = style.minWidth;
			maxWidth = style.maxWidth;

			// Put in the new values to get a computed value out
			style.minWidth = style.maxWidth = style.width = ret;
			ret = computed.width;

			// Revert the changed values
			style.width = width;
			style.minWidth = minWidth;
			style.maxWidth = maxWidth;
		}
	}

	return ret !== undefined ?
		// Support: IE
		// IE returns zIndex value as an integer.
		ret + "" :
		ret;
}


function addGetHookIf( conditionFn, hookFn ) {
	// Define the hook, we'll check on the first run if it's really needed.
	return {
		get: function() {
			if ( conditionFn() ) {
				// Hook not needed (or it's not possible to use it due
				// to missing dependency), remove it.
				delete this.get;
				return;
			}

			// Hook needed; redefine it so that the support test is not executed again.
			return (this.get = hookFn).apply( this, arguments );
		}
	};
}


(function() {
	var pixelPositionVal, boxSizingReliableVal,
		docElem = document.documentElement,
		container = document.createElement( "div" ),
		div = document.createElement( "div" );

	if ( !div.style ) {
		return;
	}

	// Support: IE9-11+
	// Style of cloned element affects source element cloned (#8908)
	div.style.backgroundClip = "content-box";
	div.cloneNode( true ).style.backgroundClip = "";
	support.clearCloneStyle = div.style.backgroundClip === "content-box";

	container.style.cssText = "border:0;width:0;height:0;top:0;left:-9999px;margin-top:1px;" +
		"position:absolute";
	container.appendChild( div );

	// Executing both pixelPosition & boxSizingReliable tests require only one layout
	// so they're executed at the same time to save the second computation.
	function computePixelPositionAndBoxSizingReliable() {
		div.style.cssText =
			// Support: Firefox<29, Android 2.3
			// Vendor-prefix box-sizing
			"-webkit-box-sizing:border-box;-moz-box-sizing:border-box;" +
			"box-sizing:border-box;display:block;margin-top:1%;top:1%;" +
			"border:1px;padding:1px;width:4px;position:absolute";
		div.innerHTML = "";
		docElem.appendChild( container );

		var divStyle = window.getComputedStyle( div, null );
		pixelPositionVal = divStyle.top !== "1%";
		boxSizingReliableVal = divStyle.width === "4px";

		docElem.removeChild( container );
	}

	// Support: node.js jsdom
	// Don't assume that getComputedStyle is a property of the global object
	if ( window.getComputedStyle ) {
		jQuery.extend( support, {
			pixelPosition: function() {

				// This test is executed only once but we still do memoizing
				// since we can use the boxSizingReliable pre-computing.
				// No need to check if the test was already performed, though.
				computePixelPositionAndBoxSizingReliable();
				return pixelPositionVal;
			},
			boxSizingReliable: function() {
				if ( boxSizingReliableVal == null ) {
					computePixelPositionAndBoxSizingReliable();
				}
				return boxSizingReliableVal;
			},
			reliableMarginRight: function() {

				// Support: Android 2.3
				// Check if div with explicit width and no margin-right incorrectly
				// gets computed margin-right based on width of container. (#3333)
				// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
				// This support function is only executed once so no memoizing is needed.
				var ret,
					marginDiv = div.appendChild( document.createElement( "div" ) );

				// Reset CSS: box-sizing; display; margin; border; padding
				marginDiv.style.cssText = div.style.cssText =
					// Support: Firefox<29, Android 2.3
					// Vendor-prefix box-sizing
					"-webkit-box-sizing:content-box;-moz-box-sizing:content-box;" +
					"box-sizing:content-box;display:block;margin:0;border:0;padding:0";
				marginDiv.style.marginRight = marginDiv.style.width = "0";
				div.style.width = "1px";
				docElem.appendChild( container );

				ret = !parseFloat( window.getComputedStyle( marginDiv, null ).marginRight );

				docElem.removeChild( container );
				div.removeChild( marginDiv );

				return ret;
			}
		});
	}
})();


// A method for quickly swapping in/out CSS properties to get correct calculations.
jQuery.swap = function( elem, options, callback, args ) {
	var ret, name,
		old = {};

	// Remember the old values, and insert the new ones
	for ( name in options ) {
		old[ name ] = elem.style[ name ];
		elem.style[ name ] = options[ name ];
	}

	ret = callback.apply( elem, args || [] );

	// Revert the old values
	for ( name in options ) {
		elem.style[ name ] = old[ name ];
	}

	return ret;
};


var
	// Swappable if display is none or starts with table except "table", "table-cell", or "table-caption"
	// See here for display values: https://developer.mozilla.org/en-US/docs/CSS/display
	rdisplayswap = /^(none|table(?!-c[ea]).+)/,
	rnumsplit = new RegExp( "^(" + pnum + ")(.*)$", "i" ),
	rrelNum = new RegExp( "^([+-])=(" + pnum + ")", "i" ),

	cssShow = { position: "absolute", visibility: "hidden", display: "block" },
	cssNormalTransform = {
		letterSpacing: "0",
		fontWeight: "400"
	},

	cssPrefixes = [ "Webkit", "O", "Moz", "ms" ];

// Return a css property mapped to a potentially vendor prefixed property
function vendorPropName( style, name ) {

	// Shortcut for names that are not vendor prefixed
	if ( name in style ) {
		return name;
	}

	// Check for vendor prefixed names
	var capName = name[0].toUpperCase() + name.slice(1),
		origName = name,
		i = cssPrefixes.length;

	while ( i-- ) {
		name = cssPrefixes[ i ] + capName;
		if ( name in style ) {
			return name;
		}
	}

	return origName;
}

function setPositiveNumber( elem, value, subtract ) {
	var matches = rnumsplit.exec( value );
	return matches ?
		// Guard against undefined "subtract", e.g., when used as in cssHooks
		Math.max( 0, matches[ 1 ] - ( subtract || 0 ) ) + ( matches[ 2 ] || "px" ) :
		value;
}

function augmentWidthOrHeight( elem, name, extra, isBorderBox, styles ) {
	var i = extra === ( isBorderBox ? "border" : "content" ) ?
		// If we already have the right measurement, avoid augmentation
		4 :
		// Otherwise initialize for horizontal or vertical properties
		name === "width" ? 1 : 0,

		val = 0;

	for ( ; i < 4; i += 2 ) {
		// Both box models exclude margin, so add it if we want it
		if ( extra === "margin" ) {
			val += jQuery.css( elem, extra + cssExpand[ i ], true, styles );
		}

		if ( isBorderBox ) {
			// border-box includes padding, so remove it if we want content
			if ( extra === "content" ) {
				val -= jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );
			}

			// At this point, extra isn't border nor margin, so remove border
			if ( extra !== "margin" ) {
				val -= jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		} else {
			// At this point, extra isn't content, so add padding
			val += jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );

			// At this point, extra isn't content nor padding, so add border
			if ( extra !== "padding" ) {
				val += jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		}
	}

	return val;
}

function getWidthOrHeight( elem, name, extra ) {

	// Start with offset property, which is equivalent to the border-box value
	var valueIsBorderBox = true,
		val = name === "width" ? elem.offsetWidth : elem.offsetHeight,
		styles = getStyles( elem ),
		isBorderBox = jQuery.css( elem, "boxSizing", false, styles ) === "border-box";

	// Some non-html elements return undefined for offsetWidth, so check for null/undefined
	// svg - https://bugzilla.mozilla.org/show_bug.cgi?id=649285
	// MathML - https://bugzilla.mozilla.org/show_bug.cgi?id=491668
	if ( val <= 0 || val == null ) {
		// Fall back to computed then uncomputed css if necessary
		val = curCSS( elem, name, styles );
		if ( val < 0 || val == null ) {
			val = elem.style[ name ];
		}

		// Computed unit is not pixels. Stop here and return.
		if ( rnumnonpx.test(val) ) {
			return val;
		}

		// Check for style in case a browser which returns unreliable values
		// for getComputedStyle silently falls back to the reliable elem.style
		valueIsBorderBox = isBorderBox &&
			( support.boxSizingReliable() || val === elem.style[ name ] );

		// Normalize "", auto, and prepare for extra
		val = parseFloat( val ) || 0;
	}

	// Use the active box-sizing model to add/subtract irrelevant styles
	return ( val +
		augmentWidthOrHeight(
			elem,
			name,
			extra || ( isBorderBox ? "border" : "content" ),
			valueIsBorderBox,
			styles
		)
	) + "px";
}

function showHide( elements, show ) {
	var display, elem, hidden,
		values = [],
		index = 0,
		length = elements.length;

	for ( ; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}

		values[ index ] = data_priv.get( elem, "olddisplay" );
		display = elem.style.display;
		if ( show ) {
			// Reset the inline display of this element to learn if it is
			// being hidden by cascaded rules or not
			if ( !values[ index ] && display === "none" ) {
				elem.style.display = "";
			}

			// Set elements which have been overridden with display: none
			// in a stylesheet to whatever the default browser style is
			// for such an element
			if ( elem.style.display === "" && isHidden( elem ) ) {
				values[ index ] = data_priv.access( elem, "olddisplay", defaultDisplay(elem.nodeName) );
			}
		} else {
			hidden = isHidden( elem );

			if ( display !== "none" || !hidden ) {
				data_priv.set( elem, "olddisplay", hidden ? display : jQuery.css( elem, "display" ) );
			}
		}
	}

	// Set the display of most of the elements in a second loop
	// to avoid the constant reflow
	for ( index = 0; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}
		if ( !show || elem.style.display === "none" || elem.style.display === "" ) {
			elem.style.display = show ? values[ index ] || "" : "none";
		}
	}

	return elements;
}

jQuery.extend({

	// Add in style property hooks for overriding the default
	// behavior of getting and setting a style property
	cssHooks: {
		opacity: {
			get: function( elem, computed ) {
				if ( computed ) {

					// We should always get a number back from opacity
					var ret = curCSS( elem, "opacity" );
					return ret === "" ? "1" : ret;
				}
			}
		}
	},

	// Don't automatically add "px" to these possibly-unitless properties
	cssNumber: {
		"columnCount": true,
		"fillOpacity": true,
		"flexGrow": true,
		"flexShrink": true,
		"fontWeight": true,
		"lineHeight": true,
		"opacity": true,
		"order": true,
		"orphans": true,
		"widows": true,
		"zIndex": true,
		"zoom": true
	},

	// Add in properties whose names you wish to fix before
	// setting or getting the value
	cssProps: {
		"float": "cssFloat"
	},

	// Get and set the style property on a DOM Node
	style: function( elem, name, value, extra ) {

		// Don't set styles on text and comment nodes
		if ( !elem || elem.nodeType === 3 || elem.nodeType === 8 || !elem.style ) {
			return;
		}

		// Make sure that we're working with the right name
		var ret, type, hooks,
			origName = jQuery.camelCase( name ),
			style = elem.style;

		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( style, origName ) );

		// Gets hook for the prefixed version, then unprefixed version
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// Check if we're setting a value
		if ( value !== undefined ) {
			type = typeof value;

			// Convert "+=" or "-=" to relative numbers (#7345)
			if ( type === "string" && (ret = rrelNum.exec( value )) ) {
				value = ( ret[1] + 1 ) * ret[2] + parseFloat( jQuery.css( elem, name ) );
				// Fixes bug #9237
				type = "number";
			}

			// Make sure that null and NaN values aren't set (#7116)
			if ( value == null || value !== value ) {
				return;
			}

			// If a number, add 'px' to the (except for certain CSS properties)
			if ( type === "number" && !jQuery.cssNumber[ origName ] ) {
				value += "px";
			}

			// Support: IE9-11+
			// background-* props affect original clone's values
			if ( !support.clearCloneStyle && value === "" && name.indexOf( "background" ) === 0 ) {
				style[ name ] = "inherit";
			}

			// If a hook was provided, use that value, otherwise just set the specified value
			if ( !hooks || !("set" in hooks) || (value = hooks.set( elem, value, extra )) !== undefined ) {
				style[ name ] = value;
			}

		} else {
			// If a hook was provided get the non-computed value from there
			if ( hooks && "get" in hooks && (ret = hooks.get( elem, false, extra )) !== undefined ) {
				return ret;
			}

			// Otherwise just get the value from the style object
			return style[ name ];
		}
	},

	css: function( elem, name, extra, styles ) {
		var val, num, hooks,
			origName = jQuery.camelCase( name );

		// Make sure that we're working with the right name
		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( elem.style, origName ) );

		// Try prefixed name followed by the unprefixed name
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// If a hook was provided get the computed value from there
		if ( hooks && "get" in hooks ) {
			val = hooks.get( elem, true, extra );
		}

		// Otherwise, if a way to get the computed value exists, use that
		if ( val === undefined ) {
			val = curCSS( elem, name, styles );
		}

		// Convert "normal" to computed value
		if ( val === "normal" && name in cssNormalTransform ) {
			val = cssNormalTransform[ name ];
		}

		// Make numeric if forced or a qualifier was provided and val looks numeric
		if ( extra === "" || extra ) {
			num = parseFloat( val );
			return extra === true || jQuery.isNumeric( num ) ? num || 0 : val;
		}
		return val;
	}
});

jQuery.each([ "height", "width" ], function( i, name ) {
	jQuery.cssHooks[ name ] = {
		get: function( elem, computed, extra ) {
			if ( computed ) {

				// Certain elements can have dimension info if we invisibly show them
				// but it must have a current display style that would benefit
				return rdisplayswap.test( jQuery.css( elem, "display" ) ) && elem.offsetWidth === 0 ?
					jQuery.swap( elem, cssShow, function() {
						return getWidthOrHeight( elem, name, extra );
					}) :
					getWidthOrHeight( elem, name, extra );
			}
		},

		set: function( elem, value, extra ) {
			var styles = extra && getStyles( elem );
			return setPositiveNumber( elem, value, extra ?
				augmentWidthOrHeight(
					elem,
					name,
					extra,
					jQuery.css( elem, "boxSizing", false, styles ) === "border-box",
					styles
				) : 0
			);
		}
	};
});

// Support: Android 2.3
jQuery.cssHooks.marginRight = addGetHookIf( support.reliableMarginRight,
	function( elem, computed ) {
		if ( computed ) {
			return jQuery.swap( elem, { "display": "inline-block" },
				curCSS, [ elem, "marginRight" ] );
		}
	}
);

// These hooks are used by animate to expand properties
jQuery.each({
	margin: "",
	padding: "",
	border: "Width"
}, function( prefix, suffix ) {
	jQuery.cssHooks[ prefix + suffix ] = {
		expand: function( value ) {
			var i = 0,
				expanded = {},

				// Assumes a single number if not a string
				parts = typeof value === "string" ? value.split(" ") : [ value ];

			for ( ; i < 4; i++ ) {
				expanded[ prefix + cssExpand[ i ] + suffix ] =
					parts[ i ] || parts[ i - 2 ] || parts[ 0 ];
			}

			return expanded;
		}
	};

	if ( !rmargin.test( prefix ) ) {
		jQuery.cssHooks[ prefix + suffix ].set = setPositiveNumber;
	}
});

jQuery.fn.extend({
	css: function( name, value ) {
		return access( this, function( elem, name, value ) {
			var styles, len,
				map = {},
				i = 0;

			if ( jQuery.isArray( name ) ) {
				styles = getStyles( elem );
				len = name.length;

				for ( ; i < len; i++ ) {
					map[ name[ i ] ] = jQuery.css( elem, name[ i ], false, styles );
				}

				return map;
			}

			return value !== undefined ?
				jQuery.style( elem, name, value ) :
				jQuery.css( elem, name );
		}, name, value, arguments.length > 1 );
	},
	show: function() {
		return showHide( this, true );
	},
	hide: function() {
		return showHide( this );
	},
	toggle: function( state ) {
		if ( typeof state === "boolean" ) {
			return state ? this.show() : this.hide();
		}

		return this.each(function() {
			if ( isHidden( this ) ) {
				jQuery( this ).show();
			} else {
				jQuery( this ).hide();
			}
		});
	}
});


function Tween( elem, options, prop, end, easing ) {
	return new Tween.prototype.init( elem, options, prop, end, easing );
}
jQuery.Tween = Tween;

Tween.prototype = {
	constructor: Tween,
	init: function( elem, options, prop, end, easing, unit ) {
		this.elem = elem;
		this.prop = prop;
		this.easing = easing || "swing";
		this.options = options;
		this.start = this.now = this.cur();
		this.end = end;
		this.unit = unit || ( jQuery.cssNumber[ prop ] ? "" : "px" );
	},
	cur: function() {
		var hooks = Tween.propHooks[ this.prop ];

		return hooks && hooks.get ?
			hooks.get( this ) :
			Tween.propHooks._default.get( this );
	},
	run: function( percent ) {
		var eased,
			hooks = Tween.propHooks[ this.prop ];

		if ( this.options.duration ) {
			this.pos = eased = jQuery.easing[ this.easing ](
				percent, this.options.duration * percent, 0, 1, this.options.duration
			);
		} else {
			this.pos = eased = percent;
		}
		this.now = ( this.end - this.start ) * eased + this.start;

		if ( this.options.step ) {
			this.options.step.call( this.elem, this.now, this );
		}

		if ( hooks && hooks.set ) {
			hooks.set( this );
		} else {
			Tween.propHooks._default.set( this );
		}
		return this;
	}
};

Tween.prototype.init.prototype = Tween.prototype;

Tween.propHooks = {
	_default: {
		get: function( tween ) {
			var result;

			if ( tween.elem[ tween.prop ] != null &&
				(!tween.elem.style || tween.elem.style[ tween.prop ] == null) ) {
				return tween.elem[ tween.prop ];
			}

			// Passing an empty string as a 3rd parameter to .css will automatically
			// attempt a parseFloat and fallback to a string if the parse fails.
			// Simple values such as "10px" are parsed to Float;
			// complex values such as "rotate(1rad)" are returned as-is.
			result = jQuery.css( tween.elem, tween.prop, "" );
			// Empty strings, null, undefined and "auto" are converted to 0.
			return !result || result === "auto" ? 0 : result;
		},
		set: function( tween ) {
			// Use step hook for back compat.
			// Use cssHook if its there.
			// Use .style if available and use plain properties where available.
			if ( jQuery.fx.step[ tween.prop ] ) {
				jQuery.fx.step[ tween.prop ]( tween );
			} else if ( tween.elem.style && ( tween.elem.style[ jQuery.cssProps[ tween.prop ] ] != null || jQuery.cssHooks[ tween.prop ] ) ) {
				jQuery.style( tween.elem, tween.prop, tween.now + tween.unit );
			} else {
				tween.elem[ tween.prop ] = tween.now;
			}
		}
	}
};

// Support: IE9
// Panic based approach to setting things on disconnected nodes
Tween.propHooks.scrollTop = Tween.propHooks.scrollLeft = {
	set: function( tween ) {
		if ( tween.elem.nodeType && tween.elem.parentNode ) {
			tween.elem[ tween.prop ] = tween.now;
		}
	}
};

jQuery.easing = {
	linear: function( p ) {
		return p;
	},
	swing: function( p ) {
		return 0.5 - Math.cos( p * Math.PI ) / 2;
	}
};

jQuery.fx = Tween.prototype.init;

// Back Compat <1.8 extension point
jQuery.fx.step = {};




var
	fxNow, timerId,
	rfxtypes = /^(?:toggle|show|hide)$/,
	rfxnum = new RegExp( "^(?:([+-])=|)(" + pnum + ")([a-z%]*)$", "i" ),
	rrun = /queueHooks$/,
	animationPrefilters = [ defaultPrefilter ],
	tweeners = {
		"*": [ function( prop, value ) {
			var tween = this.createTween( prop, value ),
				target = tween.cur(),
				parts = rfxnum.exec( value ),
				unit = parts && parts[ 3 ] || ( jQuery.cssNumber[ prop ] ? "" : "px" ),

				// Starting value computation is required for potential unit mismatches
				start = ( jQuery.cssNumber[ prop ] || unit !== "px" && +target ) &&
					rfxnum.exec( jQuery.css( tween.elem, prop ) ),
				scale = 1,
				maxIterations = 20;

			if ( start && start[ 3 ] !== unit ) {
				// Trust units reported by jQuery.css
				unit = unit || start[ 3 ];

				// Make sure we update the tween properties later on
				parts = parts || [];

				// Iteratively approximate from a nonzero starting point
				start = +target || 1;

				do {
					// If previous iteration zeroed out, double until we get *something*.
					// Use string for doubling so we don't accidentally see scale as unchanged below
					scale = scale || ".5";

					// Adjust and apply
					start = start / scale;
					jQuery.style( tween.elem, prop, start + unit );

				// Update scale, tolerating zero or NaN from tween.cur(),
				// break the loop if scale is unchanged or perfect, or if we've just had enough
				} while ( scale !== (scale = tween.cur() / target) && scale !== 1 && --maxIterations );
			}

			// Update tween properties
			if ( parts ) {
				start = tween.start = +start || +target || 0;
				tween.unit = unit;
				// If a +=/-= token was provided, we're doing a relative animation
				tween.end = parts[ 1 ] ?
					start + ( parts[ 1 ] + 1 ) * parts[ 2 ] :
					+parts[ 2 ];
			}

			return tween;
		} ]
	};

// Animations created synchronously will run synchronously
function createFxNow() {
	setTimeout(function() {
		fxNow = undefined;
	});
	return ( fxNow = jQuery.now() );
}

// Generate parameters to create a standard animation
function genFx( type, includeWidth ) {
	var which,
		i = 0,
		attrs = { height: type };

	// If we include width, step value is 1 to do all cssExpand values,
	// otherwise step value is 2 to skip over Left and Right
	includeWidth = includeWidth ? 1 : 0;
	for ( ; i < 4 ; i += 2 - includeWidth ) {
		which = cssExpand[ i ];
		attrs[ "margin" + which ] = attrs[ "padding" + which ] = type;
	}

	if ( includeWidth ) {
		attrs.opacity = attrs.width = type;
	}

	return attrs;
}

function createTween( value, prop, animation ) {
	var tween,
		collection = ( tweeners[ prop ] || [] ).concat( tweeners[ "*" ] ),
		index = 0,
		length = collection.length;
	for ( ; index < length; index++ ) {
		if ( (tween = collection[ index ].call( animation, prop, value )) ) {

			// We're done with this property
			return tween;
		}
	}
}

function defaultPrefilter( elem, props, opts ) {
	/* jshint validthis: true */
	var prop, value, toggle, tween, hooks, oldfire, display, checkDisplay,
		anim = this,
		orig = {},
		style = elem.style,
		hidden = elem.nodeType && isHidden( elem ),
		dataShow = data_priv.get( elem, "fxshow" );

	// Handle queue: false promises
	if ( !opts.queue ) {
		hooks = jQuery._queueHooks( elem, "fx" );
		if ( hooks.unqueued == null ) {
			hooks.unqueued = 0;
			oldfire = hooks.empty.fire;
			hooks.empty.fire = function() {
				if ( !hooks.unqueued ) {
					oldfire();
				}
			};
		}
		hooks.unqueued++;

		anim.always(function() {
			// Ensure the complete handler is called before this completes
			anim.always(function() {
				hooks.unqueued--;
				if ( !jQuery.queue( elem, "fx" ).length ) {
					hooks.empty.fire();
				}
			});
		});
	}

	// Height/width overflow pass
	if ( elem.nodeType === 1 && ( "height" in props || "width" in props ) ) {
		// Make sure that nothing sneaks out
		// Record all 3 overflow attributes because IE9-10 do not
		// change the overflow attribute when overflowX and
		// overflowY are set to the same value
		opts.overflow = [ style.overflow, style.overflowX, style.overflowY ];

		// Set display property to inline-block for height/width
		// animations on inline elements that are having width/height animated
		display = jQuery.css( elem, "display" );

		// Test default display if display is currently "none"
		checkDisplay = display === "none" ?
			data_priv.get( elem, "olddisplay" ) || defaultDisplay( elem.nodeName ) : display;

		if ( checkDisplay === "inline" && jQuery.css( elem, "float" ) === "none" ) {
			style.display = "inline-block";
		}
	}

	if ( opts.overflow ) {
		style.overflow = "hidden";
		anim.always(function() {
			style.overflow = opts.overflow[ 0 ];
			style.overflowX = opts.overflow[ 1 ];
			style.overflowY = opts.overflow[ 2 ];
		});
	}

	// show/hide pass
	for ( prop in props ) {
		value = props[ prop ];
		if ( rfxtypes.exec( value ) ) {
			delete props[ prop ];
			toggle = toggle || value === "toggle";
			if ( value === ( hidden ? "hide" : "show" ) ) {

				// If there is dataShow left over from a stopped hide or show and we are going to proceed with show, we should pretend to be hidden
				if ( value === "show" && dataShow && dataShow[ prop ] !== undefined ) {
					hidden = true;
				} else {
					continue;
				}
			}
			orig[ prop ] = dataShow && dataShow[ prop ] || jQuery.style( elem, prop );

		// Any non-fx value stops us from restoring the original display value
		} else {
			display = undefined;
		}
	}

	if ( !jQuery.isEmptyObject( orig ) ) {
		if ( dataShow ) {
			if ( "hidden" in dataShow ) {
				hidden = dataShow.hidden;
			}
		} else {
			dataShow = data_priv.access( elem, "fxshow", {} );
		}

		// Store state if its toggle - enables .stop().toggle() to "reverse"
		if ( toggle ) {
			dataShow.hidden = !hidden;
		}
		if ( hidden ) {
			jQuery( elem ).show();
		} else {
			anim.done(function() {
				jQuery( elem ).hide();
			});
		}
		anim.done(function() {
			var prop;

			data_priv.remove( elem, "fxshow" );
			for ( prop in orig ) {
				jQuery.style( elem, prop, orig[ prop ] );
			}
		});
		for ( prop in orig ) {
			tween = createTween( hidden ? dataShow[ prop ] : 0, prop, anim );

			if ( !( prop in dataShow ) ) {
				dataShow[ prop ] = tween.start;
				if ( hidden ) {
					tween.end = tween.start;
					tween.start = prop === "width" || prop === "height" ? 1 : 0;
				}
			}
		}

	// If this is a noop like .hide().hide(), restore an overwritten display value
	} else if ( (display === "none" ? defaultDisplay( elem.nodeName ) : display) === "inline" ) {
		style.display = display;
	}
}

function propFilter( props, specialEasing ) {
	var index, name, easing, value, hooks;

	// camelCase, specialEasing and expand cssHook pass
	for ( index in props ) {
		name = jQuery.camelCase( index );
		easing = specialEasing[ name ];
		value = props[ index ];
		if ( jQuery.isArray( value ) ) {
			easing = value[ 1 ];
			value = props[ index ] = value[ 0 ];
		}

		if ( index !== name ) {
			props[ name ] = value;
			delete props[ index ];
		}

		hooks = jQuery.cssHooks[ name ];
		if ( hooks && "expand" in hooks ) {
			value = hooks.expand( value );
			delete props[ name ];

			// Not quite $.extend, this won't overwrite existing keys.
			// Reusing 'index' because we have the correct "name"
			for ( index in value ) {
				if ( !( index in props ) ) {
					props[ index ] = value[ index ];
					specialEasing[ index ] = easing;
				}
			}
		} else {
			specialEasing[ name ] = easing;
		}
	}
}

function Animation( elem, properties, options ) {
	var result,
		stopped,
		index = 0,
		length = animationPrefilters.length,
		deferred = jQuery.Deferred().always( function() {
			// Don't match elem in the :animated selector
			delete tick.elem;
		}),
		tick = function() {
			if ( stopped ) {
				return false;
			}
			var currentTime = fxNow || createFxNow(),
				remaining = Math.max( 0, animation.startTime + animation.duration - currentTime ),
				// Support: Android 2.3
				// Archaic crash bug won't allow us to use `1 - ( 0.5 || 0 )` (#12497)
				temp = remaining / animation.duration || 0,
				percent = 1 - temp,
				index = 0,
				length = animation.tweens.length;

			for ( ; index < length ; index++ ) {
				animation.tweens[ index ].run( percent );
			}

			deferred.notifyWith( elem, [ animation, percent, remaining ]);

			if ( percent < 1 && length ) {
				return remaining;
			} else {
				deferred.resolveWith( elem, [ animation ] );
				return false;
			}
		},
		animation = deferred.promise({
			elem: elem,
			props: jQuery.extend( {}, properties ),
			opts: jQuery.extend( true, { specialEasing: {} }, options ),
			originalProperties: properties,
			originalOptions: options,
			startTime: fxNow || createFxNow(),
			duration: options.duration,
			tweens: [],
			createTween: function( prop, end ) {
				var tween = jQuery.Tween( elem, animation.opts, prop, end,
						animation.opts.specialEasing[ prop ] || animation.opts.easing );
				animation.tweens.push( tween );
				return tween;
			},
			stop: function( gotoEnd ) {
				var index = 0,
					// If we are going to the end, we want to run all the tweens
					// otherwise we skip this part
					length = gotoEnd ? animation.tweens.length : 0;
				if ( stopped ) {
					return this;
				}
				stopped = true;
				for ( ; index < length ; index++ ) {
					animation.tweens[ index ].run( 1 );
				}

				// Resolve when we played the last frame; otherwise, reject
				if ( gotoEnd ) {
					deferred.resolveWith( elem, [ animation, gotoEnd ] );
				} else {
					deferred.rejectWith( elem, [ animation, gotoEnd ] );
				}
				return this;
			}
		}),
		props = animation.props;

	propFilter( props, animation.opts.specialEasing );

	for ( ; index < length ; index++ ) {
		result = animationPrefilters[ index ].call( animation, elem, props, animation.opts );
		if ( result ) {
			return result;
		}
	}

	jQuery.map( props, createTween, animation );

	if ( jQuery.isFunction( animation.opts.start ) ) {
		animation.opts.start.call( elem, animation );
	}

	jQuery.fx.timer(
		jQuery.extend( tick, {
			elem: elem,
			anim: animation,
			queue: animation.opts.queue
		})
	);

	// attach callbacks from options
	return animation.progress( animation.opts.progress )
		.done( animation.opts.done, animation.opts.complete )
		.fail( animation.opts.fail )
		.always( animation.opts.always );
}

jQuery.Animation = jQuery.extend( Animation, {

	tweener: function( props, callback ) {
		if ( jQuery.isFunction( props ) ) {
			callback = props;
			props = [ "*" ];
		} else {
			props = props.split(" ");
		}

		var prop,
			index = 0,
			length = props.length;

		for ( ; index < length ; index++ ) {
			prop = props[ index ];
			tweeners[ prop ] = tweeners[ prop ] || [];
			tweeners[ prop ].unshift( callback );
		}
	},

	prefilter: function( callback, prepend ) {
		if ( prepend ) {
			animationPrefilters.unshift( callback );
		} else {
			animationPrefilters.push( callback );
		}
	}
});

jQuery.speed = function( speed, easing, fn ) {
	var opt = speed && typeof speed === "object" ? jQuery.extend( {}, speed ) : {
		complete: fn || !fn && easing ||
			jQuery.isFunction( speed ) && speed,
		duration: speed,
		easing: fn && easing || easing && !jQuery.isFunction( easing ) && easing
	};

	opt.duration = jQuery.fx.off ? 0 : typeof opt.duration === "number" ? opt.duration :
		opt.duration in jQuery.fx.speeds ? jQuery.fx.speeds[ opt.duration ] : jQuery.fx.speeds._default;

	// Normalize opt.queue - true/undefined/null -> "fx"
	if ( opt.queue == null || opt.queue === true ) {
		opt.queue = "fx";
	}

	// Queueing
	opt.old = opt.complete;

	opt.complete = function() {
		if ( jQuery.isFunction( opt.old ) ) {
			opt.old.call( this );
		}

		if ( opt.queue ) {
			jQuery.dequeue( this, opt.queue );
		}
	};

	return opt;
};

jQuery.fn.extend({
	fadeTo: function( speed, to, easing, callback ) {

		// Show any hidden elements after setting opacity to 0
		return this.filter( isHidden ).css( "opacity", 0 ).show()

			// Animate to the value specified
			.end().animate({ opacity: to }, speed, easing, callback );
	},
	animate: function( prop, speed, easing, callback ) {
		var empty = jQuery.isEmptyObject( prop ),
			optall = jQuery.speed( speed, easing, callback ),
			doAnimation = function() {
				// Operate on a copy of prop so per-property easing won't be lost
				var anim = Animation( this, jQuery.extend( {}, prop ), optall );

				// Empty animations, or finishing resolves immediately
				if ( empty || data_priv.get( this, "finish" ) ) {
					anim.stop( true );
				}
			};
			doAnimation.finish = doAnimation;

		return empty || optall.queue === false ?
			this.each( doAnimation ) :
			this.queue( optall.queue, doAnimation );
	},
	stop: function( type, clearQueue, gotoEnd ) {
		var stopQueue = function( hooks ) {
			var stop = hooks.stop;
			delete hooks.stop;
			stop( gotoEnd );
		};

		if ( typeof type !== "string" ) {
			gotoEnd = clearQueue;
			clearQueue = type;
			type = undefined;
		}
		if ( clearQueue && type !== false ) {
			this.queue( type || "fx", [] );
		}

		return this.each(function() {
			var dequeue = true,
				index = type != null && type + "queueHooks",
				timers = jQuery.timers,
				data = data_priv.get( this );

			if ( index ) {
				if ( data[ index ] && data[ index ].stop ) {
					stopQueue( data[ index ] );
				}
			} else {
				for ( index in data ) {
					if ( data[ index ] && data[ index ].stop && rrun.test( index ) ) {
						stopQueue( data[ index ] );
					}
				}
			}

			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && (type == null || timers[ index ].queue === type) ) {
					timers[ index ].anim.stop( gotoEnd );
					dequeue = false;
					timers.splice( index, 1 );
				}
			}

			// Start the next in the queue if the last step wasn't forced.
			// Timers currently will call their complete callbacks, which
			// will dequeue but only if they were gotoEnd.
			if ( dequeue || !gotoEnd ) {
				jQuery.dequeue( this, type );
			}
		});
	},
	finish: function( type ) {
		if ( type !== false ) {
			type = type || "fx";
		}
		return this.each(function() {
			var index,
				data = data_priv.get( this ),
				queue = data[ type + "queue" ],
				hooks = data[ type + "queueHooks" ],
				timers = jQuery.timers,
				length = queue ? queue.length : 0;

			// Enable finishing flag on private data
			data.finish = true;

			// Empty the queue first
			jQuery.queue( this, type, [] );

			if ( hooks && hooks.stop ) {
				hooks.stop.call( this, true );
			}

			// Look for any active animations, and finish them
			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && timers[ index ].queue === type ) {
					timers[ index ].anim.stop( true );
					timers.splice( index, 1 );
				}
			}

			// Look for any animations in the old queue and finish them
			for ( index = 0; index < length; index++ ) {
				if ( queue[ index ] && queue[ index ].finish ) {
					queue[ index ].finish.call( this );
				}
			}

			// Turn off finishing flag
			delete data.finish;
		});
	}
});

jQuery.each([ "toggle", "show", "hide" ], function( i, name ) {
	var cssFn = jQuery.fn[ name ];
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return speed == null || typeof speed === "boolean" ?
			cssFn.apply( this, arguments ) :
			this.animate( genFx( name, true ), speed, easing, callback );
	};
});

// Generate shortcuts for custom animations
jQuery.each({
	slideDown: genFx("show"),
	slideUp: genFx("hide"),
	slideToggle: genFx("toggle"),
	fadeIn: { opacity: "show" },
	fadeOut: { opacity: "hide" },
	fadeToggle: { opacity: "toggle" }
}, function( name, props ) {
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return this.animate( props, speed, easing, callback );
	};
});

jQuery.timers = [];
jQuery.fx.tick = function() {
	var timer,
		i = 0,
		timers = jQuery.timers;

	fxNow = jQuery.now();

	for ( ; i < timers.length; i++ ) {
		timer = timers[ i ];
		// Checks the timer has not already been removed
		if ( !timer() && timers[ i ] === timer ) {
			timers.splice( i--, 1 );
		}
	}

	if ( !timers.length ) {
		jQuery.fx.stop();
	}
	fxNow = undefined;
};

jQuery.fx.timer = function( timer ) {
	jQuery.timers.push( timer );
	if ( timer() ) {
		jQuery.fx.start();
	} else {
		jQuery.timers.pop();
	}
};

jQuery.fx.interval = 13;

jQuery.fx.start = function() {
	if ( !timerId ) {
		timerId = setInterval( jQuery.fx.tick, jQuery.fx.interval );
	}
};

jQuery.fx.stop = function() {
	clearInterval( timerId );
	timerId = null;
};

jQuery.fx.speeds = {
	slow: 600,
	fast: 200,
	// Default speed
	_default: 400
};


// Based off of the plugin by Clint Helfers, with permission.
// http://blindsignals.com/index.php/2009/07/jquery-delay/
jQuery.fn.delay = function( time, type ) {
	time = jQuery.fx ? jQuery.fx.speeds[ time ] || time : time;
	type = type || "fx";

	return this.queue( type, function( next, hooks ) {
		var timeout = setTimeout( next, time );
		hooks.stop = function() {
			clearTimeout( timeout );
		};
	});
};


(function() {
	var input = document.createElement( "input" ),
		select = document.createElement( "select" ),
		opt = select.appendChild( document.createElement( "option" ) );

	input.type = "checkbox";

	// Support: iOS<=5.1, Android<=4.2+
	// Default value for a checkbox should be "on"
	support.checkOn = input.value !== "";

	// Support: IE<=11+
	// Must access selectedIndex to make default options select
	support.optSelected = opt.selected;

	// Support: Android<=2.3
	// Options inside disabled selects are incorrectly marked as disabled
	select.disabled = true;
	support.optDisabled = !opt.disabled;

	// Support: IE<=11+
	// An input loses its value after becoming a radio
	input = document.createElement( "input" );
	input.value = "t";
	input.type = "radio";
	support.radioValue = input.value === "t";
})();


var nodeHook, boolHook,
	attrHandle = jQuery.expr.attrHandle;

jQuery.fn.extend({
	attr: function( name, value ) {
		return access( this, jQuery.attr, name, value, arguments.length > 1 );
	},

	removeAttr: function( name ) {
		return this.each(function() {
			jQuery.removeAttr( this, name );
		});
	}
});

jQuery.extend({
	attr: function( elem, name, value ) {
		var hooks, ret,
			nType = elem.nodeType;

		// don't get/set attributes on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		// Fallback to prop when attributes are not supported
		if ( typeof elem.getAttribute === strundefined ) {
			return jQuery.prop( elem, name, value );
		}

		// All attributes are lowercase
		// Grab necessary hook if one is defined
		if ( nType !== 1 || !jQuery.isXMLDoc( elem ) ) {
			name = name.toLowerCase();
			hooks = jQuery.attrHooks[ name ] ||
				( jQuery.expr.match.bool.test( name ) ? boolHook : nodeHook );
		}

		if ( value !== undefined ) {

			if ( value === null ) {
				jQuery.removeAttr( elem, name );

			} else if ( hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ) {
				return ret;

			} else {
				elem.setAttribute( name, value + "" );
				return value;
			}

		} else if ( hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ) {
			return ret;

		} else {
			ret = jQuery.find.attr( elem, name );

			// Non-existent attributes return null, we normalize to undefined
			return ret == null ?
				undefined :
				ret;
		}
	},

	removeAttr: function( elem, value ) {
		var name, propName,
			i = 0,
			attrNames = value && value.match( rnotwhite );

		if ( attrNames && elem.nodeType === 1 ) {
			while ( (name = attrNames[i++]) ) {
				propName = jQuery.propFix[ name ] || name;

				// Boolean attributes get special treatment (#10870)
				if ( jQuery.expr.match.bool.test( name ) ) {
					// Set corresponding property to false
					elem[ propName ] = false;
				}

				elem.removeAttribute( name );
			}
		}
	},

	attrHooks: {
		type: {
			set: function( elem, value ) {
				if ( !support.radioValue && value === "radio" &&
					jQuery.nodeName( elem, "input" ) ) {
					var val = elem.value;
					elem.setAttribute( "type", value );
					if ( val ) {
						elem.value = val;
					}
					return value;
				}
			}
		}
	}
});

// Hooks for boolean attributes
boolHook = {
	set: function( elem, value, name ) {
		if ( value === false ) {
			// Remove boolean attributes when set to false
			jQuery.removeAttr( elem, name );
		} else {
			elem.setAttribute( name, name );
		}
		return name;
	}
};
jQuery.each( jQuery.expr.match.bool.source.match( /\w+/g ), function( i, name ) {
	var getter = attrHandle[ name ] || jQuery.find.attr;

	attrHandle[ name ] = function( elem, name, isXML ) {
		var ret, handle;
		if ( !isXML ) {
			// Avoid an infinite loop by temporarily removing this function from the getter
			handle = attrHandle[ name ];
			attrHandle[ name ] = ret;
			ret = getter( elem, name, isXML ) != null ?
				name.toLowerCase() :
				null;
			attrHandle[ name ] = handle;
		}
		return ret;
	};
});




var rfocusable = /^(?:input|select|textarea|button)$/i;

jQuery.fn.extend({
	prop: function( name, value ) {
		return access( this, jQuery.prop, name, value, arguments.length > 1 );
	},

	removeProp: function( name ) {
		return this.each(function() {
			delete this[ jQuery.propFix[ name ] || name ];
		});
	}
});

jQuery.extend({
	propFix: {
		"for": "htmlFor",
		"class": "className"
	},

	prop: function( elem, name, value ) {
		var ret, hooks, notxml,
			nType = elem.nodeType;

		// Don't get/set properties on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

		if ( notxml ) {
			// Fix name and attach hooks
			name = jQuery.propFix[ name ] || name;
			hooks = jQuery.propHooks[ name ];
		}

		if ( value !== undefined ) {
			return hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ?
				ret :
				( elem[ name ] = value );

		} else {
			return hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ?
				ret :
				elem[ name ];
		}
	},

	propHooks: {
		tabIndex: {
			get: function( elem ) {
				return elem.hasAttribute( "tabindex" ) || rfocusable.test( elem.nodeName ) || elem.href ?
					elem.tabIndex :
					-1;
			}
		}
	}
});

if ( !support.optSelected ) {
	jQuery.propHooks.selected = {
		get: function( elem ) {
			var parent = elem.parentNode;
			if ( parent && parent.parentNode ) {
				parent.parentNode.selectedIndex;
			}
			return null;
		}
	};
}

jQuery.each([
	"tabIndex",
	"readOnly",
	"maxLength",
	"cellSpacing",
	"cellPadding",
	"rowSpan",
	"colSpan",
	"useMap",
	"frameBorder",
	"contentEditable"
], function() {
	jQuery.propFix[ this.toLowerCase() ] = this;
});




var rclass = /[\t\r\n\f]/g;

jQuery.fn.extend({
	addClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			proceed = typeof value === "string" && value,
			i = 0,
			len = this.length;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).addClass( value.call( this, j, this.className ) );
			});
		}

		if ( proceed ) {
			// The disjunction here is for better compressibility (see removeClass)
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					" "
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						if ( cur.indexOf( " " + clazz + " " ) < 0 ) {
							cur += clazz + " ";
						}
					}

					// only assign if different to avoid unneeded rendering.
					finalValue = jQuery.trim( cur );
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	removeClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			proceed = arguments.length === 0 || typeof value === "string" && value,
			i = 0,
			len = this.length;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).removeClass( value.call( this, j, this.className ) );
			});
		}
		if ( proceed ) {
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				// This expression is here for better compressibility (see addClass)
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					""
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						// Remove *all* instances
						while ( cur.indexOf( " " + clazz + " " ) >= 0 ) {
							cur = cur.replace( " " + clazz + " ", " " );
						}
					}

					// Only assign if different to avoid unneeded rendering.
					finalValue = value ? jQuery.trim( cur ) : "";
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	toggleClass: function( value, stateVal ) {
		var type = typeof value;

		if ( typeof stateVal === "boolean" && type === "string" ) {
			return stateVal ? this.addClass( value ) : this.removeClass( value );
		}

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( i ) {
				jQuery( this ).toggleClass( value.call(this, i, this.className, stateVal), stateVal );
			});
		}

		return this.each(function() {
			if ( type === "string" ) {
				// Toggle individual class names
				var className,
					i = 0,
					self = jQuery( this ),
					classNames = value.match( rnotwhite ) || [];

				while ( (className = classNames[ i++ ]) ) {
					// Check each className given, space separated list
					if ( self.hasClass( className ) ) {
						self.removeClass( className );
					} else {
						self.addClass( className );
					}
				}

			// Toggle whole class name
			} else if ( type === strundefined || type === "boolean" ) {
				if ( this.className ) {
					// store className if set
					data_priv.set( this, "__className__", this.className );
				}

				// If the element has a class name or if we're passed `false`,
				// then remove the whole classname (if there was one, the above saved it).
				// Otherwise bring back whatever was previously saved (if anything),
				// falling back to the empty string if nothing was stored.
				this.className = this.className || value === false ? "" : data_priv.get( this, "__className__" ) || "";
			}
		});
	},

	hasClass: function( selector ) {
		var className = " " + selector + " ",
			i = 0,
			l = this.length;
		for ( ; i < l; i++ ) {
			if ( this[i].nodeType === 1 && (" " + this[i].className + " ").replace(rclass, " ").indexOf( className ) >= 0 ) {
				return true;
			}
		}

		return false;
	}
});




var rreturn = /\r/g;

jQuery.fn.extend({
	val: function( value ) {
		var hooks, ret, isFunction,
			elem = this[0];

		if ( !arguments.length ) {
			if ( elem ) {
				hooks = jQuery.valHooks[ elem.type ] || jQuery.valHooks[ elem.nodeName.toLowerCase() ];

				if ( hooks && "get" in hooks && (ret = hooks.get( elem, "value" )) !== undefined ) {
					return ret;
				}

				ret = elem.value;

				return typeof ret === "string" ?
					// Handle most common string cases
					ret.replace(rreturn, "") :
					// Handle cases where value is null/undef or number
					ret == null ? "" : ret;
			}

			return;
		}

		isFunction = jQuery.isFunction( value );

		return this.each(function( i ) {
			var val;

			if ( this.nodeType !== 1 ) {
				return;
			}

			if ( isFunction ) {
				val = value.call( this, i, jQuery( this ).val() );
			} else {
				val = value;
			}

			// Treat null/undefined as ""; convert numbers to string
			if ( val == null ) {
				val = "";

			} else if ( typeof val === "number" ) {
				val += "";

			} else if ( jQuery.isArray( val ) ) {
				val = jQuery.map( val, function( value ) {
					return value == null ? "" : value + "";
				});
			}

			hooks = jQuery.valHooks[ this.type ] || jQuery.valHooks[ this.nodeName.toLowerCase() ];

			// If set returns undefined, fall back to normal setting
			if ( !hooks || !("set" in hooks) || hooks.set( this, val, "value" ) === undefined ) {
				this.value = val;
			}
		});
	}
});

jQuery.extend({
	valHooks: {
		option: {
			get: function( elem ) {
				var val = jQuery.find.attr( elem, "value" );
				return val != null ?
					val :
					// Support: IE10-11+
					// option.text throws exceptions (#14686, #14858)
					jQuery.trim( jQuery.text( elem ) );
			}
		},
		select: {
			get: function( elem ) {
				var value, option,
					options = elem.options,
					index = elem.selectedIndex,
					one = elem.type === "select-one" || index < 0,
					values = one ? null : [],
					max = one ? index + 1 : options.length,
					i = index < 0 ?
						max :
						one ? index : 0;

				// Loop through all the selected options
				for ( ; i < max; i++ ) {
					option = options[ i ];

					// IE6-9 doesn't update selected after form reset (#2551)
					if ( ( option.selected || i === index ) &&
							// Don't return options that are disabled or in a disabled optgroup
							( support.optDisabled ? !option.disabled : option.getAttribute( "disabled" ) === null ) &&
							( !option.parentNode.disabled || !jQuery.nodeName( option.parentNode, "optgroup" ) ) ) {

						// Get the specific value for the option
						value = jQuery( option ).val();

						// We don't need an array for one selects
						if ( one ) {
							return value;
						}

						// Multi-Selects return an array
						values.push( value );
					}
				}

				return values;
			},

			set: function( elem, value ) {
				var optionSet, option,
					options = elem.options,
					values = jQuery.makeArray( value ),
					i = options.length;

				while ( i-- ) {
					option = options[ i ];
					if ( (option.selected = jQuery.inArray( option.value, values ) >= 0) ) {
						optionSet = true;
					}
				}

				// Force browsers to behave consistently when non-matching value is set
				if ( !optionSet ) {
					elem.selectedIndex = -1;
				}
				return values;
			}
		}
	}
});

// Radios and checkboxes getter/setter
jQuery.each([ "radio", "checkbox" ], function() {
	jQuery.valHooks[ this ] = {
		set: function( elem, value ) {
			if ( jQuery.isArray( value ) ) {
				return ( elem.checked = jQuery.inArray( jQuery(elem).val(), value ) >= 0 );
			}
		}
	};
	if ( !support.checkOn ) {
		jQuery.valHooks[ this ].get = function( elem ) {
			return elem.getAttribute("value") === null ? "on" : elem.value;
		};
	}
});




// Return jQuery for attributes-only inclusion


jQuery.each( ("blur focus focusin focusout load resize scroll unload click dblclick " +
	"mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave " +
	"change select submit keydown keypress keyup error contextmenu").split(" "), function( i, name ) {

	// Handle event binding
	jQuery.fn[ name ] = function( data, fn ) {
		return arguments.length > 0 ?
			this.on( name, null, data, fn ) :
			this.trigger( name );
	};
});

jQuery.fn.extend({
	hover: function( fnOver, fnOut ) {
		return this.mouseenter( fnOver ).mouseleave( fnOut || fnOver );
	},

	bind: function( types, data, fn ) {
		return this.on( types, null, data, fn );
	},
	unbind: function( types, fn ) {
		return this.off( types, null, fn );
	},

	delegate: function( selector, types, data, fn ) {
		return this.on( types, selector, data, fn );
	},
	undelegate: function( selector, types, fn ) {
		// ( namespace ) or ( selector, types [, fn] )
		return arguments.length === 1 ? this.off( selector, "**" ) : this.off( types, selector || "**", fn );
	}
});


var nonce = jQuery.now();

var rquery = (/\?/);



// Support: Android 2.3
// Workaround failure to string-cast null input
jQuery.parseJSON = function( data ) {
	return JSON.parse( data + "" );
};


// Cross-browser xml parsing
jQuery.parseXML = function( data ) {
	var xml, tmp;
	if ( !data || typeof data !== "string" ) {
		return null;
	}

	// Support: IE9
	try {
		tmp = new DOMParser();
		xml = tmp.parseFromString( data, "text/xml" );
	} catch ( e ) {
		xml = undefined;
	}

	if ( !xml || xml.getElementsByTagName( "parsererror" ).length ) {
		jQuery.error( "Invalid XML: " + data );
	}
	return xml;
};


var
	rhash = /#.*$/,
	rts = /([?&])_=[^&]*/,
	rheaders = /^(.*?):[ \t]*([^\r\n]*)$/mg,
	// #7653, #8125, #8152: local protocol detection
	rlocalProtocol = /^(?:about|app|app-storage|.+-extension|file|res|widget):$/,
	rnoContent = /^(?:GET|HEAD)$/,
	rprotocol = /^\/\//,
	rurl = /^([\w.+-]+:)(?:\/\/(?:[^\/?#]*@|)([^\/?#:]*)(?::(\d+)|)|)/,

	/* Prefilters
	 * 1) They are useful to introduce custom dataTypes (see ajax/jsonp.js for an example)
	 * 2) These are called:
	 *    - BEFORE asking for a transport
	 *    - AFTER param serialization (s.data is a string if s.processData is true)
	 * 3) key is the dataType
	 * 4) the catchall symbol "*" can be used
	 * 5) execution will start with transport dataType and THEN continue down to "*" if needed
	 */
	prefilters = {},

	/* Transports bindings
	 * 1) key is the dataType
	 * 2) the catchall symbol "*" can be used
	 * 3) selection will start with transport dataType and THEN go to "*" if needed
	 */
	transports = {},

	// Avoid comment-prolog char sequence (#10098); must appease lint and evade compression
	allTypes = "*/".concat( "*" ),

	// Document location
	ajaxLocation = window.location.href,

	// Segment location into parts
	ajaxLocParts = rurl.exec( ajaxLocation.toLowerCase() ) || [];

// Base "constructor" for jQuery.ajaxPrefilter and jQuery.ajaxTransport
function addToPrefiltersOrTransports( structure ) {

	// dataTypeExpression is optional and defaults to "*"
	return function( dataTypeExpression, func ) {

		if ( typeof dataTypeExpression !== "string" ) {
			func = dataTypeExpression;
			dataTypeExpression = "*";
		}

		var dataType,
			i = 0,
			dataTypes = dataTypeExpression.toLowerCase().match( rnotwhite ) || [];

		if ( jQuery.isFunction( func ) ) {
			// For each dataType in the dataTypeExpression
			while ( (dataType = dataTypes[i++]) ) {
				// Prepend if requested
				if ( dataType[0] === "+" ) {
					dataType = dataType.slice( 1 ) || "*";
					(structure[ dataType ] = structure[ dataType ] || []).unshift( func );

				// Otherwise append
				} else {
					(structure[ dataType ] = structure[ dataType ] || []).push( func );
				}
			}
		}
	};
}

// Base inspection function for prefilters and transports
function inspectPrefiltersOrTransports( structure, options, originalOptions, jqXHR ) {

	var inspected = {},
		seekingTransport = ( structure === transports );

	function inspect( dataType ) {
		var selected;
		inspected[ dataType ] = true;
		jQuery.each( structure[ dataType ] || [], function( _, prefilterOrFactory ) {
			var dataTypeOrTransport = prefilterOrFactory( options, originalOptions, jqXHR );
			if ( typeof dataTypeOrTransport === "string" && !seekingTransport && !inspected[ dataTypeOrTransport ] ) {
				options.dataTypes.unshift( dataTypeOrTransport );
				inspect( dataTypeOrTransport );
				return false;
			} else if ( seekingTransport ) {
				return !( selected = dataTypeOrTransport );
			}
		});
		return selected;
	}

	return inspect( options.dataTypes[ 0 ] ) || !inspected[ "*" ] && inspect( "*" );
}

// A special extend for ajax options
// that takes "flat" options (not to be deep extended)
// Fixes #9887
function ajaxExtend( target, src ) {
	var key, deep,
		flatOptions = jQuery.ajaxSettings.flatOptions || {};

	for ( key in src ) {
		if ( src[ key ] !== undefined ) {
			( flatOptions[ key ] ? target : ( deep || (deep = {}) ) )[ key ] = src[ key ];
		}
	}
	if ( deep ) {
		jQuery.extend( true, target, deep );
	}

	return target;
}

/* Handles responses to an ajax request:
 * - finds the right dataType (mediates between content-type and expected dataType)
 * - returns the corresponding response
 */
function ajaxHandleResponses( s, jqXHR, responses ) {

	var ct, type, finalDataType, firstDataType,
		contents = s.contents,
		dataTypes = s.dataTypes;

	// Remove auto dataType and get content-type in the process
	while ( dataTypes[ 0 ] === "*" ) {
		dataTypes.shift();
		if ( ct === undefined ) {
			ct = s.mimeType || jqXHR.getResponseHeader("Content-Type");
		}
	}

	// Check if we're dealing with a known content-type
	if ( ct ) {
		for ( type in contents ) {
			if ( contents[ type ] && contents[ type ].test( ct ) ) {
				dataTypes.unshift( type );
				break;
			}
		}
	}

	// Check to see if we have a response for the expected dataType
	if ( dataTypes[ 0 ] in responses ) {
		finalDataType = dataTypes[ 0 ];
	} else {
		// Try convertible dataTypes
		for ( type in responses ) {
			if ( !dataTypes[ 0 ] || s.converters[ type + " " + dataTypes[0] ] ) {
				finalDataType = type;
				break;
			}
			if ( !firstDataType ) {
				firstDataType = type;
			}
		}
		// Or just use first one
		finalDataType = finalDataType || firstDataType;
	}

	// If we found a dataType
	// We add the dataType to the list if needed
	// and return the corresponding response
	if ( finalDataType ) {
		if ( finalDataType !== dataTypes[ 0 ] ) {
			dataTypes.unshift( finalDataType );
		}
		return responses[ finalDataType ];
	}
}

/* Chain conversions given the request and the original response
 * Also sets the responseXXX fields on the jqXHR instance
 */
function ajaxConvert( s, response, jqXHR, isSuccess ) {
	var conv2, current, conv, tmp, prev,
		converters = {},
		// Work with a copy of dataTypes in case we need to modify it for conversion
		dataTypes = s.dataTypes.slice();

	// Create converters map with lowercased keys
	if ( dataTypes[ 1 ] ) {
		for ( conv in s.converters ) {
			converters[ conv.toLowerCase() ] = s.converters[ conv ];
		}
	}

	current = dataTypes.shift();

	// Convert to each sequential dataType
	while ( current ) {

		if ( s.responseFields[ current ] ) {
			jqXHR[ s.responseFields[ current ] ] = response;
		}

		// Apply the dataFilter if provided
		if ( !prev && isSuccess && s.dataFilter ) {
			response = s.dataFilter( response, s.dataType );
		}

		prev = current;
		current = dataTypes.shift();

		if ( current ) {

		// There's only work to do if current dataType is non-auto
			if ( current === "*" ) {

				current = prev;

			// Convert response if prev dataType is non-auto and differs from current
			} else if ( prev !== "*" && prev !== current ) {

				// Seek a direct converter
				conv = converters[ prev + " " + current ] || converters[ "* " + current ];

				// If none found, seek a pair
				if ( !conv ) {
					for ( conv2 in converters ) {

						// If conv2 outputs current
						tmp = conv2.split( " " );
						if ( tmp[ 1 ] === current ) {

							// If prev can be converted to accepted input
							conv = converters[ prev + " " + tmp[ 0 ] ] ||
								converters[ "* " + tmp[ 0 ] ];
							if ( conv ) {
								// Condense equivalence converters
								if ( conv === true ) {
									conv = converters[ conv2 ];

								// Otherwise, insert the intermediate dataType
								} else if ( converters[ conv2 ] !== true ) {
									current = tmp[ 0 ];
									dataTypes.unshift( tmp[ 1 ] );
								}
								break;
							}
						}
					}
				}

				// Apply converter (if not an equivalence)
				if ( conv !== true ) {

					// Unless errors are allowed to bubble, catch and return them
					if ( conv && s[ "throws" ] ) {
						response = conv( response );
					} else {
						try {
							response = conv( response );
						} catch ( e ) {
							return { state: "parsererror", error: conv ? e : "No conversion from " + prev + " to " + current };
						}
					}
				}
			}
		}
	}

	return { state: "success", data: response };
}

jQuery.extend({

	// Counter for holding the number of active queries
	active: 0,

	// Last-Modified header cache for next request
	lastModified: {},
	etag: {},

	ajaxSettings: {
		url: ajaxLocation,
		type: "GET",
		isLocal: rlocalProtocol.test( ajaxLocParts[ 1 ] ),
		global: true,
		processData: true,
		async: true,
		contentType: "application/x-www-form-urlencoded; charset=UTF-8",
		/*
		timeout: 0,
		data: null,
		dataType: null,
		username: null,
		password: null,
		cache: null,
		throws: false,
		traditional: false,
		headers: {},
		*/

		accepts: {
			"*": allTypes,
			text: "text/plain",
			html: "text/html",
			xml: "application/xml, text/xml",
			json: "application/json, text/javascript"
		},

		contents: {
			xml: /xml/,
			html: /html/,
			json: /json/
		},

		responseFields: {
			xml: "responseXML",
			text: "responseText",
			json: "responseJSON"
		},

		// Data converters
		// Keys separate source (or catchall "*") and destination types with a single space
		converters: {

			// Convert anything to text
			"* text": String,

			// Text to html (true = no transformation)
			"text html": true,

			// Evaluate text as a json expression
			"text json": jQuery.parseJSON,

			// Parse text as xml
			"text xml": jQuery.parseXML
		},

		// For options that shouldn't be deep extended:
		// you can add your own custom options here if
		// and when you create one that shouldn't be
		// deep extended (see ajaxExtend)
		flatOptions: {
			url: true,
			context: true
		}
	},

	// Creates a full fledged settings object into target
	// with both ajaxSettings and settings fields.
	// If target is omitted, writes into ajaxSettings.
	ajaxSetup: function( target, settings ) {
		return settings ?

			// Building a settings object
			ajaxExtend( ajaxExtend( target, jQuery.ajaxSettings ), settings ) :

			// Extending ajaxSettings
			ajaxExtend( jQuery.ajaxSettings, target );
	},

	ajaxPrefilter: addToPrefiltersOrTransports( prefilters ),
	ajaxTransport: addToPrefiltersOrTransports( transports ),

	// Main method
	ajax: function( url, options ) {

		// If url is an object, simulate pre-1.5 signature
		if ( typeof url === "object" ) {
			options = url;
			url = undefined;
		}

		// Force options to be an object
		options = options || {};

		var transport,
			// URL without anti-cache param
			cacheURL,
			// Response headers
			responseHeadersString,
			responseHeaders,
			// timeout handle
			timeoutTimer,
			// Cross-domain detection vars
			parts,
			// To know if global events are to be dispatched
			fireGlobals,
			// Loop variable
			i,
			// Create the final options object
			s = jQuery.ajaxSetup( {}, options ),
			// Callbacks context
			callbackContext = s.context || s,
			// Context for global events is callbackContext if it is a DOM node or jQuery collection
			globalEventContext = s.context && ( callbackContext.nodeType || callbackContext.jquery ) ?
				jQuery( callbackContext ) :
				jQuery.event,
			// Deferreds
			deferred = jQuery.Deferred(),
			completeDeferred = jQuery.Callbacks("once memory"),
			// Status-dependent callbacks
			statusCode = s.statusCode || {},
			// Headers (they are sent all at once)
			requestHeaders = {},
			requestHeadersNames = {},
			// The jqXHR state
			state = 0,
			// Default abort message
			strAbort = "canceled",
			// Fake xhr
			jqXHR = {
				readyState: 0,

				// Builds headers hashtable if needed
				getResponseHeader: function( key ) {
					var match;
					if ( state === 2 ) {
						if ( !responseHeaders ) {
							responseHeaders = {};
							while ( (match = rheaders.exec( responseHeadersString )) ) {
								responseHeaders[ match[1].toLowerCase() ] = match[ 2 ];
							}
						}
						match = responseHeaders[ key.toLowerCase() ];
					}
					return match == null ? null : match;
				},

				// Raw string
				getAllResponseHeaders: function() {
					return state === 2 ? responseHeadersString : null;
				},

				// Caches the header
				setRequestHeader: function( name, value ) {
					var lname = name.toLowerCase();
					if ( !state ) {
						name = requestHeadersNames[ lname ] = requestHeadersNames[ lname ] || name;
						requestHeaders[ name ] = value;
					}
					return this;
				},

				// Overrides response content-type header
				overrideMimeType: function( type ) {
					if ( !state ) {
						s.mimeType = type;
					}
					return this;
				},

				// Status-dependent callbacks
				statusCode: function( map ) {
					var code;
					if ( map ) {
						if ( state < 2 ) {
							for ( code in map ) {
								// Lazy-add the new callback in a way that preserves old ones
								statusCode[ code ] = [ statusCode[ code ], map[ code ] ];
							}
						} else {
							// Execute the appropriate callbacks
							jqXHR.always( map[ jqXHR.status ] );
						}
					}
					return this;
				},

				// Cancel the request
				abort: function( statusText ) {
					var finalText = statusText || strAbort;
					if ( transport ) {
						transport.abort( finalText );
					}
					done( 0, finalText );
					return this;
				}
			};

		// Attach deferreds
		deferred.promise( jqXHR ).complete = completeDeferred.add;
		jqXHR.success = jqXHR.done;
		jqXHR.error = jqXHR.fail;

		// Remove hash character (#7531: and string promotion)
		// Add protocol if not provided (prefilters might expect it)
		// Handle falsy url in the settings object (#10093: consistency with old signature)
		// We also use the url parameter if available
		s.url = ( ( url || s.url || ajaxLocation ) + "" ).replace( rhash, "" )
			.replace( rprotocol, ajaxLocParts[ 1 ] + "//" );

		// Alias method option to type as per ticket #12004
		s.type = options.method || options.type || s.method || s.type;

		// Extract dataTypes list
		s.dataTypes = jQuery.trim( s.dataType || "*" ).toLowerCase().match( rnotwhite ) || [ "" ];

		// A cross-domain request is in order when we have a protocol:host:port mismatch
		if ( s.crossDomain == null ) {
			parts = rurl.exec( s.url.toLowerCase() );
			s.crossDomain = !!( parts &&
				( parts[ 1 ] !== ajaxLocParts[ 1 ] || parts[ 2 ] !== ajaxLocParts[ 2 ] ||
					( parts[ 3 ] || ( parts[ 1 ] === "http:" ? "80" : "443" ) ) !==
						( ajaxLocParts[ 3 ] || ( ajaxLocParts[ 1 ] === "http:" ? "80" : "443" ) ) )
			);
		}

		// Convert data if not already a string
		if ( s.data && s.processData && typeof s.data !== "string" ) {
			s.data = jQuery.param( s.data, s.traditional );
		}

		// Apply prefilters
		inspectPrefiltersOrTransports( prefilters, s, options, jqXHR );

		// If request was aborted inside a prefilter, stop there
		if ( state === 2 ) {
			return jqXHR;
		}

		// We can fire global events as of now if asked to
		// Don't fire events if jQuery.event is undefined in an AMD-usage scenario (#15118)
		fireGlobals = jQuery.event && s.global;

		// Watch for a new set of requests
		if ( fireGlobals && jQuery.active++ === 0 ) {
			jQuery.event.trigger("ajaxStart");
		}

		// Uppercase the type
		s.type = s.type.toUpperCase();

		// Determine if request has content
		s.hasContent = !rnoContent.test( s.type );

		// Save the URL in case we're toying with the If-Modified-Since
		// and/or If-None-Match header later on
		cacheURL = s.url;

		// More options handling for requests with no content
		if ( !s.hasContent ) {

			// If data is available, append data to url
			if ( s.data ) {
				cacheURL = ( s.url += ( rquery.test( cacheURL ) ? "&" : "?" ) + s.data );
				// #9682: remove data so that it's not used in an eventual retry
				delete s.data;
			}

			// Add anti-cache in url if needed
			if ( s.cache === false ) {
				s.url = rts.test( cacheURL ) ?

					// If there is already a '_' parameter, set its value
					cacheURL.replace( rts, "$1_=" + nonce++ ) :

					// Otherwise add one to the end
					cacheURL + ( rquery.test( cacheURL ) ? "&" : "?" ) + "_=" + nonce++;
			}
		}

		// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
		if ( s.ifModified ) {
			if ( jQuery.lastModified[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-Modified-Since", jQuery.lastModified[ cacheURL ] );
			}
			if ( jQuery.etag[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-None-Match", jQuery.etag[ cacheURL ] );
			}
		}

		// Set the correct header, if data is being sent
		if ( s.data && s.hasContent && s.contentType !== false || options.contentType ) {
			jqXHR.setRequestHeader( "Content-Type", s.contentType );
		}

		// Set the Accepts header for the server, depending on the dataType
		jqXHR.setRequestHeader(
			"Accept",
			s.dataTypes[ 0 ] && s.accepts[ s.dataTypes[0] ] ?
				s.accepts[ s.dataTypes[0] ] + ( s.dataTypes[ 0 ] !== "*" ? ", " + allTypes + "; q=0.01" : "" ) :
				s.accepts[ "*" ]
		);

		// Check for headers option
		for ( i in s.headers ) {
			jqXHR.setRequestHeader( i, s.headers[ i ] );
		}

		// Allow custom headers/mimetypes and early abort
		if ( s.beforeSend && ( s.beforeSend.call( callbackContext, jqXHR, s ) === false || state === 2 ) ) {
			// Abort if not done already and return
			return jqXHR.abort();
		}

		// Aborting is no longer a cancellation
		strAbort = "abort";

		// Install callbacks on deferreds
		for ( i in { success: 1, error: 1, complete: 1 } ) {
			jqXHR[ i ]( s[ i ] );
		}

		// Get transport
		transport = inspectPrefiltersOrTransports( transports, s, options, jqXHR );

		// If no transport, we auto-abort
		if ( !transport ) {
			done( -1, "No Transport" );
		} else {
			jqXHR.readyState = 1;

			// Send global event
			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxSend", [ jqXHR, s ] );
			}
			// Timeout
			if ( s.async && s.timeout > 0 ) {
				timeoutTimer = setTimeout(function() {
					jqXHR.abort("timeout");
				}, s.timeout );
			}

			try {
				state = 1;
				transport.send( requestHeaders, done );
			} catch ( e ) {
				// Propagate exception as error if not done
				if ( state < 2 ) {
					done( -1, e );
				// Simply rethrow otherwise
				} else {
					throw e;
				}
			}
		}

		// Callback for when everything is done
		function done( status, nativeStatusText, responses, headers ) {
			var isSuccess, success, error, response, modified,
				statusText = nativeStatusText;

			// Called once
			if ( state === 2 ) {
				return;
			}

			// State is "done" now
			state = 2;

			// Clear timeout if it exists
			if ( timeoutTimer ) {
				clearTimeout( timeoutTimer );
			}

			// Dereference transport for early garbage collection
			// (no matter how long the jqXHR object will be used)
			transport = undefined;

			// Cache response headers
			responseHeadersString = headers || "";

			// Set readyState
			jqXHR.readyState = status > 0 ? 4 : 0;

			// Determine if successful
			isSuccess = status >= 200 && status < 300 || status === 304;

			// Get response data
			if ( responses ) {
				response = ajaxHandleResponses( s, jqXHR, responses );
			}

			// Convert no matter what (that way responseXXX fields are always set)
			response = ajaxConvert( s, response, jqXHR, isSuccess );

			// If successful, handle type chaining
			if ( isSuccess ) {

				// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
				if ( s.ifModified ) {
					modified = jqXHR.getResponseHeader("Last-Modified");
					if ( modified ) {
						jQuery.lastModified[ cacheURL ] = modified;
					}
					modified = jqXHR.getResponseHeader("etag");
					if ( modified ) {
						jQuery.etag[ cacheURL ] = modified;
					}
				}

				// if no content
				if ( status === 204 || s.type === "HEAD" ) {
					statusText = "nocontent";

				// if not modified
				} else if ( status === 304 ) {
					statusText = "notmodified";

				// If we have data, let's convert it
				} else {
					statusText = response.state;
					success = response.data;
					error = response.error;
					isSuccess = !error;
				}
			} else {
				// Extract error from statusText and normalize for non-aborts
				error = statusText;
				if ( status || !statusText ) {
					statusText = "error";
					if ( status < 0 ) {
						status = 0;
					}
				}
			}

			// Set data for the fake xhr object
			jqXHR.status = status;
			jqXHR.statusText = ( nativeStatusText || statusText ) + "";

			// Success/Error
			if ( isSuccess ) {
				deferred.resolveWith( callbackContext, [ success, statusText, jqXHR ] );
			} else {
				deferred.rejectWith( callbackContext, [ jqXHR, statusText, error ] );
			}

			// Status-dependent callbacks
			jqXHR.statusCode( statusCode );
			statusCode = undefined;

			if ( fireGlobals ) {
				globalEventContext.trigger( isSuccess ? "ajaxSuccess" : "ajaxError",
					[ jqXHR, s, isSuccess ? success : error ] );
			}

			// Complete
			completeDeferred.fireWith( callbackContext, [ jqXHR, statusText ] );

			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxComplete", [ jqXHR, s ] );
				// Handle the global AJAX counter
				if ( !( --jQuery.active ) ) {
					jQuery.event.trigger("ajaxStop");
				}
			}
		}

		return jqXHR;
	},

	getJSON: function( url, data, callback ) {
		return jQuery.get( url, data, callback, "json" );
	},

	getScript: function( url, callback ) {
		return jQuery.get( url, undefined, callback, "script" );
	}
});

jQuery.each( [ "get", "post" ], function( i, method ) {
	jQuery[ method ] = function( url, data, callback, type ) {
		// Shift arguments if data argument was omitted
		if ( jQuery.isFunction( data ) ) {
			type = type || callback;
			callback = data;
			data = undefined;
		}

		return jQuery.ajax({
			url: url,
			type: method,
			dataType: type,
			data: data,
			success: callback
		});
	};
});


jQuery._evalUrl = function( url ) {
	return jQuery.ajax({
		url: url,
		type: "GET",
		dataType: "script",
		async: false,
		global: false,
		"throws": true
	});
};


jQuery.fn.extend({
	wrapAll: function( html ) {
		var wrap;

		if ( jQuery.isFunction( html ) ) {
			return this.each(function( i ) {
				jQuery( this ).wrapAll( html.call(this, i) );
			});
		}

		if ( this[ 0 ] ) {

			// The elements to wrap the target around
			wrap = jQuery( html, this[ 0 ].ownerDocument ).eq( 0 ).clone( true );

			if ( this[ 0 ].parentNode ) {
				wrap.insertBefore( this[ 0 ] );
			}

			wrap.map(function() {
				var elem = this;

				while ( elem.firstElementChild ) {
					elem = elem.firstElementChild;
				}

				return elem;
			}).append( this );
		}

		return this;
	},

	wrapInner: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function( i ) {
				jQuery( this ).wrapInner( html.call(this, i) );
			});
		}

		return this.each(function() {
			var self = jQuery( this ),
				contents = self.contents();

			if ( contents.length ) {
				contents.wrapAll( html );

			} else {
				self.append( html );
			}
		});
	},

	wrap: function( html ) {
		var isFunction = jQuery.isFunction( html );

		return this.each(function( i ) {
			jQuery( this ).wrapAll( isFunction ? html.call(this, i) : html );
		});
	},

	unwrap: function() {
		return this.parent().each(function() {
			if ( !jQuery.nodeName( this, "body" ) ) {
				jQuery( this ).replaceWith( this.childNodes );
			}
		}).end();
	}
});


jQuery.expr.filters.hidden = function( elem ) {
	// Support: Opera <= 12.12
	// Opera reports offsetWidths and offsetHeights less than zero on some elements
	return elem.offsetWidth <= 0 && elem.offsetHeight <= 0;
};
jQuery.expr.filters.visible = function( elem ) {
	return !jQuery.expr.filters.hidden( elem );
};




var r20 = /%20/g,
	rbracket = /\[\]$/,
	rCRLF = /\r?\n/g,
	rsubmitterTypes = /^(?:submit|button|image|reset|file)$/i,
	rsubmittable = /^(?:input|select|textarea|keygen)/i;

function buildParams( prefix, obj, traditional, add ) {
	var name;

	if ( jQuery.isArray( obj ) ) {
		// Serialize array item.
		jQuery.each( obj, function( i, v ) {
			if ( traditional || rbracket.test( prefix ) ) {
				// Treat each array item as a scalar.
				add( prefix, v );

			} else {
				// Item is non-scalar (array or object), encode its numeric index.
				buildParams( prefix + "[" + ( typeof v === "object" ? i : "" ) + "]", v, traditional, add );
			}
		});

	} else if ( !traditional && jQuery.type( obj ) === "object" ) {
		// Serialize object item.
		for ( name in obj ) {
			buildParams( prefix + "[" + name + "]", obj[ name ], traditional, add );
		}

	} else {
		// Serialize scalar item.
		add( prefix, obj );
	}
}

// Serialize an array of form elements or a set of
// key/values into a query string
jQuery.param = function( a, traditional ) {
	var prefix,
		s = [],
		add = function( key, value ) {
			// If value is a function, invoke it and return its value
			value = jQuery.isFunction( value ) ? value() : ( value == null ? "" : value );
			s[ s.length ] = encodeURIComponent( key ) + "=" + encodeURIComponent( value );
		};

	// Set traditional to true for jQuery <= 1.3.2 behavior.
	if ( traditional === undefined ) {
		traditional = jQuery.ajaxSettings && jQuery.ajaxSettings.traditional;
	}

	// If an array was passed in, assume that it is an array of form elements.
	if ( jQuery.isArray( a ) || ( a.jquery && !jQuery.isPlainObject( a ) ) ) {
		// Serialize the form elements
		jQuery.each( a, function() {
			add( this.name, this.value );
		});

	} else {
		// If traditional, encode the "old" way (the way 1.3.2 or older
		// did it), otherwise encode params recursively.
		for ( prefix in a ) {
			buildParams( prefix, a[ prefix ], traditional, add );
		}
	}

	// Return the resulting serialization
	return s.join( "&" ).replace( r20, "+" );
};

jQuery.fn.extend({
	serialize: function() {
		return jQuery.param( this.serializeArray() );
	},
	serializeArray: function() {
		return this.map(function() {
			// Can add propHook for "elements" to filter or add form elements
			var elements = jQuery.prop( this, "elements" );
			return elements ? jQuery.makeArray( elements ) : this;
		})
		.filter(function() {
			var type = this.type;

			// Use .is( ":disabled" ) so that fieldset[disabled] works
			return this.name && !jQuery( this ).is( ":disabled" ) &&
				rsubmittable.test( this.nodeName ) && !rsubmitterTypes.test( type ) &&
				( this.checked || !rcheckableType.test( type ) );
		})
		.map(function( i, elem ) {
			var val = jQuery( this ).val();

			return val == null ?
				null :
				jQuery.isArray( val ) ?
					jQuery.map( val, function( val ) {
						return { name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
					}) :
					{ name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
		}).get();
	}
});


jQuery.ajaxSettings.xhr = function() {
	try {
		return new XMLHttpRequest();
	} catch( e ) {}
};

var xhrId = 0,
	xhrCallbacks = {},
	xhrSuccessStatus = {
		// file protocol always yields status code 0, assume 200
		0: 200,
		// Support: IE9
		// #1450: sometimes IE returns 1223 when it should be 204
		1223: 204
	},
	xhrSupported = jQuery.ajaxSettings.xhr();

// Support: IE9
// Open requests must be manually aborted on unload (#5280)
// See https://support.microsoft.com/kb/2856746 for more info
if ( window.attachEvent ) {
	window.attachEvent( "onunload", function() {
		for ( var key in xhrCallbacks ) {
			xhrCallbacks[ key ]();
		}
	});
}

support.cors = !!xhrSupported && ( "withCredentials" in xhrSupported );
support.ajax = xhrSupported = !!xhrSupported;

jQuery.ajaxTransport(function( options ) {
	var callback;

	// Cross domain only allowed if supported through XMLHttpRequest
	if ( support.cors || xhrSupported && !options.crossDomain ) {
		return {
			send: function( headers, complete ) {
				var i,
					xhr = options.xhr(),
					id = ++xhrId;

				xhr.open( options.type, options.url, options.async, options.username, options.password );

				// Apply custom fields if provided
				if ( options.xhrFields ) {
					for ( i in options.xhrFields ) {
						xhr[ i ] = options.xhrFields[ i ];
					}
				}

				// Override mime type if needed
				if ( options.mimeType && xhr.overrideMimeType ) {
					xhr.overrideMimeType( options.mimeType );
				}

				// X-Requested-With header
				// For cross-domain requests, seeing as conditions for a preflight are
				// akin to a jigsaw puzzle, we simply never set it to be sure.
				// (it can always be set on a per-request basis or even using ajaxSetup)
				// For same-domain requests, won't change header if already provided.
				if ( !options.crossDomain && !headers["X-Requested-With"] ) {
					headers["X-Requested-With"] = "XMLHttpRequest";
				}

				// Set headers
				for ( i in headers ) {
					xhr.setRequestHeader( i, headers[ i ] );
				}

				// Callback
				callback = function( type ) {
					return function() {
						if ( callback ) {
							delete xhrCallbacks[ id ];
							callback = xhr.onload = xhr.onerror = null;

							if ( type === "abort" ) {
								xhr.abort();
							} else if ( type === "error" ) {
								complete(
									// file: protocol always yields status 0; see #8605, #14207
									xhr.status,
									xhr.statusText
								);
							} else {
								complete(
									xhrSuccessStatus[ xhr.status ] || xhr.status,
									xhr.statusText,
									// Support: IE9
									// Accessing binary-data responseText throws an exception
									// (#11426)
									typeof xhr.responseText === "string" ? {
										text: xhr.responseText
									} : undefined,
									xhr.getAllResponseHeaders()
								);
							}
						}
					};
				};

				// Listen to events
				xhr.onload = callback();
				xhr.onerror = callback("error");

				// Create the abort callback
				callback = xhrCallbacks[ id ] = callback("abort");

				try {
					// Do send the request (this may raise an exception)
					xhr.send( options.hasContent && options.data || null );
				} catch ( e ) {
					// #14683: Only rethrow if this hasn't been notified as an error yet
					if ( callback ) {
						throw e;
					}
				}
			},

			abort: function() {
				if ( callback ) {
					callback();
				}
			}
		};
	}
});




// Install script dataType
jQuery.ajaxSetup({
	accepts: {
		script: "text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"
	},
	contents: {
		script: /(?:java|ecma)script/
	},
	converters: {
		"text script": function( text ) {
			jQuery.globalEval( text );
			return text;
		}
	}
});

// Handle cache's special case and crossDomain
jQuery.ajaxPrefilter( "script", function( s ) {
	if ( s.cache === undefined ) {
		s.cache = false;
	}
	if ( s.crossDomain ) {
		s.type = "GET";
	}
});

// Bind script tag hack transport
jQuery.ajaxTransport( "script", function( s ) {
	// This transport only deals with cross domain requests
	if ( s.crossDomain ) {
		var script, callback;
		return {
			send: function( _, complete ) {
				script = jQuery("<script>").prop({
					async: true,
					charset: s.scriptCharset,
					src: s.url
				}).on(
					"load error",
					callback = function( evt ) {
						script.remove();
						callback = null;
						if ( evt ) {
							complete( evt.type === "error" ? 404 : 200, evt.type );
						}
					}
				);
				document.head.appendChild( script[ 0 ] );
			},
			abort: function() {
				if ( callback ) {
					callback();
				}
			}
		};
	}
});




var oldCallbacks = [],
	rjsonp = /(=)\?(?=&|$)|\?\?/;

// Default jsonp settings
jQuery.ajaxSetup({
	jsonp: "callback",
	jsonpCallback: function() {
		var callback = oldCallbacks.pop() || ( jQuery.expando + "_" + ( nonce++ ) );
		this[ callback ] = true;
		return callback;
	}
});

// Detect, normalize options and install callbacks for jsonp requests
jQuery.ajaxPrefilter( "json jsonp", function( s, originalSettings, jqXHR ) {

	var callbackName, overwritten, responseContainer,
		jsonProp = s.jsonp !== false && ( rjsonp.test( s.url ) ?
			"url" :
			typeof s.data === "string" && !( s.contentType || "" ).indexOf("application/x-www-form-urlencoded") && rjsonp.test( s.data ) && "data"
		);

	// Handle iff the expected data type is "jsonp" or we have a parameter to set
	if ( jsonProp || s.dataTypes[ 0 ] === "jsonp" ) {

		// Get callback name, remembering preexisting value associated with it
		callbackName = s.jsonpCallback = jQuery.isFunction( s.jsonpCallback ) ?
			s.jsonpCallback() :
			s.jsonpCallback;

		// Insert callback into url or form data
		if ( jsonProp ) {
			s[ jsonProp ] = s[ jsonProp ].replace( rjsonp, "$1" + callbackName );
		} else if ( s.jsonp !== false ) {
			s.url += ( rquery.test( s.url ) ? "&" : "?" ) + s.jsonp + "=" + callbackName;
		}

		// Use data converter to retrieve json after script execution
		s.converters["script json"] = function() {
			if ( !responseContainer ) {
				jQuery.error( callbackName + " was not called" );
			}
			return responseContainer[ 0 ];
		};

		// force json dataType
		s.dataTypes[ 0 ] = "json";

		// Install callback
		overwritten = window[ callbackName ];
		window[ callbackName ] = function() {
			responseContainer = arguments;
		};

		// Clean-up function (fires after converters)
		jqXHR.always(function() {
			// Restore preexisting value
			window[ callbackName ] = overwritten;

			// Save back as free
			if ( s[ callbackName ] ) {
				// make sure that re-using the options doesn't screw things around
				s.jsonpCallback = originalSettings.jsonpCallback;

				// save the callback name for future use
				oldCallbacks.push( callbackName );
			}

			// Call if it was a function and we have a response
			if ( responseContainer && jQuery.isFunction( overwritten ) ) {
				overwritten( responseContainer[ 0 ] );
			}

			responseContainer = overwritten = undefined;
		});

		// Delegate to script
		return "script";
	}
});




// data: string of html
// context (optional): If specified, the fragment will be created in this context, defaults to document
// keepScripts (optional): If true, will include scripts passed in the html string
jQuery.parseHTML = function( data, context, keepScripts ) {
	if ( !data || typeof data !== "string" ) {
		return null;
	}
	if ( typeof context === "boolean" ) {
		keepScripts = context;
		context = false;
	}
	context = context || document;

	var parsed = rsingleTag.exec( data ),
		scripts = !keepScripts && [];

	// Single tag
	if ( parsed ) {
		return [ context.createElement( parsed[1] ) ];
	}

	parsed = jQuery.buildFragment( [ data ], context, scripts );

	if ( scripts && scripts.length ) {
		jQuery( scripts ).remove();
	}

	return jQuery.merge( [], parsed.childNodes );
};


// Keep a copy of the old load method
var _load = jQuery.fn.load;

/**
 * Load a url into a page
 */
jQuery.fn.load = function( url, params, callback ) {
	if ( typeof url !== "string" && _load ) {
		return _load.apply( this, arguments );
	}

	var selector, type, response,
		self = this,
		off = url.indexOf(" ");

	if ( off >= 0 ) {
		selector = jQuery.trim( url.slice( off ) );
		url = url.slice( 0, off );
	}

	// If it's a function
	if ( jQuery.isFunction( params ) ) {

		// We assume that it's the callback
		callback = params;
		params = undefined;

	// Otherwise, build a param string
	} else if ( params && typeof params === "object" ) {
		type = "POST";
	}

	// If we have elements to modify, make the request
	if ( self.length > 0 ) {
		jQuery.ajax({
			url: url,

			// if "type" variable is undefined, then "GET" method will be used
			type: type,
			dataType: "html",
			data: params
		}).done(function( responseText ) {

			// Save response for use in complete callback
			response = arguments;

			self.html( selector ?

				// If a selector was specified, locate the right elements in a dummy div
				// Exclude scripts to avoid IE 'Permission Denied' errors
				jQuery("<div>").append( jQuery.parseHTML( responseText ) ).find( selector ) :

				// Otherwise use the full result
				responseText );

		}).complete( callback && function( jqXHR, status ) {
			self.each( callback, response || [ jqXHR.responseText, status, jqXHR ] );
		});
	}

	return this;
};




// Attach a bunch of functions for handling common AJAX events
jQuery.each( [ "ajaxStart", "ajaxStop", "ajaxComplete", "ajaxError", "ajaxSuccess", "ajaxSend" ], function( i, type ) {
	jQuery.fn[ type ] = function( fn ) {
		return this.on( type, fn );
	};
});




jQuery.expr.filters.animated = function( elem ) {
	return jQuery.grep(jQuery.timers, function( fn ) {
		return elem === fn.elem;
	}).length;
};




var docElem = window.document.documentElement;

/**
 * Gets a window from an element
 */
function getWindow( elem ) {
	return jQuery.isWindow( elem ) ? elem : elem.nodeType === 9 && elem.defaultView;
}

jQuery.offset = {
	setOffset: function( elem, options, i ) {
		var curPosition, curLeft, curCSSTop, curTop, curOffset, curCSSLeft, calculatePosition,
			position = jQuery.css( elem, "position" ),
			curElem = jQuery( elem ),
			props = {};

		// Set position first, in-case top/left are set even on static elem
		if ( position === "static" ) {
			elem.style.position = "relative";
		}

		curOffset = curElem.offset();
		curCSSTop = jQuery.css( elem, "top" );
		curCSSLeft = jQuery.css( elem, "left" );
		calculatePosition = ( position === "absolute" || position === "fixed" ) &&
			( curCSSTop + curCSSLeft ).indexOf("auto") > -1;

		// Need to be able to calculate position if either
		// top or left is auto and position is either absolute or fixed
		if ( calculatePosition ) {
			curPosition = curElem.position();
			curTop = curPosition.top;
			curLeft = curPosition.left;

		} else {
			curTop = parseFloat( curCSSTop ) || 0;
			curLeft = parseFloat( curCSSLeft ) || 0;
		}

		if ( jQuery.isFunction( options ) ) {
			options = options.call( elem, i, curOffset );
		}

		if ( options.top != null ) {
			props.top = ( options.top - curOffset.top ) + curTop;
		}
		if ( options.left != null ) {
			props.left = ( options.left - curOffset.left ) + curLeft;
		}

		if ( "using" in options ) {
			options.using.call( elem, props );

		} else {
			curElem.css( props );
		}
	}
};

jQuery.fn.extend({
	offset: function( options ) {
		if ( arguments.length ) {
			return options === undefined ?
				this :
				this.each(function( i ) {
					jQuery.offset.setOffset( this, options, i );
				});
		}

		var docElem, win,
			elem = this[ 0 ],
			box = { top: 0, left: 0 },
			doc = elem && elem.ownerDocument;

		if ( !doc ) {
			return;
		}

		docElem = doc.documentElement;

		// Make sure it's not a disconnected DOM node
		if ( !jQuery.contains( docElem, elem ) ) {
			return box;
		}

		// Support: BlackBerry 5, iOS 3 (original iPhone)
		// If we don't have gBCR, just use 0,0 rather than error
		if ( typeof elem.getBoundingClientRect !== strundefined ) {
			box = elem.getBoundingClientRect();
		}
		win = getWindow( doc );
		return {
			top: box.top + win.pageYOffset - docElem.clientTop,
			left: box.left + win.pageXOffset - docElem.clientLeft
		};
	},

	position: function() {
		if ( !this[ 0 ] ) {
			return;
		}

		var offsetParent, offset,
			elem = this[ 0 ],
			parentOffset = { top: 0, left: 0 };

		// Fixed elements are offset from window (parentOffset = {top:0, left: 0}, because it is its only offset parent
		if ( jQuery.css( elem, "position" ) === "fixed" ) {
			// Assume getBoundingClientRect is there when computed position is fixed
			offset = elem.getBoundingClientRect();

		} else {
			// Get *real* offsetParent
			offsetParent = this.offsetParent();

			// Get correct offsets
			offset = this.offset();
			if ( !jQuery.nodeName( offsetParent[ 0 ], "html" ) ) {
				parentOffset = offsetParent.offset();
			}

			// Add offsetParent borders
			parentOffset.top += jQuery.css( offsetParent[ 0 ], "borderTopWidth", true );
			parentOffset.left += jQuery.css( offsetParent[ 0 ], "borderLeftWidth", true );
		}

		// Subtract parent offsets and element margins
		return {
			top: offset.top - parentOffset.top - jQuery.css( elem, "marginTop", true ),
			left: offset.left - parentOffset.left - jQuery.css( elem, "marginLeft", true )
		};
	},

	offsetParent: function() {
		return this.map(function() {
			var offsetParent = this.offsetParent || docElem;

			while ( offsetParent && ( !jQuery.nodeName( offsetParent, "html" ) && jQuery.css( offsetParent, "position" ) === "static" ) ) {
				offsetParent = offsetParent.offsetParent;
			}

			return offsetParent || docElem;
		});
	}
});

// Create scrollLeft and scrollTop methods
jQuery.each( { scrollLeft: "pageXOffset", scrollTop: "pageYOffset" }, function( method, prop ) {
	var top = "pageYOffset" === prop;

	jQuery.fn[ method ] = function( val ) {
		return access( this, function( elem, method, val ) {
			var win = getWindow( elem );

			if ( val === undefined ) {
				return win ? win[ prop ] : elem[ method ];
			}

			if ( win ) {
				win.scrollTo(
					!top ? val : window.pageXOffset,
					top ? val : window.pageYOffset
				);

			} else {
				elem[ method ] = val;
			}
		}, method, val, arguments.length, null );
	};
});

// Support: Safari<7+, Chrome<37+
// Add the top/left cssHooks using jQuery.fn.position
// Webkit bug: https://bugs.webkit.org/show_bug.cgi?id=29084
// Blink bug: https://code.google.com/p/chromium/issues/detail?id=229280
// getComputedStyle returns percent when specified for top/left/bottom/right;
// rather than make the css module depend on the offset module, just check for it here
jQuery.each( [ "top", "left" ], function( i, prop ) {
	jQuery.cssHooks[ prop ] = addGetHookIf( support.pixelPosition,
		function( elem, computed ) {
			if ( computed ) {
				computed = curCSS( elem, prop );
				// If curCSS returns percentage, fallback to offset
				return rnumnonpx.test( computed ) ?
					jQuery( elem ).position()[ prop ] + "px" :
					computed;
			}
		}
	);
});


// Create innerHeight, innerWidth, height, width, outerHeight and outerWidth methods
jQuery.each( { Height: "height", Width: "width" }, function( name, type ) {
	jQuery.each( { padding: "inner" + name, content: type, "": "outer" + name }, function( defaultExtra, funcName ) {
		// Margin is only for outerHeight, outerWidth
		jQuery.fn[ funcName ] = function( margin, value ) {
			var chainable = arguments.length && ( defaultExtra || typeof margin !== "boolean" ),
				extra = defaultExtra || ( margin === true || value === true ? "margin" : "border" );

			return access( this, function( elem, type, value ) {
				var doc;

				if ( jQuery.isWindow( elem ) ) {
					// As of 5/8/2012 this will yield incorrect results for Mobile Safari, but there
					// isn't a whole lot we can do. See pull request at this URL for discussion:
					// https://github.com/jquery/jquery/pull/764
					return elem.document.documentElement[ "client" + name ];
				}

				// Get document width or height
				if ( elem.nodeType === 9 ) {
					doc = elem.documentElement;

					// Either scroll[Width/Height] or offset[Width/Height] or client[Width/Height],
					// whichever is greatest
					return Math.max(
						elem.body[ "scroll" + name ], doc[ "scroll" + name ],
						elem.body[ "offset" + name ], doc[ "offset" + name ],
						doc[ "client" + name ]
					);
				}

				return value === undefined ?
					// Get width or height on the element, requesting but not forcing parseFloat
					jQuery.css( elem, type, extra ) :

					// Set width or height on the element
					jQuery.style( elem, type, value, extra );
			}, type, chainable ? margin : undefined, chainable, null );
		};
	});
});


// The number of elements contained in the matched element set
jQuery.fn.size = function() {
	return this.length;
};

jQuery.fn.andSelf = jQuery.fn.addBack;




// Register as a named AMD module, since jQuery can be concatenated with other
// files that may use define, but not via a proper concatenation script that
// understands anonymous AMD modules. A named AMD is safest and most robust
// way to register. Lowercase jquery is used because AMD module names are
// derived from file names, and jQuery is normally delivered in a lowercase
// file name. Do this after creating the global so that if an AMD module wants
// to call noConflict to hide this version of jQuery, it will work.

// Note that for maximum portability, libraries that are not jQuery should
// declare themselves as anonymous modules, and avoid setting a global if an
// AMD loader is present. jQuery is a special case. For more information, see
// https://github.com/jrburke/requirejs/wiki/Updating-existing-libraries#wiki-anon

if ( typeof define === "function" && define.amd ) {
	define( "jquery", [], function() {
		return jQuery;
	});
}




var
	// Map over jQuery in case of overwrite
	_jQuery = window.jQuery,

	// Map over the $ in case of overwrite
	_$ = window.$;

jQuery.noConflict = function( deep ) {
	if ( window.$ === jQuery ) {
		window.$ = _$;
	}

	if ( deep && window.jQuery === jQuery ) {
		window.jQuery = _jQuery;
	}

	return jQuery;
};

// Expose jQuery and $ identifiers, even in AMD
// (#7102#comment:10, https://github.com/jquery/jquery/pull/557)
// and CommonJS for browser emulators (#13566)
if ( typeof noGlobal === strundefined ) {
	window.jQuery = window.$ = jQuery;
}




return jQuery;

}));

/*
     _ _      _       _
 ___| (_) ___| | __  (_)___
/ __| | |/ __| |/ /  | / __|
\__ \ | | (__|   < _ | \__ \
|___/_|_|\___|_|\_(_)/ |___/
                   |__/

 Version: 1.6.0
  Author: Ken Wheeler
 Website: http://kenwheeler.github.io
    Docs: http://kenwheeler.github.io/slick
    Repo: http://github.com/kenwheeler/slick
  Issues: http://github.com/kenwheeler/slick/issues

 */
/* global window, document, define, jQuery, setInterval, clearInterval */
(function(factory) {
    'use strict';
    if (typeof define === 'function' && define.amd) {
        define(['jquery'], factory);
    } else if (typeof exports !== 'undefined') {
        module.exports = factory(require('jquery'));
    } else {
        factory(jQuery);
    }

}(function($) {
    'use strict';
    var Slick = window.Slick || {};

    Slick = (function() {

        var instanceUid = 0;

        function Slick(element, settings) {

            var _ = this, dataSettings;

            _.defaults = {
                accessibility: true,
                adaptiveHeight: false,
                appendArrows: $(element),
                appendDots: $(element),
                arrows: true,
                asNavFor: null,
                prevArrow: '<button type="button" data-role="none" class="slick-prev" aria-label="Previous" tabindex="0" role="button">Previous</button>',
                nextArrow: '<button type="button" data-role="none" class="slick-next" aria-label="Next" tabindex="0" role="button">Next</button>',
                autoplay: false,
                autoplaySpeed: 3000,
                centerMode: false,
                centerPadding: '50px',
                cssEase: 'ease',
                customPaging: function(slider, i) {
                    return $('<button type="button" data-role="none" role="button" tabindex="0" />').text(i + 1);
                },
                dots: false,
                dotsClass: 'slick-dots',
                draggable: true,
                easing: 'linear',
                edgeFriction: 0.35,
                fade: false,
                focusOnSelect: false,
                infinite: true,
                initialSlide: 0,
                lazyLoad: 'ondemand',
                mobileFirst: false,
                pauseOnHover: true,
                pauseOnFocus: true,
                pauseOnDotsHover: false,
                respondTo: 'window',
                responsive: null,
                rows: 1,
                rtl: false,
                slide: '',
                slidesPerRow: 1,
                slidesToShow: 1,
                slidesToScroll: 1,
                speed: 500,
                swipe: true,
                swipeToSlide: false,
                touchMove: true,
                touchThreshold: 5,
                useCSS: true,
                useTransform: true,
                variableWidth: false,
                vertical: false,
                verticalSwiping: false,
                waitForAnimate: true,
                zIndex: 1000
            };

            _.initials = {
                animating: false,
                dragging: false,
                autoPlayTimer: null,
                currentDirection: 0,
                currentLeft: null,
                currentSlide: 0,
                direction: 1,
                $dots: null,
                listWidth: null,
                listHeight: null,
                loadIndex: 0,
                $nextArrow: null,
                $prevArrow: null,
                slideCount: null,
                slideWidth: null,
                $slideTrack: null,
                $slides: null,
                sliding: false,
                slideOffset: 0,
                swipeLeft: null,
                $list: null,
                touchObject: {},
                transformsEnabled: false,
                unslicked: false
            };

            $.extend(_, _.initials);

            _.activeBreakpoint = null;
            _.animType = null;
            _.animProp = null;
            _.breakpoints = [];
            _.breakpointSettings = [];
            _.cssTransitions = false;
            _.focussed = false;
            _.interrupted = false;
            _.hidden = 'hidden';
            _.paused = true;
            _.positionProp = null;
            _.respondTo = null;
            _.rowCount = 1;
            _.shouldClick = true;
            _.$slider = $(element);
            _.$slidesCache = null;
            _.transformType = null;
            _.transitionType = null;
            _.visibilityChange = 'visibilitychange';
            _.windowWidth = 0;
            _.windowTimer = null;

            dataSettings = $(element).data('slick') || {};

            _.options = $.extend({}, _.defaults, settings, dataSettings);

            _.currentSlide = _.options.initialSlide;

            _.originalSettings = _.options;

            if (typeof document.mozHidden !== 'undefined') {
                _.hidden = 'mozHidden';
                _.visibilityChange = 'mozvisibilitychange';
            } else if (typeof document.webkitHidden !== 'undefined') {
                _.hidden = 'webkitHidden';
                _.visibilityChange = 'webkitvisibilitychange';
            }

            _.autoPlay = $.proxy(_.autoPlay, _);
            _.autoPlayClear = $.proxy(_.autoPlayClear, _);
            _.autoPlayIterator = $.proxy(_.autoPlayIterator, _);
            _.changeSlide = $.proxy(_.changeSlide, _);
            _.clickHandler = $.proxy(_.clickHandler, _);
            _.selectHandler = $.proxy(_.selectHandler, _);
            _.setPosition = $.proxy(_.setPosition, _);
            _.swipeHandler = $.proxy(_.swipeHandler, _);
            _.dragHandler = $.proxy(_.dragHandler, _);
            _.keyHandler = $.proxy(_.keyHandler, _);

            _.instanceUid = instanceUid++;

            // A simple way to check for HTML strings
            // Strict HTML recognition (must start with <)
            // Extracted from jQuery v1.11 source
            _.htmlExpr = /^(?:\s*(<[\w\W]+>)[^>]*)$/;


            _.registerBreakpoints();
            _.init(true);

        }

        return Slick;

    }());

    Slick.prototype.activateADA = function() {
        var _ = this;

        _.$slideTrack.find('.slick-active').attr({
            'aria-hidden': 'false'
        }).find('a, input, button, select').attr({
            'tabindex': '0'
        });

    };

    Slick.prototype.addSlide = Slick.prototype.slickAdd = function(markup, index, addBefore) {

        var _ = this;

        if (typeof(index) === 'boolean') {
            addBefore = index;
            index = null;
        } else if (index < 0 || (index >= _.slideCount)) {
            return false;
        }

        _.unload();

        if (typeof(index) === 'number') {
            if (index === 0 && _.$slides.length === 0) {
                $(markup).appendTo(_.$slideTrack);
            } else if (addBefore) {
                $(markup).insertBefore(_.$slides.eq(index));
            } else {
                $(markup).insertAfter(_.$slides.eq(index));
            }
        } else {
            if (addBefore === true) {
                $(markup).prependTo(_.$slideTrack);
            } else {
                $(markup).appendTo(_.$slideTrack);
            }
        }

        _.$slides = _.$slideTrack.children(this.options.slide);

        _.$slideTrack.children(this.options.slide).detach();

        _.$slideTrack.append(_.$slides);

        _.$slides.each(function(index, element) {
            $(element).attr('data-slick-index', index);
        });

        _.$slidesCache = _.$slides;

        _.reinit();

    };

    Slick.prototype.animateHeight = function() {
        var _ = this;
        if (_.options.slidesToShow === 1 && _.options.adaptiveHeight === true && _.options.vertical === false) {
            var targetHeight = _.$slides.eq(_.currentSlide).outerHeight(true);
            _.$list.animate({
                height: targetHeight
            }, _.options.speed);
        }
    };

    Slick.prototype.animateSlide = function(targetLeft, callback) {

        var animProps = {},
            _ = this;

        _.animateHeight();

        if (_.options.rtl === true && _.options.vertical === false) {
            targetLeft = -targetLeft;
        }
        if (_.transformsEnabled === false) {
            if (_.options.vertical === false) {
                _.$slideTrack.animate({
                    left: targetLeft
                }, _.options.speed, _.options.easing, callback);
            } else {
                _.$slideTrack.animate({
                    top: targetLeft
                }, _.options.speed, _.options.easing, callback);
            }

        } else {

            if (_.cssTransitions === false) {
                if (_.options.rtl === true) {
                    _.currentLeft = -(_.currentLeft);
                }
                $({
                    animStart: _.currentLeft
                }).animate({
                    animStart: targetLeft
                }, {
                    duration: _.options.speed,
                    easing: _.options.easing,
                    step: function(now) {
                        now = Math.ceil(now);
                        if (_.options.vertical === false) {
                            animProps[_.animType] = 'translate(' +
                                now + 'px, 0px)';
                            _.$slideTrack.css(animProps);
                        } else {
                            animProps[_.animType] = 'translate(0px,' +
                                now + 'px)';
                            _.$slideTrack.css(animProps);
                        }
                    },
                    complete: function() {
                        if (callback) {
                            callback.call();
                        }
                    }
                });

            } else {

                _.applyTransition();
                targetLeft = Math.ceil(targetLeft);

                if (_.options.vertical === false) {
                    animProps[_.animType] = 'translate3d(' + targetLeft + 'px, 0px, 0px)';
                } else {
                    animProps[_.animType] = 'translate3d(0px,' + targetLeft + 'px, 0px)';
                }
                _.$slideTrack.css(animProps);

                if (callback) {
                    setTimeout(function() {

                        _.disableTransition();

                        callback.call();
                    }, _.options.speed);
                }

            }

        }

    };

    Slick.prototype.getNavTarget = function() {

        var _ = this,
            asNavFor = _.options.asNavFor;

        if ( asNavFor && asNavFor !== null ) {
            asNavFor = $(asNavFor).not(_.$slider);
        }

        return asNavFor;

    };

    Slick.prototype.asNavFor = function(index) {

        var _ = this,
            asNavFor = _.getNavTarget();

        if ( asNavFor !== null && typeof asNavFor === 'object' ) {
            asNavFor.each(function() {
                var target = $(this).slick('getSlick');
                if(!target.unslicked) {
                    target.slideHandler(index, true);
                }
            });
        }

    };

    Slick.prototype.applyTransition = function(slide) {

        var _ = this,
            transition = {};

        if (_.options.fade === false) {
            transition[_.transitionType] = _.transformType + ' ' + _.options.speed + 'ms ' + _.options.cssEase;
        } else {
            transition[_.transitionType] = 'opacity ' + _.options.speed + 'ms ' + _.options.cssEase;
        }

        if (_.options.fade === false) {
            _.$slideTrack.css(transition);
        } else {
            _.$slides.eq(slide).css(transition);
        }

    };

    Slick.prototype.autoPlay = function() {

        var _ = this;

        _.autoPlayClear();

        if ( _.slideCount > _.options.slidesToShow ) {
            _.autoPlayTimer = setInterval( _.autoPlayIterator, _.options.autoplaySpeed );
        }

    };

    Slick.prototype.autoPlayClear = function() {

        var _ = this;

        if (_.autoPlayTimer) {
            clearInterval(_.autoPlayTimer);
        }

    };

    Slick.prototype.autoPlayIterator = function() {

        var _ = this,
            slideTo = _.currentSlide + _.options.slidesToScroll;

        if ( !_.paused && !_.interrupted && !_.focussed ) {

            if ( _.options.infinite === false ) {

                if ( _.direction === 1 && ( _.currentSlide + 1 ) === ( _.slideCount - 1 )) {
                    _.direction = 0;
                }

                else if ( _.direction === 0 ) {

                    slideTo = _.currentSlide - _.options.slidesToScroll;

                    if ( _.currentSlide - 1 === 0 ) {
                        _.direction = 1;
                    }

                }

            }

            _.slideHandler( slideTo );

        }

    };

    Slick.prototype.buildArrows = function() {

        var _ = this;

        if (_.options.arrows === true ) {

            _.$prevArrow = $(_.options.prevArrow).addClass('slick-arrow');
            _.$nextArrow = $(_.options.nextArrow).addClass('slick-arrow');

            if( _.slideCount > _.options.slidesToShow ) {

                _.$prevArrow.removeClass('slick-hidden').removeAttr('aria-hidden tabindex');
                _.$nextArrow.removeClass('slick-hidden').removeAttr('aria-hidden tabindex');

                if (_.htmlExpr.test(_.options.prevArrow)) {
                    _.$prevArrow.prependTo(_.options.appendArrows);
                }

                if (_.htmlExpr.test(_.options.nextArrow)) {
                    _.$nextArrow.appendTo(_.options.appendArrows);
                }

                if (_.options.infinite !== true) {
                    _.$prevArrow
                        .addClass('slick-disabled')
                        .attr('aria-disabled', 'true');
                }

            } else {

                _.$prevArrow.add( _.$nextArrow )

                    .addClass('slick-hidden')
                    .attr({
                        'aria-disabled': 'true',
                        'tabindex': '-1'
                    });

            }

        }

    };

    Slick.prototype.buildDots = function() {

        var _ = this,
            i, dot;

        if (_.options.dots === true && _.slideCount > _.options.slidesToShow) {

            _.$slider.addClass('slick-dotted');

            dot = $('<ul />').addClass(_.options.dotsClass);

            for (i = 0; i <= _.getDotCount(); i += 1) {
                dot.append($('<li />').append(_.options.customPaging.call(this, _, i)));
            }

            _.$dots = dot.appendTo(_.options.appendDots);

            _.$dots.find('li').first().addClass('slick-active').attr('aria-hidden', 'false');

        }

    };

    Slick.prototype.buildOut = function() {

        var _ = this;

        _.$slides =
            _.$slider
                .children( _.options.slide + ':not(.slick-cloned)')
                .addClass('slick-slide');

        _.slideCount = _.$slides.length;

        _.$slides.each(function(index, element) {
            $(element)
                .attr('data-slick-index', index)
                .data('originalStyling', $(element).attr('style') || '');
        });

        _.$slider.addClass('slick-slider');

        _.$slideTrack = (_.slideCount === 0) ?
            $('<div class="slick-track"/>').appendTo(_.$slider) :
            _.$slides.wrapAll('<div class="slick-track"/>').parent();

        _.$list = _.$slideTrack.wrap(
            '<div aria-live="polite" class="slick-list"/>').parent();
        _.$slideTrack.css('opacity', 0);

        if (_.options.centerMode === true || _.options.swipeToSlide === true) {
            _.options.slidesToScroll = 1;
        }

        $('img[data-lazy]', _.$slider).not('[src]').addClass('slick-loading');

        _.setupInfinite();

        _.buildArrows();

        _.buildDots();

        _.updateDots();


        _.setSlideClasses(typeof _.currentSlide === 'number' ? _.currentSlide : 0);

        if (_.options.draggable === true) {
            _.$list.addClass('draggable');
        }

    };

    Slick.prototype.buildRows = function() {

        var _ = this, a, b, c, newSlides, numOfSlides, originalSlides,slidesPerSection;

        newSlides = document.createDocumentFragment();
        originalSlides = _.$slider.children();

        if(_.options.rows > 1) {

            slidesPerSection = _.options.slidesPerRow * _.options.rows;
            numOfSlides = Math.ceil(
                originalSlides.length / slidesPerSection
            );

            for(a = 0; a < numOfSlides; a++){
                var slide = document.createElement('div');
                for(b = 0; b < _.options.rows; b++) {
                    var row = document.createElement('div');
                    for(c = 0; c < _.options.slidesPerRow; c++) {
                        var target = (a * slidesPerSection + ((b * _.options.slidesPerRow) + c));
                        if (originalSlides.get(target)) {
                            row.appendChild(originalSlides.get(target));
                        }
                    }
                    slide.appendChild(row);
                }
                newSlides.appendChild(slide);
            }

            _.$slider.empty().append(newSlides);
            _.$slider.children().children().children()
                .css({
                    'width':(100 / _.options.slidesPerRow) + '%',
                    'display': 'inline-block'
                });

        }

    };

    Slick.prototype.checkResponsive = function(initial, forceUpdate) {

        var _ = this,
            breakpoint, targetBreakpoint, respondToWidth, triggerBreakpoint = false;
        var sliderWidth = _.$slider.width();
        var windowWidth = window.innerWidth || $(window).width();

        if (_.respondTo === 'window') {
            respondToWidth = windowWidth;
        } else if (_.respondTo === 'slider') {
            respondToWidth = sliderWidth;
        } else if (_.respondTo === 'min') {
            respondToWidth = Math.min(windowWidth, sliderWidth);
        }

        if ( _.options.responsive &&
            _.options.responsive.length &&
            _.options.responsive !== null) {

            targetBreakpoint = null;

            for (breakpoint in _.breakpoints) {
                if (_.breakpoints.hasOwnProperty(breakpoint)) {
                    if (_.originalSettings.mobileFirst === false) {
                        if (respondToWidth < _.breakpoints[breakpoint]) {
                            targetBreakpoint = _.breakpoints[breakpoint];
                        }
                    } else {
                        if (respondToWidth > _.breakpoints[breakpoint]) {
                            targetBreakpoint = _.breakpoints[breakpoint];
                        }
                    }
                }
            }

            if (targetBreakpoint !== null) {
                if (_.activeBreakpoint !== null) {
                    if (targetBreakpoint !== _.activeBreakpoint || forceUpdate) {
                        _.activeBreakpoint =
                            targetBreakpoint;
                        if (_.breakpointSettings[targetBreakpoint] === 'unslick') {
                            _.unslick(targetBreakpoint);
                        } else {
                            _.options = $.extend({}, _.originalSettings,
                                _.breakpointSettings[
                                    targetBreakpoint]);
                            if (initial === true) {
                                _.currentSlide = _.options.initialSlide;
                            }
                            _.refresh(initial);
                        }
                        triggerBreakpoint = targetBreakpoint;
                    }
                } else {
                    _.activeBreakpoint = targetBreakpoint;
                    if (_.breakpointSettings[targetBreakpoint] === 'unslick') {
                        _.unslick(targetBreakpoint);
                    } else {
                        _.options = $.extend({}, _.originalSettings,
                            _.breakpointSettings[
                                targetBreakpoint]);
                        if (initial === true) {
                            _.currentSlide = _.options.initialSlide;
                        }
                        _.refresh(initial);
                    }
                    triggerBreakpoint = targetBreakpoint;
                }
            } else {
                if (_.activeBreakpoint !== null) {
                    _.activeBreakpoint = null;
                    _.options = _.originalSettings;
                    if (initial === true) {
                        _.currentSlide = _.options.initialSlide;
                    }
                    _.refresh(initial);
                    triggerBreakpoint = targetBreakpoint;
                }
            }

            // only trigger breakpoints during an actual break. not on initialize.
            if( !initial && triggerBreakpoint !== false ) {
                _.$slider.trigger('breakpoint', [_, triggerBreakpoint]);
            }
        }

    };

    Slick.prototype.changeSlide = function(event, dontAnimate) {

        var _ = this,
            $target = $(event.currentTarget),
            indexOffset, slideOffset, unevenOffset;

        // If target is a link, prevent default action.
        if($target.is('a')) {
            event.preventDefault();
        }

        // If target is not the <li> element (ie: a child), find the <li>.
        if(!$target.is('li')) {
            $target = $target.closest('li');
        }

        unevenOffset = (_.slideCount % _.options.slidesToScroll !== 0);
        indexOffset = unevenOffset ? 0 : (_.slideCount - _.currentSlide) % _.options.slidesToScroll;

        switch (event.data.message) {

            case 'previous':
                slideOffset = indexOffset === 0 ? _.options.slidesToScroll : _.options.slidesToShow - indexOffset;
                if (_.slideCount > _.options.slidesToShow) {
                    _.slideHandler(_.currentSlide - slideOffset, false, dontAnimate);
                }
                break;

            case 'next':
                slideOffset = indexOffset === 0 ? _.options.slidesToScroll : indexOffset;
                if (_.slideCount > _.options.slidesToShow) {
                    _.slideHandler(_.currentSlide + slideOffset, false, dontAnimate);
                }
                break;

            case 'index':
                var index = event.data.index === 0 ? 0 :
                    event.data.index || $target.index() * _.options.slidesToScroll;

                _.slideHandler(_.checkNavigable(index), false, dontAnimate);
                $target.children().trigger('focus');
                break;

            default:
                return;
        }

    };

    Slick.prototype.checkNavigable = function(index) {

        var _ = this,
            navigables, prevNavigable;

        navigables = _.getNavigableIndexes();
        prevNavigable = 0;
        if (index > navigables[navigables.length - 1]) {
            index = navigables[navigables.length - 1];
        } else {
            for (var n in navigables) {
                if (index < navigables[n]) {
                    index = prevNavigable;
                    break;
                }
                prevNavigable = navigables[n];
            }
        }

        return index;
    };

    Slick.prototype.cleanUpEvents = function() {

        var _ = this;

        if (_.options.dots && _.$dots !== null) {

            $('li', _.$dots)
                .off('click.slick', _.changeSlide)
                .off('mouseenter.slick', $.proxy(_.interrupt, _, true))
                .off('mouseleave.slick', $.proxy(_.interrupt, _, false));

        }

        _.$slider.off('focus.slick blur.slick');

        if (_.options.arrows === true && _.slideCount > _.options.slidesToShow) {
            _.$prevArrow && _.$prevArrow.off('click.slick', _.changeSlide);
            _.$nextArrow && _.$nextArrow.off('click.slick', _.changeSlide);
        }

        _.$list.off('touchstart.slick mousedown.slick', _.swipeHandler);
        _.$list.off('touchmove.slick mousemove.slick', _.swipeHandler);
        _.$list.off('touchend.slick mouseup.slick', _.swipeHandler);
        _.$list.off('touchcancel.slick mouseleave.slick', _.swipeHandler);

        _.$list.off('click.slick', _.clickHandler);

        $(document).off(_.visibilityChange, _.visibility);

        _.cleanUpSlideEvents();

        if (_.options.accessibility === true) {
            _.$list.off('keydown.slick', _.keyHandler);
        }

        if (_.options.focusOnSelect === true) {
            $(_.$slideTrack).children().off('click.slick', _.selectHandler);
        }

        $(window).off('orientationchange.slick.slick-' + _.instanceUid, _.orientationChange);

        $(window).off('resize.slick.slick-' + _.instanceUid, _.resize);

        $('[draggable!=true]', _.$slideTrack).off('dragstart', _.preventDefault);

        $(window).off('load.slick.slick-' + _.instanceUid, _.setPosition);
        $(document).off('ready.slick.slick-' + _.instanceUid, _.setPosition);

    };

    Slick.prototype.cleanUpSlideEvents = function() {

        var _ = this;

        _.$list.off('mouseenter.slick', $.proxy(_.interrupt, _, true));
        _.$list.off('mouseleave.slick', $.proxy(_.interrupt, _, false));

    };

    Slick.prototype.cleanUpRows = function() {

        var _ = this, originalSlides;

        if(_.options.rows > 1) {
            originalSlides = _.$slides.children().children();
            originalSlides.removeAttr('style');
            _.$slider.empty().append(originalSlides);
        }

    };

    Slick.prototype.clickHandler = function(event) {

        var _ = this;

        if (_.shouldClick === false) {
            event.stopImmediatePropagation();
            event.stopPropagation();
            event.preventDefault();
        }

    };

    Slick.prototype.destroy = function(refresh) {

        var _ = this;

        _.autoPlayClear();

        _.touchObject = {};

        _.cleanUpEvents();

        $('.slick-cloned', _.$slider).detach();

        if (_.$dots) {
            _.$dots.remove();
        }


        if ( _.$prevArrow && _.$prevArrow.length ) {

            _.$prevArrow
                .removeClass('slick-disabled slick-arrow slick-hidden')
                .removeAttr('aria-hidden aria-disabled tabindex')
                .css('display','');

            if ( _.htmlExpr.test( _.options.prevArrow )) {
                _.$prevArrow.remove();
            }
        }

        if ( _.$nextArrow && _.$nextArrow.length ) {

            _.$nextArrow
                .removeClass('slick-disabled slick-arrow slick-hidden')
                .removeAttr('aria-hidden aria-disabled tabindex')
                .css('display','');

            if ( _.htmlExpr.test( _.options.nextArrow )) {
                _.$nextArrow.remove();
            }

        }


        if (_.$slides) {

            _.$slides
                .removeClass('slick-slide slick-active slick-center slick-visible slick-current')
                .removeAttr('aria-hidden')
                .removeAttr('data-slick-index')
                .each(function(){
                    $(this).attr('style', $(this).data('originalStyling'));
                });

            _.$slideTrack.children(this.options.slide).detach();

            _.$slideTrack.detach();

            _.$list.detach();

            _.$slider.append(_.$slides);
        }

        _.cleanUpRows();

        _.$slider.removeClass('slick-slider');
        _.$slider.removeClass('slick-initialized');
        _.$slider.removeClass('slick-dotted');

        _.unslicked = true;

        if(!refresh) {
            _.$slider.trigger('destroy', [_]);
        }

    };

    Slick.prototype.disableTransition = function(slide) {

        var _ = this,
            transition = {};

        transition[_.transitionType] = '';

        if (_.options.fade === false) {
            _.$slideTrack.css(transition);
        } else {
            _.$slides.eq(slide).css(transition);
        }

    };

    Slick.prototype.fadeSlide = function(slideIndex, callback) {

        var _ = this;

        if (_.cssTransitions === false) {

            _.$slides.eq(slideIndex).css({
                zIndex: _.options.zIndex
            });

            _.$slides.eq(slideIndex).animate({
                opacity: 1
            }, _.options.speed, _.options.easing, callback);

        } else {

            _.applyTransition(slideIndex);

            _.$slides.eq(slideIndex).css({
                opacity: 1,
                zIndex: _.options.zIndex
            });

            if (callback) {
                setTimeout(function() {

                    _.disableTransition(slideIndex);

                    callback.call();
                }, _.options.speed);
            }

        }

    };

    Slick.prototype.fadeSlideOut = function(slideIndex) {

        var _ = this;

        if (_.cssTransitions === false) {

            _.$slides.eq(slideIndex).animate({
                opacity: 0,
                zIndex: _.options.zIndex - 2
            }, _.options.speed, _.options.easing);

        } else {

            _.applyTransition(slideIndex);

            _.$slides.eq(slideIndex).css({
                opacity: 0,
                zIndex: _.options.zIndex - 2
            });

        }

    };

    Slick.prototype.filterSlides = Slick.prototype.slickFilter = function(filter) {

        var _ = this;

        if (filter !== null) {

            _.$slidesCache = _.$slides;

            _.unload();

            _.$slideTrack.children(this.options.slide).detach();

            _.$slidesCache.filter(filter).appendTo(_.$slideTrack);

            _.reinit();

        }

    };

    Slick.prototype.focusHandler = function() {

        var _ = this;

        _.$slider
            .off('focus.slick blur.slick')
            .on('focus.slick blur.slick',
                '*:not(.slick-arrow)', function(event) {

            event.stopImmediatePropagation();
            var $sf = $(this);

            setTimeout(function() {

                if( _.options.pauseOnFocus ) {
                    _.focussed = $sf.is(':focus');
                    _.autoPlay();
                }

            }, 0);

        });
    };

    Slick.prototype.getCurrent = Slick.prototype.slickCurrentSlide = function() {

        var _ = this;
        return _.currentSlide;

    };

    Slick.prototype.getDotCount = function() {

        var _ = this;

        var breakPoint = 0;
        var counter = 0;
        var pagerQty = 0;

        if (_.options.infinite === true) {
            while (breakPoint < _.slideCount) {
                ++pagerQty;
                breakPoint = counter + _.options.slidesToScroll;
                counter += _.options.slidesToScroll <= _.options.slidesToShow ? _.options.slidesToScroll : _.options.slidesToShow;
            }
        } else if (_.options.centerMode === true) {
            pagerQty = _.slideCount;
        } else if(!_.options.asNavFor) {
            pagerQty = 1 + Math.ceil((_.slideCount - _.options.slidesToShow) / _.options.slidesToScroll);
        }else {
            while (breakPoint < _.slideCount) {
                ++pagerQty;
                breakPoint = counter + _.options.slidesToScroll;
                counter += _.options.slidesToScroll <= _.options.slidesToShow ? _.options.slidesToScroll : _.options.slidesToShow;
            }
        }

        return pagerQty - 1;

    };

    Slick.prototype.getLeft = function(slideIndex) {

        var _ = this,
            targetLeft,
            verticalHeight,
            verticalOffset = 0,
            targetSlide;

        _.slideOffset = 0;
        verticalHeight = _.$slides.first().outerHeight(true);

        if (_.options.infinite === true) {
            if (_.slideCount > _.options.slidesToShow) {
                _.slideOffset = (_.slideWidth * _.options.slidesToShow) * -1;
                verticalOffset = (verticalHeight * _.options.slidesToShow) * -1;
            }
            if (_.slideCount % _.options.slidesToScroll !== 0) {
                if (slideIndex + _.options.slidesToScroll > _.slideCount && _.slideCount > _.options.slidesToShow) {
                    if (slideIndex > _.slideCount) {
                        _.slideOffset = ((_.options.slidesToShow - (slideIndex - _.slideCount)) * _.slideWidth) * -1;
                        verticalOffset = ((_.options.slidesToShow - (slideIndex - _.slideCount)) * verticalHeight) * -1;
                    } else {
                        _.slideOffset = ((_.slideCount % _.options.slidesToScroll) * _.slideWidth) * -1;
                        verticalOffset = ((_.slideCount % _.options.slidesToScroll) * verticalHeight) * -1;
                    }
                }
            }
        } else {
            if (slideIndex + _.options.slidesToShow > _.slideCount) {
                _.slideOffset = ((slideIndex + _.options.slidesToShow) - _.slideCount) * _.slideWidth;
                verticalOffset = ((slideIndex + _.options.slidesToShow) - _.slideCount) * verticalHeight;
            }
        }

        if (_.slideCount <= _.options.slidesToShow) {
            _.slideOffset = 0;
            verticalOffset = 0;
        }

        if (_.options.centerMode === true && _.options.infinite === true) {
            _.slideOffset += _.slideWidth * Math.floor(_.options.slidesToShow / 2) - _.slideWidth;
        } else if (_.options.centerMode === true) {
            _.slideOffset = 0;
            _.slideOffset += _.slideWidth * Math.floor(_.options.slidesToShow / 2);
        }

        if (_.options.vertical === false) {
            targetLeft = ((slideIndex * _.slideWidth) * -1) + _.slideOffset;
        } else {
            targetLeft = ((slideIndex * verticalHeight) * -1) + verticalOffset;
        }

        if (_.options.variableWidth === true) {

            if (_.slideCount <= _.options.slidesToShow || _.options.infinite === false) {
                targetSlide = _.$slideTrack.children('.slick-slide').eq(slideIndex);
            } else {
                targetSlide = _.$slideTrack.children('.slick-slide').eq(slideIndex + _.options.slidesToShow);
            }

            if (_.options.rtl === true) {
                if (targetSlide[0]) {
                    targetLeft = (_.$slideTrack.width() - targetSlide[0].offsetLeft - targetSlide.width()) * -1;
                } else {
                    targetLeft =  0;
                }
            } else {
                targetLeft = targetSlide[0] ? targetSlide[0].offsetLeft * -1 : 0;
            }

            if (_.options.centerMode === true) {
                if (_.slideCount <= _.options.slidesToShow || _.options.infinite === false) {
                    targetSlide = _.$slideTrack.children('.slick-slide').eq(slideIndex);
                } else {
                    targetSlide = _.$slideTrack.children('.slick-slide').eq(slideIndex + _.options.slidesToShow + 1);
                }

                if (_.options.rtl === true) {
                    if (targetSlide[0]) {
                        targetLeft = (_.$slideTrack.width() - targetSlide[0].offsetLeft - targetSlide.width()) * -1;
                    } else {
                        targetLeft =  0;
                    }
                } else {
                    targetLeft = targetSlide[0] ? targetSlide[0].offsetLeft * -1 : 0;
                }

                targetLeft += (_.$list.width() - targetSlide.outerWidth()) / 2;
            }
        }

        return targetLeft;

    };

    Slick.prototype.getOption = Slick.prototype.slickGetOption = function(option) {

        var _ = this;

        return _.options[option];

    };

    Slick.prototype.getNavigableIndexes = function() {

        var _ = this,
            breakPoint = 0,
            counter = 0,
            indexes = [],
            max;

        if (_.options.infinite === false) {
            max = _.slideCount;
        } else {
            breakPoint = _.options.slidesToScroll * -1;
            counter = _.options.slidesToScroll * -1;
            max = _.slideCount * 2;
        }

        while (breakPoint < max) {
            indexes.push(breakPoint);
            breakPoint = counter + _.options.slidesToScroll;
            counter += _.options.slidesToScroll <= _.options.slidesToShow ? _.options.slidesToScroll : _.options.slidesToShow;
        }

        return indexes;

    };

    Slick.prototype.getSlick = function() {

        return this;

    };

    Slick.prototype.getSlideCount = function() {

        var _ = this,
            slidesTraversed, swipedSlide, centerOffset;

        centerOffset = _.options.centerMode === true ? _.slideWidth * Math.floor(_.options.slidesToShow / 2) : 0;

        if (_.options.swipeToSlide === true) {
            _.$slideTrack.find('.slick-slide').each(function(index, slide) {
                if (slide.offsetLeft - centerOffset + ($(slide).outerWidth() / 2) > (_.swipeLeft * -1)) {
                    swipedSlide = slide;
                    return false;
                }
            });

            slidesTraversed = Math.abs($(swipedSlide).attr('data-slick-index') - _.currentSlide) || 1;

            return slidesTraversed;

        } else {
            return _.options.slidesToScroll;
        }

    };

    Slick.prototype.goTo = Slick.prototype.slickGoTo = function(slide, dontAnimate) {

        var _ = this;

        _.changeSlide({
            data: {
                message: 'index',
                index: parseInt(slide)
            }
        }, dontAnimate);

    };

    Slick.prototype.init = function(creation) {

        var _ = this;

        if (!$(_.$slider).hasClass('slick-initialized')) {

            $(_.$slider).addClass('slick-initialized');

            _.buildRows();
            _.buildOut();
            _.setProps();
            _.startLoad();
            _.loadSlider();
            _.initializeEvents();
            _.updateArrows();
            _.updateDots();
            _.checkResponsive(true);
            _.focusHandler();

        }

        if (creation) {
            _.$slider.trigger('init', [_]);
        }

        if (_.options.accessibility === true) {
            _.initADA();
        }

        if ( _.options.autoplay ) {

            _.paused = false;
            _.autoPlay();

        }

    };

    Slick.prototype.initADA = function() {
        var _ = this;
        _.$slides.add(_.$slideTrack.find('.slick-cloned')).attr({
            'aria-hidden': 'true',
            'tabindex': '-1'
        }).find('a, input, button, select').attr({
            'tabindex': '-1'
        });

        _.$slideTrack.attr('role', 'listbox');

        _.$slides.not(_.$slideTrack.find('.slick-cloned')).each(function(i) {
            $(this).attr({
                'role': 'option',
                'aria-describedby': 'slick-slide' + _.instanceUid + i + ''
            });
        });

        if (_.$dots !== null) {
            _.$dots.attr('role', 'tablist').find('li').each(function(i) {
                $(this).attr({
                    'role': 'presentation',
                    'aria-selected': 'false',
                    'aria-controls': 'navigation' + _.instanceUid + i + '',
                    'id': 'slick-slide' + _.instanceUid + i + ''
                });
            })
                .first().attr('aria-selected', 'true').end()
                .find('button').attr('role', 'button').end()
                .closest('div').attr('role', 'toolbar');
        }
        _.activateADA();

    };

    Slick.prototype.initArrowEvents = function() {

        var _ = this;

        if (_.options.arrows === true && _.slideCount > _.options.slidesToShow) {
            _.$prevArrow
               .off('click.slick')
               .on('click.slick', {
                    message: 'previous'
               }, _.changeSlide);
            _.$nextArrow
               .off('click.slick')
               .on('click.slick', {
                    message: 'next'
               }, _.changeSlide);
        }

    };

    Slick.prototype.initDotEvents = function() {

        var _ = this;

        if (_.options.dots === true && _.slideCount > _.options.slidesToShow) {
            $('li', _.$dots).on('click.slick', {
                message: 'index'
            }, _.changeSlide);
        }

        if ( _.options.dots === true && _.options.pauseOnDotsHover === true ) {

            $('li', _.$dots)
                .on('mouseenter.slick', $.proxy(_.interrupt, _, true))
                .on('mouseleave.slick', $.proxy(_.interrupt, _, false));

        }

    };

    Slick.prototype.initSlideEvents = function() {

        var _ = this;

        if ( _.options.pauseOnHover ) {

            _.$list.on('mouseenter.slick', $.proxy(_.interrupt, _, true));
            _.$list.on('mouseleave.slick', $.proxy(_.interrupt, _, false));

        }

    };

    Slick.prototype.initializeEvents = function() {

        var _ = this;

        _.initArrowEvents();

        _.initDotEvents();
        _.initSlideEvents();

        _.$list.on('touchstart.slick mousedown.slick', {
            action: 'start'
        }, _.swipeHandler);
        _.$list.on('touchmove.slick mousemove.slick', {
            action: 'move'
        }, _.swipeHandler);
        _.$list.on('touchend.slick mouseup.slick', {
            action: 'end'
        }, _.swipeHandler);
        _.$list.on('touchcancel.slick mouseleave.slick', {
            action: 'end'
        }, _.swipeHandler);

        _.$list.on('click.slick', _.clickHandler);

        $(document).on(_.visibilityChange, $.proxy(_.visibility, _));

        if (_.options.accessibility === true) {
            _.$list.on('keydown.slick', _.keyHandler);
        }

        if (_.options.focusOnSelect === true) {
            $(_.$slideTrack).children().on('click.slick', _.selectHandler);
        }

        $(window).on('orientationchange.slick.slick-' + _.instanceUid, $.proxy(_.orientationChange, _));

        $(window).on('resize.slick.slick-' + _.instanceUid, $.proxy(_.resize, _));

        $('[draggable!=true]', _.$slideTrack).on('dragstart', _.preventDefault);

        $(window).on('load.slick.slick-' + _.instanceUid, _.setPosition);
        $(document).on('ready.slick.slick-' + _.instanceUid, _.setPosition);

    };

    Slick.prototype.initUI = function() {

        var _ = this;

        if (_.options.arrows === true && _.slideCount > _.options.slidesToShow) {

            _.$prevArrow.show();
            _.$nextArrow.show();

        }

        if (_.options.dots === true && _.slideCount > _.options.slidesToShow) {

            _.$dots.show();

        }

    };

    Slick.prototype.keyHandler = function(event) {

        var _ = this;
         //Dont slide if the cursor is inside the form fields and arrow keys are pressed
        if(!event.target.tagName.match('TEXTAREA|INPUT|SELECT')) {
            if (event.keyCode === 37 && _.options.accessibility === true) {
                _.changeSlide({
                    data: {
                        message: _.options.rtl === true ? 'next' :  'previous'
                    }
                });
            } else if (event.keyCode === 39 && _.options.accessibility === true) {
                _.changeSlide({
                    data: {
                        message: _.options.rtl === true ? 'previous' : 'next'
                    }
                });
            }
        }

    };

    Slick.prototype.lazyLoad = function() {

        var _ = this,
            loadRange, cloneRange, rangeStart, rangeEnd;

        function loadImages(imagesScope) {

            $('img[data-lazy]', imagesScope).each(function() {

                var image = $(this),
                    imageSource = $(this).attr('data-lazy'),
                    imageToLoad = document.createElement('img');

                imageToLoad.onload = function() {

                    image
                        .animate({ opacity: 0 }, 100, function() {
                            image
                                .attr('src', imageSource)
                                .animate({ opacity: 1 }, 200, function() {
                                    image
                                        .removeAttr('data-lazy')
                                        .removeClass('slick-loading');
                                });
                            _.$slider.trigger('lazyLoaded', [_, image, imageSource]);
                        });

                };

                imageToLoad.onerror = function() {

                    image
                        .removeAttr( 'data-lazy' )
                        .removeClass( 'slick-loading' )
                        .addClass( 'slick-lazyload-error' );

                    _.$slider.trigger('lazyLoadError', [ _, image, imageSource ]);

                };

                imageToLoad.src = imageSource;

            });

        }

        if (_.options.centerMode === true) {
            if (_.options.infinite === true) {
                rangeStart = _.currentSlide + (_.options.slidesToShow / 2 + 1);
                rangeEnd = rangeStart + _.options.slidesToShow + 2;
            } else {
                rangeStart = Math.max(0, _.currentSlide - (_.options.slidesToShow / 2 + 1));
                rangeEnd = 2 + (_.options.slidesToShow / 2 + 1) + _.currentSlide;
            }
        } else {
            rangeStart = _.options.infinite ? _.options.slidesToShow + _.currentSlide : _.currentSlide;
            rangeEnd = Math.ceil(rangeStart + _.options.slidesToShow);
            if (_.options.fade === true) {
                if (rangeStart > 0) rangeStart--;
                if (rangeEnd <= _.slideCount) rangeEnd++;
            }
        }

        loadRange = _.$slider.find('.slick-slide').slice(rangeStart, rangeEnd);
        loadImages(loadRange);

        if (_.slideCount <= _.options.slidesToShow) {
            cloneRange = _.$slider.find('.slick-slide');
            loadImages(cloneRange);
        } else
        if (_.currentSlide >= _.slideCount - _.options.slidesToShow) {
            cloneRange = _.$slider.find('.slick-cloned').slice(0, _.options.slidesToShow);
            loadImages(cloneRange);
        } else if (_.currentSlide === 0) {
            cloneRange = _.$slider.find('.slick-cloned').slice(_.options.slidesToShow * -1);
            loadImages(cloneRange);
        }

    };

    Slick.prototype.loadSlider = function() {

        var _ = this;

        _.setPosition();

        _.$slideTrack.css({
            opacity: 1
        });

        _.$slider.removeClass('slick-loading');

        _.initUI();

        if (_.options.lazyLoad === 'progressive') {
            _.progressiveLazyLoad();
        }

    };

    Slick.prototype.next = Slick.prototype.slickNext = function() {

        var _ = this;

        _.changeSlide({
            data: {
                message: 'next'
            }
        });

    };

    Slick.prototype.orientationChange = function() {

        var _ = this;

        _.checkResponsive();
        _.setPosition();

    };

    Slick.prototype.pause = Slick.prototype.slickPause = function() {

        var _ = this;

        _.autoPlayClear();
        _.paused = true;

    };

    Slick.prototype.play = Slick.prototype.slickPlay = function() {

        var _ = this;

        _.autoPlay();
        _.options.autoplay = true;
        _.paused = false;
        _.focussed = false;
        _.interrupted = false;

    };

    Slick.prototype.postSlide = function(index) {

        var _ = this;

        if( !_.unslicked ) {

            _.$slider.trigger('afterChange', [_, index]);

            _.animating = false;

            _.setPosition();

            _.swipeLeft = null;

            if ( _.options.autoplay ) {
                _.autoPlay();
            }

            if (_.options.accessibility === true) {
                _.initADA();
            }

        }

    };

    Slick.prototype.prev = Slick.prototype.slickPrev = function() {

        var _ = this;

        _.changeSlide({
            data: {
                message: 'previous'
            }
        });

    };

    Slick.prototype.preventDefault = function(event) {

        event.preventDefault();

    };

    Slick.prototype.progressiveLazyLoad = function( tryCount ) {

        tryCount = tryCount || 1;

        var _ = this,
            $imgsToLoad = $( 'img[data-lazy]', _.$slider ),
            image,
            imageSource,
            imageToLoad;

        if ( $imgsToLoad.length ) {

            image = $imgsToLoad.first();
            imageSource = image.attr('data-lazy');
            imageToLoad = document.createElement('img');

            imageToLoad.onload = function() {

                image
                    .attr( 'src', imageSource )
                    .removeAttr('data-lazy')
                    .removeClass('slick-loading');

                if ( _.options.adaptiveHeight === true ) {
                    _.setPosition();
                }

                _.$slider.trigger('lazyLoaded', [ _, image, imageSource ]);
                _.progressiveLazyLoad();

            };

            imageToLoad.onerror = function() {

                if ( tryCount < 3 ) {

                    /**
                     * try to load the image 3 times,
                     * leave a slight delay so we don't get
                     * servers blocking the request.
                     */
                    setTimeout( function() {
                        _.progressiveLazyLoad( tryCount + 1 );
                    }, 500 );

                } else {

                    image
                        .removeAttr( 'data-lazy' )
                        .removeClass( 'slick-loading' )
                        .addClass( 'slick-lazyload-error' );

                    _.$slider.trigger('lazyLoadError', [ _, image, imageSource ]);

                    _.progressiveLazyLoad();

                }

            };

            imageToLoad.src = imageSource;

        } else {

            _.$slider.trigger('allImagesLoaded', [ _ ]);

        }

    };

    Slick.prototype.refresh = function( initializing ) {

        var _ = this, currentSlide, lastVisibleIndex;

        lastVisibleIndex = _.slideCount - _.options.slidesToShow;

        // in non-infinite sliders, we don't want to go past the
        // last visible index.
        if( !_.options.infinite && ( _.currentSlide > lastVisibleIndex )) {
            _.currentSlide = lastVisibleIndex;
        }

        // if less slides than to show, go to start.
        if ( _.slideCount <= _.options.slidesToShow ) {
            _.currentSlide = 0;

        }

        currentSlide = _.currentSlide;

        _.destroy(true);

        $.extend(_, _.initials, { currentSlide: currentSlide });

        _.init();

        if( !initializing ) {

            _.changeSlide({
                data: {
                    message: 'index',
                    index: currentSlide
                }
            }, false);

        }

    };

    Slick.prototype.registerBreakpoints = function() {

        var _ = this, breakpoint, currentBreakpoint, l,
            responsiveSettings = _.options.responsive || null;

        if ( $.type(responsiveSettings) === 'array' && responsiveSettings.length ) {

            _.respondTo = _.options.respondTo || 'window';

            for ( breakpoint in responsiveSettings ) {

                l = _.breakpoints.length-1;
                currentBreakpoint = responsiveSettings[breakpoint].breakpoint;

                if (responsiveSettings.hasOwnProperty(breakpoint)) {

                    // loop through the breakpoints and cut out any existing
                    // ones with the same breakpoint number, we don't want dupes.
                    while( l >= 0 ) {
                        if( _.breakpoints[l] && _.breakpoints[l] === currentBreakpoint ) {
                            _.breakpoints.splice(l,1);
                        }
                        l--;
                    }

                    _.breakpoints.push(currentBreakpoint);
                    _.breakpointSettings[currentBreakpoint] = responsiveSettings[breakpoint].settings;

                }

            }

            _.breakpoints.sort(function(a, b) {
                return ( _.options.mobileFirst ) ? a-b : b-a;
            });

        }

    };

    Slick.prototype.reinit = function() {

        var _ = this;

        _.$slides =
            _.$slideTrack
                .children(_.options.slide)
                .addClass('slick-slide');

        _.slideCount = _.$slides.length;

        if (_.currentSlide >= _.slideCount && _.currentSlide !== 0) {
            _.currentSlide = _.currentSlide - _.options.slidesToScroll;
        }

        if (_.slideCount <= _.options.slidesToShow) {
            _.currentSlide = 0;
        }

        _.registerBreakpoints();

        _.setProps();
        _.setupInfinite();
        _.buildArrows();
        _.updateArrows();
        _.initArrowEvents();
        _.buildDots();
        _.updateDots();
        _.initDotEvents();
        _.cleanUpSlideEvents();
        _.initSlideEvents();

        _.checkResponsive(false, true);

        if (_.options.focusOnSelect === true) {
            $(_.$slideTrack).children().on('click.slick', _.selectHandler);
        }

        _.setSlideClasses(typeof _.currentSlide === 'number' ? _.currentSlide : 0);

        _.setPosition();
        _.focusHandler();

        _.paused = !_.options.autoplay;
        _.autoPlay();

        _.$slider.trigger('reInit', [_]);

    };

    Slick.prototype.resize = function() {

        var _ = this;

        if ($(window).width() !== _.windowWidth) {
            clearTimeout(_.windowDelay);
            _.windowDelay = window.setTimeout(function() {
                _.windowWidth = $(window).width();
                _.checkResponsive();
                if( !_.unslicked ) { _.setPosition(); }
            }, 50);
        }
    };

    Slick.prototype.removeSlide = Slick.prototype.slickRemove = function(index, removeBefore, removeAll) {

        var _ = this;

        if (typeof(index) === 'boolean') {
            removeBefore = index;
            index = removeBefore === true ? 0 : _.slideCount - 1;
        } else {
            index = removeBefore === true ? --index : index;
        }

        if (_.slideCount < 1 || index < 0 || index > _.slideCount - 1) {
            return false;
        }

        _.unload();

        if (removeAll === true) {
            _.$slideTrack.children().remove();
        } else {
            _.$slideTrack.children(this.options.slide).eq(index).remove();
        }

        _.$slides = _.$slideTrack.children(this.options.slide);

        _.$slideTrack.children(this.options.slide).detach();

        _.$slideTrack.append(_.$slides);

        _.$slidesCache = _.$slides;

        _.reinit();

    };

    Slick.prototype.setCSS = function(position) {

        var _ = this,
            positionProps = {},
            x, y;

        if (_.options.rtl === true) {
            position = -position;
        }
        x = _.positionProp == 'left' ? Math.ceil(position) + 'px' : '0px';
        y = _.positionProp == 'top' ? Math.ceil(position) + 'px' : '0px';

        positionProps[_.positionProp] = position;

        if (_.transformsEnabled === false) {
            _.$slideTrack.css(positionProps);
        } else {
            positionProps = {};
            if (_.cssTransitions === false) {
                positionProps[_.animType] = 'translate(' + x + ', ' + y + ')';
                _.$slideTrack.css(positionProps);
            } else {
                positionProps[_.animType] = 'translate3d(' + x + ', ' + y + ', 0px)';
                _.$slideTrack.css(positionProps);
            }
        }

    };

    Slick.prototype.setDimensions = function() {

        var _ = this;

        if (_.options.vertical === false) {
            if (_.options.centerMode === true) {
                _.$list.css({
                    padding: ('0px ' + _.options.centerPadding)
                });
            }
        } else {
            _.$list.height(_.$slides.first().outerHeight(true) * _.options.slidesToShow);
            if (_.options.centerMode === true) {
                _.$list.css({
                    padding: (_.options.centerPadding + ' 0px')
                });
            }
        }

        _.listWidth = _.$list.width();
        _.listHeight = _.$list.height();


        if (_.options.vertical === false && _.options.variableWidth === false) {
            _.slideWidth = Math.ceil(_.listWidth / _.options.slidesToShow);
            _.$slideTrack.width(Math.ceil((_.slideWidth * _.$slideTrack.children('.slick-slide').length)));

        } else if (_.options.variableWidth === true) {
            _.$slideTrack.width(5000 * _.slideCount);
        } else {
            _.slideWidth = Math.ceil(_.listWidth);
            _.$slideTrack.height(Math.ceil((_.$slides.first().outerHeight(true) * _.$slideTrack.children('.slick-slide').length)));
        }

        var offset = _.$slides.first().outerWidth(true) - _.$slides.first().width();
        if (_.options.variableWidth === false) _.$slideTrack.children('.slick-slide').width(_.slideWidth - offset);

    };

    Slick.prototype.setFade = function() {

        var _ = this,
            targetLeft;

        _.$slides.each(function(index, element) {
            targetLeft = (_.slideWidth * index) * -1;
            if (_.options.rtl === true) {
                $(element).css({
                    position: 'relative',
                    right: targetLeft,
                    top: 0,
                    zIndex: _.options.zIndex - 2,
                    opacity: 0
                });
            } else {
                $(element).css({
                    position: 'relative',
                    left: targetLeft,
                    top: 0,
                    zIndex: _.options.zIndex - 2,
                    opacity: 0
                });
            }
        });

        _.$slides.eq(_.currentSlide).css({
            zIndex: _.options.zIndex - 1,
            opacity: 1
        });

    };

    Slick.prototype.setHeight = function() {

        var _ = this;

        if (_.options.slidesToShow === 1 && _.options.adaptiveHeight === true && _.options.vertical === false) {
            var targetHeight = _.$slides.eq(_.currentSlide).outerHeight(true);
            _.$list.css('height', targetHeight);
        }

    };

    Slick.prototype.setOption =
    Slick.prototype.slickSetOption = function() {

        /**
         * accepts arguments in format of:
         *
         *  - for changing a single option's value:
         *     .slick("setOption", option, value, refresh )
         *
         *  - for changing a set of responsive options:
         *     .slick("setOption", 'responsive', [{}, ...], refresh )
         *
         *  - for updating multiple values at once (not responsive)
         *     .slick("setOption", { 'option': value, ... }, refresh )
         */

        var _ = this, l, item, option, value, refresh = false, type;

        if( $.type( arguments[0] ) === 'object' ) {

            option =  arguments[0];
            refresh = arguments[1];
            type = 'multiple';

        } else if ( $.type( arguments[0] ) === 'string' ) {

            option =  arguments[0];
            value = arguments[1];
            refresh = arguments[2];

            if ( arguments[0] === 'responsive' && $.type( arguments[1] ) === 'array' ) {

                type = 'responsive';

            } else if ( typeof arguments[1] !== 'undefined' ) {

                type = 'single';

            }

        }

        if ( type === 'single' ) {

            _.options[option] = value;


        } else if ( type === 'multiple' ) {

            $.each( option , function( opt, val ) {

                _.options[opt] = val;

            });


        } else if ( type === 'responsive' ) {

            for ( item in value ) {

                if( $.type( _.options.responsive ) !== 'array' ) {

                    _.options.responsive = [ value[item] ];

                } else {

                    l = _.options.responsive.length-1;

                    // loop through the responsive object and splice out duplicates.
                    while( l >= 0 ) {

                        if( _.options.responsive[l].breakpoint === value[item].breakpoint ) {

                            _.options.responsive.splice(l,1);

                        }

                        l--;

                    }

                    _.options.responsive.push( value[item] );

                }

            }

        }

        if ( refresh ) {

            _.unload();
            _.reinit();

        }

    };

    Slick.prototype.setPosition = function() {

        var _ = this;

        _.setDimensions();

        _.setHeight();

        if (_.options.fade === false) {
            _.setCSS(_.getLeft(_.currentSlide));
        } else {
            _.setFade();
        }

        _.$slider.trigger('setPosition', [_]);

    };

    Slick.prototype.setProps = function() {

        var _ = this,
            bodyStyle = document.body.style;

        _.positionProp = _.options.vertical === true ? 'top' : 'left';

        if (_.positionProp === 'top') {
            _.$slider.addClass('slick-vertical');
        } else {
            _.$slider.removeClass('slick-vertical');
        }

        if (bodyStyle.WebkitTransition !== undefined ||
            bodyStyle.MozTransition !== undefined ||
            bodyStyle.msTransition !== undefined) {
            if (_.options.useCSS === true) {
                _.cssTransitions = true;
            }
        }

        if ( _.options.fade ) {
            if ( typeof _.options.zIndex === 'number' ) {
                if( _.options.zIndex < 3 ) {
                    _.options.zIndex = 3;
                }
            } else {
                _.options.zIndex = _.defaults.zIndex;
            }
        }

        if (bodyStyle.OTransform !== undefined) {
            _.animType = 'OTransform';
            _.transformType = '-o-transform';
            _.transitionType = 'OTransition';
            if (bodyStyle.perspectiveProperty === undefined && bodyStyle.webkitPerspective === undefined) _.animType = false;
        }
        if (bodyStyle.MozTransform !== undefined) {
            _.animType = 'MozTransform';
            _.transformType = '-moz-transform';
            _.transitionType = 'MozTransition';
            if (bodyStyle.perspectiveProperty === undefined && bodyStyle.MozPerspective === undefined) _.animType = false;
        }
        if (bodyStyle.webkitTransform !== undefined) {
            _.animType = 'webkitTransform';
            _.transformType = '-webkit-transform';
            _.transitionType = 'webkitTransition';
            if (bodyStyle.perspectiveProperty === undefined && bodyStyle.webkitPerspective === undefined) _.animType = false;
        }
        if (bodyStyle.msTransform !== undefined) {
            _.animType = 'msTransform';
            _.transformType = '-ms-transform';
            _.transitionType = 'msTransition';
            if (bodyStyle.msTransform === undefined) _.animType = false;
        }
        if (bodyStyle.transform !== undefined && _.animType !== false) {
            _.animType = 'transform';
            _.transformType = 'transform';
            _.transitionType = 'transition';
        }
        _.transformsEnabled = _.options.useTransform && (_.animType !== null && _.animType !== false);
    };


    Slick.prototype.setSlideClasses = function(index) {

        var _ = this,
            centerOffset, allSlides, indexOffset, remainder;

        allSlides = _.$slider
            .find('.slick-slide')
            .removeClass('slick-active slick-center slick-current')
            .attr('aria-hidden', 'true');

        _.$slides
            .eq(index)
            .addClass('slick-current');

        if (_.options.centerMode === true) {

            centerOffset = Math.floor(_.options.slidesToShow / 2);

            if (_.options.infinite === true) {

                if (index >= centerOffset && index <= (_.slideCount - 1) - centerOffset) {

                    _.$slides
                        .slice(index - centerOffset, index + centerOffset + 1)
                        .addClass('slick-active')
                        .attr('aria-hidden', 'false');

                } else {

                    indexOffset = _.options.slidesToShow + index;
                    allSlides
                        .slice(indexOffset - centerOffset + 1, indexOffset + centerOffset + 2)
                        .addClass('slick-active')
                        .attr('aria-hidden', 'false');

                }

                if (index === 0) {

                    allSlides
                        .eq(allSlides.length - 1 - _.options.slidesToShow)
                        .addClass('slick-center');

                } else if (index === _.slideCount - 1) {

                    allSlides
                        .eq(_.options.slidesToShow)
                        .addClass('slick-center');

                }

            }

            _.$slides
                .eq(index)
                .addClass('slick-center');

        } else {

            if (index >= 0 && index <= (_.slideCount - _.options.slidesToShow)) {

                _.$slides
                    .slice(index, index + _.options.slidesToShow)
                    .addClass('slick-active')
                    .attr('aria-hidden', 'false');

            } else if (allSlides.length <= _.options.slidesToShow) {

                allSlides
                    .addClass('slick-active')
                    .attr('aria-hidden', 'false');

            } else {

                remainder = _.slideCount % _.options.slidesToShow;
                indexOffset = _.options.infinite === true ? _.options.slidesToShow + index : index;

                if (_.options.slidesToShow == _.options.slidesToScroll && (_.slideCount - index) < _.options.slidesToShow) {

                    allSlides
                        .slice(indexOffset - (_.options.slidesToShow - remainder), indexOffset + remainder)
                        .addClass('slick-active')
                        .attr('aria-hidden', 'false');

                } else {

                    allSlides
                        .slice(indexOffset, indexOffset + _.options.slidesToShow)
                        .addClass('slick-active')
                        .attr('aria-hidden', 'false');

                }

            }

        }

        if (_.options.lazyLoad === 'ondemand') {
            _.lazyLoad();
        }

    };

    Slick.prototype.setupInfinite = function() {

        var _ = this,
            i, slideIndex, infiniteCount;

        if (_.options.fade === true) {
            _.options.centerMode = false;
        }

        if (_.options.infinite === true && _.options.fade === false) {

            slideIndex = null;

            if (_.slideCount > _.options.slidesToShow) {

                if (_.options.centerMode === true) {
                    infiniteCount = _.options.slidesToShow + 1;
                } else {
                    infiniteCount = _.options.slidesToShow;
                }

                for (i = _.slideCount; i > (_.slideCount -
                        infiniteCount); i -= 1) {
                    slideIndex = i - 1;
                    $(_.$slides[slideIndex]).clone(true).attr('id', '')
                        .attr('data-slick-index', slideIndex - _.slideCount)
                        .prependTo(_.$slideTrack).addClass('slick-cloned');
                }
                for (i = 0; i < infiniteCount; i += 1) {
                    slideIndex = i;
                    $(_.$slides[slideIndex]).clone(true).attr('id', '')
                        .attr('data-slick-index', slideIndex + _.slideCount)
                        .appendTo(_.$slideTrack).addClass('slick-cloned');
                }
                _.$slideTrack.find('.slick-cloned').find('[id]').each(function() {
                    $(this).attr('id', '');
                });

            }

        }

    };

    Slick.prototype.interrupt = function( toggle ) {

        var _ = this;

        if( !toggle ) {
            _.autoPlay();
        }
        _.interrupted = toggle;

    };

    Slick.prototype.selectHandler = function(event) {

        var _ = this;

        var targetElement =
            $(event.target).is('.slick-slide') ?
                $(event.target) :
                $(event.target).parents('.slick-slide');

        var index = parseInt(targetElement.attr('data-slick-index'));

        if (!index) index = 0;

        if (_.slideCount <= _.options.slidesToShow) {

            _.setSlideClasses(index);
            _.asNavFor(index);
            return;

        }

        _.slideHandler(index);

    };

    Slick.prototype.slideHandler = function(index, sync, dontAnimate) {

        var targetSlide, animSlide, oldSlide, slideLeft, targetLeft = null,
            _ = this, navTarget;

        sync = sync || false;

        if (_.animating === true && _.options.waitForAnimate === true) {
            return;
        }

        if (_.options.fade === true && _.currentSlide === index) {
            return;
        }

        if (_.slideCount <= _.options.slidesToShow) {
            return;
        }

        if (sync === false) {
            _.asNavFor(index);
        }

        targetSlide = index;
        targetLeft = _.getLeft(targetSlide);
        slideLeft = _.getLeft(_.currentSlide);

        _.currentLeft = _.swipeLeft === null ? slideLeft : _.swipeLeft;

        if (_.options.infinite === false && _.options.centerMode === false && (index < 0 || index > _.getDotCount() * _.options.slidesToScroll)) {
            if (_.options.fade === false) {
                targetSlide = _.currentSlide;
                if (dontAnimate !== true) {
                    _.animateSlide(slideLeft, function() {
                        _.postSlide(targetSlide);
                    });
                } else {
                    _.postSlide(targetSlide);
                }
            }
            return;
        } else if (_.options.infinite === false && _.options.centerMode === true && (index < 0 || index > (_.slideCount - _.options.slidesToScroll))) {
            if (_.options.fade === false) {
                targetSlide = _.currentSlide;
                if (dontAnimate !== true) {
                    _.animateSlide(slideLeft, function() {
                        _.postSlide(targetSlide);
                    });
                } else {
                    _.postSlide(targetSlide);
                }
            }
            return;
        }

        if ( _.options.autoplay ) {
            clearInterval(_.autoPlayTimer);
        }

        if (targetSlide < 0) {
            if (_.slideCount % _.options.slidesToScroll !== 0) {
                animSlide = _.slideCount - (_.slideCount % _.options.slidesToScroll);
            } else {
                animSlide = _.slideCount + targetSlide;
            }
        } else if (targetSlide >= _.slideCount) {
            if (_.slideCount % _.options.slidesToScroll !== 0) {
                animSlide = 0;
            } else {
                animSlide = targetSlide - _.slideCount;
            }
        } else {
            animSlide = targetSlide;
        }

        _.animating = true;

        _.$slider.trigger('beforeChange', [_, _.currentSlide, animSlide]);

        oldSlide = _.currentSlide;
        _.currentSlide = animSlide;

        _.setSlideClasses(_.currentSlide);

        if ( _.options.asNavFor ) {

            navTarget = _.getNavTarget();
            navTarget = navTarget.slick('getSlick');

            if ( navTarget.slideCount <= navTarget.options.slidesToShow ) {
                navTarget.setSlideClasses(_.currentSlide);
            }

        }

        _.updateDots();
        _.updateArrows();

        if (_.options.fade === true) {
            if (dontAnimate !== true) {

                _.fadeSlideOut(oldSlide);

                _.fadeSlide(animSlide, function() {
                    _.postSlide(animSlide);
                });

            } else {
                _.postSlide(animSlide);
            }
            _.animateHeight();
            return;
        }

        if (dontAnimate !== true) {
            _.animateSlide(targetLeft, function() {
                _.postSlide(animSlide);
            });
        } else {
            _.postSlide(animSlide);
        }

    };

    Slick.prototype.startLoad = function() {

        var _ = this;

        if (_.options.arrows === true && _.slideCount > _.options.slidesToShow) {

            _.$prevArrow.hide();
            _.$nextArrow.hide();

        }

        if (_.options.dots === true && _.slideCount > _.options.slidesToShow) {

            _.$dots.hide();

        }

        _.$slider.addClass('slick-loading');

    };

    Slick.prototype.swipeDirection = function() {

        var xDist, yDist, r, swipeAngle, _ = this;

        xDist = _.touchObject.startX - _.touchObject.curX;
        yDist = _.touchObject.startY - _.touchObject.curY;
        r = Math.atan2(yDist, xDist);

        swipeAngle = Math.round(r * 180 / Math.PI);
        if (swipeAngle < 0) {
            swipeAngle = 360 - Math.abs(swipeAngle);
        }

        if ((swipeAngle <= 45) && (swipeAngle >= 0)) {
            return (_.options.rtl === false ? 'left' : 'right');
        }
        if ((swipeAngle <= 360) && (swipeAngle >= 315)) {
            return (_.options.rtl === false ? 'left' : 'right');
        }
        if ((swipeAngle >= 135) && (swipeAngle <= 225)) {
            return (_.options.rtl === false ? 'right' : 'left');
        }
        if (_.options.verticalSwiping === true) {
            if ((swipeAngle >= 35) && (swipeAngle <= 135)) {
                return 'down';
            } else {
                return 'up';
            }
        }

        return 'vertical';

    };

    Slick.prototype.swipeEnd = function(event) {

        var _ = this,
            slideCount,
            direction;

        _.dragging = false;
        _.interrupted = false;
        _.shouldClick = ( _.touchObject.swipeLength > 10 ) ? false : true;

        if ( _.touchObject.curX === undefined ) {
            return false;
        }

        if ( _.touchObject.edgeHit === true ) {
            _.$slider.trigger('edge', [_, _.swipeDirection() ]);
        }

        if ( _.touchObject.swipeLength >= _.touchObject.minSwipe ) {

            direction = _.swipeDirection();

            switch ( direction ) {

                case 'left':
                case 'down':

                    slideCount =
                        _.options.swipeToSlide ?
                            _.checkNavigable( _.currentSlide + _.getSlideCount() ) :
                            _.currentSlide + _.getSlideCount();

                    _.currentDirection = 0;

                    break;

                case 'right':
                case 'up':

                    slideCount =
                        _.options.swipeToSlide ?
                            _.checkNavigable( _.currentSlide - _.getSlideCount() ) :
                            _.currentSlide - _.getSlideCount();

                    _.currentDirection = 1;

                    break;

                default:


            }

            if( direction != 'vertical' ) {

                _.slideHandler( slideCount );
                _.touchObject = {};
                _.$slider.trigger('swipe', [_, direction ]);

            }

        } else {

            if ( _.touchObject.startX !== _.touchObject.curX ) {

                _.slideHandler( _.currentSlide );
                _.touchObject = {};

            }

        }

    };

    Slick.prototype.swipeHandler = function(event) {

        var _ = this;

        if ((_.options.swipe === false) || ('ontouchend' in document && _.options.swipe === false)) {
            return;
        } else if (_.options.draggable === false && event.type.indexOf('mouse') !== -1) {
            return;
        }

        _.touchObject.fingerCount = event.originalEvent && event.originalEvent.touches !== undefined ?
            event.originalEvent.touches.length : 1;

        _.touchObject.minSwipe = _.listWidth / _.options
            .touchThreshold;

        if (_.options.verticalSwiping === true) {
            _.touchObject.minSwipe = _.listHeight / _.options
                .touchThreshold;
        }

        switch (event.data.action) {

            case 'start':
                _.swipeStart(event);
                break;

            case 'move':
                _.swipeMove(event);
                break;

            case 'end':
                _.swipeEnd(event);
                break;

        }

    };

    Slick.prototype.swipeMove = function(event) {

        var _ = this,
            edgeWasHit = false,
            curLeft, swipeDirection, swipeLength, positionOffset, touches;

        touches = event.originalEvent !== undefined ? event.originalEvent.touches : null;

        if (!_.dragging || touches && touches.length !== 1) {
            return false;
        }

        curLeft = _.getLeft(_.currentSlide);

        _.touchObject.curX = touches !== undefined ? touches[0].pageX : event.clientX;
        _.touchObject.curY = touches !== undefined ? touches[0].pageY : event.clientY;

        _.touchObject.swipeLength = Math.round(Math.sqrt(
            Math.pow(_.touchObject.curX - _.touchObject.startX, 2)));

        if (_.options.verticalSwiping === true) {
            _.touchObject.swipeLength = Math.round(Math.sqrt(
                Math.pow(_.touchObject.curY - _.touchObject.startY, 2)));
        }

        swipeDirection = _.swipeDirection();

        if (swipeDirection === 'vertical') {
            return;
        }

        if (event.originalEvent !== undefined && _.touchObject.swipeLength > 4) {
            event.preventDefault();
        }

        positionOffset = (_.options.rtl === false ? 1 : -1) * (_.touchObject.curX > _.touchObject.startX ? 1 : -1);
        if (_.options.verticalSwiping === true) {
            positionOffset = _.touchObject.curY > _.touchObject.startY ? 1 : -1;
        }


        swipeLength = _.touchObject.swipeLength;

        _.touchObject.edgeHit = false;

        if (_.options.infinite === false) {
            if ((_.currentSlide === 0 && swipeDirection === 'right') || (_.currentSlide >= _.getDotCount() && swipeDirection === 'left')) {
                swipeLength = _.touchObject.swipeLength * _.options.edgeFriction;
                _.touchObject.edgeHit = true;
            }
        }

        if (_.options.vertical === false) {
            _.swipeLeft = curLeft + swipeLength * positionOffset;
        } else {
            _.swipeLeft = curLeft + (swipeLength * (_.$list.height() / _.listWidth)) * positionOffset;
        }
        if (_.options.verticalSwiping === true) {
            _.swipeLeft = curLeft + swipeLength * positionOffset;
        }

        if (_.options.fade === true || _.options.touchMove === false) {
            return false;
        }

        if (_.animating === true) {
            _.swipeLeft = null;
            return false;
        }

        _.setCSS(_.swipeLeft);

    };

    Slick.prototype.swipeStart = function(event) {

        var _ = this,
            touches;

        _.interrupted = true;

        if (_.touchObject.fingerCount !== 1 || _.slideCount <= _.options.slidesToShow) {
            _.touchObject = {};
            return false;
        }

        if (event.originalEvent !== undefined && event.originalEvent.touches !== undefined) {
            touches = event.originalEvent.touches[0];
        }

        _.touchObject.startX = _.touchObject.curX = touches !== undefined ? touches.pageX : event.clientX;
        _.touchObject.startY = _.touchObject.curY = touches !== undefined ? touches.pageY : event.clientY;

        _.dragging = true;

    };

    Slick.prototype.unfilterSlides = Slick.prototype.slickUnfilter = function() {

        var _ = this;

        if (_.$slidesCache !== null) {

            _.unload();

            _.$slideTrack.children(this.options.slide).detach();

            _.$slidesCache.appendTo(_.$slideTrack);

            _.reinit();

        }

    };

    Slick.prototype.unload = function() {

        var _ = this;

        $('.slick-cloned', _.$slider).remove();

        if (_.$dots) {
            _.$dots.remove();
        }

        if (_.$prevArrow && _.htmlExpr.test(_.options.prevArrow)) {
            _.$prevArrow.remove();
        }

        if (_.$nextArrow && _.htmlExpr.test(_.options.nextArrow)) {
            _.$nextArrow.remove();
        }

        _.$slides
            .removeClass('slick-slide slick-active slick-visible slick-current')
            .attr('aria-hidden', 'true')
            .css('width', '');

    };

    Slick.prototype.unslick = function(fromBreakpoint) {

        var _ = this;
        _.$slider.trigger('unslick', [_, fromBreakpoint]);
        _.destroy();

    };

    Slick.prototype.updateArrows = function() {

        var _ = this,
            centerOffset;

        centerOffset = Math.floor(_.options.slidesToShow / 2);

        if ( _.options.arrows === true &&
            _.slideCount > _.options.slidesToShow &&
            !_.options.infinite ) {

            _.$prevArrow.removeClass('slick-disabled').attr('aria-disabled', 'false');
            _.$nextArrow.removeClass('slick-disabled').attr('aria-disabled', 'false');

            if (_.currentSlide === 0) {

                _.$prevArrow.addClass('slick-disabled').attr('aria-disabled', 'true');
                _.$nextArrow.removeClass('slick-disabled').attr('aria-disabled', 'false');

            } else if (_.currentSlide >= _.slideCount - _.options.slidesToShow && _.options.centerMode === false) {

                _.$nextArrow.addClass('slick-disabled').attr('aria-disabled', 'true');
                _.$prevArrow.removeClass('slick-disabled').attr('aria-disabled', 'false');

            } else if (_.currentSlide >= _.slideCount - 1 && _.options.centerMode === true) {

                _.$nextArrow.addClass('slick-disabled').attr('aria-disabled', 'true');
                _.$prevArrow.removeClass('slick-disabled').attr('aria-disabled', 'false');

            }

        }

    };

    Slick.prototype.updateDots = function() {

        var _ = this;

        if (_.$dots !== null) {

            _.$dots
                .find('li')
                .removeClass('slick-active')
                .attr('aria-hidden', 'true');

            _.$dots
                .find('li')
                .eq(Math.floor(_.currentSlide / _.options.slidesToScroll))
                .addClass('slick-active')
                .attr('aria-hidden', 'false');

        }

    };

    Slick.prototype.visibility = function() {

        var _ = this;

        if ( _.options.autoplay ) {

            if ( document[_.hidden] ) {

                _.interrupted = true;

            } else {

                _.interrupted = false;

            }

        }

    };

    $.fn.slick = function() {
        var _ = this,
            opt = arguments[0],
            args = Array.prototype.slice.call(arguments, 1),
            l = _.length,
            i,
            ret;
        for (i = 0; i < l; i++) {
            if (typeof opt == 'object' || typeof opt == 'undefined')
                _[i].slick = new Slick(_[i], opt);
            else
                ret = _[i].slick[opt].apply(_[i].slick, args);
            if (typeof ret != 'undefined') return ret;
        }
        return _;
    };

}));

//request animation frame polyfill support
(function() {
    var lastTime = 0;
    var vendors = ['ms', 'moz', 'webkit', 'o'];
    for (var x = 0; x < vendors.length && !window.requestAnimationFrame; ++x) {
        window.requestAnimationFrame = window[vendors[x] + 'RequestAnimationFrame'];
        window.cancelAnimationFrame = window[vendors[x] + 'CancelAnimationFrame'] ||
            window[vendors[x] + 'CancelRequestAnimationFrame'];
    }

    if (!window.requestAnimationFrame)
        window.requestAnimationFrame = function(callback, element) {
            var currTime = new Date().getTime();
            var timeToCall = Math.max(0, 16 - (currTime - lastTime));
            var id = window.setTimeout(function() {
                    callback(currTime + timeToCall);
                },
                timeToCall);
            lastTime = currTime + timeToCall;
            return id;
        };

    if (!window.cancelAnimationFrame)
        window.cancelAnimationFrame = function(id) {
            clearTimeout(id);
        };
}());

function msieversion() {
    var ua = window.navigator.userAgent;
    var msie = ua.indexOf("MSIE ");

    if (msie > 0 || !!navigator.userAgent.match(/Trident.*rv\:11\./)) {
        return (parseInt(ua.substring(msie + 5, ua.indexOf(".", msie))));
    }
    return false;
}

function loadScript(src, callback) {

    var script = document.createElement("script");
    script.type = "text/javascript";
    if (callback) script.onload = callback;
    document.getElementsByTagName("head")[0].appendChild(script);
    script.src = src;
}

var is_google_api_loaded = false;
var is_google_maps_api_loaded = false;

function google_maps_loaded() {
    //console.log('google_maps_loaded has been called');
    is_google_maps_api_loaded = true;
}

/**
 * A few fixes to make the storytelling section work on mobile landscape.
 * I hate this
 */
function fixStorytellingLandscape(is_mobile, is_short_width, current_slug) {

    if ((is_mobile && is_short_width == false) && current_slug == '/storytelling/') {

        // 1. Push the card 5 down
        $('#storytelling_card5_background').css('top', '0px');

        // 2. Swap cards 3 and 4 positions
        if (is_short_width == false) {
            var card3 = $('#storytelling_card3_background');
            var card4 = $('#storytelling_card4_background');
            $('#storytelling_card3_background').remove();
            $('#storytelling_card4_background').remove();
            $('#storytelling_card3').append(card4);
            $('#storytelling_card4').append(card3);
        }

        // 3. Push the footer down
        var bodyHeight = 0;
        bodyHeight += parseInt($('#storytelling_header').css('height').replace('px', ''));
        bodyHeight += parseInt($('#storytelling_card1').css('height').replace('px', '')) * 2;
        bodyHeight += parseInt($('#storytelling_card5').css('height').replace('px', ''));

        $('#footer').css('top', bodyHeight + 'px');

    }
}

/**
 * The footer position gets messed up when switching sections
 */
var already_fixed_footer = false;

function fixFooterPosition(is_mobile, current_slug) {

    if (is_mobile && current_slug != '/storytelling/') {

        var bodyHeight = parseInt($('body').css('height').replace('px', ''));

        /* After the first time, don't take into consideration the footer height */
        if (already_fixed_footer) {
            var footerHeight = parseInt($('#footer').css('height').replace('px', ''));
            bodyHeight -= footerHeight;
        } else {
            already_fixed_footer = true;
        }

        $('#footer').css('top', bodyHeight + 'px');
    }
}

//not too much here
(function() {
    //test

    var PROFILE = false;
    if (PROFILE) var global_start = new Date().getTime();


    function addScript(src) {
        var s = document.createElement('script');
        s.setAttribute('src', src);
        document.body.appendChild(s);
    }

    var dom_is_loaded = false;
    window.onload = function() { /*suspectLoop();*/
        //console.log('is loaded');
        dom_is_loaded = true;
    };

    function calc_diff(current, destination) {
        if ((destination - current) == 0) return 0;
        var diff = (destination - current) / 2;
        //var abs_diff=Math.abs(diff);
        //var max_diff=Math.abs(destination-current);

        var maxmove = 0.08 * Math.max(1, Math.abs(destination - current));
        ////console.log('maxmove=',maxmove);
        //var minmove=0.005;
        if (diff < -maxmove) diff = -maxmove;
        else if (diff > maxmove) diff = maxmove;
        //else if(diff<0 && diff>-minmove){ diff=-Math.min(minmove,max_diff); }
        //else if(diff>0 && diff< minmove){ diff= Math.min(minmove,max_diff); }

        return diff;
    }

    function hasClass(el, className) {
        if (el.classList)
            return (el.classList.contains(className));
        else
            return (new RegExp('(^| )' + className + '( |$)', 'gi').test(el.className));
    }

    function addClass(el, className) {
        ////console.log('add class ',className,' to ',el.toString());
        if (el.classList)
            el.classList.add(className);
        else
            el.className += ' ' + className;
    }

    function add_class_to_list(elements, className) {
        Array.prototype.forEach.call(elements, function(element_el, i) { /*suspectLoop();*/

            addClass(element_el, className);
        });
    }

    function remove(el) {
        el.innerHTML = '';
        if (el.parentNode) {
            el.parentNode.removeChild(el);
        }

    }

    function remove_from_list(elements) {
        if (elements && elements.length) {
            Array.prototype.forEach.call(elements, function(element_el, i) { /*suspectLoop();*/
                ////console.log('remove',element_el.toString());
                remove(element_el);
            });
        }

    }




    var is_ready = false;

    var ready = function() {

        is_ready = true;
        if (PROFILE) console.log('Ready in: ' + ((new Date().getTime()) - global_start) + 'ms');

        //var updater_subscriptions_object={};
        //var updater_subscriptions_array=[];

        function closest_above(list, value) {
            var i = list.length - 2;
            while (i >= 0 && list[i] >= value) {
                i--;
            }
            return list[i + 1];
        }

        function calc_stoppoint(value) {
            return Math.ceil(value / 20) * 20;
        }


        var images_being_loaded = [];

        function add_image_being_loaded(el) {
            images_being_loaded.push({
                el: el,
                completed: false
            });
        }

        function check_images_being_loaded_percent() {

            var count_total = 0;
            var count_loaded = 0;

            Array.prototype.forEach.call(images_being_loaded, function(img, i) {

                count_total++;

                if (!img.completed) {
                    img.completed = img.el[0].complete;
                }
                if (img.completed) {
                    count_loaded++;
                }

            });

            if (count_total == 0) {
                return 1;
            }
            var images_pc = count_loaded / count_total;
            ////console.log('images_pc=',images_pc);
            return images_pc;

        }

        var ua = navigator.userAgent;

        //USER AGENT DETECTIONS
        var is_android = !!(ua.match(/Android/i));
        var is_blackberry = !!(ua.match(/BlackBerry/i));
        var is_iPhone = !!(ua.match(/iPhone/i));
        var is_iPhone4_or_less = !!(is_iPhone && window.screen.height <= 480);
        var is_iPhone5_or_more = !!(is_iPhone && window.screen.height > 480);
        var is_iPad = !!(ua.match(/iPad/i));
        var is_iPod = !!(ua.match(/iPod/i));
        var is_chromeIOS = !!(ua.match('CriOS'));
        var is_iOS = !!(is_iPhone || is_iPad || is_iPod || is_chromeIOS);
        var is_opera = !!(ua.match(/Opera Mini/i));
        var is_ie_mobile = !!(ua.match(/IEMobile/i));
        var smallScreenWidth = 568;

        var msie_version = msieversion();
        var is_internet_explorer = !(msie_version === false);

        var is_chrome = false;
        var is_safari = false;
        var ua = ua.toLowerCase();
        if (ua.indexOf('safari') != -1) {
            if (ua.indexOf('chrome') > -1) {
                is_chrome = true;
            } else {
                is_safari = true;
            }
        }
        var is_mobile = is_android || is_blackberry || is_iOS || is_opera || is_ie_mobile || (is_internet_explorer && msie_version <= 9);
        var is_desktop = !is_mobile;
        var is_short_width = $(window).width() < smallScreenWidth;

        var everything;

        var count_primary_inits = 0;
        var primary_initializations_completed = false;

        function run_primary_initializations() {
            count_primary_inits++;
            switch (count_primary_inits) {

                case 1:
                    //console.log('initialization ',count_primary_inits,' add mobile classes')

                    if (is_short_width) {
                        remove_from_list(document.querySelectorAll('.desktop-only'));
                    } else {
                        remove_from_list(document.querySelectorAll('.mobile-only'));
                    }

                    break;

                case 2:


                    break;

                case 3:


                    break;

                case 4:

                    menu.el.style.display = "none";

                    break;

                case 5:

                    everything = document.querySelectorAll('body,section,div,ul,li,video,img,span,a,h1,h2,h3,h4,h5');

                    //console.log('initialization ',count_primary_inits,' remove unused device content');
                    if (is_desktop) {
                        add_class_to_list(everything, 'desktop');
                    }
                    if (is_mobile) {
                        add_class_to_list(everything, 'mobile');
                    }
                    if (is_short_width) {
                        add_class_to_list(everything, 'short-width');
                    }

                    break;

                case 6:
                    //console.log('initialization ',count_primary_inits,' replace mobiles texts')
                    if (is_short_width) {
                        $('.mobile-text').each(function() {
                            $(this).html($(this).attr('data-mobile-text'));
                        })
                    }
                    break;

                case 7:
                    //console.log('initialization ',count_primary_inits,' replace hashtag texts');

                    var hashtag_regular_expression = /(\S*#\[[^\]]+\])|(\S*#\S+)/gi;
                    $('.replace-hashtags').each(function() {

                        var str_old = $(this).html() + '';
                        var str_new = str_old.replace(hashtag_regular_expression, function(t) {
                            return '<em>' + t + '</em>';
                        });
                        if (str_new == str_old) {
                            //do nothing
                        } else {
                            $(this).html(str_new);
                        }
                    });
                    break;

                case 8:
                    //console.log('initialization ',count_primary_inits,' replace links');

                    var link_regular_expression = /(https?:\/\/[^\s]+)/g;
                    $('.replace-links').each(function() {
                        var str_old = $(this).html() + '';

                        ////console.log('str_old',str_old);

                        var str_new = str_old.replace(link_regular_expression, function(t) {
                            return '<em>' + t + '</em>';
                        });
                        if (str_new == str_old) {
                            //do nothing
                        } else {
                            $(this).html(str_new);
                        }
                    });
                    break;

                case 9:
                    //console.log('initialization ',count_primary_inits,' run main resize handler');
                    main_resize_handler(); //this already loads backgrounds
                    break;

                case 10:
                    //console.log('initialization ',count_primary_inits,' ask to preload initial sections');

                    $('.header_brand').each(function() {
                        var header_brand_el = $(this);
                        image_load(header_brand_el);
                    });


                    var count = 0;
                    $.each(cards, function(key, card) {

                        if (count < count_cards_showing) {
                            ////console.log('load card ',count);
                            card.load();
                        }
                        count++;
                    });

                    //addScript('https://maps.googleapis.com/maps/api/js');
                    //loadScript('http://maps.googleapis.com/maps/api/js?v=3&sensor=false&callback=google_maps_loaded', function(){
                    //    //console.log('google-loader has been loaded, but not the maps-API ');
                    //    is_google_api_loaded=true;
                    //});

                    loadScript('//maps.googleapis.com/maps/api/js?sensor=false&callback=google_maps_loaded', function() {
                        //console.log('google-loader has been loaded, but not the maps-API ');
                        is_google_api_loaded = true;
                    });

                    break;
                case 11:
                    primary_initializations_completed = true;
                    break;
            }
        }

        function moveProductsLeft() {
            // if (window.innerWidth <= 1024) {
            //     $('#more-products-left').hide();
            //     $('#more-products-right').show();
            // } else {
            //     $('#more-products-left').hide();
            //     $('#more-products-right').hide();
            // }

            /* Tablets */
            if (window.innerWidth > 420 && window.innerWidth <= 1024) {
                $('#products_name1').show();
                $('#products_name2').show();
                $('#products_name3').show();
                $('#products_name4').hide();
                $('#products_name5').hide();
                $('#products_name6').hide();
                $('#products_name7').show();
                $('#products_name8').show();
                $('#products_name9').show();
                $('#products_name10').hide();
                $('#products_name11').hide();
                $('#products_name12').hide();
            }
        }

        function moveProductsRight() {
            if (productsPage == 0) {
                var imageWidth = parseInt($('#products_background').css('width').replace('px', ''));
                if (window.innerWidth <= 667) {
                    imageWidth -= 36;
                }
                $('#products_background').css('left', (-imageWidth / 2) + 'px');
            }
            productsPage = 1;

            // if (window.innerWidth <= 1024) {
            //     $('#more-products-left').show();
            //     $('#more-products-right').hide();
            // } else {
            //     $('#more-products-left').hide();
            //     $('#more-products-right').hide();
            // }

            /* Tablets */
            if (window.innerWidth > 420 && window.innerWidth <= 1024) {
                $('#products_name1').hide();
                $('#products_name2').hide();
                $('#products_name3').hide();
                $('#products_name4').show();
                $('#products_name5').show();
                $('#products_name6').show();
                $('#products_name7').show();
                $('#products_name8').show();
                $('#products_name9').show();
                $('#products_name10').show();
                $('#products_name11').show();
                $('#products_name12').show();
            }
        }

        var check_products_visibility;

        var count_secondary_inits = 0;
        var secondary_initializations_completed = false;

        var productsPage = 0;

        function run_secondary_initializations() {
            count_secondary_inits++;
            switch (count_secondary_inits) {

                case 1:

                    // $('#more-products-left').on('click', function() {
                    //     moveProductsLeft();
                    // });

                    // $('#more-products-right').on('click', function() {
                    //     moveProductsRight();
                    // });

                    $('.products_zoom,.products_button,.products_symbol').on('click', function(e) {
                        var product = parseInt($(this).attr('rel'));
                        // console.log(product);
                        var target = $(e.target);

                        /* Product id map */
                        // if (window.innerWidth <= 1024 && productsPage == 1 && target.attr('class').indexOf('products_button') == -1) {
                        //   if (product == 4) {
                        //     product = 1;
                        //   } else if (product == 3) {
                        //     product = 5;
                        //   } else if (product == 2) {
                        //     product = 6;
                        //   }
                        // }

                        /* Product section setup: last 2 flavors don't have the play video button */
                        if (product == 5 || product == 6) {
                            $('#view-product-video').hide();
                            $('#products_more_info').css('left', '0');
                            $('#products_more_info').css('margin-left', 'auto');
                            $('#products_more_info').css('margin-right', 'auto');
                        } else {
                            $('#view-product-video').show();
                            $('#products_more_info').css('left', 'auto');
                            $('#products_more_info').css('margin-left', '0');
                            $('#products_more_info').css('margin-right', '0');
                        }

                        if(product == 10 || product == 11 || product == 12) {
                            $('#products_more_info').hide();
                            // $('#products_nutritional').css({top: '20%'});
                        } else {
                            $('#products_more_info').show();
                            // $('#products_nutritional').css({top: ((230/614)*100)+'%'});
                        }

                        sections.products_detail.open(product);
                    });

                    break;

                case 2:
                    //console.log('initialization ',count_secondary_inits,' replace mobiles texts')
                    $('#products_close').on('mousedown', function() {
                        if (nutritional_opened) {
                            nutritional_opened = false;
                            $('#products_navigation_animation').fadeIn();
                            $('.products_nutritional').fadeOut();
                        } else {
                            sections.products_detail.close();

                        }
                    });

                    $('#products_more_info').on('mousedown', function() {
                        current_subsection = parseInt(current_product);

                        console.log(current_subsection);
                    });

                    /* Click to load a new video */
                    $('#view-product-video').on('mousedown', function() {
                        var videoToWatch = parseInt(current_product);
                        clickToWatchVideo(videoToWatch, is_iOS);
                    });
                    break;

                case 3:

                    //console.log('initialization ',count_secondary_inits,' remove unused device content');
                    sections.products_detail.el.each(function() {
                        $(this).find('.products_bullet').on('touchstart mousedown', function() {
                            sections.products_detail.change_background($(this).attr('rel'));
                        });
                    });

                    break;

                case 4:
                    //console.log('initialization ',count_secondary_inits,' replace hashtag texts');
                    $('.card .card_share').on('mousedown', function() {
                        share($(this).closest('.card'));
                    });

                    $('#footer').find('li').on('mousedown', function() {
                        if (current_subsection) {
                            current_subsection_back_to_path = $(this).attr('data-href');
                            current_subsection = null;
                        } else {
                            animating_globalScrollTop = true;

                            globalScrollTop_destination = Math.min(body.height_value - browserHeight, sections[$(this).attr('rel')].top_value);

                            if (is_mobile) {
                                globalScrollTop = globalScrollTop_old = globalScrollTop_eased = globalScrollTop_eased_rounded = globalScrollTop_eased_rounded_old = $(window).scrollTop(); //globalScrollTop_destination;;
                            }
                        }

                    });

                    $('#header_more').on('mousedown', function() {
                        clickToWatchVideo(0, is_iOS);
                    });

                    if (grid_slider) {
                        var cardsTouchHandler = function(event) {
                            //window.alert('touch handler');
                            //console.log('productBackgroundTouchHandler()',event);
                            var touch;
                            if (typeof event !== 'undefined') {

                                //event.preventDefault();

                                if (typeof event.touches !== 'undefined') {
                                    touch = event.touches[0];

                                    switch (event.type) {
                                        case 'touchstart':
                                            last_touch = {
                                                x: touch.pageX,
                                                y: touch.pageY
                                            }
                                            break;
                                        case 'touchmove':
                                            //event.preventDefault();

                                            if (last_touch) {
                                                accumulated_touch.x += touch.pageX - last_touch.x;
                                                accumulated_touch.y += touch.pageY - last_touch.y;


                                                if (Math.abs(accumulated_touch.y) > 100) {

                                                    accumulated_touch = {
                                                        x: 0,
                                                        y: 0,
                                                    };
                                                    last_touch = false;

                                                    //console.log('accumulated_touch reset')


                                                } else if (accumulated_touch.x > 100) {

                                                    accumulated_touch = {
                                                        x: 0,
                                                        y: 0,
                                                    };
                                                    last_touch = false;

                                                    grid_slider.prev();

                                                } else if (accumulated_touch.x < -100) {

                                                    accumulated_touch = {
                                                        x: 0,
                                                        y: 0,
                                                    };
                                                    last_touch = false;

                                                    grid_slider.next();
                                                }

                                                //console.log('accumulated_touch',accumulated_touch.x,accumulated_touch.y);
                                            }

                                            break;
                                        case 'touchend':
                                            accumulated_touch = {
                                                x: 0,
                                                y: 0,
                                            }
                                            last_touch = false;
                                        default:
                                            break;
                                    }
                                }
                            }
                        }

                        $('#cards')[0].addEventListener('touchstart', cardsTouchHandler, false);
                        $('#cards')[0].addEventListener('touchmove', cardsTouchHandler, false);
                        $('#cards')[0].addEventListener('touchend', cardsTouchHandler, false);
                    }

                    $('.harmonizacoes_header_more').on('mousedown', function() {
                        animating_globalScrollTop = true;

                        var section_el = $(this).closest('.harmonizacoes_header')
                        var section_id = section_el.attr('id');
                        //console.log('section_id=',section_id);
                        var receita_id = 'recipe_harmonizacoes_' + sections[section_id].subsection;
                        //console.log('receita_id=',receita_id);
                        globalScrollTop_destination = Math.min(body.height_value - browserHeight, sections[receita_id].top_value);

                        if (is_mobile) {
                            globalScrollTop = globalScrollTop_old = globalScrollTop_eased = globalScrollTop_eased_rounded = globalScrollTop_eased_rounded_old = $(window).scrollTop(); //globalScrollTop_destination;
                        }
                    });
                    break;

                case 9:
                    bind_products_background(sections.products_detail.background_1, '1', false, 0);
                    break;

                case 10:
                    bind_products_background(sections.products_detail.background_2, '2', false, 0);
                    break;

                case 11:
                    bind_products_background(sections.products_detail.background_3, '3', false, 0);
                    break;

                case 12:
                    bind_products_background(sections.products_detail.background_4, '4', false, 0);
                    bind_products_background(sections.products_detail.background_5, '5', false, 0);
                    bind_products_background(sections.products_detail.background_6, '6', false, 0);
                    bind_products_background(sections.products_detail.background_7, '7', false, 0);
                    bind_products_background(sections.products_detail.background_8, '8', false, 0);
                    bind_products_background(sections.products_detail.background_9, '9', false, 0);
                    bind_products_background(sections.products_detail.background_10, '10', false, 0);
                    bind_products_background(sections.products_detail.background_11, '11', false, 0);
                    bind_products_background(sections.products_detail.background_12, '12', false, 0);
                    break;
                case 13:
                    initialize_products_controls();

                    if (!is_short_width) {
                        $('.recipe_info_image').each(function() {
                            var recipe_info_image_el = $(this);
                            image_load(recipe_info_image_el);
                        });
                    }


                    break;
                case 14:
                    //console.log('initialization ',count_secondary_inits);
                    $('.show_more').on('touchstart mousedown', function() {

                        var show_more = $(this);

                        grid.show_more();

                        if ((count_cards_showing + grid.cards_per_line) <= count_cards_total) {
                            show_more.show();
                        } else {
                            show_more.hide();
                        }
                    });
                    break;
                case 15:
                    $('.card video').each(function() {
                        var card = $(this).closest('.card');
                        var table = card.find('.table');

                        table.on('click', function() {
                            var video = card.find('video');
                            var play_button = card.find('.card_play');

                            if (video.length) {
                                if (video.is('.initialized')) {

                                    //play_button.fadeOut();
                                } else {

                                    video.addClass('initialized');

                                    video[0].autoplay = true;
                                    video[0].src = video[0].getAttribute('data-src');


                                    video[0].addEventListener('paused', function() {
                                        video.removeClass('playing');
                                        play_button.fadeIn();
                                    });

                                    video[0].addEventListener('playing', function() {
                                        video.addClass('playing');
                                        play_button.fadeOut();
                                    });
                                }
                            }
                            if (video.is('.playing')) {
                                video.removeClass('playing');
                                video[0].currentTime = 0;
                                video[0].pause();
                                play_button.fadeIn();
                            } else {
                                video.addClass('playing');
                                video[0].currentTime = 0;
                                video[0].play();
                                play_button.fadeOut();
                            }
                        });
                    });
                    break;

                case 16:
                    check_products_visibility = function() {
                        // if (current_product <= 1) {
                        //     opacity($('#products_previous'), 0.2);
                        // } else {
                        //     opacity($('#products_previous'), 1);
                        // }

                        // if (current_product >= 6) {
                        //     opacity($('#products_next'), 0.2);
                        // } else {
                        //     opacity($('#products_next'), 1);
                        // }

                        $('#products_selected').text($('#products_name' + current_product).text());

                        products_background.update_destination(current_product - 1)
                    }

                    check_products_visibility();

                    $('#products_selected').on('mousedown', function() {
                        sections.products_detail.open('' + current_product);
                    });

                    if (is_short_width) {
                        $('#products_background').on('mousedown', function() {
                            /* Due to the new product order, we need to map it to the new values */
                            var intendedProduct = current_product;
                            // if (current_product == 4) {
                            //     intendedProduct = 1;
                            // } else if (current_product == 3) {
                            //     intendedProduct = 2;
                            // } else if (current_product == 2) {
                            //     intendedProduct = 3;
                            // } else if (current_product == 1) {
                            //     intendedProduct = 4;
                            // }

                            /* Product section setup: last 2 flavors don't have the play video button */
                            if (intendedProduct == 5 || intendedProduct == 6) {
                                $('#view-product-video').hide();
                                $('#products_more_info').css('top', '40px');
                            } else {
                                $('#view-product-video').show();
                                // $('#products_more_info').css('top', '0px');
                            }

                            if(intendedProduct == 10 || intendedProduct == 11 || intendedProduct == 12) {
                                $('#products_more_info').hide();
                                // $('#products_nutritional').css({top: '20%'});
                            } else {
                                $('#products_more_info').show();
                                // $('#products_nutritional').css({top: ((230/614)*100)+'%'});
                            }

                            sections.products_detail.open('' + intendedProduct);
                        });
                    }

                    // $('#products_previous').on('mousedown', function() {
                    //     if (current_product > 1) {
                    //         current_product--;
                    //     }

                    //     check_products_visibility();
                    // });

                    // $('#products_next').on('mousedown', function() {
                    //     if (current_product < 6) {
                    //         current_product++;
                    //     }
                    //     check_products_visibility();
                    // });

                    if (grid_slider) {
                        $('#cards_previous').on('mousedown touchstart', function(evt) {
                            if (grid_slider) {
                                evt.preventDefault();
                                grid_slider.prev();
                            }
                        });

                        $('#cards_next').on('mousedown touchstart', function(evt) {
                            if (grid_slider) {
                                evt.preventDefault();
                                grid_slider.next();
                            }
                        });
                    }
                    break;
                case 17:
                    $('#products_nutritional').on('mousedown', function() {
                        if (!nutritional_opened) {
                            nutritional_opened = true;
                            $('#products_nutritional_' + current_product).hide();
                            $('#products_nutritional_' + current_product).fadeIn();
                            $('#products_navigation_animation').fadeOut();
                        }
                    });

                    allow_body_size = true;
                    body.commit();

                    break;
                case 18:
                    //console.log('initialization ',count_secondary_inits);
                    force_render_paralax_once = true;


                    $('#header_sanduiche,#header_aba').on('mousedown', function(evt) {
                        //console.log('open menu');
                        //evt.preventDefault();
                        menu.open();
                        return false;

                    });

                    $('#menu_close').on('mousedown', function(evt) {
                        //console.log('close menu');
                        //evt.preventDefault();
                        menu.close();
                        return false;
                    });

                    $('.menu-link').click(function(evt) {
                        //console.log('go to menu item');
                        //evt.preventDefault();
                        menu.close();

                        if (current_subsection) {
                            current_subsection_back_to_path = $(this).attr('href');
                            current_subsection = null;
                        } else {
                            go_to_path($(this).attr('href'), true);
                        }
                        return false;
                    });

                    break;
                case 19:
                    //console.log('initialization ',count_secondary_inits);
                    current_slug = window.location.pathname;
                    //console.log('current_slug',current_slug);
                    go_to_path(current_slug, true);

                    force_render_paralax_once = true;
                    break;
                case 20:
                    //console.log('initialization ',count_secondary_inits);
                    animating_globalScrollTop = true;
                    force_render_paralax_once = true;
                    break;
                case 21:
                    animating_globalScrollTop = true;
                    force_render_paralax_once = true;
                    secondary_initializations_completed = true;
                    break;
            }
        }

        var current_subsection = null;
        var current_subsection_old = null;
        var current_subsection_back_to_path = null;

        function go_to_path(path, instantly) {
            console.log(path);

            var rel = 'header';
            switch (path) {
                case '/':
                    rel = 'header';
                    current_subsection = null;
                    break;
                case '/storytelling':
                case '/storytelling/':
                    rel = 'header';
                    current_subsection = 5;
                    break;
                case '/la_mia_gelateria':
                case '/la_mia_gelateria/':
                    rel = 'wall';
                    current_subsection = null;
                    break;
                case '/isapori':
                case '/isapori/':
                    sections.products_detail.close();
                    rel = 'products';
                    current_subsection = null;
                    break;
                case '/cioccolato_nero':
                case '/cioccolato_nero/':
                    sections.products_detail.open('1');
                    rel = 'products';
                    current_subsection = null;
                    break;
                case '/vaniglia':
                case '/vaniglia/':
                    sections.products_detail.open('2');
                    rel = 'products';
                    current_subsection = null;
                    break;
                case '/caramello_salato':
                case '/caramello_salato/':
                    sections.products_detail.open('3');
                    rel = 'products';
                    current_subsection = null;
                    break;
                case '/limoncello':
                case '/limoncello/':
                    sections.products_detail.open('4');
                    rel = 'products';
                    current_subsection = null;
                    break;
                case '/pistacchio':
                case '/pistacchio/':
                    sections.products_detail.open('5');
                    rel = 'products';
                    current_subsection = null;
                    break;
                case '/panna_cotta':
                case '/panna_cotta/':
                    sections.products_detail.open('6');
                    rel = 'products';
                    current_subsection = null;
                    break;
                case '/gianduia':
                case '/gianduia/':
                    sections.products_detail.open('7');
                    rel = 'products';
                    current_subsection = null;
                    break;
                case '/fragola':
                case '/fragola/':
                    sections.products_detail.open('8');
                    rel = 'products';
                    current_subsection = null;
                    break;
                case '/cappuccino':
                case '/cappuccino/':
                    sections.products_detail.open('9');
                    rel = 'products';
                    current_subsection = null;
                    break;
                case '/limoncello_picole':
                case '/limoncello_picole/':
                    sections.products_detail.open('10');
                    rel = 'products';
                    current_subsection = null;
                    break;
                case '/pisctacchio_picole':
                case '/pisctacchio_picole/':
                    sections.products_detail.open('11');
                    rel = 'products';
                    current_subsection = null;
                    break;
                case '/fragola_picole':
                case '/fragola_picole/':
                    sections.products_detail.open('12');
                    rel = 'products';
                    current_subsection = null;
                    break;
                case '/harmonizacoes_cioccolato_nero':
                case '/harmonizacoes_cioccolato_nero/':
                    rel = 'harmonizacoes';
                    current_subsection = 2;
                    break;
                case '/harmonizacoes_vaniglia':
                case '/harmonizacoes_vaniglia/':
                    rel = 'harmonizacoes';
                    current_subsection = 1;
                    break;
                case '/harmonizacoes_caramello_salato':
                case '/harmonizacoes_caramello_salato/':
                    rel = 'harmonizacoes';
                    current_subsection = 3;
                    break;
                case '/harmonizacoes_limoncello':
                case '/harmonizacoes_limoncello/':
                    rel = 'harmonizacoes';
                    current_subsection = 4;
                    break;
                case '/harmonizacoes_pistacchio':
                case '/harmonizacoes_pistacchio/':
                    rel = 'harmonizacoes';
                    current_subsection = 5;
                    break;
                case '/harmonizacoes_panna_cotta':
                case '/harmonizacoes_panna_cotta/':
                    rel = 'harmonizacoes';
                    current_subsection = 6;
                    break;
                case '/harmonizacoes_gianduia':
                case '/harmonizacoes_gianduia/':
                    rel = 'harmonizacoes';
                    current_subsection = 7;
                    break;
                case '/harmonizacoes_fragola':
                case '/harmonizacoes_fragola/':
                    rel = 'harmonizacoes';
                    current_subsection = 8;
                    break;
                case '/harmonizacoes_cappuccino':
                case '/harmonizacoes_cappuccino/':
                    rel = 'harmonizacoes';
                    current_subsection = 9;
                    break;
                case '/harmonizacoes_limoncello_picole':
                case '/harmonizacoes_limoncello_picole/':
                    rel = 'harmonizacoes';
                    current_subsection = 10;
                    break;
                case '/harmonizacoes_pisctacchio_picole':
                case '/harmonizacoes_pisctacchio_picole/':
                    rel = 'harmonizacoes';
                    current_subsection = 11;
                    break;
                case '/harmonizacoes_fragola_picole':
                case '/harmonizacoes_fragola_picole/':
                    rel = 'harmonizacoes';
                    current_subsection = 12;
                    break;
                case '/dove_trovare':
                case '/dove_trovare/':
                    rel = 'buy';
                    current_subsection = null;
                    break;
                default:
                    rel = 'header';
                    current_subsection = null;
                    break;
            }

            animating_globalScrollTop = true;

            if (!sections[rel]) {
                //console.log('not found ',rel);
                globalScrollTop_destination = 0;
                return;
            }

            globalScrollTop_destination = Math.min(body.height_value - browserHeight, sections[rel].top_value);

            if (rel == 'products') {
                globalScrollTop_destination -= Math.round((browserHeight - sections[rel].height_value) / 2);
            }

            //console.log('go_to_path=',rel,globalScrollTop_destination)

            if (instantly) {
                globalScrollTop = globalScrollTop_old = globalScrollTop_eased = globalScrollTop_eased_rounded = globalScrollTop_eased_rounded_old = globalScrollTop_destination;;
            } else if (is_mobile) {
                globalScrollTop = globalScrollTop_old = globalScrollTop_eased = globalScrollTop_eased_rounded = globalScrollTop_eased_rounded_old = $(window).scrollTop(); //globalScrollTop_destination;;
            }
        }

        var current_slug = window.location.pathname;

        function popstate(evt) {
            if (!intro_completed) return false;

            //console.log('hash changed to ',evt.state)
            if (current_slug !== window.location.pathname) {
                //console.log('need to go to url ',window.location.pathname);
                current_slug = window.location.pathname;
                go_to_path(current_slug);
            }
            evt.preventDefault();
        }

        window.addEventListener("popstate", popstate);

        if (is_internet_explorer) {
            if (msie_version <= 9) {
                //console.log('is internet explorer');
                var transform_x_y_not_3d = function(el, translateX, translateY) {
                    el[0].style.msTransform = 'translate(' + Math.round(translateX) + 'px, ' + Math.round(translateY) + 'px)';
                }
                var transform_x_y = function(el, translateX, translateY) {
                    el[0].style.msTransform = 'translate(' + Math.round(translateX) + 'px, ' + Math.round(translateY) + 'px)';
                }
                var transform_x_y_percent = function(el, translateX, translateY) {
                    el[0].style.msTransform = 'translate(' + Math.round(translateX * 100) / 100 + '%, ' + Math.round(translateY * 100) / 100 + '%)';
                }
                var transform_x_y_vwvh = function(el, translateX, translateY) {
                    el[0].style.msTransform = 'translate(' + Math.round(translateX * 100) / 100 + 'vw, ' + Math.round(translateY * 100) / 100 + 'vh)';
                }
                var transform_y = function(el, translateY) {
                    el[0].style.msTransform = 'translate(0, ' + Math.round(translateY) + 'px)';
                }
                var transform_y_scale = function(el, translateY, scale) {
                    el[0].style.msTransform = 'translate(0, ' + Math.round(translateY) + 'px) scale(' + Math.round(scale * 200) / 200 + ') ';
                }
                var transform_y_scale_rotate = function(el, translateY, scale, degrees) {
                    el[0].style.msTransform = 'translate(0, ' + Math.round(translateY) + 'px) scale(' + Math.round(scale * 200) / 200 + ') rotate(' + Math.round(degrees * 360) / 360 + 'deg)';
                }
                var transform_x_y_scale_rotate = function(el, translateX, translateY, scale, degrees) {
                    el[0].style.msTransform = 'translate(' + translateX + 'px, ' + Math.round(translateY) + 'px) scale(' + Math.round(scale * 200) / 200 + ') rotate(' + Math.round(degrees * 360) / 360 + 'deg)';
                }
            } else {
                //console.log('is internet explorer');
                var transform_x_y_not_3d = function(el, translateX, translateY) {
                    el[0].style.msTransform = 'translate(' + Math.round(translateX) + 'px, ' + Math.round(translateY) + 'px)';
                }

                var transform_x_y = function(el, translateX, translateY) {
                    el[0].style.msTransform = 'translate(' + Math.round(translateX) + 'px, ' + Math.round(translateY) + 'px) translate3d(0px, 0px, 0px)';
                }
                var transform_x_y_percent = function(el, translateX, translateY) {
                    el[0].style.msTransform = 'translate(' + Math.round(translateX * 100) / 100 + '%, ' + Math.round(translateY * 100) / 100 + '%) translate3d(0px, 0px, 0px)';
                }
                var transform_x_y_vwvh = function(el, translateX, translateY) {
                    el[0].style.msTransform = 'translate(' + Math.round(translateX * 100) / 100 + 'vw, ' + Math.round(translateY * 100) / 100 + 'vh) translate3d(0px, 0px, 0px)';
                }
                var transform_y = function(el, translateY) {
                    el[0].style.msTransform = 'translate(0, ' + Math.round(translateY) + 'px) translate3d(0px, 0px, 0px)';
                }
                var transform_y_scale = function(el, translateY, scale) {
                    el[0].style.msTransform = 'translate(0, ' + Math.round(translateY) + 'px) scale(' + Math.round(scale * 200) / 200 + ')  translate3d(0px, 0px, 0px)';
                }
                var transform_y_scale_rotate = function(el, translateY, scale, degrees) {
                    el[0].style.msTransform = 'translate(0, ' + Math.round(translateY) + 'px) scale(' + Math.round(scale * 200) / 200 + ') rotate(' + Math.round(degrees * 360) / 360 + 'deg) translate3d(0px, 0px, 0px)';
                }
                var transform_x_y_scale_rotate = function(el, translateX, translateY, scale, degrees) {
                    el[0].style.msTransform = 'translate(' + translateX + 'px, ' + Math.round(translateY) + 'px) scale(' + Math.round(scale * 200) / 200 + ') rotate(' + Math.round(degrees * 360) / 360 + 'deg) translate3d(0px, 0px, 0px)';
                }
            }

        } else if (is_safari) {
            var transform_x_y_not_3d = function(el, translateX, translateY) {
                el[0].style.webkitTransform = 'translate(' + Math.round(translateX) + 'px, ' + Math.round(translateY) + 'px)';
            }

            var transform_x_y = function(el, translateX, translateY) {
                el[0].style.webkitTransform = 'translate(' + Math.round(translateX) + 'px, ' + Math.round(translateY) + 'px) translate3d(0px, 0px, 0px)';
            }
            var transform_x_y_percent = function(el, translateX, translateY) {
                el[0].style.webkitTransform = 'translate(' + Math.round(translateX * 100) / 100 + '%, ' + Math.round(translateY * 100) / 100 + '%) translate3d(0px, 0px, 0px)';
            }
            var transform_x_y_vwvh = function(el, translateX, translateY) {
                el[0].style.webkitTransform = 'translate(' + Math.round(translateX * 100) / 100 + 'vw, ' + Math.round(translateY * 100) / 100 + 'vh) translate3d(0px, 0px, 0px)';
            }
            var transform_y = function(el, translateY) {
                el[0].style.webkitTransform = 'translate(0, ' + Math.round(translateY) + 'px) translate3d(0px, 0px, 0px)';
            }
            var transform_y_scale = function(el, translateY, scale) {
                el[0].style.webkitTransform = 'translate(0, ' + Math.round(translateY) + 'px) scale(' + Math.round(scale * 200) / 200 + ')  translate3d(0px, 0px, 0px)';
            }
            var transform_y_scale_rotate = function(el, translateY, scale, degrees) {
                el[0].style.webkitTransform = 'translate(0, ' + Math.round(translateY) + 'px) scale(' + Math.round(scale * 200) / 200 + ') rotate(' + Math.round(degrees * 360) / 360 + 'deg) translate3d(0px, 0px, 0px)';
            }
            var transform_x_y_scale_rotate = function(el, translateX, translateY, scale, degrees) {
                el[0].style.webkitTransform = 'translate(' + translateX + 'px, ' + Math.round(translateY) + 'px) scale(' + Math.round(scale * 200) / 200 + ') rotate(' + Math.round(degrees * 360) / 360 + 'deg) translate3d(0px, 0px, 0px)';
            }
        } else {
            var transform_x_y_not_3d = function(el, translateX, translateY) {
                el[0].style.transform = 'translate(' + Math.round(translateX) + 'px, ' + Math.round(translateY) + 'px)';
            }

            var transform_x_y = function(el, translateX, translateY) {
                el[0].style.transform = 'translate(' + Math.round(translateX) + 'px, ' + Math.round(translateY) + 'px) translate3d(0px, 0px, 0px)';
            }
            var transform_x_y_percent = function(el, translateX, translateY) {
                el[0].style.transform = 'translate(' + Math.round(translateX) + '%, ' + Math.round(translateY) + '%) translate3d(0px, 0px, 0px)';
            }
            var transform_x_y_vwvh = function(el, translateX, translateY) {
                el[0].style.transform = 'translate(' + Math.round(translateX) + 'vw, ' + Math.round(translateY) + 'vh) translate3d(0px, 0px, 0px)';
            }
            var transform_y = function(el, translateY) {
                el[0].style.transform = 'translate(0, ' + Math.round(translateY) + 'px) translate3d(0px, 0px, 0px)';
            }
            var transform_y_scale = function(el, translateY, scale) {
                el[0].style.transform = 'translate(0, ' + Math.round(translateY) + 'px) scale(' + Math.round(scale * 200) / 200 + ')  translate3d(0px, 0px, 0px)';
            }
            var transform_y_scale_rotate = function(el, translateY, scale, degrees) {
                el[0].style.transform = 'translate(0, ' + Math.round(translateY) + 'px) scale(' + Math.round(scale * 200) / 200 + ') rotate(' + Math.round(degrees * 360) / 360 + 'deg) translate3d(0px, 0px, 0px)';
            }
            var transform_x_y_scale_rotate = function(el, translateX, translateY, scale, degrees) {
                el[0].style.transform = 'translate(' + translateX + 'px, ' + Math.round(translateY) + 'px) scale(' + Math.round(scale * 200) / 200 + ') rotate(' + Math.round(degrees * 360) / 360 + 'deg) translate3d(0px, 0px, 0px)';
            }
        }

        var opacity = function(el, value) {
            el[0].style.opacity = Math.max(0, Math.min(1, value));
        }

        var dpr = window.devicePixelRatio || 1;

        var supported_dpr_values = [0.75, 1.0, 1.3, 1.5, 2.0, 3.0];
        var dpr_used;
        var dpr_string

        function calc_dpr() {
            //dpr_used = closest_above(supported_dpr_values, dpr);
            //dpr_string = dpr_used.toString();
            //if (dpr_string.match(/^\d+$/)) dpr_string += ".0";

            dpr_used = 1.0;
            dpr_string = '1.0';
        }
        //calc_dpr();

        var image_load = function(image_el) {

            if (is_short_width) {
                var data_attr_name = 'mobile-data-src';
            } else {
                var data_attr_name = 'desktop-data-src';
            }

            var image_src = image_el[0].getAttribute(data_attr_name);

            if ((image_src.split('.png').length > 1)) {
                image_src = image_src.replace(/\bf_auto\b/g, 'f_png');
            } else {
                image_src = image_src.replace(/\bf_auto\b/g, 'f_jpg');
            }
            image_el[0].setAttribute('src', image_src);

            add_image_being_loaded(image_el);

        }


        function cover_container_by_replacing_if_needed(image_el, container_width, container_height) {

            if (container_width == undefined || container_height == undefined) {
                var rect = image_el.parentNode.getBoundingClientRect();
                if (container_width == undefined) {
                    container_width = rect.right - rect.left;
                }

                if (container_height == undefined) {
                    container_height = rect.bottom - rect.top;
                }
            }

            if (container_width == 0) return; //problem
            if (container_height == 0) return; //problem

            /**
             * storytelling_fix
             * This is a list of image elements that should not be treated under the general rule.
             * I'm doing this to make the text in the Storytelling section more readable in the new
             * landscape mode.
             * The only other possible way to do it would be making this site again from scratch.
             */
            var imageExceptions = [
                'storytelling_card2_background',
                'storytelling_card3_background',
                'storytelling_card4_background',
            ];
            var isElementException = imageExceptions.indexOf(image_el.id) >= 0;

            if ((is_mobile && isElementException) || is_short_width) {

                var data_src_attr_name = 'mobile-data-src';
                var data_width_attr_name = 'mobile-data-original-width';
                var data_height_attr_name = 'mobile-data-original-height';

            } else {

                var data_src_attr_name = 'desktop-data-src';
                var data_width_attr_name = 'desktop-data-original-width';
                var data_height_attr_name = 'desktop-data-original-height';

            }

            var original_width = image_el.getAttribute(data_width_attr_name); ////console.log('original_width=',original_width);
            var original_height = image_el.getAttribute(data_height_attr_name); ////console.log('original_height=',original_height);
            var original_ratio = original_width / original_height; ////console.log('original_ratio=',original_ratio);
            var available_space_width = container_width; ////console.log('available_space_width=',available_space_width);
            var available_space_height = container_height; ////console.log('available_space_height=',available_space_height);
            var available_space_ratio = available_space_width / available_space_height; ////console.log('available_space_ratio=',available_space_ratio);
            var to_be_covered_space_width = available_space_width; ////console.log('to_be_covered_space_width=',to_be_covered_space_width);
            var to_be_covered_space_height = available_space_height; ////console.log('to_be_covered_space_height=',to_be_covered_space_height);
            var to_be_covered_space_ratio = to_be_covered_space_width / to_be_covered_space_height; ////console.log('to_be_covered_space_ratio=',to_be_covered_space_ratio);

            var image_width = Math.ceil(cover_width / 20) * 20;;
            var image_height = Math.ceil(cover_height / 20) * 20;;

            if (original_ratio <= to_be_covered_space_ratio) {
                var requested_width = Math.ceil(to_be_covered_space_width / 320) * 320; ////console.log('requested_width=',requested_width);
                var requested_height = Math.ceil(requested_width / original_ratio); ////console.log('requested_height=',requested_height);
            } else {
                var requested_height = Math.ceil(to_be_covered_space_height / 180) * 180; ////console.log('requested_height=',requested_height);
                var requested_width = Math.ceil(requested_height * original_ratio); ////console.log('requested_width=',requested_width);
            }

            requested_width = Math.round(requested_width * dpr_used);
            requested_height = Math.round(requested_height * dpr_used);
            if (requested_width >= original_width || requested_height >= original_height) {
                requested_width = original_width;
                requested_height = original_height;
            }


            var requested_ratio = requested_width / requested_height; ////console.log('requested_ratio=',requested_ratio);

            if (requested_ratio <= to_be_covered_space_ratio) {
                var cover_width = (to_be_covered_space_width); ////console.log('cover_width=',cover_width);
                var cover_height = cover_width / requested_ratio; ////console.log('cover_height=',cover_height);
            } else {
                var cover_height = (to_be_covered_space_height); ////console.log('cover_height=',cover_height);
                var cover_width = cover_height * requested_ratio; ////console.log('cover_width=',cover_width);
            }
            var cover_offset_x = cover_width - available_space_width; //console.log('cover_offset_x=',cover_offset_x);
            var cover_offset_y = cover_height - available_space_height; //console.log('cover_offset_y=',cover_offset_y);

            var image_src = image_el.getAttribute(data_src_attr_name); //TODO cache this?
            if (!image_src) {
                // console.log('image_src null for ', image_el, ' using ', data_src_attr_name);
            }

            /* Replacing backgrounds with landscape specific ones */
            var landscapeReplacements = [
                'storytelling_header_background',
                'storytelling_card5_background',
            ];
            var isSrcException = landscapeReplacements.indexOf(image_el.id) >= 0;

            if (is_mobile && is_short_width == false && isSrcException) {

                /* Landscape image ratios */
                var landscapeRatio = 632 / 1136;

                if (image_el.id == 'storytelling_header_background') {

                    var imageElement = $(image_el);
                    imageElement.attr('src', '../images/storytelling-header-landscape.jpg');
                    var headerSectionHeight = parseInt($('#storytelling_header').css('height').replace('px', ''));
                    imageElement.css('height', headerSectionHeight + 'px');
                    var imageWidth = headerSectionHeight / landscapeRatio;
                    imageElement.css('width', imageWidth + 'px');
                    var imageOffset = (browserWidth - imageWidth) / 2;
                    imageElement.css('left', imageOffset + 'px');

                } else if (image_el.id == 'storytelling_card5_background') {

                    var imageElement = $(image_el);
                    imageElement.attr('src', '../images/storytelling-products-landscape.jpg');

                    var headerSectionHeight = parseInt($('#storytelling_card5').css('height').replace('px', ''));
                    imageElement.css('height', headerSectionHeight + 'px');
                    var imageWidth = headerSectionHeight / landscapeRatio;
                    imageElement.css('width', imageWidth + 'px');
                    var imageOffset = (browserWidth - imageWidth) / 2;
                    imageElement.css('left', imageOffset + 'px');

                }

            } else {
                image_src = image_src.replace(/\bw_auto\b/g, "w_" + requested_width);
                image_src = image_src.replace(/\bh_auto\b/g, "h_" + requested_height);
                image_src = image_src.replace(/\bdpr_auto\b/g, "dpr_1.0"); //+ dpr_string

                if ((image_src.split('.png').length > 1)) {
                    image_src = image_src.replace(/\bf_auto\b/g, 'f_png');
                } else {
                    image_src = image_src.replace(/\bf_auto\b/g, 'f_jpg');
                }

                if (!(image_el.getAttribute('src') == image_src)) {

                    image_el.setAttribute('data-requested-width', requested_width);
                    image_el.setAttribute('data-requested-height', requested_height);

                    image_el.setAttribute('src', '');
                    image_el.setAttribute('src', image_src);

                }

                image_el.setAttribute('width', Math.ceil(cover_width));
                image_el.setAttribute('height', Math.ceil(cover_height));
                image_el.style.width = Math.ceil(cover_width) + 'px';
                image_el.style.height = Math.ceil(cover_height) + 'px';
                image_el.style.left = -Math.round(cover_offset_x / 2) + 'px';
                image_el.style.top = -Math.round(cover_offset_y / 2) + 'px';
            }

            /**
             * Several fixes to make the Storytelling section work on mobile landscape
             */
            fixStorytellingLandscape(is_mobile, is_short_width, current_slug);
        }

        /*
        function cover_container_only_by_resizing(video_el,container_width,container_height){


          if(container_width==undefined || container_height==undefined){
          var rect = video_el.parentNode.getBoundingClientRect();
            if(container_width==undefined){
                container_width=rect.right-rect.left;
              }

              if(container_height==undefined){
                container_height=rect.bottom-rect.top;
              }
          }

          if (container_width == 0) return;   //problem
            if (container_height == 0) return;  //problem

            var requested_width=video_el.getAttribute('data-requested-width');            ////console.log('requested_width=',requested_width);
              var requested_height=video_el.getAttribute('data-requested-height');            ////console.log('requested_height=',requested_height);
              var requested_ratio=requested_width/requested_height;                   ////console.log('requested_ratio=',requested_ratio);
              var available_space_width=container_width;                      ////console.log('available_space_width=',available_space_width);
              var available_space_height=container_height;                    ////console.log('available_space_height=',available_space_height);
        var available_space_ratio=available_space_width/available_space_height;       ////console.log('available_space_ratio=',available_space_ratio);
        var to_be_covered_space_width=available_space_width;                ////console.log('to_be_covered_space_width=',to_be_covered_space_width);
              var to_be_covered_space_height=available_space_height;                ////console.log('to_be_covered_space_height=',to_be_covered_space_height);
        var to_be_covered_space_ratio=to_be_covered_space_width/to_be_covered_space_height; ////console.log('to_be_covered_space_ratio=',to_be_covered_space_ratio);
              if(requested_ratio<=to_be_covered_space_ratio){
                  var cover_width=Math.ceil(to_be_covered_space_width);                   ////console.log('cover_width=',cover_width);
                  var cover_height=Math.ceil((to_be_covered_space_width)/requested_ratio);          ////console.log('cover_height=',cover_height);
              }else{
                  var cover_height=Math.ceil(to_be_covered_space_height);                 ////console.log('cover_height=',cover_height);
                  var cover_width=Math.ceil((to_be_covered_space_height)*requested_ratio);          ////console.log('cover_width=',cover_width);
              }
              var cover_offset_x=cover_width-available_space_width;                 ////console.log('cover_offset_x=',cover_offset_x);
              var cover_offset_y=cover_height-available_space_height;               ////console.log('cover_offset_y=',cover_offset_y);


        if(!video_el.getAttribute('src') || !video_el.getAttribute('src').length){
          var video_src = video_el.getAttribute('data-src'); //TODO cache this?
              //var video_width = calc_stoppoint(container_width);
              //var video_height = calc_stoppoint(container_height);
              //video_src = video_src.replace(/\bw_auto\b/g, "w_" + video_width);
              //video_src = video_src.replace(/\bh_auto\b/g, "h_" + video_height);
              //video_src = video_src.replace(/\bdpr_auto\b/g, "dpr_" + dpr_string);

              if(!( video_el.getAttribute('src') == video_src)){
                video_el.setAttribute('src', '');
                video_el.setAttribute('src', video_src);
                video_el.load(); ////console.log('get video to load on first resize');

              }
        }

            video_el.style.width=Math.ceil(cover_width)+'px';
            video_el.style.height=Math.ceil(cover_height)+'px',
            video_el.style.top=Math.round(-cover_offset_y/2)+'px';
            video_el.style.left=Math.round(-cover_offset_x/2)+'px';
        }
        */

        var image_cover_container = function(image_el, container_width, container_height) {


            //console.log('image_cover_container ',image_el[0].getAttribute('src'),container_width,container_height)
            cover_container_by_replacing_if_needed(image_el[0], container_width, container_height);

            //if(is_short_width){
            //  var data_attr_name = 'mobile-data-src';
            //}else{
            //  var data_attr_name = 'desktop-data-src';
            //}
            //var image_src = image_el[0].getAttribute(data_attr_name); ////console.log('image_src=',image_src);
            //var image_width = calc_stoppoint(container_width); ////console.log('image_width=',image_width);
            //var image_height = calc_stoppoint(container_height);
            //
            //image_src = image_src.replace(/\bw_auto\b/g, "w_" + image_width);
            //image_src = image_src.replace(/\bh_auto\b/g, "h_" + image_height);
            //image_src = image_src.replace(/\bdpr_auto\b/g, "dpr_" + dpr_string);
            //
            //image_el[0].setAttribute('src', image_src);
            //image_el[0].style.width=image_width+'px';
            //image_el[0].style.height=image_height+'px';
            //image_el[0].style.left=(-Math.round((image_width-container_width)/2))+'px';
            //image_el[0].style.top=(-Math.round((image_height-container_height)/2))+'px';

            add_image_being_loaded(image_el);


        }

        function hasClass(el, className) {
            if (el.classList)
                return (el.classList.contains(className));
            else
                return (new RegExp('(^| )' + className + '( |$)', 'gi').test(el.className));
        }


        var needs_resize = false;
        $(window).resize(function() {
            needs_resize = true;
        });


        var allow_body_size = false;

        var body = {
            el: $('#body'),
            width_value: 0,
            height_value: 0,
            commit: function() {
                this.el[0].style.height = this.height_value + 'px';
            }

        }



        //var wrapper = {
        //  el: $('#wrapper'),
        //}

        //remove-pattern//var pattern = {
        //remove-pattern//  el: $('#pattern'),
        //remove-pattern//  width_value: 0,
        //remove-pattern//  height_value: 0,
        //remove-pattern//}



        var sections = {};

        //remove-pattern//sections.pattern= {
        //remove-pattern//  visible:true,
        //remove-pattern//  active:true,
        //remove-pattern//  el: $('#pattern'),
        //remove-pattern//  background: $('#pattern_background'),
        //remove-pattern//  get_background_width_value: function(){ return this.width_value},
        //remove-pattern//  get_background_height_value: function(){ return this.height_value},
        //remove-pattern//  accumulate: false,
        //remove-pattern//  //commit_el_width: function(){ this.el[0].style.width=this.width_value+'px'; },
        //remove-pattern//  calc_height: function(){ this.height_value=browserHeight+152+152; },
        //remove-pattern//  commit_el_height: function(){ this.el[0].style.height=this.height_value+'px'; },
        //remove-pattern//  always_visible:true,
        //remove-pattern//  active:true,
        //remove-pattern//  height_value: 0,
        //remove-pattern//  width_value: 0,
        //remove-pattern//  top_value: 0,
        //remove-pattern//  middle_value: 0,
        //remove-pattern//  bottom_value: 0,
        //remove-pattern//  parallaxed_top: 0,
        //remove-pattern//  parallaxed_bottom: 0,
        //remove-pattern//  get_parallax_diff: function(top,middle,bottom){ return -((Math.max(0,top-sections.wall.height_value)%152)); },
        //remove-pattern//  reposition_internal_elements: function(top,middle,bottom){
        //remove-pattern//
        //remove-pattern//  },
        //remove-pattern//  commit_parallax: function(top,middle,bottom,hide){
        //remove-pattern//    transform_y(this.el, this.parallaxed_diff );
        //remove-pattern//    this.reposition_internal_elements(top,middle,bottom);
        //remove-pattern//  },
        //remove-pattern//};

        sections.header = {
            visible: true,
            active: true,
            el: $('#header'),
            background: $('#header_background'),
            get_background_width_value: function() {
                return this.width_value
            },
            get_background_height_value: function() {
                return this.height_value
            },
            accumulate: true,

            //height_auto:true,
            calc_height: function() {

                if (is_short_width) {

                    this.height_value = Math.max(browserHeight, 480);

                } else if (is_mobile && is_short_width == false && window.innerWidth < 740) {

                    /* Mobile landscape header height */
                    this.height_value = 420;

                } else {

                    this.height_value = browserHeight;
                    if (this.height_min && this.height_value < this.height_min) {
                        this.height_value = this.height_min;
                    }
                }

            },
            height_ratio: 698 / 1440,
            height_min: 698,

            commit_el_width: function() {
                this.el[0].style.width = this.width_value + 'px';
            },
            commit_el_height: function() {
                this.el[0].style.height = this.height_value + 'px';
            },

            height_value: 0,
            width_value: 0,
            top_value: 0,
            middle_value: 0,
            bottom_value: 0,
            parallaxed_top: 0,
            parallaxed_bottom: 0,
            get_parallax_diff: function(top, middle, bottom) {
                return -top;
            }, //-(top-this.top_value)/2;

            el_title: $('#header_title'),
            el_text: $('#header_text'),
            el_play: $('#header_play'),

            el_title_scale: 1,
            el_text_scale: 1,
            el_play_scale: 1,

            afterResize: function() {

                if (is_mobile && is_short_width == false) {

                    /* Mobile landscape */
                    this.el_title_scale = 0.7;
                    /* Header background on landscape mode*/
                    this.background.attr('src', '../images/header-landscape.jpg');

                    /* Calculate the new image dimensions */
                    var imageWidth = 1136;
                    var imageHeight = 637;
                    var bgWidth = this.height_value * imageWidth / imageHeight;
                    var leftOffset = (bgWidth - browserWidth) / 2;

                    this.background.css('width', bgWidth);
                    this.background.css('left', -leftOffset + 'px');

                } else {
                    this.el_title_scale = Math.min(1, browserWidth / (680 + 35 + 35));
                    if (is_short_width && this.el_title_scale > 0.6) {
                        this.el_title_scale = 0.6;
                    }
                }

                transform_x_y_scale_rotate(this.el_title, 0, 0, this.el_title_scale, 0);
            },

            //el_button: $('#header_button'),
            reposition_internal_elements: function(top, middle, bottom) {
                var diff = this.top_value - top;
                diff_abs = Math.abs(diff);

                var y_value = -(diff / 20)
                transform_x_y_scale_rotate(this.el_title, 0, y_value, this.el_title_scale, 0);
                transform_x_y_scale_rotate(this.el_text, 0, y_value, this.el_text_scale, 0);
                transform_x_y_scale_rotate(this.el_play, 0, y_value, this.el_play_scale, 0);

                var opacity_value = 1.5 - diff_abs / 500;
                opacity(this.el_title, opacity_value);
                opacity(this.el_text, opacity_value);
                opacity(this.el_play, opacity_value);

            },
            commit_parallax: function(top, middle, bottom, hide) {
                transform_y(this.el, this.parallaxed_diff);
                this.reposition_internal_elements(top, middle, bottom);
            },
        };




        $('#storytelling_header').each(function() {
            var section_el = $(this);
            var section_id = section_el.attr('id');
            var section_subsection = 5;

            sections[section_id] = {
                visible: true,
                active: true,
                el: section_el,
                background: section_el.find('img.background'),
                get_background_width_value: function() {
                    return this.width_value
                },
                get_background_height_value: function() {
                    return this.height_value
                },
                accumulate: true,
                subsection: section_subsection,

                //height_auto:true,
                calc_height: function() {

                    if (is_short_width) {
                        this.height_value = Math.max(browserHeight, 480);
                    } else if (is_mobile && is_short_width == false) {

                        if (browserWidth <= 660) {
                            this.height_value = 360;
                        } else {
                            this.height_value = 430;
                        }


                    } else {
                        this.height_value = browserHeight;
                        //this.height_value=Math.round(browserWidth*this.height_ratio);
                        if (this.height_min && this.height_value < this.height_min) {
                            this.height_value = this.height_min;
                        }
                    }
                },
                //height_ratio: 698/1440,
                height_min: 600,
                commit_el_width: function() {
                    this.el[0].style.width = this.width_value + 'px';
                },
                commit_el_height: function() {
                    this.el[0].style.height = this.height_value + 'px'
                },
                height_value: 0,
                width_value: 0,
                top_value: 0,
                middle_value: 0,
                bottom_value: 0,
                parallaxed_top: 0,
                parallaxed_bottom: 0,
                get_parallax_diff: function(top, middle, bottom) {
                    return -top;
                }, //-(top-this.top_value)/2;
                afterResize: function() {},
                reposition_internal_elements: function(top, middle, bottom) {},
                commit_parallax: function(top, middle, bottom, hide) {
                    transform_y(this.el, this.parallaxed_diff);
                    //this.reposition_internal_elements(top,middle,bottom);
                },
            };
        });

        $('#storytelling_card1').each(function() {
            var section_el = $(this);
            var section_id = section_el.attr('id');
            var section_subsection = 5;

            sections[section_id] = {
                visible: true,
                active: true,
                el: section_el,
                background: section_el.find('img.background'),
                get_background_width_value: function() {
                    return this.width_value
                },
                get_background_height_value: function() {
                    return this.height_value
                },
                accumulate: is_short_width,
                subsection: section_subsection,

                //height_auto:true,
                calc_height: function() {

                    if (is_short_width) {
                        //this.height_value=Math.max(browserHeight,480);
                        this.width_value = browserWidth;
                        this.height_value = browserWidth;
                    } else {
                        this.width_value = browserWidth / 2;
                        this.height_value = browserWidth / 2;
                        //this.height_value=Math.round(browserWidth*this.height_ratio);
                        if (this.height_min && this.height_value < this.height_min) {
                            this.height_value = this.height_min;
                        }
                    }

                },
                //height_ratio: 698/1440,
                height_min: 1,
                commit_el_width: function() {
                    this.el[0].style.width = this.width_value + 'px';
                },
                commit_el_height: function() {
                    this.el[0].style.height = this.height_value + 'px';
                },
                height_value: 0,
                width_value: 0,
                top_value: 0,
                middle_value: 0,
                bottom_value: 0,
                parallaxed_top: 0,
                parallaxed_bottom: 0,
                get_parallax_diff: function(top, middle, bottom) {
                    return -top;
                }, //-(top-this.top_value)/2;
                afterResize: function() {},
                reposition_internal_elements: function(top, middle, bottom) {},
                commit_parallax: function(top, middle, bottom, hide) {
                    transform_y(this.el, this.parallaxed_diff);
                    //this.reposition_internal_elements(top,middle,bottom);
                },
            };
        });

        $('#storytelling_card2').each(function() {
            var section_el = $(this);
            var section_id = section_el.attr('id');
            var section_subsection = 5;

            sections[section_id] = {
                visible: true,
                active: true,
                el: section_el,
                background: section_el.find('img.background'),
                get_background_width_value: function() {
                    return this.width_value
                },
                get_background_height_value: function() {
                    return this.height_value
                },
                accumulate: true,
                subsection: section_subsection,

                //height_auto:true,
                calc_height: function() {

                    if (is_short_width) {
                        //this.height_value=Math.max(browserHeight,480);
                        this.width_value = browserWidth;
                        this.height_value = browserWidth;
                    } else {
                        this.width_value = browserWidth / 2;
                        this.height_value = browserWidth / 2;
                        //this.height_value=Math.round(browserWidth*this.height_ratio);
                        if (this.height_min && this.height_value < this.height_min) {
                            this.height_value = this.height_min;
                        }
                    }

                },
                //height_ratio: 698/1440,
                height_min: 1,
                commit_el_width: function() {
                    this.el[0].style.width = this.width_value + 'px';
                },
                commit_el_height: function() {
                    this.el[0].style.height = this.height_value + 'px';
                },
                height_value: 0,
                width_value: 0,
                top_value: 0,
                middle_value: 0,
                bottom_value: 0,
                parallaxed_top: 0,
                parallaxed_bottom: 0,
                get_parallax_diff: function(top, middle, bottom) {
                    return -top;
                }, //-(top-this.top_value)/2;
                afterResize: function() {},
                reposition_internal_elements: function(top, middle, bottom) {},
                commit_parallax: function(top, middle, bottom, hide) {
                    transform_y(this.el, this.parallaxed_diff);
                    //this.reposition_internal_elements(top,middle,bottom);
                },
            };
        });

        $('#storytelling_card3').each(function() {
            var section_el = $(this);
            var section_id = section_el.attr('id');
            var section_subsection = 5;

            sections[section_id] = {
                visible: true,
                active: true,
                el: section_el,
                background: section_el.find('img.background'),
                get_background_width_value: function() {
                    return this.width_value
                },
                get_background_height_value: function() {
                    return this.height_value
                },
                accumulate: is_short_width,
                subsection: section_subsection,

                //height_auto:true,
                calc_height: function() {

                    if (is_short_width) {
                        //this.height_value=Math.max(browserHeight,480);
                        this.width_value = browserWidth;
                        this.height_value = browserWidth;
                    } else {
                        this.width_value = browserWidth / 2;
                        this.height_value = browserWidth / 2;
                        //this.height_value=Math.round(browserWidth*this.height_ratio);
                        if (this.height_min && this.height_value < this.height_min) {
                            this.height_value = this.height_min;
                        }
                    }

                },
                //height_ratio: 698/1440,
                height_min: 1,
                commit_el_width: function() {
                    this.el[0].style.width = this.width_value + 'px';
                },
                commit_el_height: function() {
                    this.el[0].style.height = this.height_value + 'px';
                },
                height_value: 0,
                width_value: 0,
                top_value: 0,
                middle_value: 0,
                bottom_value: 0,
                parallaxed_top: 0,
                parallaxed_bottom: 0,
                get_parallax_diff: function(top, middle, bottom) {
                    return -top;
                }, //-(top-this.top_value)/2;
                afterResize: function() {},
                reposition_internal_elements: function(top, middle, bottom) {},
                commit_parallax: function(top, middle, bottom, hide) {
                    transform_y(this.el, this.parallaxed_diff);
                    //this.reposition_internal_elements(top,middle,bottom);
                },
            };
        });

        $('#storytelling_card4').each(function() {
            var section_el = $(this);
            var section_id = section_el.attr('id');
            var section_subsection = 5;

            sections[section_id] = {
                visible: true,
                active: true,
                el: section_el,
                background: section_el.find('img.background'),
                get_background_width_value: function() {
                    return this.width_value
                },
                get_background_height_value: function() {
                    return this.height_value
                },
                accumulate: true,
                subsection: section_subsection,

                //height_auto:true,
                calc_height: function() {

                    if (is_short_width) {
                        //this.height_value=Math.max(browserHeight,480);
                        this.width_value = browserWidth;
                        this.height_value = browserWidth;
                    } else {
                        this.width_value = browserWidth / 2;
                        this.height_value = browserWidth / 2;
                        //this.height_value=Math.round(browserWidth*this.height_ratio);
                        if (this.height_min && this.height_value < this.height_min) {
                            this.height_value = this.height_min;
                        }
                    }

                },
                //height_ratio: 698/1440,
                height_min: 1,
                commit_el_width: function() {
                    this.el[0].style.width = this.width_value + 'px';
                },
                commit_el_height: function() {
                    this.el[0].style.height = this.height_value + 'px';
                },
                height_value: 0,
                width_value: 0,
                top_value: 0,
                middle_value: 0,
                bottom_value: 0,
                parallaxed_top: 0,
                parallaxed_bottom: 0,
                get_parallax_diff: function(top, middle, bottom) {
                    return -top;
                }, //-(top-this.top_value)/2;
                afterResize: function() {},
                reposition_internal_elements: function(top, middle, bottom) {},
                commit_parallax: function(top, middle, bottom, hide) {
                    transform_y(this.el, this.parallaxed_diff);
                    //this.reposition_internal_elements(top,middle,bottom);
                },
            };
        });



        $('#storytelling_card5').each(function() {
            var section_el = $(this);
            var section_id = section_el.attr('id');
            var section_subsection = 5;

            sections[section_id] = {
                visible: true,
                active: true,
                el: section_el,
                background: section_el.find('img.background'),
                get_background_width_value: function() {
                    return this.width_value
                },
                get_background_height_value: function() {
                    return this.height_value
                },
                accumulate: true,
                subsection: section_subsection,

                //height_auto:true,
                calc_height: function() {

                    if (is_short_width) {
                        //this.height_value=Math.max(browserHeight,480);
                        this.height_value = Math.round(browserWidth * (943 / 640));
                    } else if (is_mobile && is_short_width == false) {
                        if (browserWidth <= 660) {
                            this.height_value = 360;
                        } else {
                            this.height_value = 430;
                        }
                    } else {
                        //this.width_value=browserWidth/2;
                        //this.height_value=browserWidth/2;
                        this.height_value = Math.round(browserWidth * (1276 / 2556));
                    }

                },
                commit_el_width: function() {
                    this.el[0].style.width = this.width_value + 'px';
                },
                commit_el_height: function() {
                    this.el[0].style.height = this.height_value + 'px';
                },
                height_value: 0,
                width_value: 0,
                top_value: 0,
                middle_value: 0,
                bottom_value: 0,
                parallaxed_top: 0,
                parallaxed_bottom: 0,
                get_parallax_diff: function(top, middle, bottom) {
                    return -top;
                }, //-(top-this.top_value)/2;
                afterResize: function() {},
                reposition_internal_elements: function(top, middle, bottom) {},
                commit_parallax: function(top, middle, bottom, hide) {
                    transform_y(this.el, this.parallaxed_diff);
                    //this.reposition_internal_elements(top,middle,bottom);
                },
            };
        });




        $('.harmonizacoes_header').each(function() {
            var section_el = $(this);
            var section_id = section_el.attr('id');
            var section_subsection = 0;
            if (section_id == 'header_harmonizacoes_1') {
                section_subsection = 1;
            } else if (section_id == 'header_harmonizacoes_2') {
                section_subsection = 2;
            } else if (section_id == 'header_harmonizacoes_3') {
                section_subsection = 3;
            } else if (section_id == 'header_harmonizacoes_4') {
                section_subsection = 4;
            } else if (section_id == 'header_harmonizacoes_5') {
                section_subsection = 5;
            } else if (section_id == 'header_harmonizacoes_6') {
                section_subsection = 6;
            } else if (section_id == 'header_harmonizacoes_7') {
                section_subsection = 7;
            } else if (section_id == 'header_harmonizacoes_8') {
                section_subsection = 8;
            } else if (section_id == 'header_harmonizacoes_9') {
                section_subsection = 9;
            } else if (section_id == 'header_harmonizacoes_10') {
                section_subsection = 10;
            } else if (section_id == 'header_harmonizacoes_11') {
                section_subsection = 11;
            } else if (section_id == 'header_harmonizacoes_12') {
                section_subsection = 12;
            }

            sections[section_id] = {
                visible: true,
                active: true,
                el: section_el,
                background: section_el.find('img.background'),
                get_background_width_value: function() {
                    return this.width_value
                },
                get_background_height_value: function() {
                    return this.height_value
                },
                accumulate: true,
                subsection: section_subsection,

                //height_auto:true,
                calc_height: function() {

                    if (is_short_width) {
                        this.height_value = Math.max(browserHeight, 480);
                    } else if (is_mobile && is_short_width == false) {

                        /** Mobile landscape: section height is sligtly shorter for the image to fit better */
                        var backgroundImageRatio = 1445 / 720;
                        var landscapeBackgrounds = $('.harmonizacoes_header_background_image');
                        var buttons = $('.harmonizacoes_header_more');

                        for (var i = 0; i < landscapeBackgrounds.length; i++) {

                            var landscapeBackground = $(landscapeBackgrounds[i]);

                            var backgroundHeight = 430;
                            landscapeBackground.css('height', backgroundHeight + 'px');

                            var backgroundWidth = Math.round(this.height_value * backgroundImageRatio);
                            landscapeBackground.css('width', backgroundWidth + 'px');

                            /** Set the section height according to the background image height */
                            this.height_value = Math.round(browserWidth * this.height_ratio);
                            if (this.height_min && this.height_value < this.height_min) {
                                this.height_value = backgroundHeight;
                            }

                            /** Button height (can't use media queries for this because this structure sucks) */
                            var button = $(buttons[i]);
                            button.css('top', 'auto');
                            button.css('bottom', '20px');
                        }
                    } else {
                        this.height_value = browserHeight;
                        //this.height_value=Math.round(browserWidth*this.height_ratio);
                        if (this.height_min && this.height_value < this.height_min) {
                            this.height_value = this.height_min;
                        }
                    }
                },
                height_ratio: 698 / 1440,
                height_min: 698,

                commit_el_width: function() {
                    this.el[0].style.width = this.width_value + 'px';
                },
                commit_el_height: function() {
                    this.el[0].style.height = this.height_value + 'px';
                },

                height_value: 0,
                width_value: 0,
                top_value: 0,
                middle_value: 0,
                bottom_value: 0,
                parallaxed_top: 0,
                parallaxed_bottom: 0,
                get_parallax_diff: function(top, middle, bottom) {
                    return -top;
                }, //-(top-this.top_value)/2;

                el_title: section_el.find('#harmonizacoes_header_title'),
                el_text: section_el.find('#harmonizacoes_header_text'),
                el_more: section_el.find('#harmonizacoes_header_more'),

                el_title_scale: 1,
                el_text_scale: 1,
                el_more_scale: 1,

                afterResize: function() {
                    //this.el_title_scale=Math.min(1,browserWidth/(680+35+35));
                    //transform_x_y_scale_rotate(this.el_title, 0,  0, this.el_title_scale, 0 );
                },

                //el_button: $('#header_button'),
                reposition_internal_elements: function(top, middle, bottom) {
                    var diff = this.top_value - top;
                    diff_abs = Math.abs(diff);

                    var y_value = -(diff / 20)
                    transform_x_y_scale_rotate(this.el_title, 0, y_value, this.el_title_scale, 0);
                    transform_x_y_scale_rotate(this.el_text, 0, y_value, this.el_text_scale, 0);
                    transform_x_y_scale_rotate(this.el_more, 0, y_value, this.el_more_scale, 0);

                    var opacity_value = 1.5 - diff_abs / 500;
                    opacity(this.el_title, opacity_value);
                    opacity(this.el_text, opacity_value);
                    opacity(this.el_more, opacity_value);
                },
                commit_parallax: function(top, middle, bottom, hide) {
                    transform_y(this.el, this.parallaxed_diff);
                    this.reposition_internal_elements(top, middle, bottom);
                },
            };
        });



        $('.harmonizacoes_capsules').each(function() {
            var section_el = $(this);
            var section_id = section_el.attr('id');
            var section_subsection = 0;

            if (section_id == 'capsules_harmonizacoes_1') {
                section_subsection = 1;
            } else if (section_id == 'capsules_harmonizacoes_2') {
                section_subsection = 2;
            } else if (section_id == 'capsules_harmonizacoes_3') {
                section_subsection = 3;
            } else if (section_id == 'capsules_harmonizacoes_4') {
                section_subsection = 4;
            } else if (section_id == 'capsules_harmonizacoes_5') {
                section_subsection = 5;
            } else if (section_id == 'capsules_harmonizacoes_6') {
                section_subsection = 6;
            } else if (section_id == 'capsules_harmonizacoes_7') {
                section_subsection = 7;
            } else if (section_id == 'capsules_harmonizacoes_8') {
                section_subsection = 8;
            } else if (section_id == 'capsules_harmonizacoes_9') {
                section_subsection = 9;
            } else if (section_id == 'capsules_harmonizacoes_10') {
                section_subsection = 10;
            } else if (section_id == 'capsules_harmonizacoes_11') {
                section_subsection = 11;
            } else if (section_id == 'capsules_harmonizacoes_12') {
                section_subsection = 12;
            }

            sections[section_id] = {
                visible: true,
                active: true,
                el: section_el,
                background: section_el.find('img.background'),
                get_background_width_value: function() {
                    return this.width_value
                },
                get_background_height_value: function() {
                    return this.height_value
                },
                accumulate: true,
                subsection: section_subsection,

                //height_auto:true,
                calc_height: function() {

                    if (is_short_width) {
                        this.height_value = Math.round(browserWidth * this.height_ratio);
                        if (this.height_min && this.height_value < 195) {
                            this.height_value = 195;
                        }
                        //this.height_value=Math.max(browserHeight,300);
                    } else if (is_mobile && is_short_width == false) {

                        /** Better height to make the content fit properly */
                        this.height_value = 300;

                    } else {
                        //this.height_value=browserHeight;
                        this.height_value = Math.round(browserWidth * this.height_ratio);
                        if (this.height_min && this.height_value < this.height_min) {
                            this.height_value = this.height_min;
                        }
                    }

                },
                height_ratio: 380 / 1280,
                height_min: 380,

                commit_el_width: function() {
                    this.el[0].style.width = this.width_value + 'px';
                },
                commit_el_height: function() {
                    this.el[0].style.height = this.height_value + 'px';
                },

                height_value: 0,
                width_value: 0,
                top_value: 0,
                middle_value: 0,
                bottom_value: 0,
                parallaxed_top: 0,
                parallaxed_bottom: 0,
                get_parallax_diff: function(top, middle, bottom) {
                    return -top;
                }, //-(top-this.top_value)/2;

                //el_title: section_el.find('#harmonizacoes_header_title'),
                //el_text: section_el.find('#harmonizacoes_header_text'),
                //el_more: section_el.find('#harmonizacoes_header_more'),

                //el_title_scale: 1,
                //el_text_scale:  1,
                //el_more_scale:  1,

                afterResize: function() {
                    //this.el_title_scale=Math.min(1,browserWidth/(680+35+35));
                    //transform_x_y_scale_rotate(this.el_title, 0,  0, this.el_title_scale, 0 );
                },

                //el_button: $('#header_button'),
                reposition_internal_elements: function(top, middle, bottom) {
                    //var diff=this.top_value-top;
                    //diff_abs=Math.abs(diff);

                    //var y_value=-(diff/20)
                    //transform_x_y_scale_rotate(this.el_title, 0,  y_value, this.el_title_scale, 0 );
                    //transform_x_y_scale_rotate(this.el_text,  0,  y_value, this.el_text_scale, 0 );
                    //transform_x_y_scale_rotate(this.el_more,  0,  y_value, this.el_more_scale, 0 );
                    //
                    //var opacity_value=1.5-diff_abs/500;
                    //opacity(this.el_title, opacity_value);
                    //opacity(this.el_text,  opacity_value);
                    //opacity(this.el_more,  opacity_value);
                },
                commit_parallax: function(top, middle, bottom, hide) {
                    transform_y(this.el, this.parallaxed_diff);
                    //this.reposition_internal_elements(top,middle,bottom);
                },
            };
        });


        $('.harmonizacoes_recipe').each(function() {
            var section_el = $(this);
            var section_id = section_el.attr('id');
            var section_subsection = 0;
            if (section_id == 'recipe_harmonizacoes_1') {
                section_subsection = 1;
            } else if (section_id == 'recipe_harmonizacoes_2') {
                section_subsection = 2;
            } else if (section_id == 'recipe_harmonizacoes_3') {
                section_subsection = 3;
            } else if (section_id == 'recipe_harmonizacoes_4') {
                section_subsection = 4;
            } else if (section_id == 'recipe_harmonizacoes_5') {
                section_subsection = 5;
            } else if (section_id == 'recipe_harmonizacoes_6') {
                section_subsection = 6;
            } else if (section_id == 'recipe_harmonizacoes_7') {
                section_subsection = 7;
            } else if (section_id == 'recipe_harmonizacoes_8') {
                section_subsection = 8;
            } else if (section_id == 'recipe_harmonizacoes_9') {
                section_subsection = 9;
            } else if (section_id == 'recipe_harmonizacoes_10') {
                section_subsection = 10;
            } else if (section_id == 'recipe_harmonizacoes_11') {
                section_subsection = 11;
            } else if (section_id == 'recipe_harmonizacoes_12') {
                section_subsection = 12;
            }

            var section_recipe_width = section_el.find('img.background')[0].getAttribute('mobile-data-original-width');
            var section_recipe_height = section_el.find('img.background')[0].getAttribute('mobile-data-original-height');

            sections[section_id] = {
                visible: true,
                active: true,
                el: section_el,
                background: section_el.find('img.background'),
                get_background_width_value: function() {
                    return this.width_value
                },
                get_background_height_value: function() {
                    return this.height_value
                },
                accumulate: true,
                subsection: section_subsection,

                //height_auto:true,
                calc_height: function() {

                    if (is_short_width) {
                        this.height_value = Math.round(browserWidth * (section_recipe_height / section_recipe_width));
                    } else {

                        /** Specific mobile landscape rules */
                        if (is_mobile && is_short_width == false) {

                            var backgroundImageRatio = 1136 / 620;

                            var landscapeBackgrounds = $('.harmonizacoes_recipe_background_landscape');
                            var landscapeRecipes = $('.recipe_info_image');
                            var recipeInfoContainers = $('.recipe_info_container');

                            for (var i = 0; i < landscapeBackgrounds.length; i++) {

                                var landscapeBackground = $(landscapeBackgrounds[i]);
                                var landscapeRecipe = $(landscapeRecipes[i]);
                                var recipeInfoContainer = $(recipeInfoContainers[i]);
                                var backgroundHeight = 0;
                                var recipeRatio = 0;

                                /** Background landscape product image. This really does suck */
                                if (this.subsection == 1) { /** Chocolate */
                                    landscapeBackground.attr('src', '../images/chocolate-landscape.jpg');
                                    landscapeRecipe.attr('src', '../images/receita-chocolate-landscape.png');
                                    recipeRatio = 1280 / 900;
                                } else if (this.subsection == 2) { /** Vanilla */
                                    landscapeBackground.attr('src', '../images/vanilla-landscape.jpg');
                                    landscapeRecipe.attr('src', '../images/receita-vanilla-landscape.png');
                                    recipeRatio = 1280 / 700;
                                } else if (this.subsection == 3) { /** Caramelo */
                                    landscapeBackground.attr('src', '../images/caramelo-landscape.jpg');
                                    landscapeRecipe.attr('src', '../images/receita-caramelo-landscape.png');
                                    recipeRatio = 1280 / 700;
                                } else if (this.subsection == 4) { /** Limão */
                                    landscapeBackground.attr('src', '../images/limao-landscape.jpg');
                                    landscapeRecipe.attr('src', '../images/receita-limao-landscape.png');
                                    recipeRatio = 1280 / 900;
                                } else if (this.subsection == 5) { /** Pistacchio */
                                    landscapeBackground.attr('src', '../images/pistacchio-landscape.jpg');
                                    landscapeRecipe.attr('src', '../images/receita-pistacchio-landscape.png');
                                    recipeRatio = 1280 / 900;
                                } else if (this.subsection == 6) { /** Panna Cotta */
                                    landscapeBackground.attr('src', '../images/panna-landscape.jpg');
                                    landscapeRecipe.attr('src', '../images/receita-panna-landscape.png');
                                    recipeRatio = 1280 / 900;
                                } else if (this.subsection == 7) { /** Panna Cotta */
                                    landscapeBackground.attr('src', '../images/panna-landscape.jpg');
                                    landscapeRecipe.attr('src', '../images/receita-panna-landscape.png');
                                    recipeRatio = 1280 / 900;
                                } else if (this.subsection == 8) { /** Panna Cotta */
                                    landscapeBackground.attr('src', '../images/panna-landscape.jpg');
                                    landscapeRecipe.attr('src', '../images/receita-panna-landscape.png');
                                    recipeRatio = 1280 / 900;
                                } else if (this.subsection == 9) { /** Panna Cotta */
                                    landscapeBackground.attr('src', '../images/panna-landscape.jpg');
                                    landscapeRecipe.attr('src', '../images/receita-panna-landscape.png');
                                    recipeRatio = 1280 / 900;
                                } else if (this.subsection == 10) { /** Panna Cotta */
                                    landscapeBackground.attr('src', '../images/panna-landscape.jpg');
                                    landscapeRecipe.attr('src', '../images/receita-panna-landscape.png');
                                    recipeRatio = 1280 / 900;
                                } else if (this.subsection == 11) { /** Panna Cotta */
                                    landscapeBackground.attr('src', '../images/panna-landscape.jpg');
                                    landscapeRecipe.attr('src', '../images/receita-panna-landscape.png');
                                    recipeRatio = 1280 / 900;
                                } else if (this.subsection == 12) { /** Panna Cotta */
                                    landscapeBackground.attr('src', '../images/panna-landscape.jpg');
                                    landscapeRecipe.attr('src', '../images/receita-panna-landscape.png');
                                    recipeRatio = 1280 / 900;
                                }

                                landscapeBackground.css('width', this.width_value);
                                var backgroundHeight = Math.round(this.width_value / backgroundImageRatio);
                                landscapeBackground.css('height', backgroundHeight + 'px');

                                recipeInfoContainer.css('top', backgroundHeight + 'px');
                                recipeHeight = Math.round(this.width_value / recipeRatio);

                                /** Set the section height, according to the image height */
                                this.height_value = Math.round(browserWidth * this.height_ratio);
                                if (this.height_min && this.height_value < this.height_min) {
                                    this.height_value = backgroundHeight + recipeHeight;
                                }

                            }

                        } else {
                            //this.height_value=browserHeight;
                            this.height_value = Math.round(browserWidth * this.height_ratio);
                            if (this.height_min && this.height_value < this.height_min) {
                                this.height_value = this.height_min;
                            }
                        }
                    }

                },
                height_ratio: 580 / 1280,
                height_min: 580,

                commit_el_width: function() {
                    this.el[0].style.width = this.width_value + 'px';
                },
                commit_el_height: function() {
                    this.el[0].style.height = this.height_value + 'px';
                },

                height_value: 0,
                width_value: 0,
                top_value: 0,
                middle_value: 0,
                bottom_value: 0,
                parallaxed_top: 0,
                parallaxed_bottom: 0,
                get_parallax_diff: function(top, middle, bottom) {
                    return -top;
                }, //-(top-this.top_value)/2;

                //el_title: section_el.find('#harmonizacoes_header_title'),
                //el_text: section_el.find('#harmonizacoes_header_text'),
                //el_more: section_el.find('#harmonizacoes_header_more'),

                //el_title_scale: 1,
                //el_text_scale:  1,
                //el_more_scale:  1,

                afterResize: function() {
                    //this.el_title_scale=Math.min(1,browserWidth/(680+35+35));
                    //transform_x_y_scale_rotate(this.el_title, 0,  0, this.el_title_scale, 0 );
                },

                //el_button: $('#header_button'),
                reposition_internal_elements: function(top, middle, bottom) {
                    //var diff=this.top_value-top;
                    //diff_abs=Math.abs(diff);

                    //var y_value=-(diff/20)
                    //transform_x_y_scale_rotate(this.el_title, 0,  y_value, this.el_title_scale, 0 );
                    //transform_x_y_scale_rotate(this.el_text,  0,  y_value, this.el_text_scale, 0 );
                    //transform_x_y_scale_rotate(this.el_more,  0,  y_value, this.el_more_scale, 0 );
                    //
                    //var opacity_value=1.5-diff_abs/500;
                    //opacity(this.el_title, opacity_value);
                    //opacity(this.el_text,  opacity_value);
                    //opacity(this.el_more,  opacity_value);
                },
                commit_parallax: function(top, middle, bottom, hide) {
                    transform_y(this.el, this.parallaxed_diff);
                    //this.reposition_internal_elements(top,middle,bottom);
                },
            };
        });


        sections.wall = {
            visible: true,
            active: true,
            el: $('#wall'),
            background: $('#wall_background'),
            get_background_width_value: function() {
                return this.width_value
            },
            get_background_height_value: function() {
                return this.height_value
            },
            accumulate: true,

            //height_auto:true,
            calc_height: function() {
                //if(is_short_width){
                //  this.height_value=Math.max(browserHeight,620);
                //}else{
                this.height_value = Math.round(browserWidth * this.height_ratio);
                if (this.height_min && this.height_value < this.height_min) {
                    this.height_value = this.height_min;
                }

                //}
            },
            //height_ratio: 698/1440,
            //height_min: 698,
            height_ratio: 620 / 1440,
            height_min: 620,

            //commit_el_width: function(){ this.el[0].style.width=this.width_value+'px'; },
            commit_el_height: function() {
                this.el[0].style.height = this.height_value + 'px';
            },

            height_value: 0,
            width_value: 0,
            top_value: 0,
            middle_value: 0,
            bottom_value: 0,
            parallaxed_top: 0,
            parallaxed_bottom: 0,
            get_parallax_diff: function(top, middle, bottom) {

                var value = -top + Math.min(0, (-this.height_value) + top)
                    //console.log();
                return value;
            },

            el_badge: $('#icecream_badge'),
            el_title: $('#wall_title'),
            el_text: $('#wall_text'),
            el_separator: $('#icecream_separator'),

            el_badge_scale: 1,
            el_title_scale: 1,
            el_text_scale: 1,
            el_separator_scale: 1,

            afterResize: function() {
                this.el_title_scale = 0.7;
                transform_x_y_scale_rotate(this.el_title, 0, 0, this.el_title_scale, 0);
                //this.el_title_scale=Math.min(1,browserWidth/1000);
            },

            reposition_internal_elements: function(top, middle, bottom) {

                var diff = this.bottom_value - bottom;
                diff_abs = Math.abs(diff);

                var y_value = Math.min(0, diff / 20);
                transform_x_y_scale_rotate(this.el_badge, 0, y_value, this.el_badge_scale, 0);
                transform_x_y_scale_rotate(this.el_title, 0, y_value, this.el_title_scale, 0);
                transform_x_y_scale_rotate(this.el_text, 0, y_value, this.el_text_scale, 0);
                transform_x_y_scale_rotate(this.el_separator, 0, y_value, this.el_separator_scale, 0);

                var opacity_value = 1.5 - diff_abs / (browserHeight * 0.75);
                opacity(this.el_badge, opacity_value);
                opacity(this.el_title, opacity_value);
                opacity(this.el_text, opacity_value);
                opacity(this.el_separator, opacity_value);

                //opacity(this.el_title, 1.5-diff_abs/500);
                //opacity(this.el_text, 1.5-diff_abs/500);

            },
            commit_parallax: function(top, middle, bottom, hide) {
                transform_y(this.el, this.parallaxed_diff);
                this.reposition_internal_elements(top, middle, bottom);
            },

        };


        /** Mobile vertical */
        if (is_short_width && is_mobile) {

            var grid = {
                cards_per_line: 1,
                max_card_width: 9999,
                card_width: 0,
                card_height: 0,
                row_widths: [],

                recalc: function() {

                    var this_grid = this;

                    this.card_width = this.card_height = browserWidth;

                    var left_value = 0;
                    $.each(cards, function(key, card) {

                        //if(card.card_index==(count_cards_total-1)){
                        //  card.accumulate=true;
                        //}else{
                        card.accumulate = false;
                        //}
                        //if(card.hidden){
                        //  card.accumulate=false;
                        //  return;
                        //}

                        card.left_value = left_value;
                        card.width_value = grid.row_widths[card.card_index % grid.cards_per_line];
                        card.height_value = grid.card_height;
                        //card.accumulate=false;
                        left_value += card.width_value;

                        card.commit_el_width();
                        card.commit_el_height();
                        card.commit_el_left();

                    });


                },

                show_more: function() {

                },



            }




        } else {

            var grid = {
                cards_per_line: 3,
                max_card_width: 480,
                card_width: 0,
                card_height: 0,
                row_widths: [],

                recalc: function() {

                    var this_grid = this;




                    this.cards_per_line = Math.ceil(browserWidth / this.max_card_width);
                    this.row_widths = [];
                    var accumulated_width = 0;
                    for (var i = 0; i < this.cards_per_line; i++) {
                        this.row_widths[i] = Math.floor(browserWidth / this.cards_per_line);
                        accumulated_width += this.row_widths[i];
                    }
                    var missing_width = browserWidth - accumulated_width;
                    this.row_widths[this.row_widths.length - 1] += missing_width;

                    this.card_width = this.card_height = this.row_widths[this.row_widths.length - 1];

                    ////console.log('this.row_widths=',this.row_widths);

                    var left_value = 0;
                    var i = 0;
                    $.each(cards, function(key, card) {

                        if (card.hidden) {
                            card.accumulate = false;
                            return;
                        }

                        card.left_value = left_value;
                        card.width_value = grid.row_widths[card.card_index % grid.cards_per_line];
                        card.height_value = grid.card_height;

                        if ((card.card_index % grid.cards_per_line) == (grid.cards_per_line - 1)) {
                            ////console.log('card.card_index >> accumulate');
                            card.accumulate = true;
                            left_value = 0;
                        } else {
                            card.accumulate = false;
                            left_value += card.width_value;
                        }

                        card.commit_el_width();
                        card.commit_el_height();
                        card.commit_el_left();

                    });


                },

                show_more: function() {
                    // console.log("calling show more");
                    var count_show_more = 0;

                    //count_cards_showing=0;

                    $.each(cards, function(key, card) {

                        //if(!card.hidden){
                        //  count_cards_showing++;
                        //  return;
                        //}
                        //if(is_short_width){
                        //  if(count_show_more>=2){
                        //    return;
                        //  }
                        //}else{

                        var maxShowMore = 12;
                        if (is_mobile) {
                            maxShowMore = 8; /** On mobile landscape, load 2 cards at a time */
                        }
                        if (count_show_more >= maxShowMore) {
                            // console.log("leaving");
                            return;
                        }
                        //}


                        if (card.hidden) {
                            // console.log("entered");
                            count_show_more++;
                            card.active = true;
                            card.hidden = false;
                            //card.visible=true;
                            count_cards_showing++;
                            card.el.removeClass('hidden');
                            card.el.show();
                            card.load();
                        }

                    });

                    //console.log('count_show_more=',count_show_more);
                    if (count_show_more > 0) {
                        // console.log("resizing");
                        main_resize_handler();
                        //grid.recalc();
                        force_render_paralax_once = true;
                    }
                }
            }
        }



        var cards = {};
        var count_cards_total = 0;
        var count_cards_showing = 0;
        var unordered_cards = {};
        $('section.card').each(function() {
            var card_id = this.getAttribute('id');
            ////console.log('card_id=',card_id)
            var card_type = this.getAttribute('data-type');

            if (card_type == 'instagram-video' && is_mobile) {
                return;
            }

            unordered_cards[card_id] = {
                id: card_id,

                el: $('#' + card_id),
                //background: $('#grid_background'),
                //get_background_width_value: function(){ return this.width_value},
                //get_background_height_value: function(){ return this.height_value},
                accumulate: true,

                commit_el_width: function() {
                    this.el[0].style.width = this.width_value + 'px';
                },
                commit_el_height: function() {
                    this.el[0].style.height = this.height_value + 'px';
                },
                commit_el_left: function() {
                    this.el[0].style.left = this.left_value + 'px';
                },

                left_value: 0,
                width_value: 0,
                height_value: 0,
                top_value: 0,
                middle_value: 0,
                bottom_value: 0,
                parallaxed_top: 0,
                parallaxed_bottom: 0,
                parallaxed_diff: 0,

                scale_diff: 0,
                horizontal_diff: 0,
                rotate_diff: 0,

                parallax_constant: 0,
                horizontal_constant: 0,

                loaded: false,

                load: function() {
                    if (!this.loaded) {
                        this.loaded == true;
                        $(this.el).find('img').each(function() {
                            $(this).attr('src', $(this).attr('data-src'));
                            //add_image_being_loaded($(this));
                        });
                        $(this.el).find('video').each(function() {
                            $(this).attr('poster', $(this).attr('poster-src'));
                        });
                    }

                },

                afterResize: function() {
                    this.parallax_constant = this.top_value + (grid.card_height / grid.cards_per_line) * (this.card_index % grid.cards_per_line) * 1.333;

                    this.horizontal_constant = -1 + Math.random() * 2;
                    while (Math.abs(this.horizontal_constant) < 0.5) this.horizontal_constant = -1 + Math.random() * 2;
                    if ((Math.random()) >= 0.5) {
                        this.horizontal_constant = 1;
                    } else {
                        this.horizontal_constant = -1;
                    }

                    ////console.log('this.horizontal_constant=',this.horizontal_constant);
                },
                get_parallax_diff: function(top, middle, bottom) {
                    //if((this.middle_value-middle) > 0 ){


                    //return (-top);

                    //

                    //if(true || diff<0){
                    this.scale_diff = 1;
                    this.rotate_diff = 0;
                    this.horizontal_diff = 0;
                    //return -top;
                    //}
                    var diff = 0;

                    //if(is_short_width){
                    //
                    //}else{
                    var diff = (this.parallax_constant - (bottom * 1 + middle) / 2);

                    //var radius=browserHeight/2-diff/2;
                    //var angle=Math.min(3.14/10,Math.asin(Math.min(radius,Math.max(0,diff))/radius));
                    //var degrees=angle*57.2957795;
                    //var x=radius-radius*Math.cos(angle);
                    //var y=radius*Math.sin(angle);
                    //var rotate=degrees;
                    ////if(this.card_index==1){
                    ////  //console.log(x,y);
                    ////}
                    //

                    this.scale_diff = Math.max(0.94, Math.min(1, 1 - Math.max(0, diff + 5) / (grid.card_height * 1)));
                    //this.rotate_diff=-this.horizontal_constant*degrees;
                    ////this.horizontal_diff=this.horizontal_constant*x/2;
                    //return -top+Math.max(0,y);
                    ////return -top
                    var diff = (this.parallax_constant - (bottom * 1 + middle) / 2);
                    //this.scale_diff=Math.max(0.9,Math.min(1,  1-  Math.max(0,diff+5)/(grid.card_height*1)   ));
                    //this.rotate_diff=-(1-  Math.max(0.5,Math.min(1,  1-  Math.max(0,diff-0)/(grid.card_height*4)   ))        )*160*this.horizontal_constant;
                    //this.horizontal_diff=-Math.max(0,diff)*this.rotate_diff*0.08;
                    //////console.log('this.horizontal_diff=',this.horizontal_diff);
                    //}

                    return -top + Math.max(0, diff); //-grid.cards_per_line*grid.card_height/2  )  ;
                    //}else{
                    //  return -top;
                    //}


                },

                card_index: count_cards_total,

                //reposition_internal_elements: function(top,middle,bottom){
                //
                //},
                commit_parallax: function(top, middle, bottom, hide) {
                    ////console.log(this.el);
                    //transform_y_scale(this.el, this.parallaxed_diff, this.scale_diff );
                    if (hide) {
                        transform_x_y_scale_rotate(this.el, this.horizontal_diff, this.parallaxed_diff * 10, this.scale_diff, this.rotate_diff);
                    } else {
                        transform_x_y_scale_rotate(this.el, this.horizontal_diff, this.parallaxed_diff, this.scale_diff, this.rotate_diff);
                    }

                    //this.reposition_internal_elements(top,middle,bottom);
                },
            }

            //$(this).css({'z-index': 2000-count_cards_total})
            count_cards_total++;


            //cards[card_id] = sections[card_id] =

        });

        var cards_array_shuffle = [];
        var ordered_cards_array = [];
        $.each(unordered_cards, function(key, card) {
            var position = card.el[0].getAttribute('data-position');
            if (position) {
                position = parseInt(position) - 1;
                ////console.log('position=',position);
                while (ordered_cards_array[position]) {
                    position++;
                }
                ordered_cards_array[position] = card;
                card.ordered = true;
            } else {
                cards_array_shuffle.push(card);
            }
        });

        function shuffle(o) {
            for (var j, x, i = o.length; i; j = Math.floor(Math.random() * i), x = o[--i], o[i] = o[j], o[j] = x);
            return o;
        }
        shuffle(cards_array_shuffle);
        var index = 0;
        $.each(cards_array_shuffle, function(key, card) {

            while (ordered_cards_array[index]) {
                index++;
            }
            ordered_cards_array[index] = card;
        });

        ////console.log('ordered_cards_array=',ordered_cards_array);

        index = 0;
        Array.prototype.forEach.call(ordered_cards_array, function(card, i) {

            var hidden = false;
            var active = false;
            if (is_short_width) { /** Mobile portrait */
                if (index > 0) {
                    hidden = true;
                }
            } else if (is_mobile) { /** Mobile landscape: show 2 cards only */
                if (index >= 4) {
                    hidden = true;
                }
            } else { /** Desktop */
                if (index >= 12) {
                    hidden = true;
                }
            }

            if (!hidden) {
                card.el.show();
                count_cards_showing++;
            }
            card.card_index = index;
            card.visible = !hidden;
            card.active = !hidden;
            card.hidden = hidden;


            cards[card.id] = sections[card.id] = card;
            index++;
        });



        if (is_short_width && is_mobile) {
            var grid_slider = {
                next_el: $('#cards_next'),
                prev_el: $('#cards_previous'),
                position: 0,
                destination: 0,
                reset: function() { /*suspectLoop();*/

                },
                update_destination: function(num) {
                    this.destination = num;
                },
                update_position: function() { /*suspectLoop();*/
                    var diff = (this.destination - this.position) / 2;
                    var maxmove = Math.max(0.08);
                    if (diff < -maxmove) diff = -maxmove;
                    if (diff > maxmove) diff = maxmove;

                    this.position += diff;
                    if (this.destination == 0 || this.destination == 1) {
                        if (Math.abs(this.destination - this.position) < 0.01) {
                            this.position = this.destination;
                        }
                    }
                },


                out_of_screen: true,
                commit_position: function() { /*suspectLoop();*/
                    var pos = this.position;
                    var slides = ordered_cards_array;
                    Array.prototype.forEach.call(slides, function(slide, i) { /*suspectLoop();*/
                        //addClass(element_el,className);
                        var el_pos = i - pos;
                        while (el_pos > 2) {
                            el_pos -= slides.length;
                        }
                        while (el_pos < -2) {
                            el_pos += slides.length;
                        }
                        //console.log('el_pos=',el_pos);
                        //console.log('slide.el=',slide.el);

                        if (el_pos <= -2 || el_pos >= 2) {
                            if (!slide.hidden) {
                                slide.hidden = true;
                                slide.el.hide();
                            }
                        } else {
                            if (slide.hidden) {
                                slide.hidden = false;
                                slide.el.show();
                                slide.el.removeClass('hidden');
                                slide.load();
                            }
                        }

                        if (!slide.hidden) {
                            transform_x_y_percent(slide.el, el_pos * 100, 0);
                        }



                    });

                    //this.el.style.opacity=this.position;
                    //
                    ////transform_x_y_percent([this.el],0,this.position*100);
                    ////transform_x_y_vwvh([this.menu_link_el],0,100+this.position*100);
                    //
                    //if(this.position==0){
                    //  if(!this.out_of_screen){
                    //    this.out_of_screen=true;
                    //    this.el.style.display='none';
                    //    //transform_x_y_percent(this.el,100,0);
                    //  }
                    //}else{
                    //  if(this.out_of_screen){
                    //    this.out_of_screen=false;
                    //    this.el.style.display='block';
                    //    //transform_x_y_percent(this.el,0,0);
                    //  }
                    //}

                },

                prev: function() {
                    var slides = ordered_cards_array;
                    //if(this.destination>0){
                    this.destination -= 1;
                    this.counter = 0;
                    this.check();
                    //}

                },
                next: function() {
                    var slides = ordered_cards_array;
                    //if(this.destination<(slides.length-1)){
                    this.destination += 1;
                    this.counter = 0;
                    this.check();
                    //}
                },

                check: function() {
                    //var slides=ordered_cards_array;
                    //if(this.destination>0){
                    //  this.prev_el.fadeIn();
                    //}else{
                    //  this.prev_el.fadeOut();
                    //}
                    //
                    //if(this.destination<(slides.length-1)){
                    //  this.next_el.fadeIn();
                    //}else{
                    //  this.next_el.fadeOut();
                    //}
                },

                //counter:0,
                update: function() {

                    //if( current_slug=='/' && !current_subsection && !grid_previous_hovered && !grid_next_hovered){
                    //  this.counter++;
                    //  if(this.counter>60*10){
                    //    this.next();
                    //  }
                    //}else{
                    //  this.counter=0;
                    //}
                    if (this.position !== this.destination) {
                        this.update_position();
                        this.commit_position();
                    }
                },

                //adapt: function(){
                //  var slides=this.slides;
                //  Array.prototype.forEach.call(slides, function(slide, i){ /*suspectLoop();*/
                //
                //    var img=slide.querySelectorAll('img');
                //    //console.log('img=',img);
                //    cover_container_by_replacing_if_needed(img[0],sections.header.get_background_width_value(),sections.header.get_background_height_value());
                //
                //  });
                //}
            };
        }



        //$.


        //sections.grid= {
        //  visible:true,
        //  active:true,
        //  el: $('#grid'),
        //  background: $('#grid_background'),
        //  get_background_width_value: function(){ return this.width_value},
        //  get_background_height_value: function(){ return this.height_value},
        //  accumulate: true,
        //
        //  //commit_el_width: function(){ this.el[0].style.width=this.width_value+'px'; },
        //  commit_el_height: function(){ this.el[0].style.height=this.height_value+'px'; },
        //
        //  height_value: 0,
        //  width_value: 0,
        //  top_value: 0,
        //  middle_value: 0,
        //  bottom_value: 0,
        //  parallaxed_top: 0,
        //  parallaxed_bottom: 0,
        //  get_parallax_diff: function(top,middle,bottom){ return -top; },
        //  reposition_internal_elements: function(top,middle,bottom){
        //
        //  },
        //};

        if (grid_slider) {
            sections.cards = {
                visible: true,
                active: true,
                always_visible: true,
                el: $('#cards'),
                background: null,
                accumulate: true,

                //commit_el_width: function(){ this.el[0].style.width=this.width_value+'px'; },
                //commit_el_height: function(){ this.el[0].style.height=this.height_value+'px'; },

                height_value: browserWidth,
                width_value: browserWidth,
                top_value: 0,
                middle_value: 0,
                bottom_value: 0,
                parallaxed_top: 0,
                parallaxed_bottom: 0,
                get_parallax_diff: function(top, middle, bottom) {

                    var diff = bottom - this.top_value;
                    ////console.log('diff=',diff);
                    if (diff < -300) {
                        diff = -300;
                    }
                    if (diff > 0) {
                        diff = 0;
                    }

                    return -top + diff;
                },
                //reposition_internal_elements: function(top,middle,bottom){
                //
                //},
                commit_parallax: function(top, middle, bottom, hide) {
                    transform_y(this.el, this.parallaxed_diff);
                    //this.reposition_internal_elements(top,middle,bottom);
                },
            };
        }


        sections.divider_before_products = {
            visible: true,
            active: true,
            always_visible: true,
            el: $('#divider_before_products'),
            background: null,
            accumulate: true,

            //commit_el_width: function(){ this.el[0].style.width=this.width_value+'px'; },
            //commit_el_height: function(){ this.el[0].style.height=this.height_value+'px'; },

            height_value: 6,
            width_value: 0,
            top_value: 0,
            middle_value: 0,
            bottom_value: 0,
            parallaxed_top: 0,
            parallaxed_bottom: 0,
            get_parallax_diff: function(top, middle, bottom) {

                var diff = bottom - this.top_value;
                ////console.log('diff=',diff);
                if (diff < -300) {
                    diff = -300;
                }
                if (diff > 0) {
                    diff = 0;
                }

                return -top + diff;
            },
            //reposition_internal_elements: function(top,middle,bottom){
            //
            //},
            commit_parallax: function(top, middle, bottom, hide) {
                transform_y(this.el, this.parallaxed_diff);
                //this.reposition_internal_elements(top,middle,bottom);
            },
        };

        var nutritional_opened = false;
        var current_product = 1;

        sections.products_detail = {
            visible: true,
            active: true,
            el: $('#products_detail'),
            //background: $('#products_detail_background'),
            //get_background_width_value: function(){ return this.width_value},
            //get_background_height_value: function(){ return this.height_value},
            accumulate: false,

            controls: {
                el: $('#products_controls'),
            },
            closer: {
                el: $('#products_close'),
            },
            bullets: [],

            //height_auto:true,
            calc_height: function() {

                if (is_short_width) {
                    //this.width_value=browserWidth*4;
                    this.height_value = Math.max(568, browserHeight);
                } else {
                    this.height_value = Math.round(browserWidth * this.height_ratio);
                    if (this.height_min && this.height_value < this.height_min) {
                        this.height_value = this.height_min;
                    }
                }
            },
            height_ratio: 621 / 1280,
            height_min: 580,

            //commit_el_width: function(){ this.el[0].style.width=this.width_value+'px'; },
            commit_el_height: function() {
                this.el[0].style.height = this.height_value + 'px';
            },

            height_value: 0,
            width_value: 0,
            top_value: 0,
            middle_value: 0,
            bottom_value: 0,
            parallaxed_top: 0,
            parallaxed_bottom: 0,
            get_parallax_diff: function(top, middle, bottom) {
                return -top; /*(top-this.top_value)/2;*/
            },

            el_title1: $('#products_detail_title1'),
            el_text1: $('#products_detail_text1'),
            el_title2: $('#products_detail_title2'),
            el_text2: $('#products_detail_text2'),
            el_title3: $('#products_detail_title3'),
            el_text3: $('#products_detail_text3'),
            el_title4: $('#products_detail_title4'),
            el_text4: $('#products_detail_text4'),
            el_title5: $('#products_detail_title5'),
            el_text5: $('#products_detail_text5'),
            el_title6: $('#products_detail_title6'),
            el_text6: $('#products_detail_text6'),
            el_title7: $('#products_detail_title7'),
            el_text7: $('#products_detail_text7'),
            el_title8: $('#products_detail_title8'),
            el_text8: $('#products_detail_text8'),
            el_title9: $('#products_detail_title9'),
            el_text9: $('#products_detail_text9'),
            el_title10: $('#products_detail_title10'),
            el_text10: $('#products_detail_text10'),
            el_title11: $('#products_detail_title11'),
            el_text11: $('#products_detail_text11'),
            el_title12: $('#products_detail_title12'),
            el_text12: $('#products_detail_text12'),

            el_title1_scale: 1,
            el_text1_scale: 1,
            el_title2_scale: 1,
            el_text2_scale: 1,
            el_title3_scale: 1,
            el_text3_scale: 1,
            el_title4_scale: 1,
            el_text4_scale: 1,
            el_title5_scale: 1,
            el_text5_scale: 1,
            el_title6_scale: 1,
            el_text6_scale: 1,
            el_title7_scale: 1,
            el_text7_scale: 1,
            el_title8_scale: 1,
            el_text8_scale: 1,
            el_title9_scale: 1,
            el_text9_scale: 1,
            el_title10_scale: 1,
            el_text10_scale: 1,
            el_title11_scale: 1,
            el_text11_scale: 1,
            el_title12_scale: 1,
            el_text12_scale: 1,

            el_more_info: $('#products_more_info'),
            el_view_video: $('#view-product-video'),
            el_nutritional: $('#products_nutritional'),

            backgrounds: {
                el: $('#products_detail_backgrounds'),
            },
            background_1: {
                el: $('#products_detail_backgrounds'),
            },
            background_2: {
                el: $('#products_detail_backgrounds'),
            },
            background_3: {
                el: $('#products_detail_backgrounds'),
            },
            background_4: {
                el: $('#products_detail_backgrounds'),
            },
            background_5: {
                el: $('#products_detail_backgrounds'),
            },
            background_6: {
                el: $('#products_detail_backgrounds'),
            },
            background_7: {
                el: $('#products_detail_backgrounds'),
            },
            background_8: {
                el: $('#products_detail_backgrounds'),
            },
            background_9: {
                el: $('#products_detail_backgrounds'),
            },
            background_10: {
                el: $('#products_detail_backgrounds'),
            },
            background_11: {
                el: $('#products_detail_backgrounds'),
            },
            background_12: {
                el: $('#products_detail_backgrounds'),
            },

            computer_element_positions: function() {

            },

            afterResize: function() {
                var titleScale = 0.7;

                transform_x_y_scale_rotate(this.el_title1, 0, 0, titleScale, 0);
                transform_x_y_scale_rotate(this.el_title2, 0, 0, titleScale, 0);
                transform_x_y_scale_rotate(this.el_title3, 0, 0, titleScale, 0);
                transform_x_y_scale_rotate(this.el_title4, 0, 0, titleScale, 0);
                transform_x_y_scale_rotate(this.el_title5, 0, 0, titleScale, 0);
                transform_x_y_scale_rotate(this.el_title6, 0, 0, titleScale, 0);

            },

            reposition_internal_elements: function(top, middle, bottom) {
                var diff = this.top_value + 0.125 * this.height_value - middle;
                ////console.log('diff',diff)
                var diff_abs = Math.abs(diff);

                var x_translate = this.hide_translate_position * browserWidth;
                ////console.log('y_translate=',y_translate);

                var y_value = diff / 20;
                transform_x_y_scale_rotate(this.el_title1, 0, y_value, this.el_title1_scale, 0);
                transform_x_y_scale_rotate(this.el_text1, 0, y_value, this.el_text1_scale, 0);
                transform_x_y_scale_rotate(this.el_title2, 0, y_value, this.el_title2_scale, 0);
                transform_x_y_scale_rotate(this.el_text2, 0, y_value, this.el_text2_scale, 0);
                transform_x_y_scale_rotate(this.el_title3, 0, y_value, this.el_title3_scale, 0);
                transform_x_y_scale_rotate(this.el_text3, 0, y_value, this.el_text3_scale, 0);
                transform_x_y_scale_rotate(this.el_title4, 0, y_value, this.el_title4_scale, 0);
                transform_x_y_scale_rotate(this.el_text4, 0, y_value, this.el_text4_scale, 0);
                transform_x_y_scale_rotate(this.el_title5, 0, y_value, this.el_title5_scale, 0);
                transform_x_y_scale_rotate(this.el_text5, 0, y_value, this.el_text5_scale, 0);
                transform_x_y_scale_rotate(this.el_title6, 0, y_value, this.el_title6_scale, 0);
                transform_x_y_scale_rotate(this.el_text6, 0, y_value, this.el_text6_scale, 0);
                transform_x_y_scale_rotate(this.el_title7, 0, y_value, this.el_title7_scale, 0);
                transform_x_y_scale_rotate(this.el_text7, 0, y_value, this.el_text7_scale, 0);
                transform_x_y_scale_rotate(this.el_title8, 0, y_value, this.el_title8_scale, 0);
                transform_x_y_scale_rotate(this.el_text8, 0, y_value, this.el_text8_scale, 0);
                transform_x_y_scale_rotate(this.el_title9, 0, y_value, this.el_title9_scale, 0);
                transform_x_y_scale_rotate(this.el_text9, 0, y_value, this.el_text9_scale, 0);
                transform_x_y_scale_rotate(this.el_title10, 0, y_value, this.el_title10_scale, 0);
                transform_x_y_scale_rotate(this.el_text10, 0, y_value, this.el_text10_scale, 0);
                transform_x_y_scale_rotate(this.el_title11, 0, y_value, this.el_title11_scale, 0);
                transform_x_y_scale_rotate(this.el_text11, 0, y_value, this.el_text11_scale, 0);
                transform_x_y_scale_rotate(this.el_title12, 0, y_value, this.el_title12_scale, 0);
                transform_x_y_scale_rotate(this.el_text12, 0, y_value, this.el_text12_scale, 0);

                transform_x_y_scale_rotate(this.el_more_info, 0, y_value, this.el_more_info, 0);
                transform_x_y_scale_rotate(this.el_view_video, 0, y_value, this.el_view_video, 0);
                transform_x_y_scale_rotate(this.el_nutritional, 0, y_value, this.el_nutritional, 0);

                var opacity_value = 1.5 - diff_abs / 500;
                opacity(this.el_title1, opacity_value);
                opacity(this.el_text1, opacity_value);
                opacity(this.el_title2, opacity_value);
                opacity(this.el_text2, opacity_value);
                opacity(this.el_title3, opacity_value);
                opacity(this.el_text3, opacity_value);
                opacity(this.el_title4, opacity_value);
                opacity(this.el_text4, opacity_value);
                opacity(this.el_title5, opacity_value);
                opacity(this.el_text5, opacity_value);
                opacity(this.el_title6, opacity_value);
                opacity(this.el_text6, opacity_value);
                opacity(this.el_title7, opacity_value);
                opacity(this.el_text7, opacity_value);
                opacity(this.el_title8, opacity_value);
                opacity(this.el_text8, opacity_value);
                opacity(this.el_title9, opacity_value);
                opacity(this.el_text9, opacity_value);
                opacity(this.el_title10, opacity_value);
                opacity(this.el_text10, opacity_value);
                opacity(this.el_title11, opacity_value);
                opacity(this.el_text11, opacity_value);
                opacity(this.el_title12, opacity_value);
                opacity(this.el_text12, opacity_value);
                // opacity(this.el_more_info, opacity_value );
                // opacity(this.el_view_video, opacity_value );
                opacity(this.el_nutritional, opacity_value);

                if (!(this.hide_translate_position_commited == this.hide_translate_position)) {

                    if (x_translate == 0) {
                        transform_x_y_not_3d(this.backgrounds.el, x_translate, 0);
                        //transform_x_y_not_3d(this.background_1.el, x_translate, 0 );
                        //transform_x_y_not_3d(this.background_2.el, x_translate, 0 );
                        //transform_x_y_not_3d(this.background_3.el, x_translate, 0 );
                        //transform_x_y_not_3d(this.background_4.el, x_translate, 0 );
                    } else {
                        transform_x_y(this.backgrounds.el, x_translate, 0);
                        //transform_x_y(this.background_1.el, x_translate, 0 );
                        //transform_x_y(this.background_2.el, x_translate, 0 );
                        //transform_x_y(this.background_3.el, x_translate, 0 );
                        //transform_x_y(this.background_4.el, x_translate, 0 );
                    }



                    this.hide_translate_position_commited = this.hide_translate_position;
                }

                /* Mobile landscape product background */
                if (is_mobile && is_short_width == false) {

                    var bg1 = $($('.background.desktop-only.products_detail_background1.mobile')[0]);
                    var bg2 = $($('.background.desktop-only.products_detail_background2.mobile')[0]);
                    var bg3 = $($('.background.desktop-only.products_detail_background3.mobile')[0]);
                    var bg4 = $($('.background.desktop-only.products_detail_background4.mobile')[0]);
                    var bg5 = $($('.background.desktop-only.products_detail_background5.mobile')[0]);
                    var bg6 = $($('.background.desktop-only.products_detail_background6.mobile')[0]);
                    var bg7 = $($('.background.desktop-only.products_detail_background7.mobile')[0]);
                    var bg8 = $($('.background.desktop-only.products_detail_background8.mobile')[0]);
                    var bg9 = $($('.background.desktop-only.products_detail_background9.mobile')[0]);
                    var bg10 = $($('.background.desktop-only.products_detail_background10.mobile')[0]);
                    var bg11 = $($('.background.desktop-only.products_detail_background11.mobile')[0]);
                    var bg12 = $($('.background.desktop-only.products_detail_background12.mobile')[0]);

                    /* Calculate the new image dimensions */
                    var imageWidth = 1280;
                    var imageHeight = 621;
                    var sectionHeight = 580;
                    var bgWidth = sectionHeight * imageWidth / imageHeight;
                    var leftOffset = (bgWidth - browserWidth) / 2;

                    /* It may be necessary to add a small offset in smaller screens */

                    bg1.css('width', bgWidth);
                    bg1.css('left', -leftOffset + 'px');
                    if (browserWidth <= 667) {
                        bg1.css('left', (-leftOffset - 60) + 'px');
                    }

                    bg2.css('width', bgWidth);
                    bg2.css('left', -leftOffset + 'px');
                    if (browserWidth <= 736) {
                        bg2.css('left', (-leftOffset - 140) + 'px');
                    }

                    bg3.css('width', bgWidth);
                    bg3.css('left', -leftOffset + 'px');
                    if (browserWidth <= 600) {
                        bg3.css('left', (-leftOffset - 30) + 'px');
                    }

                    bg4.css('width', bgWidth);
                    bg4.css('left', -leftOffset + 'px');
                    if (browserWidth <= 736) {
                        bg4.css('left', (-leftOffset + 140) + 'px');
                    }

                    var bg5_0 = $($('.background.desktop-only.products_detail_background5.mobile')[0]);
                    bg5_0.css('top', '0px');

                    bg5.css('width', bgWidth);
                    bg5.css('left', -leftOffset + 'px');
                    if (browserWidth <= 667) {
                        bg5.css('left', (-leftOffset - 100) + 'px');
                    }

                    bg6.css('width', bgWidth);
                    bg6.css('left', -leftOffset + 'px');
                    if (browserWidth <= 740) {
                        bg6.css('left', (-leftOffset - 160) + 'px');
                    }

                    bg7.css('width', bgWidth);
                    bg7.css('left', -leftOffset + 'px');
                    if (browserWidth <= 740) {
                        bg7.css('left', (-leftOffset - 160) + 'px');
                    }

                    bg8.css('width', bgWidth);
                    bg8.css('left', -leftOffset + 'px');
                    if (browserWidth <= 740) {
                        bg8.css('left', (-leftOffset - 160) + 'px');
                    }

                    bg9.css('width', bgWidth);
                    bg9.css('left', -leftOffset + 'px');
                    if (browserWidth <= 740) {
                        bg9.css('left', (-leftOffset - 160) + 'px');
                    }

                    bg10.css('width', bgWidth);
                    bg10.css('left', -leftOffset + 'px');
                    if (browserWidth <= 740) {
                        bg10.css('left', (-leftOffset - 160) + 'px');
                    }

                    bg11.css('width', bgWidth);
                    bg11.css('left', -leftOffset + 'px');
                    if (browserWidth <= 740) {
                        bg11.css('left', (-leftOffset - 160) + 'px');
                    }

                    bg12.css('width', bgWidth);
                    bg12.css('left', -leftOffset + 'px');
                    if (browserWidth <= 740) {
                        bg12.css('left', (-leftOffset - 160) + 'px');
                    }
                }

            },
            commit_parallax: function(top, middle, bottom, hide) {
                transform_y(this.el, this.parallaxed_diff);
                this.reposition_internal_elements(top, middle, bottom);
            },

            hide_translate_position: 1,
            hide_translate_position_commited: 1,

            animation: function() {
                this.hide_translate_position = 1 + sections.products.hide_translate_position;
                ////console.log('this.hide_translate_position=',this.hide_translate_position);
            },

            opened: false,
            hidden: false,

            open: function(id) {
                var was_closed = !this.opened;

                if (!this.opened) {
                    this.opened = true;
                    sections.products.close();
                    this.active = true;
                    this.hidden = false;
                    force_render_paralax_once = true;

                    this.el.show();
                }

                current_product = parseInt(id);
                //console.log('current_product=',current_product);

                image_cover_container($('.products_nutritional[rel="'+current_product+'"]'), sections.products_detail.width_value, sections.products_detail.height_value);

                if (nutritional_opened) {
                    $('.products_nutritional').fadeOut();
                    $('#products_nutritional_' + current_product).hide();
                    $('#products_nutritional_' + current_product).fadeIn();
                }

                // console.log(sections);

                sections.products_detail.background_1.deactivate();
                sections.products_detail.background_2.deactivate();
                sections.products_detail.background_3.deactivate();
                sections.products_detail.background_4.deactivate();
                sections.products_detail.background_5.deactivate();
                sections.products_detail.background_6.deactivate();
                sections.products_detail.background_7.deactivate();
                sections.products_detail.background_8.deactivate();
                sections.products_detail.background_9.deactivate();
                sections.products_detail.background_10.deactivate();
                sections.products_detail.background_11.deactivate();
                sections.products_detail.background_12.deactivate();

                sections.products_navigation.button_1.el[0].style.color = '';
                sections.products_navigation.button_2.el[0].style.color = '';
                sections.products_navigation.button_3.el[0].style.color = '';
                sections.products_navigation.button_4.el[0].style.color = '';
                sections.products_navigation.button_5.el[0].style.color = '';
                sections.products_navigation.button_6.el[0].style.color = '';
                sections.products_navigation.button_7.el[0].style.color = '';
                sections.products_navigation.button_8.el[0].style.color = '';
                sections.products_navigation.button_9.el[0].style.color = '';
                sections.products_navigation.button_10.el[0].style.color = '';
                sections.products_navigation.button_11.el[0].style.color = '';
                sections.products_navigation.button_12.el[0].style.color = '';

                switch (Number(id)) {
                    case 1:
                        products_aba.go(1);
                        sections.products_detail.background_1.activate();
                        dots_change(sections.products_detail.background_1);
                        sections.products_navigation.button_1.el[0].style.color = '#847140';

                        $('#view-product-video').show();
                        if (is_mobile && is_short_width) {
                            $('#products_more_info').css('top', '64px');
                        } else if (is_mobile && is_short_width == false) {
                            $('#products_more_info').css('top', '0px');
                            $('#products_more_info').css('left', 'auto');
                            $('#products_more_info').css('margin-left', '0');
                            $('#products_more_info').css('margin-right', '0');
                        } else {
                            $('#products_more_info').css('left', 'auto');
                            $('#products_more_info').css('margin-left', '0');
                            $('#products_more_info').css('margin-right', '0');
                        }
                        break;
                    case 2:
                        products_aba.go(2);
                        sections.products_detail.background_2.activate();
                        dots_change(sections.products_detail.background_2);
                        sections.products_navigation.button_2.el[0].style.color = '#847140';

                        $('#view-product-video').show();
                        if (is_mobile && is_short_width) {
                            $('#products_more_info').css('top', '64px');
                        } else if (is_mobile && is_short_width == false) {
                            $('#products_more_info').css('top', '0px');
                            $('#products_more_info').css('left', 'auto');
                            $('#products_more_info').css('margin-left', '0');
                            $('#products_more_info').css('margin-right', '0');
                        } else {
                            $('#products_more_info').css('left', 'auto');
                            $('#products_more_info').css('margin-left', '0');
                            $('#products_more_info').css('margin-right', '0');
                        }

                        break;
                    case 3:
                        products_aba.go(3);
                        sections.products_detail.background_3.activate();
                        dots_change(sections.products_detail.background_3);
                        sections.products_navigation.button_3.el[0].style.color = '#847140';

                        $('#view-product-video').show();
                        if (is_mobile && is_short_width) {
                            $('#products_more_info').css('top', '64px');
                        } else if (is_mobile && is_short_width == false) {
                            $('#products_more_info').css('top', '0px');
                            $('#products_more_info').css('left', 'auto');
                            $('#products_more_info').css('margin-left', '0');
                            $('#products_more_info').css('margin-right', '0');
                        } else {
                            $('#products_more_info').css('left', 'auto');
                            $('#products_more_info').css('margin-left', '0');
                            $('#products_more_info').css('margin-right', '0');
                        }

                        break;
                    case 4:
                        products_aba.go(4);
                        sections.products_detail.background_4.activate();
                        dots_change(sections.products_detail.background_4);
                        sections.products_navigation.button_4.el[0].style.color = '#847140';

                        $('#view-product-video').show();
                        if (is_mobile && is_short_width) {
                            $('#products_more_info').css('top', '64px');
                        } else if (is_mobile && is_short_width == false) {
                            $('#products_more_info').css('top', '0px');
                            $('#products_more_info').css('left', 'auto');
                            $('#products_more_info').css('margin-left', '0');
                            $('#products_more_info').css('margin-right', '0');
                        } else {
                            $('#products_more_info').css('left', 'auto');
                            $('#products_more_info').css('margin-left', '0');
                            $('#products_more_info').css('margin-right', '0');
                        }
                        break;
                    case 5:
                        products_aba.go(5);
                        sections.products_detail.background_5.activate();
                        dots_change(sections.products_detail.background_5);
                        sections.products_navigation.button_5.el[0].style.color = '#847140';

                        /* Product section setup: last 2 flavors don't have the play video button */
                        $('#view-product-video').hide();
                        if (is_mobile && is_short_width) {
                            // $('#products_more_info').css('top', '40px');
                        } else if (is_mobile && is_short_width == false) {
                            $('#products_more_info').css('top', '40px');
                            $('#products_more_info').css('left', '0');
                            $('#products_more_info').css('margin-left', 'auto');
                            $('#products_more_info').css('margin-right', 'auto');
                        } else {
                            $('#products_more_info').css('left', '0');
                            $('#products_more_info').css('margin-left', 'auto');
                            $('#products_more_info').css('margin-right', 'auto');
                        }

                        break;
                    case 6:
                        products_aba.go(6);
                        sections.products_detail.background_6.activate();
                        dots_change(sections.products_detail.background_6);
                        sections.products_navigation.button_6.el[0].style.color = '#847140';

                        $('#view-product-video').hide();
                        if (is_mobile && is_short_width) {
                            // $('#products_more_info').css('top', '40px');
                        } else if (is_mobile && is_short_width == false) {
                            $('#products_more_info').css('top', '40px');
                            $('#products_more_info').css('left', '0');
                            $('#products_more_info').css('margin-left', 'auto');
                            $('#products_more_info').css('margin-right', 'auto');
                        } else {
                            $('#products_more_info').css('left', '0');
                            $('#products_more_info').css('margin-left', 'auto');
                            $('#products_more_info').css('margin-right', 'auto');
                        }
                        break;
                    case 7:
                        products_aba.go(7);
                        sections.products_detail.background_7.activate();
                        dots_change(sections.products_detail.background_7);
                        sections.products_navigation.button_7.el[0].style.color = '#847140';

                        $('#view-product-video').hide();
                        if (is_mobile && is_short_width) {
                            // $('#products_more_info').css('top', '40px');
                        } else if (is_mobile && is_short_width == false) {
                            $('#products_more_info').css('top', '40px');
                            $('#products_more_info').css('left', '0');
                            $('#products_more_info').css('margin-left', 'auto');
                            $('#products_more_info').css('margin-right', 'auto');
                        } else {
                            $('#products_more_info').css('left', '0');
                            $('#products_more_info').css('margin-left', 'auto');
                            $('#products_more_info').css('margin-right', 'auto');
                        }
                        break;
                    case 8:
                        products_aba.go(8);
                        sections.products_detail.background_8.activate();
                        dots_change(sections.products_detail.background_8);
                        sections.products_navigation.button_8.el[0].style.color = '#847140';

                        $('#view-product-video').hide();
                        if (is_mobile && is_short_width) {
                            // $('#products_more_info').css('top', '40px');
                        } else if (is_mobile && is_short_width == false) {
                            $('#products_more_info').css('top', '40px');
                            $('#products_more_info').css('left', '0');
                            $('#products_more_info').css('margin-left', 'auto');
                            $('#products_more_info').css('margin-right', 'auto');
                        } else {
                            $('#products_more_info').css('left', '0');
                            $('#products_more_info').css('margin-left', 'auto');
                            $('#products_more_info').css('margin-right', 'auto');
                        }
                        break;
                    case 9:
                        products_aba.go(9);
                        sections.products_detail.background_9.activate();
                        dots_change(sections.products_detail.background_9);
                        sections.products_navigation.button_9.el[0].style.color = '#847140';

                        $('#view-product-video').hide();
                        if (is_mobile && is_short_width) {
                            // $('#products_more_info').css('top', '40px');
                        } else if (is_mobile && is_short_width == false) {
                            $('#products_more_info').css('top', '40px');
                            $('#products_more_info').css('left', '0');
                            $('#products_more_info').css('margin-left', 'auto');
                            $('#products_more_info').css('margin-right', 'auto');
                        } else {
                            $('#products_more_info').css('left', '0');
                            $('#products_more_info').css('margin-left', 'auto');
                            $('#products_more_info').css('margin-right', 'auto');
                        }
                        break;
                    case 10:
                        products_aba.go(10);
                        sections.products_detail.background_10.activate();
                        dots_change(sections.products_detail.background_10);
                        sections.products_navigation.button_10.el[0].style.color = '#847140';

                        $('#view-product-video').hide();
                        if (is_mobile && is_short_width) {
                            // $('#products_more_info').css('top', '40px');
                        } else if (is_mobile && is_short_width == false) {
                            $('#products_more_info').css('top', '40px');
                            $('#products_more_info').css('left', '0');
                            $('#products_more_info').css('margin-left', 'auto');
                            $('#products_more_info').css('margin-right', 'auto');
                        } else {
                            $('#products_more_info').css('left', '0');
                            $('#products_more_info').css('margin-left', 'auto');
                            $('#products_more_info').css('margin-right', 'auto');
                        }
                        break;
                    case 11:
                        products_aba.go(11);
                        sections.products_detail.background_11.activate();
                        dots_change(sections.products_detail.background_11);
                        sections.products_navigation.button_11.el[0].style.color = '#847140';

                        $('#view-product-video').hide();
                        if (is_mobile && is_short_width) {
                            // $('#products_more_info').css('top', '40px');
                        } else if (is_mobile && is_short_width == false) {
                            $('#products_more_info').css('top', '40px');
                            $('#products_more_info').css('left', '0');
                            $('#products_more_info').css('margin-left', 'auto');
                            $('#products_more_info').css('margin-right', 'auto');
                        } else {
                            $('#products_more_info').css('left', '0');
                            $('#products_more_info').css('margin-left', 'auto');
                            $('#products_more_info').css('margin-right', 'auto');
                        }
                        break;
                    case 12:
                        products_aba.go(12);
                        sections.products_detail.background_12.activate();
                        dots_change(sections.products_detail.background_12);
                        sections.products_navigation.button_12.el[0].style.color = '#847140';

                        $('#view-product-video').hide();
                        if (is_mobile && is_short_width) {
                            // $('#products_more_info').css('top', '40px');
                        } else if (is_mobile && is_short_width == false) {
                            $('#products_more_info').css('top', '40px');
                            $('#products_more_info').css('left', '0');
                            $('#products_more_info').css('margin-left', 'auto');
                            $('#products_more_info').css('margin-right', 'auto');
                        } else {
                            $('#products_more_info').css('left', '0');
                            $('#products_more_info').css('margin-left', 'auto');
                            $('#products_more_info').css('margin-right', 'auto');
                        }
                        break;
                }

                //if(current_background_object){
                //  for(var i=0; i<current_background_object.images.length; i++){
                //    var img=current_background_object.images[i];
                //    if(img.index==0){
                //      img.activate();
                //    }else{
                //      img.deactivate();
                //    }
                //  }
                //}

                if (was_closed) {
                    if (activated_image) {
                        activated_image.position = activated_image.destination;
                        activated_image.commit_position();
                    }
                }


                this.el.find('.products_detail_title, .products_detail_text').hide();

                $('#products_detail_title' + id).show();
                $('#products_detail_text' + id).show();
                //$('#products_symbol_'+id).show();

            },

            close: function() {
                if (this.opened) {
                    this.opened = false;

                    /* Map the current product back to the correct ones due to the order change */
                    // if (current_product == 4) {
                    //     current_product = 1;
                    // } else if (current_product == 3) {
                    //     current_product = 2;
                    // } else if (current_product == 2) {
                    //     current_product = 3;
                    // } else if (current_product == 1) {
                    //     current_product = 4;
                    // }

                    sections.products.open();
                }
            },

            finishedOpening: function() {

            },

            finishedClosing: function() {
                this.active = false;
                force_render_paralax_once = true;
                this.hidden = true;
                this.el.hide();

                if (current_background_object) {
                    for (var i = 0; i < current_background_object.images.length; i++) {
                        var img = current_background_object.images[i];
                        img.position = 0;
                        img.destination = 0;
                        img.commit_position();
                    }
                }
            },


            change_background: function(id) {

            },
        };

        sections.products = {
            visible: true,
            active: true,
            el: $('#products'),
            background: $('#products_background'),
            get_background_width_value: function() {
                return this.width_value
            },
            get_background_height_value: function() {
                return this.height_value
            },
            accumulate: true,

            //height_auto:true,
            calc_height: function() {
                if (is_short_width) {
                    this.width_value = browserWidth * 6;
                    this.height_value = Math.max(568, browserHeight);
                } else {
                    this.height_value = Math.round(browserWidth * this.height_ratio);
                    if (this.height_min && this.height_value < this.height_min) {
                        this.height_value = this.height_min;
                    }
                }

            },
            height_ratio: 621 / 1280,
            height_min: 580,

            commit_el_width: function() {
                this.el[0].style.width = this.width_value + 'px';
            },
            commit_el_height: function() {
                this.el[0].style.height = this.height_value + 'px';
            },

            height_value: 0,
            width_value: 0,
            top_value: 0,
            middle_value: 0,
            bottom_value: 0,
            parallaxed_top: 0,
            parallaxed_bottom: 0,
            get_parallax_diff: function(top, middle, bottom) {
                return -top; /*(top-this.top_value)/2;*/
            },

            el_title: $('#products_title'),
            el_text: $('#products_text'),

            el_title_scale: 1,
            el_text_scale: 1,

            computer_element_positions: function() {


            },

            afterResize: function() {
                /* Product menu: mobile landscape and <= 1024 */
                if (window.innerWidth >= 480 && window.innerWidth <= 1024) {
                    moveProductsLeft();

                    this.background.attr('src', '../images/products-background-fix.jpg');

                    /* Normal height calculation */
                    this.height_value = Math.round(browserWidth * this.height_ratio);
                    if (this.height_min && this.height_value < this.height_min) {
                        this.height_value = this.height_min;
                    }

                    // 1280 x 621
                    var imageWidth = window.innerWidth;
                    var imageHeight = imageWidth / 1280 * 621;

                    this.background.css('width', (imageWidth * 2) + 'px');
                    this.background.css('height', (imageHeight * 2) + 'px');
                    this.background.css('left', '0px');
                    $('#products').css('background-color', '#000');

                    /* Hide the product names (they're in the images) */
                    $('#products_name4').hide();
                    $('#products_name5').hide();
                    $('#products_name6').hide();

                    if (window.innerWidth >= 480 && window.innerWidth <= 568) {
                        this.background.css('top', '20px');
                        this.background.css('left', '-12px');
                    } else if (window.innerWidth > 568 && window.innerWidth <= 600) {
                        this.background.css('top', '20px');
                    } else if (window.innerWidth >= 700 && window.innerWidth < 768) {
                        this.background.css('top', '-40px');
                    } else if (window.innerWidth >= 768 && window.innerWidth < 860) {
                        this.background.css('top', '-60px');
                    } else if (window.innerWidth >= 860) {
                        this.background.css('top', '-140px');
                    }
                }

                /* Desktop */
                else if (window.innerWidth > 1024) {
                    moveProductsLeft();

                    /* Show the product names */
                    // $('#products_name1').show();
                    // $('#products_name2').show();
                    // $('#products_name3').show();
                    // $('#products_name4').show();
                    // $('#products_name5').show();
                    // $('#products_name6').show();
                    // $('#products_name7').show();
                    // $('#products_name8').show();
                    // $('#products_name9').show();
                    // $('#products_name10').show();
                    // $('#products_name11').show();
                    // $('#products_name12').show();
                } else if (window.innerWidth >= 370 && window.innerWidth < 420) {
                    /* Should be a simple css rule :( */
                    $('#products_background').css('left', '-37px');
                    $('#products_background').css('top', '-240px');
                } else if (window.innerWidth > 320 && window.innerWidth < 370) {
                    $('#products_background').css('left', '-26px');
                    $('#products_background').css('top', '-200px');
                } else if (window.innerWidth <= 320) {
                    $('#products_background').css('left', '-26px');
                    $('#products_background').css('top', '-140px');
                }
            },

            reposition_internal_elements: function(top, middle, bottom) {
                var diff = this.top_value + 0.125 * this.height_value - middle;
                var diff_abs = Math.abs(diff);

                var y_value = diff / 20;
                var x_translate = 0; //this.hide_translate_position*this.width_value;
                ////console.log('y_translate=',y_translate);
                transform_x_y_scale_rotate(this.el_title, x_translate, y_value, this.el_title_scale, 0);
                transform_x_y_scale_rotate(this.el_text, x_translate, y_value, this.el_text_scale, 0);

                var opacity_value = 1.5 - diff_abs / 500;
                opacity(this.el_title, opacity_value);
                opacity(this.el_text, opacity_value);
            },

            commit_parallax: function(top, middle, bottom, hide) {
                var x_translate = this.hide_translate_position * browserWidth;

                if (is_mobile) {
                    transform_x_y(this.el, x_translate, 0);
                } else {
                    if (hide) {
                        transform_x_y(this.el, x_translate, this.parallaxed_diff * 10);
                    } else {
                        transform_x_y(this.el, x_translate, this.parallaxed_diff);
                    }
                }

                this.reposition_internal_elements(top, middle, bottom);
            },


            hide_translate_position: 0,
            hide_translate_position_commited: 0,
            hide_translate_destination: 0,


            animation: function() {
                ////console.log('animation triggered');
                if (!(this.hide_translate_position == this.hide_translate_destination)) {
                    this.hide_translate_position = this.hide_translate_position + (this.hide_translate_destination - this.hide_translate_position) / 8;
                    if (Math.abs(this.hide_translate_destination - this.hide_translate_position) < 0.001) {
                        this.hide_translate_position = this.hide_translate_destination;
                        if (this.hide_translate_position < 0) {
                            this.finishedClosing();
                        } else {
                            this.finishedOpening();
                        }
                    }
                    ////console.log('this.hide_translate_position=',this.hide_translate_position);
                    force_render_paralax_once = true;
                }
            },

            opened: true,
            hidden: false,

            open: function() {
                if (!this.opened) {
                    this.opened = true;
                    this.active = true;
                    this.hidden = false;
                    this.hide_translate_destination = 0;
                    ////console.log('told to open products');
                    this.el.show();

                }
            },

            close: function() {
                if (this.opened) {
                    this.opened = false;
                    ////console.log('told to close products');
                    this.hide_translate_destination = -1;

                }
            },

            finishedOpening: function() {
                sections.products_detail.finishedClosing();
            },

            finishedClosing: function() {
                this.active = false;
                sections.products_detail.finishedOpening();
                this.hidden = true;
                force_render_paralax_once = true;
                ////console.log('finished closing products');
                this.el.hide();
            },

        };



        sections.products_navigation = {

            visible: true,
            active: true,
            el: $('#products_navigation'),
            background: null,
            //get_background_width_value: function(){ return this.width_value},
            //get_background_height_value: function(){ return this.height_value},
            accumulate: false,

            //height_auto:true,
            //calc_height: function(){
            //  //this.height_value=Math.round(browserWidth*this.height_ratio);
            //  //if(this.height_min && this.height_value<this.height_min){
            //  //  this.height_value=this.height_min;
            //  //}
            //},
            //height_ratio: 614/1280,
            //height_min: 500,

            //commit_el_width: function(){ this.el[0].style.width=this.width_value+'px'; },
            commit_el_height: function() {
                this.el[0].style.height = this.height_value + 'px';
            },

            height_value: 100,
            width_value: 0,
            top_value: 0,
            middle_value: 0,
            bottom_value: 0,
            parallaxed_top: 0,
            parallaxed_bottom: 0,
            get_parallax_diff: function(top, middle, bottom) {
                return -top - 100; /*(top-this.top_value)/2;*/
            },
            aba: {
                el: $('#products_aba'),
            },
            button_1: {
                el: $('.products_button[rel="1"]'),
            },
            button_2: {
                el: $('.products_button[rel="2"]'),
            },
            button_3: {
                el: $('.products_button[rel="3"]'),
            },
            button_4: {
                el: $('.products_button[rel="4"]'),
            },
            button_5: {
                el: $('.products_button[rel="5"]'),
            },
            button_6: {
                el: $('.products_button[rel="6"]'),
            },
            button_7: {
                el: $('.products_button[rel="7"]'),
            },
            button_8: {
                el: $('.products_button[rel="8"]'),
            },
            button_9: {
                el: $('.products_button[rel="9"]'),
            },
            button_10: {
                el: $('.products_button[rel="10"]'),
            },
            button_11: {
                el: $('.products_button[rel="11"]'),
            },
            button_12: {
                el: $('.products_button[rel="12"]'),
            },

            internal: {
                el: $('#products_navigation_animation'),
            },

            computer_element_positions: function() {


            },

            afterResize: function() {
                //this.el_title_scale=Math.min(1,browserWidth/1300);
            },

            hide_translate_position: 1,
            hide_translate_position_commited: 1,

            animation: function() {
                this.hide_translate_position = 1 + sections.products.hide_translate_position;
                ////console.log('this.hide_translate_position=',this.hide_translate_position);
            },


            reposition_internal_elements: function(top, middle, bottom) {


            },
            commit_parallax: function(top, middle, bottom, hide) {

                var x_translate = this.hide_translate_position * browserWidth;

                if (is_mobile) {
                    transform_x_y(this.el, 0, -100);
                    transform_x_y(this.internal.el, x_translate, 0);
                } else {
                    transform_x_y(this.el, x_translate, this.parallaxed_diff);
                }

                //transform_y(this.el, this.parallaxed_diff );
                this.reposition_internal_elements(top, middle, bottom);
            },


        };

        function bind_aba(obj, id, active, position) {
            obj.id = id;
            obj.active = active;
            obj.in_display = false;
            obj.activate = function(instantly) {
                ////console.log(obj.el[0].getAttribute('id'),'activate');
                if (!obj.active) {
                    obj.active = true;
                    if (!obj.in_display) {
                        obj.in_display = true;
                        obj.el[0].style.display = 'block';
                    }
                }

            };
            obj.deactivate = function(instantly) {
                ////console.log(obj.el[0].getAttribute('id'),'deactivate');
                if (obj.active) {
                    obj.active = false;
                    if (obj.in_display) {
                        obj.in_display = false;
                        obj.el[0].style.display = 'none';
                    }

                }
            }
        }

        var activated_image;

        function bind_products_image(obj) {
            obj.position = 0;
            obj.destination = 0;
            obj.update_destination = function(num) {
                ////console.log(obj.el[0].getAttribute('id'),'update_destination',num);
                obj.destination = num;
            };
            obj.update_position = function() {
                var diff = (obj.destination - obj.position) / 8;
                var maxmove = Math.max(0.08);
                if (diff < -maxmove) diff = -maxmove;
                if (diff > maxmove) diff = maxmove;

                obj.position += diff;

                if (Math.abs(obj.destination - obj.position) < 0.01) {
                    obj.position = obj.destination;
                }
            };
            obj.in_display = false;
            obj.commit_position = function() {

                obj.el.style.opacity = Math.round(Math.max(0, Math.min(1, obj.position)) * 100) / 100;
                if (obj.position == 0) {
                    if (obj.in_display) {
                        obj.in_display = false;
                        obj.el.style.display = 'none';
                    }
                } else {
                    if (!obj.in_display) {
                        obj.in_display = true;
                        obj.el.style.display = 'block';
                    }
                }
            };
            obj.active = false;
            obj.activate = function() {

                ////console.log(obj.el.getAttribute('id'),'activate');
                if (!obj.active) {
                    obj.active = true;

                    if (activated_image) {
                        activated_image.el.style.zIndex = 2561;
                    }

                    //obj.position=0;
                    activated_image = obj;

                    obj.update_destination(1);

                    activated_image.el.style.zIndex = 2562;
                }

            };
            obj.deactivate = function() {
                ////console.log(obj.el.getAttribute('id'),'deactivate');
                if (obj.active) {
                    obj.active = false;
                    obj.update_destination(0);
                }
            }
        }

        function bind_products_background(obj, id, active, position) {

            obj.id = id;
            obj.position = position;
            obj.destination = position;
            obj.update_destination = function(num) {
                ////console.log(obj.el[0].getAttribute('id'),'update_destination',num);
                obj.destination = num;
            };
            obj.update_position = function() {
                obj.position = obj.destination;
            };
            obj.in_display = false;
            obj.commit_position = function() {

            };
            obj.active = active;
            obj.activate = function(instantly) {
                ////console.log(obj.el[0].getAttribute('id'),'activate');
                if (!obj.active) {
                    obj.active = true;
                    obj.update_destination(1);
                }

            };
            obj.deactivate = function(instantly) {
                ////console.log(obj.el[0].getAttribute('id'),'deactivate');
                if (obj.active) {
                    obj.active = false;
                    obj.update_destination(0);
                }
            }

            obj.animate = function() {
                for (var i = 0; i < obj.images.length; i++) {
                    var img = obj.images[i];
                    if (img.position !== img.destination) {
                        img.update_position();
                        img.commit_position();
                    }
                }
            }

            obj.images = [];

            var imgs = obj.el[0].querySelectorAll('img.products_detail_background' + id);
            Array.prototype.forEach.call(imgs, function(img_el, i) {
                obj.images.push({
                    el: img_el,
                    isImage: true,
                    loaded: false,
                    completed: false,
                    index: i,
                    //fullscreen: hasClass(img_el,'fullscreen'),
                });


            });

            for (var i = 0; i < obj.images.length; i++) {
                var img = obj.images[i];
                bind_products_image(img);
            }

            if (!obj.loaded) {

                obj.loaded = true;
                var completed = true;

                if (obj.images.length) {
                    for (var i = 0; i < obj.images.length; i++) {
                        var img = obj.images[i];

                        completed = false;
                        ////console.log('img.el=',img.el);
                        img.loaded = true;

                        image_cover_container([img.el], browserWidth, sections.products.get_background_height_value());
                    }
                }

                obj.completed = completed;

            }
        }

        sections.divider_after_products = {
            visible: true,
            active: true,
            el: $('#divider_after_products'),
            background: null,
            accumulate: true,

            //commit_el_width: function(){ this.el[0].style.width=this.width_value+'px'; },
            //commit_el_height: function(){ this.el[0].style.height=this.height_value+'px'; },

            height_value: 6,
            width_value: 0,
            top_value: 0,
            middle_value: 0,
            bottom_value: 0,
            parallaxed_top: 0,
            parallaxed_bottom: 0,
            get_parallax_diff: function(top, middle, bottom) {
                return -top;
            },

            commit_parallax: function(top, middle, bottom, hide) {
                if (is_mobile) return;
                transform_y(this.el, this.parallaxed_diff);
                //this.reposition_internal_elements(top,middle,bottom);
            },
        };


        function initialize_products_controls() {
            sections.products_detail.bullets = [];
            var count_dots = 0;
            var bullets = sections.products_detail.controls.el[0].querySelectorAll('li.products_bullet');
            Array.prototype.forEach.call(bullets, function(bullet_el, i) {
                sections.products_detail.bullets.push({
                    el: bullet_el,
                    index: count_dots,
                    hover: false,
                    position: 0.4,
                    destination: 0.4,
                    active: false,
                    visible: false,
                });
                count_dots++;
            });

            for (var i = 0; i < sections.products_detail.bullets.length; i++) {
                var bullet = sections.products_detail.bullets[i];
                bind_bullet(bullet);
            }

            sections.products_detail.el.onmouseenter = function() {
                sections.products_detail.hover = true;
            }

            sections.products_detail.el.onmouseleave = function() {
                sections.products_detail.hover = false;
            }
        }

        var dot_clicked = -1;

        function change_bullet_to_index(new_index) {

            for (var i = 0; i < sections.products_detail.bullets.length; i++) {
                var item = sections.products_detail.bullets[i];
                if (item.visible) {
                    if (item.index == new_index) {
                        //item.destination=1;
                        item.active = true;
                        ////console.log('clicked ',bullet.index);
                        clicked_index = new_index;
                        current_active_dot = new_index;

                    } else {
                        //item.destination=0.4;
                        item.active = false;
                    }
                }
            }
            for (var i = 0; i < current_background_object.images.length; i++) {
                var img = current_background_object.images[i];
                if (img.index == new_index) {
                    img.activate();
                } else {
                    img.deactivate();
                }
            }
        }

        function bind_bullet(bullet) {

            bullet.el.onmouseenter = function() {
                bullet.hover = true;
                bullet.position = 1;
                bullet.destination = 1;
                bullet.commit_position();
            }

            bullet.el.onmouseleave = function() {
                bullet.hover = false;
            }

            function bullet_click() {


                var clicked_index = -1;
                for (var i = 0; i < sections.products_detail.bullets.length; i++) {
                    var item = sections.products_detail.bullets[i];
                    if (item.visible) {
                        if (item.index == bullet.index) {
                            //item.destination=1;
                            item.active = true;
                            ////console.log('clicked ',bullet.index);
                            clicked_index = bullet.index;
                            current_active_dot = bullet.index;

                        } else {
                            //item.destination=0.4;
                            item.active = false;
                        }
                    }
                }

                for (var i = 0; i < current_background_object.images.length; i++) {
                    var img = current_background_object.images[i];
                    if (img.index == clicked_index) {
                        img.activate();
                    } else {
                        img.deactivate();
                    }
                }

                //if(!sections.products_detail.active) return;
                //////console.log('bullet.index=',bullet.index);
                ////menu_open_section(bullet.target);
                //if( bullet.index !== scroll_x_destination ){
                //  dot_clicked=bullet.index;
                //  //scroll_x_destination=bullet.index;
                //  ////console.log('new scroll_x_destination=',scroll_x_destination);
                //}
                //mosaic[scroll_y_destination][scroll_x_destination]
            }

            bullet.el.onmousedown = function(evt) {
                if (evt.buttons == 2) return;
                bullet_click();
            };

            bullet.el.addEventListener('touchstart', function(evt) {
                bullet_click();
                evt.preventDefault();
            }, false);

            bullet.update_destination = function(num) {
                console.log('this=',this);
                this.destination = num;
            }

            bullet.update_position = function() {
                var diff = (this.destination - this.position) / 8;
                var maxmove = Math.max(0.08);
                if (diff < -maxmove) diff = -maxmove;
                if (diff > maxmove) diff = maxmove;

                this.position += diff;
                if (this.destination == 0 || this.destination == 1) {
                    if (Math.abs(this.destination - this.position) < 0.01) {
                        this.position = this.destination;
                    }
                }
            }

            bullet.commit_position = function() {
                bullet.el.style.opacity = Math.round(this.position * 10000) / 10000;
            }
        }

        var current_background_object = null;
        var count_active_dots;
        var current_active_dot = 0;

        function dots_change(background_object) {

            if (current_background_object) {
                for (var i = 0; i < current_background_object.images.length; i++) {
                    var img = current_background_object.images[i];
                    img.deactivate();
                }
            }

            current_active_dot = 0;
            current_background_object = background_object;


            for (var i = 0; i < current_background_object.images.length; i++) {
                var img = current_background_object.images[i];
                if (img.index == 0) {
                    img.activate();
                } else {
                    img.deactivate();
                }
            }

            count_active_dots = background_object.images.length;
            ////console.log('count_active_dots=',count_active_dots);

            //if(count_active_dots>1){
            //  //sections.products_detail.controls.activate();
            //  sections.products_detail.controls.el[0].style.display='block';
            //}else{
            //  sections.products_detail.controls.el[0].style.display='none';
            //  //sections.products_detail.controls.deactivate();
            //  return;
            //}

            for (var i = 0; i < sections.products_detail.bullets.length; i++) {
                var bullet = sections.products_detail.bullets[i];

                if (bullet.index >= count_active_dots) {
                    if (bullet.visible) {
                        bullet.visible = false;
                        bullet.el.style.display = 'none';
                    }
                } else if (bullet.index == 0) {
                    bullet.active = true;
                    if (!bullet.visible) {
                        bullet.visible = true;
                        bullet.el.style.display = 'block';
                    }
                } else {
                    bullet.active = false;
                    if (!bullet.visible) {
                        bullet.visible = true;
                        bullet.el.style.display = 'block';
                    }
                }
            }

            //reposition dots
            ////console.log('dots translate = ',-Math.round((count_active_dots*15)/2));
            if (is_short_width) {
                transform_x_y(sections.products_detail.controls.el, -Math.round((count_active_dots * 42) / 2), 0);
                sections.products_detail.controls.el[0].style.width = count_active_dots * 42 + 'px';
                sections.products_detail.controls.el[0].style.height = 1 * 42 + 'px';
            } else {
                transform_x_y(sections.products_detail.controls.el, 0, -Math.round((count_active_dots * 42) / 2));
                sections.products_detail.controls.el[0].style.height = count_active_dots * 42 + 'px';
                sections.products_detail.controls.el[0].style.width = 1 * 42 + 'px';
            }
        }

        function dots_updater() {
            for (var i = 0; i < sections.products_detail.bullets.length; i++) {
                var bullet = sections.products_detail.bullets[i];
                bullet.index = i;


                if (bullet.hover || bullet.active) {
                    bullet.destination = 1;
                } else {
                    bullet.destination = 0.4;
                }

                if (bullet.destination !== bullet.position) {
                    bullet.update_position();
                    bullet.commit_position();
                }
            }

        }

        sections.buy = {
            visible: true,
            active: true,
            el: $('#buy'),
            background: null, //$('#buy_background'),
            get_background_width_value: function() {
                return this.width_value
            },
            get_background_height_value: function() {
                return this.height_value
            },
            accumulate: true,

            //height_auto:true,
            calc_height: function() {
                if (is_short_width) {
                    this.height_value = Math.max(browserHeight, 400);
                } else {
                    this.height_value = Math.round(browserWidth * this.height_ratio);
                    if (this.height_min && this.height_value < this.height_min) {
                        this.height_value = this.height_min;
                    }
                }
            },
            height_ratio: 480 / 1440,
            height_min: 480,

            //commit_el_width: function(){ this.el[0].style.width=this.width_value+'px'; },
            commit_el_height: function() {
                this.el[0].style.height = this.height_value + 'px';
            },

            height_value: 0,
            width_value: 0,
            top_value: 0,
            middle_value: 0,
            bottom_value: 0,
            parallaxed_top: 0,
            parallaxed_bottom: 0,
            get_parallax_diff: function(top, middle, bottom) {
                return -top;
            },

            el_title: $('#buy_title'),
            el_text: $('#buy_text'),
            el_button: $('#buy_button'),

            el_title_scale: 1,
            el_text_scale: 1,



            afterResize: function() {
                //this.el_title_scale=Math.min(1,browserWidth/1300);
            },

            reposition_internal_elements: function(top, middle, bottom) {
                var diff = this.middle_value - middle;
                var diff_abs = Math.abs(diff);

                var y_value = diff / 20;
                transform_x_y_scale_rotate(this.el_title, 0, y_value, this.el_title_scale, 0);
                transform_x_y_scale_rotate(this.el_text, 0, y_value, this.el_text_scale, 0);
                transform_x_y_scale_rotate(this.el_button, 0, y_value, this.el_text_scale, 0);

                var opacity_value = 1.5 - diff_abs / 500;
                opacity(this.el_title, opacity_value);
                opacity(this.el_text, opacity_value);
                opacity(this.el_button, opacity_value);

            },
            commit_parallax: function(top, middle, bottom, hide) {
                if (is_mobile) return;
                transform_y(this.el, this.parallaxed_diff);
                this.reposition_internal_elements(top, middle, bottom);
            },
        };

        sections.footer = {
            visible: true,
            active: true,
            el: $('#footer'),
            background: null,
            accumulate: true,
            subsection: 'any',

            //commit_el_width: function(){ this.el[0].style.width=this.width_value+'px'; },
            // commit_el_height: function(){this.el[0].style.height=this.height_value+'px';},

            height_value: 60,
            width_value: 0,
            top_value: 0,
            middle_value: 0,
            bottom_value: 0,
            parallaxed_top: 0,
            parallaxed_bottom: 0,
            get_parallax_diff: function(top, middle, bottom) {
                return -top;
            },
            reposition_internal_elements: function(top, middle, bottom) {

            },

            commit_parallax: function(top, middle, bottom, hide) {
                if (is_mobile) return;
                transform_y(this.el, this.parallaxed_diff);
                this.reposition_internal_elements(top, middle, bottom);
            },
        };


        var browserWidth = 0;
        var browserHeight = 0;

        var main_resize_handler = function() {

                browserWidth = $(window).width();
                browserHeight = $(window).height();
                calc_dpr();

                var new_is_short_width = browserWidth < smallScreenWidth;

                if (new_is_short_width !== is_short_width) {
                    location.reload();
                }

                grid.recalc();

                globalScrollTop_eased_rounded_old = null;

                var accumulated_height = 0;

                $.each(sections, function(key, section) {

                    //if(!section.active) return;

                    if (section.subsection == 'any') {
                        //always render
                        //console.log('always show ',key);
                    } else {
                        if (current_subsection && !section.subsection) {
                            //does not render
                            //console.log('does not show ',key);
                            section.el[0].style.display = 'none';
                            return;

                        } else if (!current_subsection && !section.subsection) {
                            //console.log('show2 ',key);
                            if (section.visible && section.active) {
                                section.el[0].style.display = 'block';
                            }
                        } else {
                            if (current_subsection === section.subsection) {
                                //it is the same, render
                                //console.log('show ',key);
                                if (section.visible && section.active) {
                                    section.el[0].style.display = 'block';
                                }

                            } else {
                                //not the same subsection
                                //console.log('not the same subsection so hide',key);
                                section.el[0].style.display = 'none';
                                return;
                            }
                        }
                    }

                    section.top_value = Math.round(accumulated_height);
                    section.el[0].style.top = section.top_value + 'px';

                    section.width_value = browserWidth;

                    if (section.calc_height) {
                        //set new height
                        section.calc_height();
                        //section.el[0].style.height=section.height_value+'px';
                        section.commit_el_height();
                    } else {
                        section.height_value = section.el.height();
                    }

                    if (section.width_auto) {
                        section.width_value = Math.round(browserWidth);
                        section.commit_el_width();
                    }




                    section.bottom_value = Math.round(section.top_value + section.height_value);
                    section.middle_value = (section.bottom_value + section.top_value) / 2;

                    if (section.accumulate) {
                        accumulated_height += section.height_value;
                    }



                    if (section.background && section.background.length) {
                        image_cover_container(section.background, section.get_background_width_value(), section.get_background_height_value());
                    }

                    if (section.computer_element_positions) section.computer_element_positions();

                    ////console.log('accumulated_height=',accumulated_height);
                });

                body.height_value = Math.round(accumulated_height);

                if (allow_body_size) {
                    body.commit();
                }

                $.each(sections, function(key, section) {
                    section.visible = true;
                });
                $.each(sections, function(key, section) {
                    if (section.afterResize) section.afterResize();
                });


                /**
                 * We apply this restriction to prevent this code from running on mobile landscape.
                 * If it does, when the visibility status of the mobile browsers' address bars changes (shows up
                 * or hides), the height of the images is recalculated, fucking everything up.
                 */
                if (is_mobile == false || (is_mobile && is_short_width)) {
                    sections.products_detail.el.find('img').each(function() {
                        //sections.products.get_background_width_value()
                        image_cover_container($(this), browserWidth, sections.products.get_background_height_value());
                    });
                } else {
                    fixStorytellingLandscape(is_mobile, is_short_width, current_slug);
                }

                //if(main_loader_completed){
                //  storytelling_slider.adapt();
                //}

                treshold_buy = Math.min(body.height_value - browserHeight, sections.buy.top_value) - 100;
                treshold_products = (sections.products.top_value - (browserHeight - sections.products.height_value) / 2 - 50);
                treshold_wall = sections.wall.top_value - 100;
            }
            //add_resize_handler(main_resize_handler,0);




        var animating_globalScrollTop = false;
        var globalScrollTop_destination = 0;
        var globalScrollTop = $(window).scrollTop();
        var globalScrollTop_old = globalScrollTop;
        var globalScrollTop_eased = globalScrollTop;
        var globalScrollTop_eased_rounded = globalScrollTop;
        var globalScrollTop_eased_rounded_old = 0;
        var force_render_paralax_once = false;
        var visible_top = 0;
        var visible_bottom = 0;
        var visible_middle = 0;

        //var scrollHandlersByPriority=[[],[],[],[],[],[]];

        if (is_mobile) {
            //$('body')[0].addEventListener('touchmove', function(){
            //  if(!animating_globalScrollTop){
            //    globalScrollTop=$(window).scrollTop()
            //  }
            //}, false);

            //$('body').bind('touchmove', function(e) {
            //  if(!animating_globalScrollTop){
            //    globalScrollTop_eased_rounded=globalScrollTop=$(window).scrollTop()
            //  }
            //
            //});
            //}else{
        } else {
            $(document).scroll(function() {
                if (!animating_globalScrollTop) {
                    globalScrollTop = $(window).scrollTop()
                }
            });
            $(window).scroll(function() {
                if (!animating_globalScrollTop) {
                    globalScrollTop = $(window).scrollTop()
                }
            });
        }
        //}


        var treshold_buy;
        var treshold_products;
        var treshold_wall;
        var count_measure_scroll_top = 0;
        var force_scroll_to_top = 5;
        var updater_count = 0;
        var first_run = true;
        var updater_fullfill_subcriptions = function(forceParalaxRender) {
            updater_count++;

            //switch(updater_count){
            //  //removepackshots//case 1:  bind_scalable(sections.products_navigation.packshot_1,             '1', true,   1 );  break;
            //  //removepackshots//case 2:  bind_scalable(sections.products_navigation.packshot_2,             '2', true,   1 );  break;
            //  //removepackshots//case 3:  bind_scalable(sections.products_navigation.packshot_3,             '3', true,   1 );  break;
            //  //removepackshots//case 4:  bind_scalable(sections.products_navigation.packshot_4,             '4', true,   1 );  break;
            //  //remove-products-symbol//case 5:  bind_scalable(sections.products_navigation.symbol_1,               '1', false,  0 );   break;
            //  //remove-products-symbol//case 6:  bind_scalable(sections.products_navigation.symbol_2,               '2', false,  0 );   break;
            //  //remove-products-symbol//case 7:  bind_scalable(sections.products_navigation.symbol_3,               '3', false,  0 );   break;
            //  //remove-products-symbol//case 8:  bind_scalable(sections.products_navigation.symbol_4,               '4', false,  0 );   break;
            //}



            if (current_subsection_old === current_subsection) {
                //do nothing
            } else {

                //console.log('change to subsection ', current_subsection);

                main_resize_handler();

                current_subsection_old = current_subsection;

                if (!current_subsection) {
                    go_to_path(current_subsection_back_to_path, true);
                    current_subsection_back_to_path = '/';
                } else {
                    current_subsection_back_to_path = current_slug;
                    globalScrollTop_destination = globalScrollTop = globalScrollTop_old = globalScrollTop_eased = globalScrollTop_eased_rounded = globalScrollTop_eased_rounded_old = 0;
                    force_scroll_to_top = 5;
                }

                force_render_paralax_once = true;


                needs_resize = false;

            }

            if (needs_resize) {
                main_resize_handler();
                needs_resize = false;
                return;
            }

            if (force_scroll_to_top > 0) {
                force_scroll_to_top--;
                $(window).scrollTop(0);
                //console.log('scroll to top');
            }

            if ( /*sections.buy.visible &&*/ updater_count > 5) {
                run_map();
            }

            if (animating_globalScrollTop) {

                globalScrollTop = globalScrollTop_destination;
                //console.log('animating_globalScrollTop=',globalScrollTop);
                ////console.log('animating scrolltop',globalScrollTop);
                $(window).scrollTop(globalScrollTop_eased);
                if (Math.abs(globalScrollTop_eased - globalScrollTop_destination) < 2) {
                    animating_globalScrollTop = false;
                    ////console.log('stop animating scrolltop');
                }
            } else {
                if (is_mobile) {
                    count_measure_scroll_top++;
                    if (count_measure_scroll_top > 10) {
                        count_measure_scroll_top = 0;
                        globalScrollTop = $(window).scrollTop();
                    }

                }
            }

            globalScrollTop_eased += (globalScrollTop - globalScrollTop_eased) / 8;
            globalScrollTop_eased_rounded = Math.round(globalScrollTop_eased);

            if (!animating_globalScrollTop && intro_completed) {
                var new_slug = '/';

                if (current_subsection) {
                    switch (current_subsection) {
                        case 2:
                            new_slug = '/harmonizacoes_cioccolato_nero/';
                            break;
                        case 1:
                            new_slug = '/harmonizacoes_vaniglia/';
                            break;
                        case 3:
                            new_slug = '/harmonizacoes_caramello_salato/';
                            break;
                        case 4:
                            new_slug = '/harmonizacoes_limoncello/';
                            break;
                        case 5:
                            new_slug = '/harmonizacoes_pistacchio/';
                            break;
                        case 6:
                            new_slug = '/harmonizacoes_panna_cotta/';
                            break;
                        case 7:
                            new_slug = '/harmonizacoes_gianduia/';
                            break;
                        case 8:
                            new_slug = '/harmonizacoes_fragola/';
                            break;
                        case 9:
                            new_slug = '/harmonizacoes_cappuccino/';
                            break;
                        case 10:
                            new_slug = '/harmonizacoes_limoncello_picole/';
                            break;
                        case 11:
                            new_slug = '/harmonizacoes_pisctacchio_picole/';
                            break;
                        case 12:
                            new_slug = '/harmonizacoes_fragola_picole/';
                            break;
                    }
                } else if (globalScrollTop_eased_rounded > treshold_buy) {
                    new_slug = '/dove_trovare/';

                } else if (globalScrollTop_eased_rounded > treshold_products) {
                    new_slug = '/isapori/';

                    if (sections.products_detail.opened) {
                        if (current_product == 2) {
                            new_slug = '/cioccolato_nero/';
                        } else if (current_product == 1) {
                            new_slug = '/vaniglia/';
                        } else if (current_product == 3) {
                            new_slug = '/caramello_salato/';
                        } else if (current_product == 4) {
                            new_slug = '/limoncello/';
                        } else if (current_product == 5) {
                            new_slug = '/pistacchio/';
                        } else if (current_product == 6) {
                            new_slug = '/panna_cotta/';
                        } else if (current_product == 7) {
                            new_slug = '/gianduia/';
                        } else if (current_product == 8) {
                            new_slug = '/fragola/';
                        } else if (current_product == 9) {
                            new_slug = '/cappuccino/';
                        } else if (current_product == 10) {
                            new_slug = '/limoncello_picole/';
                        } else if (current_product == 11) {
                            new_slug = '/pisctacchio_picole/';
                        } else if (current_product == 12) {
                            new_slug = '/fragola_picole/';
                        }
                    }

                } else if (globalScrollTop_eased_rounded > treshold_wall) {
                    new_slug = '/la_mia_gelateria/';
                }
                if (new_slug !== current_slug) {
                    current_slug = new_slug;
                    if (window.history && window.history.pushState) {
                        window.history.pushState('', document.title, new_slug);
                    }

                    /**
                     * Several fixes needed to make the Storytelling section work on mobile landscape
                     */
                    fixStorytellingLandscape(is_mobile, is_short_width, current_slug);
                    fixFooterPosition(is_mobile, current_slug, already_fixed_footer);
                }


            }

            visible_top = globalScrollTop_eased_rounded;
            visible_bottom = visible_top + browserHeight;
            visible_middle = (visible_bottom + visible_top) / 2;

            if (menu.position !== menu.destination) {
                menu.update_position();
                menu.commit_position();
            }

            if (sections.products_detail.opened || sections.products_detail.hide_translate_position !== 1) {
                if (sections.products_detail.backgrounds.position !== sections.products_detail.backgrounds.destination) {
                    sections.products_detail.backgrounds.update_position();
                    sections.products_detail.backgrounds.commit_position();
                }

                sections.products_detail.background_1.animate();
                sections.products_detail.background_2.animate();
                sections.products_detail.background_3.animate();
                sections.products_detail.background_4.animate();
                sections.products_detail.background_5.animate();
                sections.products_detail.background_6.animate();
                sections.products_detail.background_7.animate();
                sections.products_detail.background_8.animate();
                sections.products_detail.background_9.animate();
                sections.products_detail.background_10.animate();
                sections.products_detail.background_11.animate();
                sections.products_detail.background_12.animate();

                dots_updater();
            }

            if (products_background.position !== products_background.destination) {
                products_background.update_position();
                products_background.commit_position();
            }


            sections.products.animation();
            sections.products_detail.animation();
            sections.products_navigation.animation();

            if (grid_slider) {
                grid_slider.update();
            }


            if (is_mobile) {
                if (forceParalaxRender || sections.products_detail.opened || sections.products_detail.hide_translate_position !== 1) {

                    if (!current_subsection) {
                        sections.products.commit_parallax();
                        sections.products_detail.commit_parallax();
                        sections.products_navigation.commit_parallax();
                    }
                }
            } else {
                if (forceParalaxRender || (globalScrollTop_eased_rounded !== globalScrollTop_eased_rounded_old) || force_render_paralax_once) {
                    $.each(sections, function(key, section) {

                        if (section.subsection == 'any') {
                            //always render
                            //console.log('always render ',key);
                        } else {
                            if (current_subsection && !section.subsection) {
                                //does not render
                                //console.log('does not render ',key);
                                return;

                            } else if (!current_subsection && !section.subsection) {
                                //console.log('show2 ',key);


                            } else {
                                if (current_subsection === section.subsection) {
                                    //it is the same, render
                                    //console.log('render ',key);
                                } else {
                                    //not the same subsection
                                    //console.log('not the same subsection ',key);
                                    return;
                                }
                            }
                        }
                        if (!section.active && !section.always_visible) return;

                        ////console.log('try');
                        section.parallaxed_diff = section.get_parallax_diff(visible_top, visible_middle, visible_bottom);

                        section.parallaxed_top = Math.round(section.top_value + section.parallaxed_diff + visible_top);
                        section.parallaxed_bottom = Math.round(section.bottom_value + section.parallaxed_diff + visible_top);



                        var visible;

                        if (section.hidden) {
                            visible = false;
                            section.visible = true;
                            //console.log('something hidden here and it is ',key);
                        } else if (section.always_visible) {
                            visible = true;
                            section.visible = true;
                        } else if (section.parallaxed_top > visible_bottom) {
                            //section.el[0].style.display='none';
                            visible = false;
                        } else if (section.parallaxed_bottom < visible_top) {
                            //section.el[0].style.display='none';
                            visible = false;
                        } else {
                            visible = true;
                            section.visible = true;
                            //section.el[0].style.display='block';
                        }
                        if (section.visible) {
                            //
                            if (!visible) {
                                section.commit_parallax(visible_top, visible_middle, visible_bottom, true);
                            } else {
                                section.commit_parallax(visible_top, visible_middle, visible_bottom, false);
                            }

                        }
                        section.visible = visible;

                        //section.el.attr($.extend(section,{
                        //  'visible_top': visible_top,
                        //  'visible_bottom': visible_bottom
                        //}));


                        ////console.log('accumulated_height=',accumulated_height);
                    });

                    globalScrollTop_eased_rounded_old = globalScrollTop_eased_rounded;


                }
            }

            /*
          var tmp_subscriptions_object=updater_subscriptions_object;
          var tmp_subscriptions_array=updater_subscriptions_array;
          updater_subscriptions_object={};
          updater_subscriptions_array=[];
          $.each( tmp_subscriptions_object, function( key, value ) {
              ////console.log( key );
              value();
          });
          $.each( tmp_subscriptions_array, function( index, value ) {
              ////console.log( index );
              value();
          });
      */

            if (first_run) {
                first_run = false;
                //if(wrapper.el.length){
                //  wrapper.el.removeClass('hidden');
                //}
                $.each(sections, function(key, section) {
                    if (!section.active) return;
                    section.visible = true;
                    section.el.removeClass('hidden');
                });


            }
        }

        var sharebox = false;


        function share(card) {

            if (!sharebox) {
                sharebox =   {
                    el: $('#share'),
                    close_el: $('#share_close'),
                    title_el: $('#share_title'),
                    text_el: $('#share_text'),
                    facebook_el: $('#share_facebook'),
                    twitter_el: $('#share_twitter'),

                    card: null,
                    open: function() {
                        sharebox.el.fadeIn();
                    },

                    close: function() {
                        sharebox.el.fadeOut();
                    },
                }

                sharebox.close_el.on('touchstart mousedown', function() {
                    sharebox.close();
                });

                sharebox.facebook_el.on('click', function() {
                    ////console.log('share on facebook');
                    var winWidth = 520;
                    var winHeight = 350;
                    var winTop = (screen.height / 2) - (winHeight / 2);
                    var winLeft = (screen.width / 2) - (winWidth / 2);
                    var url = 'http://www.nestlegelato.com.br' + sharebox.card.data('permalink');
                    //url='http://www.google.com';
                    //window.open('http://www.facebook.com/sharer.php?s=100&p[title]=' + title + '&p[summary]=' + descr + '&p[url]=' + url + '&p[images][0]=' + image, 'sharer', 'top=' + winTop + ',left=' + winLeft + ',toolbar=0,status=0,width=' + winWidth + ',height=' + winHeight);
                    window.open('http://www.facebook.com/sharer.php?s=100&p[title]=' + '&p[url]=' + url, 'sharer', 'top=' + winTop + ',left=' + winLeft + ',toolbar=0,status=0,width=' + winWidth + ',height=' + winHeight);

                });

                sharebox.twitter_el.on('click', function() {
                    //console.log('share on twitter');



                    var winWidth = 520;
                    var winHeight = 253;
                    var winTop = (screen.height / 2) - (winHeight / 2);
                    var winLeft = (screen.width / 2) - (winWidth / 2);
                    var url = 'https://twitter.com/intent/tweet?text=' + encodeURI('Nestlé Gelato. Inspirado nas autênticas gelaterias italianas. L\'arte italiana. Per te. ') + escape('http://www.nestlegelato.com.br' + sharebox.card.data('permalink'));
                    //url='http://www.google.com';
                    //window.open('http://www.facebook.com/sharer.php?s=100&p[title]=' + title + '&p[summary]=' + descr + '&p[url]=' + url + '&p[images][0]=' + image, 'sharer', 'top=' + winTop + ',left=' + winLeft + ',toolbar=0,status=0,width=' + winWidth + ',height=' + winHeight);
                    window.open(url, 'sharer', 'top=' + winTop + ',left=' + winLeft + ',toolbar=0,status=0,width=' + winWidth + ',height=' + winHeight);
                });

            }

            sharebox.card = card;
            sharebox.open();


        }



        var updater_run = function() {
            ////console.log('animator run');
            window.requestAnimationFrame(updater_run);
            updater_fullfill_subcriptions();
        }




        //removepackshots//sections.products_navigation.el.each(function(){
        //removepackshots// $(this).find('.products_packshot,.products_button,.products_symbol').on('click',function(){
        //removepackshots//   ////console.log('clicou ',$(this).attr('rel'));
        //removepackshots//   sections.products_detail.open($(this).attr('rel'));
        //removepackshots// });
        //removepackshots//});

        //sections.products_navigation.el.each(function(){




        var map = {
            initialized: false,
            el: document.getElementById("map"),
            gmap: null,
            initialLocation: null,
            geolocationInitialized: false,
            markersInitialized: false,
            youMarker: null,
            lastLat: ' -23.5505199',
            lastLng: '-46.63330939999997',
            pdvList: null,

            initializeMarkers: function() {
                if (map.markersInitialized) {
                    return;
                }
                map.markersInitialized = true;

                //Read markers file
                $.get("/markers.json", {}, function(data) {
                    map.pdvList = data;
                }, "json");
            },

            putYouMarker: function(latLng) {
                //console.log('latLng=',latLng);
                map.lastLat = latLng.lat();
                map.lastLng = latLng.lng();
                if (map.youMarker) {
                    map.youMarker.setPosition(latLng);
                } else {
                    map.youMarker = new google.maps.Marker({
                        position: latLng,
                        map: map.gmap,
                        title: 'Você',
                        icon: {
                            url: '/images/icons/you.png',
                            scaledSize: new google.maps.Size(55, 40), // scaled size
                            origin: new google.maps.Point(0, 0), // origin
                            anchor: new google.maps.Point(54 / 2, 40) // anchor
                        },
                    });
                }
            },

            initializeGeolocation: function() {
                if (!map.geolocationInitialized) {
                    map.geolocationInitialized = true;
                    if (navigator.geolocation) {
                        browserSupportFlag = true;
                        navigator.geolocation.getCurrentPosition(function(position) {
                            map.initialLocation = new google.maps.LatLng(position.coords.latitude, position.coords.longitude);
                            map.gmap.setZoom(16);
                            map.gmap.setCenter(map.initialLocation);
                            map.putYouMarker(map.initialLocation);
                            map.updateMarkers();

                        }, function() {
                            // Update markers regardless of geolocation permission
                            map.updateMarkers();
                        });
                    } else {
                        // Update markers regardless of geolocation capabilities
                        map.updateMarkers();
                    }
                }
            },

            initialize: function() {

                var customMapType = new google.maps.StyledMapType([{
                    "featureType": "all",
                    "elementType": "labels.text.fill",
                    "stylers": [{
                        "saturation": 36
                    }, {
                        "color": "#4d4d4d"
                    }, {
                        "lightness": 0
                    }]
                }, {
                    "featureType": "all",
                    "elementType": "labels.text.stroke",
                    "stylers": [{
                        "visibility": "on"
                    }, {
                        "color": "#101010"
                    }, {
                        "lightness": 0
                    }]
                }, {
                    "featureType": "all",
                    "elementType": "labels.icon",
                    "stylers": [{
                        "visibility": "off"
                    }]
                }, {
                    "featureType": "administrative",
                    "elementType": "geometry.fill",
                    "stylers": [{
                        "color": "#171717"
                    }, {
                        "lightness": 0
                    }]
                }, {
                    "featureType": "administrative",
                    "elementType": "geometry.stroke",
                    "stylers": [{
                        "color": "#171717"
                    }, {
                        "lightness": 0
                    }, {
                        "weight": 1.2
                    }]
                }, {
                    "featureType": "landscape",
                    "elementType": "geometry",
                    "stylers": [{
                        "color": "#171717"
                    }, {
                        "lightness": 0
                    }]
                }, {
                    "featureType": "poi",
                    "elementType": "geometry",
                    "stylers": [{
                        "color": "#101010"
                    }, {
                        "lightness": 0
                    }]
                }, {
                    "featureType": "road.highway",
                    "elementType": "geometry.fill",
                    "stylers": [{
                        "color": "#141414"
                    }, {
                        "lightness": 0
                    }]
                }, {
                    "featureType": "road.highway",
                    "elementType": "geometry.stroke",
                    "stylers": [{
                        "color": "#141414"
                    }, {
                        "lightness": 0
                    }, {
                        "weight": 0.2
                    }]
                }, {
                    "featureType": "road.arterial",
                    "elementType": "geometry",
                    "stylers": [{
                        "color": "#101010"
                    }, {
                        "lightness": 0
                    }]
                }, {
                    "featureType": "road.local",
                    "elementType": "geometry",
                    "stylers": [{
                        "color": "#101010"
                    }, {
                        "lightness": 0
                    }]
                }, {
                    "featureType": "transit",
                    "elementType": "geometry",
                    "stylers": [{
                        "color": "#101010"
                    }, {
                        "lightness": 0
                    }]
                }, {
                    "featureType": "water",
                    "elementType": "geometry",
                    "stylers": [{
                        "color": "#000000"
                    }, {
                        "lightness": 0
                    }]
                }]);
                var customMapTypeId = 'custom_style';

                var options = {
                    zoom: 16,
                    //minZoom: 14,
                    mapTypeId: google.maps.MapTypeId.ROADMAP,
                    center: {
                        lat: -23.5505199,
                        lng: -46.63330939999997
                    }, //são paulo
                    mapTypeControlOptions: {
                        mapTypeIds: [google.maps.MapTypeId.ROADMAP, customMapTypeId]
                    },
                    panControl: true,
                    zoomControl: true,
                    mapTypeControl: false,
                    scaleControl: false,
                    streetViewControl: false,
                    overviewMapControl: false,
                    backgroundColor: '#101010',
                };

                var browserSupportFlag = new Boolean();

                map.gmap = new google.maps.Map(map.el, options);
                map.gmap.mapTypes.set(customMapTypeId, customMapType);
                map.gmap.setMapTypeId(customMapTypeId);

                //create the marker
                map.updateMarkers = function() {

                    if (map.pdvList !== null && map.gmap.getZoom() >= 14) {
                        for (var i = 0; i < map.pdvList.length; i++) {
                            var pdv = map.pdvList[i];
                            var latlngpdv = new google.maps.LatLng(pdv.lat, pdv.lng);
                            if (map.gmap.getBounds().contains(latlngpdv)) {
                                var marker = new google.maps.Marker({
                                    position: latlngpdv,
                                    map: map.gmap,
                                    title: pdv.content,
                                    icon: '/images/icons/' + pdv.icon + '4.png'
                                });
                                map.infoBox(map, marker, pdv);
                            }
                        }
                    }
                };

                map.gmap.addListener('dragend', function(e) {
                    map.updateMarkers();
                });

                map.gmap.addListener('zoom_changed', function(e) {
                    map.updateMarkers();
                });


                var infoWindow = new google.maps.InfoWindow();
                map.infoBox = function(map, marker, data) {
                    // Attaching a click event to the current marker
                    var evtbind = 'mouseover';
                    if (is_mobile) {
                        evtbind = 'click';
                    }

                    google.maps.event.addListener(marker, evtbind, function(e) {

                        infoWindow.setContent(data.content);

                        var addrfriendly = data.address.split('\xa0').join(' ').split('CEP').join('').split(',').join(' ').split('  ').join(' ');
                        var addrfriendlyescaped = encodeURI(addrfriendly); //.split('%C2%A0').join('%20').split('%26nbsp%3B').join('%20').split('%20%20').join('%20');

                        var route = 'http://maps.google.com/maps?saddr=' + map.lastLat + ',' + map.lastLng + '&daddr=' + addrfriendlyescaped; //

                        var content = '<div id="content" class="gmap-info-window">';
                        content += '<div class="top"></div>';
                        content += '<div class="internal">';
                        if (data.title && data.title.length) content += '<div class="gmap-info-window-title">' + data.title + '</div>';
                        if (data.address && data.address.length) content += '<div>Endereço: ' + data.address + '</div>';
                        if (data.phone && data.phone.length) content += '<div class="gmap-info-window-phone">Telefone: ' + data.phone + '</div>';

                        content += '<div class="gmap-info-window-route"><a href="' + route + '" target="_blank">TRAÇAR ROTA</a></div>';

                        content += '</div>';
                        content += '<div class="bottom"></div>';
                        content += '</div>';
                        infoWindow.setContent(content);
                        infoWindow.open(map.gmap, marker);

                        var iwOuter = $('.gm-style-iw');
                        var iwBackground = iwOuter.prev();
                        var iwArrow = iwOuter.next();
                        // Remove the background shadow DIV
                        iwBackground.children(':nth-child(2)').css({
                            'display': 'none'
                        });
                        iwBackground.children(':nth-child(4)').css({
                            'display': 'none'
                        });
                        iwArrow.css({
                            'display': 'none'
                        });
                        iwBackground.css({
                            'display': 'none'
                        });
                    });
                }



                // Browser doesn't support Geolocation
                //else {
                //  browserSupportFlag = false;
                //  handleNoGeolocation(browserSupportFlag);
                //}

                $('#buy_searchbutton,#buy_button').on('mousedown', function() {
                    if ($('#buy_searchfield')[0].style.display == 'block') {
                        $('#buy_form').submit();
                    } else {
                        map.initializeGeolocation();
                        $('#buy_title').fadeOut();
                        $('#buy_text').fadeOut();
                        $('#buy_button').fadeOut();
                        $('#buy_searchbutton').fadeIn();
                        $('#buy_searchfield').fadeIn();
                        $('#map-disabler').hide();
                    }
                });

                $('#buy_form').submit(function(evt) {
                    evt.preventDefault();
                    //var input = document.getElementById('latlng').value;
                    //var latlngStr = input.split(',', 2);
                    //var latlng = {lat: parseFloat(latlngStr[0]), lng: parseFloat(latlngStr[1])};
                    //
                    ////console.log('input val = ',$('#buy_input').val());
                    //map.gmap.setCenter({ address: $('#buy_input').val()});

                    //infowindow = new google.maps.InfoWindow();

                    $('#buy_searchfield').fadeOut();

                    var geocoder = new google.maps.Geocoder();
                    var geocodeOptions = {
                        'address': $('#buy_input').val(),
                        region: 'BR',
                    };
                    ////console.log('geocodeOptions=',geocodeOptions);
                    geocoder.geocode(geocodeOptions, function(results, status) {
                        if (status === google.maps.GeocoderStatus.OK) {
                            if (results[0]) {
                                map.gmap.setZoom(16);
                                map.gmap.setCenter(results[0].geometry.location);
                                map.putYouMarker(results[0].geometry.location);
                                map.updateMarkers();
                            } else {
                                map.updateMarkers();
                            }
                        } else {
                            map.updateMarkers();
                        }
                    });

                    //var service = new google.maps.places.PlacesService(map.gmap);
                    //  service.nearbySearch({
                    //    location: pyrmont,
                    //    radius: 500,
                    //    types: ['address']
                    //  }, callback);
                    //}
                    //
                    //function callback(results, status) {
                    //  if (status === google.maps.places.PlacesServiceStatus.OK) {
                    //    for (var i = 0; i < results.length; i++) {
                    //      //console.log('results[i]=',results[i]);
                    //      //createMarker(results[i]);
                    //    }
                    //  }
                    //}
                    //
                    //function createMarker(place) {
                    //  var placeLoc = place.geometry.location;
                    //  var marker = new google.maps.Marker({
                    //    map: map,
                    //    position: place.geometry.location
                    //  });
                    //
                    //  google.maps.event.addListener(marker, 'click', function() {
                    //    infowindow.setContent(place.name);
                    //    infowindow.open(map, this);
                    //  });
                    //}

                    return false;
                })

                map.initializeMarkers();

                map.initialized = true;
            },

            //handleNoGeolocation: function(errorFlag) {
            //  if (errorFlag == true) {
            //    alert("Geolocation service failed.");
            //    map.initialLocation = google.maps.LatLng(60, 105);
            //  } else {
            //    alert("Your browser doesn't support geolocation. We've placed you in Siberia.");
            //    map.initialLocation = google.maps.LatLng(40.69847032728747, -73.9514422416687);
            //  }
            //  map.gmap.setCenter(map.initialLocation);
            //},


            // Try W3C Geolocation (Preferred)

        };

        var run_map = function() {

            ////console.log('run_map');

            if (!map.initialized) {
                //console.log('would initialize map');
                if (is_google_api_loaded && is_google_maps_api_loaded && typeof google === 'object' && typeof google.maps === 'object') {
                    //console.log('will initialize map');
                    map.initialize();
                }
            }


        }


        var menu = {
            el: document.getElementById('menu'),
            menu_link_el: document.getElementById('menu_link'),
            position: -1,
            destination: -1,
            reset: function() { /*suspectLoop();*/

            },
            update_destination: function(num) {
                this.destination = num;
            },
            update_position: function() { /*suspectLoop();*/
                var diff = (this.destination - this.position) / 2;
                var maxmove = Math.max(0.08);
                if (diff < -maxmove) diff = -maxmove;
                if (diff > maxmove) diff = maxmove;

                this.position += diff;
                if (this.destination == 0 || this.destination == 1) {
                    if (Math.abs(this.destination - this.position) < 0.01) {
                        this.position = this.destination;
                    }
                }
            },


            out_of_screen: true,
            commit_position: function() { /*suspectLoop();*/

                this.el.style.opacity = 1 + this.position;

                //transform_x_y_percent([this.el],0,this.position*100);
                //transform_x_y_vwvh([this.menu_link_el],0,100+this.position*100);

                if (this.position == -1) {
                    if (!this.out_of_screen) {
                        this.out_of_screen = true;
                        this.el.style.display = 'none';
                        //transform_x_y_percent(this.el,100,0);
                    }
                } else {
                    if (this.out_of_screen) {
                        this.out_of_screen = false;
                        this.el.style.display = 'block';
                        //transform_x_y_percent(this.el,0,0);
                    }
                }

            },

            opened: false,

            open: function() {
                if (!this.opened) {
                    this.opened = true;

                    this.update_destination(0);
                }
            },

            close: function() {
                if (this.opened) {
                    this.opened = false;

                    this.update_destination(-1);

                }
            },
        };

        //      var storytelling = {
        //        el: document.getElementById('storytelling'),
        //      position:-1,
        //      destination:-1,
        //      reset: function(){ /*suspectLoop();*/
        //
        //      },
        //      update_destination: function(num){
        //        this.destination=num;
        //      },
        //      update_position: function(){ /*suspectLoop();*/
        //        var diff=(this.destination-this.position)/2;
        //        var maxmove=Math.max(0.08);
        //        if(diff<-maxmove) diff=-maxmove;
        //        if(diff> maxmove) diff= maxmove;
        //
        //        this.position+=diff;
        //        if(this.destination==0 || this.destination==1){
        //          if(Math.abs(this.destination-this.position)<0.01){
        //            this.position=this.destination;
        //          }
        //        }
        //      },
        //
        //
        //      out_of_screen: true,
        //      commit_position: function(){ /*suspectLoop();*/
        //
        //        this.el.style.opacity=this.position;
        //
        //        //transform_x_y_percent([this.el],0,this.position*100);
        //        //transform_x_y_vwvh([this.menu_link_el],0,100+this.position*100);
        //
        //        if(this.position==0){
        //          if(!this.out_of_screen){
        //            this.out_of_screen=true;
        //            this.el.style.display='none';
        //            //transform_x_y_percent(this.el,100,0);
        //          }
        //        }else{
        //          if(this.out_of_screen){
        //            this.out_of_screen=false;
        //            this.el.style.display='block';
        //            //transform_x_y_percent(this.el,0,0);
        //          }
        //        }
        //
        //      },
        //
        //      opened:false,
        //
        //      open: function(){
        //        if(!this.opened){
        //          this.opened=true;
        //
        //          this.update_destination(1);
        //        }
        //      },
        //
        //      close: function(){
        //        if(this.opened){
        //          this.opened=false;
        //
        //          this.update_destination(0);
        //
        //        }
        //      },
        //
        //
        //
        //      };

        //      var storytelling_previous_hovered=false;
        //    var storytelling_next_hovered=false;
        //
        //      var storytelling_slider = {
        //        slides: storytelling.el.querySelectorAll('.slide'),
        //        next_el: $('#storytelling_next'),
        //        prev_el: $('#storytelling_previous'),
        //        position:0,
        //      destination:0,
        //      reset: function(){ /*suspectLoop();*/
        //
        //      },
        //      update_destination: function(num){
        //        this.destination=num;
        //      },
        //      update_position: function(){ /*suspectLoop();*/
        //        var diff=(this.destination-this.position)/2;
        //        var maxmove=Math.max(0.08);
        //        if(diff<-maxmove) diff=-maxmove;
        //        if(diff> maxmove) diff= maxmove;
        //
        //        this.position+=diff;
        //        if(this.destination==0 || this.destination==1){
        //          if(Math.abs(this.destination-this.position)<0.01){
        //            this.position=this.destination;
        //          }
        //        }
        //      },
        //
        //
        //      out_of_screen: true,
        //      commit_position: function(){ /*suspectLoop();*/
        //        var pos=this.position;
        //        var slides=this.slides;
        //        Array.prototype.forEach.call(slides, function(slide, i){ /*suspectLoop();*/
        //          //addClass(element_el,className);
        //          var el_pos=i-pos;
        //          while(el_pos>2){
        //            el_pos-=slides.length;
        //          }
        //          while(el_pos<-2){
        //            el_pos+=slides.length;
        //          }
        //          //console.log('el_pos=',el_pos);
        //          transform_x_y_percent([slide],el_pos*100,0);
        //
        //        });
        //
        //        //this.el.style.opacity=this.position;
        ////
        //        ////transform_x_y_percent([this.el],0,this.position*100);
        //        ////transform_x_y_vwvh([this.menu_link_el],0,100+this.position*100);
        ////
        //        //if(this.position==0){
        //        //  if(!this.out_of_screen){
        //        //    this.out_of_screen=true;
        //        //    this.el.style.display='none';
        //        //    //transform_x_y_percent(this.el,100,0);
        //        //  }
        //        //}else{
        //        //  if(this.out_of_screen){
        //        //    this.out_of_screen=false;
        //        //    this.el.style.display='block';
        //        //    //transform_x_y_percent(this.el,0,0);
        //        //  }
        //        //}
        //
        //      },
        //
        //      prev: function(){
        //        if(this.destination>0){
        //          this.destination-=1;
        //          this.counter=0;
        //          this.check();
        //        }
        //
        //      },
        //      next: function(){
        //        if(this.destination<(this.slides.length-1)){
        //          this.destination+=1;
        //          this.counter=0;
        //          this.check();
        //        }
        //      },
        //
        //      check: function(){
        //        if(this.destination>0){
        //          this.prev_el.fadeIn();
        //        }else{
        //          this.prev_el.fadeOut();
        //        }
        //
        //        if(this.destination<(this.slides.length-1)){
        //          this.next_el.fadeIn();
        //        }else{
        //          this.next_el.fadeOut();
        //        }
        //      },
        //
        //      counter:0,
        //
        //        update: function(){
        //
        //          if( current_slug=='/' && !current_subsection && !storytelling_previous_hovered && !storytelling_next_hovered){
        //            this.counter++;
        //            if(this.counter>60*10){
        //              this.next();
        //            }
        //          }else{
        //            this.counter=0;
        //          }
        //          if(this.position !== this.destination){
        //            this.update_position();
        //            this.commit_position();
        //          }
        //        },
        //
        //        adapt: function(){
        //          var slides=this.slides;
        //          Array.prototype.forEach.call(slides, function(slide, i){ /*suspectLoop();*/
        //
        //          var img=slide.querySelectorAll('img');
        //          //console.log('img=',img);
        //          cover_container_by_replacing_if_needed(img[0],sections.header.get_background_width_value(),sections.header.get_background_height_value());
        //
        //        });
        //        }
        //      };

        var products_background = {
            el: document.getElementById('products_background'),
            position: 0,
            destination: 0,
            reset: function() { /*suspectLoop();*/

            },
            update_destination: function(num) {
                this.destination = num;
            },
            update_position: function() { /*suspectLoop();*/
                var diff = (this.destination - this.position) / 2;
                var maxmove = Math.max(0.08);
                if (diff < -maxmove) diff = -maxmove;
                if (diff > maxmove) diff = maxmove;

                this.position += diff;
                if (this.destination == 0 || this.destination == 1) {
                    if (Math.abs(this.destination - this.position) < 0.01) {
                        this.position = this.destination;
                    }
                }
            },

            //out_of_screen: false,
            commit_position: function() { /*suspectLoop();*/
                /* Moves the product menu on mobile */
                transform_x_y_percent([this.el], -this.position * 16, 0);
            }
        };


        var last_touch = false;
        var accumulated_touch = {
            x: 0,
            y: 0,
        };

        /* Gestures only available in mobile (portrait or landscape) */
        if (is_mobile) {
            //console.log('touch handler events');

            var productsBackgroundTouchHandler = function(event) {
                //window.alert('touch handler');
                //console.log('productsBackgroundTouchHandler()',event);
                var touch;
                if (typeof event !== 'undefined') {

                    //event.preventDefault();

                    if (typeof event.touches !== 'undefined') {
                        touch = event.touches[0];

                        switch (event.type) {
                            case 'touchstart':
                                last_touch = {
                                    x: touch.pageX,
                                    y: touch.pageY
                                }
                                break;
                            case 'touchmove':
                                //event.preventDefault();

                                if (last_touch) {
                                    accumulated_touch.x += touch.pageX - last_touch.x;
                                    accumulated_touch.y += touch.pageY - last_touch.y;


                                    if (Math.abs(accumulated_touch.y) > 100) {

                                        accumulated_touch = {
                                            x: 0,
                                            y: 0,
                                        };
                                        last_touch = false;

                                        //console.log('accumulated_touch reset')

                                    } else if (accumulated_touch.x > 100) {

                                        accumulated_touch = {
                                            x: 0,
                                            y: 0,
                                        };
                                        last_touch = false;

                                        if (current_product > 1) {
                                            current_product--;
                                        }
                                        check_products_visibility();
                                    } else if (accumulated_touch.x < -100) {

                                        accumulated_touch = {
                                            x: 0,
                                            y: 0,
                                        };
                                        last_touch = false;

                                        if (current_product < 6) {
                                            current_product++;
                                        }
                                        check_products_visibility();
                                    }

                                    //console.log('accumulated_touch',accumulated_touch.x,accumulated_touch.y);
                                }

                                break;
                            case 'touchend':
                                accumulated_touch = {
                                    x: 0,
                                    y: 0,
                                }
                                last_touch = false;
                            default:
                                break;
                        }
                    }
                }
            }

            /* Drag/slide/gesture listeners */
            // products_background.el.addEventListener('touchstart', productsBackgroundTouchHandler, false);
            // products_background.el.addEventListener('touchmove', productsBackgroundTouchHandler, false);
            // products_background.el.addEventListener('touchend', productsBackgroundTouchHandler, false);


            var productBackgroundTouchHandler = function(event) {
                //window.alert('touch handler');
                //console.log('productBackgroundTouchHandler()',event);
                var touch;
                if (typeof event !== 'undefined') {

                    //event.preventDefault();

                    if (typeof event.touches !== 'undefined') {
                        touch = event.touches[0];

                        switch (event.type) {
                            case 'touchstart':
                                last_touch = {
                                    x: touch.pageX,
                                    y: touch.pageY
                                }
                                break;
                            case 'touchmove':
                                //event.preventDefault();

                                if (last_touch) {
                                    accumulated_touch.x += touch.pageX - last_touch.x;
                                    accumulated_touch.y += touch.pageY - last_touch.y;


                                    if (Math.abs(accumulated_touch.y) > 100) {

                                        accumulated_touch = {
                                            x: 0,
                                            y: 0,
                                        };
                                        last_touch = false;

                                        //console.log('accumulated_touch reset')

                                    } else if (accumulated_touch.x > 100) {

                                        accumulated_touch = {
                                            x: 0,
                                            y: 0,
                                        };
                                        last_touch = false;

                                        if (current_active_dot > 0) {
                                            change_bullet_to_index(current_active_dot - 1)
                                        }
                                    } else if (accumulated_touch.x < -100) {

                                        accumulated_touch = {
                                            x: 0,
                                            y: 0,
                                        };
                                        last_touch = false;

                                        if (current_active_dot < (count_active_dots - 1)) {
                                            change_bullet_to_index(current_active_dot + 1)
                                        }
                                    }

                                    //console.log('accumulated_touch',accumulated_touch.x,accumulated_touch.y);
                                }

                                break;
                            case 'touchend':
                                accumulated_touch = {
                                    x: 0,
                                    y: 0,
                                }
                                last_touch = false;
                            default:
                                break;
                        }
                    }
                }
            }

            $('#products_detail_backgrounds')[0].addEventListener('touchstart', productBackgroundTouchHandler, false);
            $('#products_detail_backgrounds')[0].addEventListener('touchmove', productBackgroundTouchHandler, false);
            $('#products_detail_backgrounds')[0].addEventListener('touchend', productBackgroundTouchHandler, false);
        }

        var products_aba = {
            _el: document.getElementById('products_aba'),
            _position: 1,
            go: function(position) {
                this._position = position;

                var $button = $('.products_button[rel='+position+']');
                var x = $button.offset().left + ($button.width() / 2) - $('#products_navigation').offset().left;

                transform_x_y([this._el], x, 0);
            }
        };

        $(window).on('resize', function(){
          try {
            if ($(window).width() <= 1024) {
              $('.products_list').slick({
                infinite: false,
                speed: 300,
                prevArrow: $('#more-products-left'),
                nextArrow: $('#more-products-right'),
                slidesToShow: 3,
                slidesToScroll: 3,
                responsive: [
                  {
                    breakpoint: 567,
                    settings: {

                        slidesToShow: 1,
                        slidesToScroll: 1,
                        prevArrow: $('#products_previous'),
                        nextArrow: $('#products_next'),
                    }
                  }
                ]
              });
            } else {
              $('.products_list').slick('unslick');
            }
          } catch(e) {}

          products_aba.go(products_aba._position);
        });

        var layout_loader_blackout = {
            el: document.getElementById('blackout'),
        }

        var layout_loader_screen = {
            el: document.getElementById('loader'),
            position: 0,
            destination: 0,
            reset: function() { /*suspectLoop();*/

            },
            update_destination: function(num) {
                this.destination = num;
            },
            update_position: function() { /*suspectLoop();*/
                //if(this.destination==1 || this.destination==0){
                var diff = (this.destination - this.position) / 20;
                //}else{
                //  var diff=(this.destination-this.position)/20;
                //}

                //if(this.destination>0 && this.destination<0.5){
                //  var maxmove=this.destination*Math.max(0.01);
                //}else{
                var maxmove = Math.max(0.08);
                //}

                if (diff < -maxmove) diff = -maxmove;
                if (diff > maxmove) diff = maxmove;

                this.position += diff;
                if (this.destination == 0 || this.destination == 1) {
                    if (Math.abs(this.destination - this.position) < 0.01) {
                        this.position = this.destination;
                    }
                }
            },


            //out_of_screen: false,
            commit_position: function() { /*suspectLoop();*/

                this.el.style.opacity = this.position;

                //if(this.position==0){
                //  if(!this.out_of_screen){
                //    this.out_of_screen=true;
                //    transform_x_y_percent(this.el,100,0);
                //  }
                //}else{
                //  if(this.out_of_screen){
                //    this.out_of_screen=false;
                //    transform_x_y_percent(this.el,0,0);
                //  }
                //}
                //this.el.style.width=(this.position*100)+'%';
            }
        };


        var layout_loader_display = {
            el: document.getElementById('loader_display'),
            position: 0,
            destination: 0,
            reset: function() { /*suspectLoop();*/

            },
            update_destination: function(num) {
                this.destination = num;
            },
            update_position: function() { /*suspectLoop();*/
                if (this.destination == 1 || this.destination == 0) {
                    var diff = (this.destination - this.position) / 2;
                } else {
                    var diff = (this.destination - this.position) / 20;
                }
                var maxmove = 1 / 14 / 2;

                if (diff < -maxmove) diff = -maxmove;
                if (diff > maxmove) diff = maxmove;

                if (diff < 0.005) {
                    diff = 0.005;
                }

                this.position += diff;
                if (this.destination == 0 || this.destination == 1) {
                    if (Math.abs(this.destination - this.position) < 0.0005) {
                        this.position = this.destination;
                    }

                }
            },
            commit_position: function() { /*suspectLoop();*/

                var classUse = 'floater sprite loader' + Math.floor(this.position * 13);
                ////console.log('classUse=',classUse);
                //$(this.el).addClass(classUse);
                this.el.className = classUse;
                //this.el.style.width=Math.round(this.position*100*100)/100+'%';
            }
        };

        var count_wait_total = 0;
        var count_wait_after_dom_was_loaded = 0;
        var asked_to_preload_initial_sections = false;
        var frames_loading_count_for_checking_load_errors = 0;
        var wait_for_dom_load = function() {
            //updater_didnt_run_count=0;

            calls = 0;

            count_wait_total++;

            if (dom_is_loaded) { //(count_wait_after_dom_was_loaded<10 || count_wait_total<10 || !asked_to_preload_initial_sections)

                if (primary_initializations_completed) {

                    //console.log('dom is loaded and initialized, move to main loader');
                    window.requestAnimationFrame(main_loader_run);

                    transform_x_y_percent([layout_loader_screen.el], 0, 0);
                    opacity([layout_loader_screen.el], 0);
                    layout_loader_screen.update_destination(1);

                } else {
                    count_wait_after_dom_was_loaded++;
                    window.requestAnimationFrame(wait_for_dom_load);
                    run_primary_initializations();
                }

            } else {
                window.requestAnimationFrame(wait_for_dom_load);
            }
        }

        var frames_at_100_percent = 0;
        var main_loader_completed = false;
        var fake_percent = 0.3;


        var frames_at_main_loader = 0;
        var main_loader_run = function() {
            frames_loading_count_for_checking_load_errors++;
            frames_at_main_loader++;
            calls = 0;


            layout_loader_screen.update_position();
            layout_loader_screen.commit_position();

            //if(intro_card){
            //  intro_card.opacity+=calc_diff(intro_card.opacity,Math.min(1,frames_at_main_loader*0.01));
            //  opacity(intro_card.el, intro_card.opacity);
            //}

            if (main_loader_completed) {

                remove(layout_loader_blackout.el);
                layout_loader_blackout = null;

                $(window).trigger('resize');

                window.requestAnimationFrame(intro_run);
                return;
            } else {
                window.requestAnimationFrame(main_loader_run);

            }

            if (layout_loader_screen) {
                if (layout_loader_screen.position < 0.9) {
                    return;
                }
            }

            updater_fullfill_subcriptions();
            run_secondary_initializations();


            var count_sections = 0;
            var count_completed = 0;

            var images_pc = check_images_being_loaded_percent();
            count_sections += 5 * 1;
            count_completed += 5 * images_pc;

            var percent_completed = 0;
            if (count_sections == 0) {
                percent_completed = 1;
            } else {
                percent_completed = count_completed / count_sections;
            }

            fake_percent += 0.001;
            if (fake_percent > 1) fake_percent = 1;
            if (percent_completed >= 1) fake_percent += 0.01;

            if (percent_completed >= 1 && (fake_percent > 0.4 || frames_at_main_loader > 60 * 3)) {
                layout_loader_display.update_destination(percent_completed);
            } else {
                layout_loader_display.update_destination(Math.min(fake_percent, 0.3 + percent_completed * 0.7));
            }

            layout_loader_display.update_position();
            layout_loader_display.commit_position();

            if (percent_completed >= 0.9 && layout_loader_display.position >= 1 /*0.99*/ ) {
                frames_at_100_percent++;

                if (frames_at_100_percent >= 10 && secondary_initializations_completed) {
                    main_loader_completed = true;
                    //console.log('tell main loader is completed')
                }
            }
        }

        var intro_opacity = 0;
        var intro_completed = false;
        var first_section_initialized = false;
        var intro_run = function() {
            //updater_didnt_run_count=0;
            calls = 0;

            updater_fullfill_subcriptions();

            if (intro_completed) {

                //console.log('intro completed');
                //layout_blackout.update_position();

                //if(intro_card){
                //  invert(intro_card.el, 0);
                //}
                //opacity(layout_title.el, 1);
                //opacity(layout_subtitle.el, 1);


                //layout_loader_display.position=1;
                //layout_loader_display.commit_position();
                //opacity(layout_loader_display.el, 1);


                //layout_body.commit_position();
                //remove(layout_loader_screen.el);
                //transform_x_y_percent([layout_loader_screen.el],0,-intro_opacity*100);
                remove(layout_loader_screen.el);
                layout_loader_screen = null;

                window.requestAnimationFrame(updater_run);
                return;
            } else {
                //last_animation_function=intro_run;
                //last_animation_call=
                window.requestAnimationFrame(intro_run);
            }

            intro_opacity += calc_diff(intro_opacity, 1);
            ////console.log('intro_opacity=',intro_opacity);
            transform_x_y_percent([layout_loader_screen.el], 0, -intro_opacity * 100);

            //opacity(layout_title.el, intro_opacity);
            //opacity(layout_subtitle.el, intro_opacity);
            //opacity(layout_loader_display.el, 1-intro_opacity);

            //layout_loader_display.update_position();
            //layout_loader_display.commit_position();

            if (intro_opacity > 0.99) {
                //console.log('tell intro is completed')
                intro_completed = true;
            }


        }

        //main_resize_handler();
        //updater_run();
        wait_for_dom_load();

        if (PROFILE) console.log('Global Initialize time: ' + ((new Date().getTime()) - global_start) + 'ms');
    }

    if (document.readyState != 'loading') {
        ready();
    } else {
        document.addEventListener('DOMContentLoaded', ready);
    }

})();

// 1. Video player state
var isShowingVideo = true;
var isPlayingVideo = false;
var isHidingVideo = false; /* Click to hide video state control */
var videoSeekUpdateInterval = 100;

var headerVideoId = 'DvI6I3pjz5U';
var product1VideoId = 'IjAx_MxYxg0';
var product2VideoId = 'pRSZXleEStE';
var product3VideoId = '8uxHiBTM4Do';
var product4VideoId = 'c7PNJ_J1VTU';
var currentVideoId = headerVideoId;

// 2. This code loads the IFrame Player API code asynchronously.
var tag = document.createElement('script');
tag.src = "https://www.youtube.com/iframe_api";
var firstScriptTag = document.getElementsByTagName('script')[0];
firstScriptTag.parentNode.insertBefore(tag, firstScriptTag);

// 3. This function creates an <iframe> (and YouTube player)
//    after the API code downloads.
var headerPlayer;
var productPlayer;
function onYouTubeIframeAPIReady() {

  headerPlayer = new YT.Player('video-container', {
    height: innerWidth,
    width: innerHeight,
    events: {
      'onReady': onHeaderPlayerReady,
      'onStateChange': onHeaderPlayerStateChange
    },
    playerVars: { 'autoplay': 0, 'controls': 0, 'showinfo': 0 },
  });

  productPlayer = new YT.Player('product-video-container', {
    height: innerWidth,
    width: innerHeight,
    events: {
      'onReady': onProductPlayerReady,
      'onStateChange': onProductPlayerStateChange
    },
    playerVars: { 'autoplay': 0, 'controls': 0, 'showinfo': 0 },
  });
}

// 4. The API will call this function when the video player is ready.
function onHeaderPlayerReady(event) {

}
function onHeaderPlayerStateChange(event) {

}
function onProductPlayerReady(event) {

}
function onProductPlayerStateChange(event) {

}

function stopVideo() {

  if (currentVideoId == headerVideoId) {
    headerPlayer.stopVideo();
  } else {
    productPlayer.stopVideo();
  }

  isPlayingVideo = false;
}

function playVideo(is_iOS) {

  isPlayingVideo = true;

  if (currentVideoId == headerVideoId) {
    $('#video-container').show();
    $('#product-video-container').hide();

    $('#video-close-button').show();
    $('#video-seek-bar-container').show();
    $('#product-video-close-button').hide();
    $('#product-video-seek-bar-container').hide();

    if (is_iOS == false) {
      headerPlayer.playVideo();
    }

  } else {
    $('#video-container').hide();
    $('#product-video-container').show();

    $('#video-close-button').hide();
    $('#video-seek-bar-container').hide();
    $('#product-video-close-button').show();
    $('#product-video-seek-bar-container').show();

    if (is_iOS == false) {
      productPlayer.playVideo();
    }
  }

  /* Update seek bar */
  setTimeout(updateSeekBar, videoSeekUpdateInterval);
}

/* Updates the seek bar in an interval */
function updateSeekBar() {
  if (isPlayingVideo) {

    /* Bar width */
    var barWidth = window.innerWidth;
    var currentTime = 0;
    var totalTime = 0;
    if (currentVideoId == headerVideoId) {

      currentTime = headerPlayer.getCurrentTime();
      totalTime = headerPlayer.getDuration();
      $('#video-seek-bar-white').css('width', (barWidth * (currentTime / totalTime)) + 'px');

      /* Bar left */
      var barLeft = 0;
      $('#video-seek-bar-white').css('left', barLeft + 'px');

    } else {

      currentTime = productPlayer.getCurrentTime();
      totalTime = productPlayer.getDuration();
      $('#product-video-seek-bar-white').css('width', (barWidth * (currentTime / totalTime)) + 'px');

      /* Bar left */
      var barLeft = 0;
      $('#product-video-seek-bar-white').css('left', barLeft + 'px');
    }

    setTimeout(updateSeekBar, videoSeekUpdateInterval);
  }
}

/* Click the X to hide the video */
function hideVideo() {

  stopVideo();

  if (currentVideoId == headerVideoId) {
    $('#video-container').hide();
    $('#product-video-container').hide();

    $('#video-close-button').hide();
    $('#video-seek-bar-container').hide();
    $('#product-video-close-button').hide();
    $('#product-video-seek-bar-container').hide();
  } else {
    $('#video-container').hide();
    $('#product-video-container').hide();

    $('#video-close-button').hide();
    $('#video-seek-bar-container').hide();
    $('#product-video-close-button').hide();
    $('#product-video-seek-bar-container').hide();
  }

  isShowingVideo = false;

  $('#products_navigation').css('display', 'block');
}

/* Hit esc to hide video */
$('body').keyup(function(e) {
  if(e.which == 27) {
    if (isShowingVideo) {
      hideVideo();
    }
  }
});

/* When clicking the bar, seek the video to that point */
function seekTo(x) {

  var barStart = 0;
  var barEnd = window.innerWidth;

  var barWidth = window.innerWidth;
  var totalTime = 0;
  if (currentVideoId == headerVideoId) {
    totalTime = headerPlayer.getDuration();
    if (x >= barStart && x <= barEnd) {
      headerPlayer.seekTo((x / barWidth) * totalTime);
    }
  } else {
    totalTime = productPlayer.getDuration();
    if (x >= barStart && x <= barEnd) {
      productPlayer.seekTo((x / barWidth) * totalTime);
    }
  }
}

/* Close button */
$('#video-close-button').click(function() {
  closeVideo();
});
$('#product-video-close-button').click(function() {
  closeVideo();
});

/* Play/pause when clicking anywhere in the video */
$('#video-controls').click(function(e) {
  videoControlsClick(e);
});
$('#product-video-controls').click(function(e) {
  videoControlsClick(e);
});

function loadNewVideo(videoId, is_iOS) {

  /* Hide the product navigation section */
  if (videoId == headerVideoId) {
    $('#products_navigation').css('display', 'block');
  } else {
    $('#products_navigation').css('display', 'none');
  }

  /* Close button */
  $('#video-close-button').unbind('click');
  $('#product-video-close-button').unbind('click');
  $('#video-close-button').click(function() {
    closeVideo();
  });
  $('#product-video-close-button').click(function() {
    closeVideo();
  });

  /* Video seeker bar controls */
  $('#video-seek-bar-container').unbind('click');
  $('#product-video-seek-bar-container').unbind('click');
  $('#video-seek-bar-container').click(function(e) {
    videoControlsClick(e);
  });
  $('#product-video-seek-bar-container').click(function(e) {
    videoControlsClick(e);
  });

  if (videoId == headerVideoId) {
    headerPlayer.cueVideoById(videoId);
  } else {
    productPlayer.cueVideoById(videoId);
  }

  playVideo(is_iOS);
}

function videoControlsClick(e) {

  /* Seek to if clicking the bar  */
  if (e.target.id == 'video-seek-bar-container' || e.target.id == 'video-seek-bar-white' || e.target.id == 'video-seek-bar-yellow'
   || e.target.id == 'product-video-seek-bar-container' || e.target.id == 'product-video-seek-bar-white' || e.target.id == 'product-video-seek-bar-yellow') {
    var clickX = e.pageX;
    seekTo(clickX);
    return;
  }

  /* Hiding video state control */
  if (isHidingVideo) {
    isHidingVideo = false;
    return;
  }

  /* Play/pause */
  if (isPlayingVideo) {
    stopVideo();
  } else {
    playVideo(is_iOS);
  }
}

function closeVideo() {
  hideVideo();
  isHidingVideo = true;
}

/* Called from site.js, as the user clicks 'view-product-video' */
function clickToWatchVideo(section, is_iOS) {

  if (section == 0) {
    currentVideoId = headerVideoId;
  } else if (section == 1) {
    currentVideoId = product1VideoId;
  } else if (section == 2) {
    currentVideoId = product2VideoId;
  } else if (section == 3) {
    currentVideoId = product3VideoId;
  } else if (section == 4) {
    currentVideoId = product4VideoId;
  }

  loadNewVideo(currentVideoId, is_iOS);
}
